#include <stdio.h>
#include <stdlib.h>
#include <stdint.h>
#include <string.h>
#include <algorithm>
#include <stdarg.h>

#include "signature.h"
#include "patcher.h"
#include "types.h"

#if _MSC_VER
#define snprintf _snprintf
#endif

using namespace std;

game_info_t game_info = {
  5,
  {
    { "u26.bin",
      0x80000, /* ROM size */
      0x4F3A914A, /* ROM CRC */
      0,
    },
    { "u27.bin",
      0x80000, /* ROM size */
      0x2432FF9B, /* ROM CRC */
      0,
    },
    { "u51.bin",
      0x200000, /* ROM size */
      0xE7BA8CCE, /* ROM CRC */
      0,
    },
    { "u62.bin",
      0x200000, /* ROM size */
      0x292BFB6B, /* ROM CRC */
      0,
    },
    { "eeprom-ddonpach.bin",
      0x80, /* ROM size */
      0x315FB546, /* ROM CRC */
      1,
    },
  },
};

void patch_u26()
{
  uint32_t patch0_addr = 0x000003BD;
  uint8_t patch0_data[] = {
    0xE1, 0x50, 0xF0, 0xE1, 0x71, 0x69, 0x28, 0xB1, 0xE1, 0x73, 0x69, 0x28, 0xB1, 0xD1, 0x71, 0x69, 
    0x28, 0xB1, 0xD1, 0x73, 0x69, 0x28, 0xB1, 0xC1, 0x71, 0x69, 0x28, 0xB1, 0xC1, 0x73, 
  };
  APPLY_PATCH(0);

  uint32_t patch1_addr = 0x000004C5;
  uint8_t patch1_data[] = {
    0xC0, 0xD9, 0x42, 
  };
  APPLY_PATCH(1);

  uint32_t patch2_addr = 0x000019FE;
  uint8_t patch2_data[] = {
    0x38, 0x61, 0x0B, 
  };
  APPLY_PATCH(2);

  uint32_t patch3_addr = 0x000020AA;
  uint8_t patch3_data[] = {
    0x70, 0x65, 0x01, 0x62, 
  };
  APPLY_PATCH(3);

  uint32_t patch4_addr = 0x000020AF;
  uint8_t patch4_data[] = {
    0x02, 0x61, 0x61, 
  };
  APPLY_PATCH(4);

  uint32_t patch5_addr = 0x000020B3;
  uint8_t patch5_data[] = {
    0x10, 0x74, 0x1A, 0x74, 0x6E, 
  };
  APPLY_PATCH(5);

  uint32_t patch6_addr = 0x000020E4;
  uint8_t patch6_data[] = {
    0x10, 
  };
  APPLY_PATCH(6);

  uint32_t patch7_addr = 0x000020E7;
  uint8_t patch7_data[] = {
    0x60, 0x63, 0x74, 0x10, 0x68, 0x75, 0x74, 0x74, 
  };
  APPLY_PATCH(7);

  uint32_t patch8_addr = 0x000020F3;
  uint8_t patch8_data[] = {
    0x15, 0x02, 
  };
  APPLY_PATCH(8);

  uint32_t patch9_addr = 0x000020F7;
  uint8_t patch9_data[] = {
    0x64, 0x70, 0x60, 0x75, 0x64, 0x7E, 0x70, 0x73, 
  };
  APPLY_PATCH(9);

  uint32_t patch10_addr = 0x00002104;
  uint8_t patch10_data[] = {
    0x01, 
  };
  APPLY_PATCH(10);

  uint32_t patch11_addr = 0x00002108;
  uint8_t patch11_data[] = {
    0x04, 0x73, 0x1D, 
  };
  APPLY_PATCH(11);

  uint32_t patch12_addr = 0x0000210C;
  uint8_t patch12_data[] = {
    0x1D, 
  };
  APPLY_PATCH(12);

  uint32_t patch13_addr = 0x00002115;
  uint8_t patch13_data[] = {
    0x6E, 0x6F, 
  };
  APPLY_PATCH(13);

  uint32_t patch14_addr = 0x00002123;
  uint8_t patch14_data[] = {
    0x0D, 0x61, 0x72, 0x16, 
  };
  APPLY_PATCH(14);

  uint32_t patch15_addr = 0x00002128;
  uint8_t patch15_data[] = {
    0x09, 0x69, 
  };
  APPLY_PATCH(15);

  uint32_t patch16_addr = 0x00002197;
  uint8_t patch16_data[] = {
    0x70, 
  };
  APPLY_PATCH(16);

  uint32_t patch17_addr = 0x000021A0;
  uint8_t patch17_data[] = {
    0x72, 
  };
  APPLY_PATCH(17);

  uint32_t patch18_addr = 0x000021A9;
  uint8_t patch18_data[] = {
    0x15, 
  };
  APPLY_PATCH(18);

  uint32_t patch19_addr = 0x000021B2;
  uint8_t patch19_data[] = {
    0x01, 
  };
  APPLY_PATCH(19);

  uint32_t patch20_addr = 0x000021BB;
  uint8_t patch20_data[] = {
    0x16, 
  };
  APPLY_PATCH(20);

  uint32_t patch21_addr = 0x000021C4;
  uint8_t patch21_data[] = {
    0x62, 
  };
  APPLY_PATCH(21);

  uint32_t patch22_addr = 0x000021CD;
  uint8_t patch22_data[] = {
    0x03, 
  };
  APPLY_PATCH(22);

  uint32_t patch23_addr = 0x000021D6;
  uint8_t patch23_data[] = {
    0x7E, 
  };
  APPLY_PATCH(23);

  uint32_t patch24_addr = 0x000021DF;
  uint8_t patch24_data[] = {
    0x02, 
  };
  APPLY_PATCH(24);

  uint32_t patch25_addr = 0x000021E8;
  uint8_t patch25_data[] = {
    0x61, 
  };
  APPLY_PATCH(25);

  uint32_t patch26_addr = 0x000021F1;
  uint8_t patch26_data[] = {
    0x04, 
  };
  APPLY_PATCH(26);

  uint32_t patch27_addr = 0x000021FA;
  uint8_t patch27_data[] = {
    0x12, 
  };
  APPLY_PATCH(27);

  uint32_t patch28_addr = 0x00002203;
  uint8_t patch28_data[] = {
    0x06, 
  };
  APPLY_PATCH(28);

  uint32_t patch29_addr = 0x0000220C;
  uint8_t patch29_data[] = {
    0x15, 
  };
  APPLY_PATCH(29);

  uint32_t patch30_addr = 0x00002215;
  uint8_t patch30_data[] = {
    0x10, 
  };
  APPLY_PATCH(30);

  uint32_t patch31_addr = 0x0000221E;
  uint8_t patch31_data[] = {
    0x01, 
  };
  APPLY_PATCH(31);

  uint32_t patch32_addr = 0x00002227;
  uint8_t patch32_data[] = {
    0x16, 
  };
  APPLY_PATCH(32);

  uint32_t patch33_addr = 0x00002230;
  uint8_t patch33_data[] = {
    0x01, 
  };
  APPLY_PATCH(33);

  uint32_t patch34_addr = 0x00002239;
  uint8_t patch34_data[] = {
    0x1B, 
  };
  APPLY_PATCH(34);

  uint32_t patch35_addr = 0x00002242;
  uint8_t patch35_data[] = {
    0x1A, 
  };
  APPLY_PATCH(35);

  uint32_t patch36_addr = 0x0000224B;
  uint8_t patch36_data[] = {
    0x6F, 
  };
  APPLY_PATCH(36);

  uint32_t patch37_addr = 0x00002254;
  uint8_t patch37_data[] = {
    0x6E, 
  };
  APPLY_PATCH(37);

  uint32_t patch38_addr = 0x000029F7;
  uint8_t patch38_data[] = {
    0x48, 0x71, 0x9F, 0x31, 0x7B, 0x48, 0x71, 0x83, 0x31, 0x79, 0x8D, 0x70, 0x61, 0x1F, 
  };
  APPLY_PATCH(38);

  uint32_t patch39_addr = 0x000030B8;
  uint8_t patch39_data[] = {
    0x07, 
  };
  APPLY_PATCH(39);

  uint32_t patch40_addr = 0x0000318B;
  uint8_t patch40_data[] = {
    0xB1, 0x61, 0xB9, 0xB1, 0x61, 0xBD, 0xB1, 0x61, 0xA1, 0xB1, 0x61, 0xA3, 0xB1, 0x61, 0xA5, 0xB1, 
    0x61, 0xA7, 0xB1, 0x61, 0xAF, 0xB1, 0x61, 0x93, 0xB1, 0x61, 0x9B, 
  };
  APPLY_PATCH(40);

  uint32_t patch41_addr = 0x00003209;
  uint8_t patch41_data[] = {
    0xBB, 0x2D, 0x42, 0x54, 
  };
  APPLY_PATCH(41);

  uint32_t patch42_addr = 0x0000329B;
  uint8_t patch42_data[] = {
    0x01, 
  };
  APPLY_PATCH(42);

  uint32_t patch43_addr = 0x00003401;
  uint8_t patch43_data[] = {
    0xD7, 0x2D, 0xD9, 0x61, 0xBD, 
  };
  APPLY_PATCH(43);

  uint32_t patch44_addr = 0x000037D1;
  uint8_t patch44_data[] = {
    0x08, 0x61, 0x0B, 0x79, 
  };
  APPLY_PATCH(44);

  uint32_t patch45_addr = 0x000037DF;
  uint8_t patch45_data[] = {
    0x08, 0x61, 0x0B, 0x79, 
  };
  APPLY_PATCH(45);

  uint32_t patch46_addr = 0x00006AE8;
  uint8_t patch46_data[] = {
    0xB1, 0x61, 0x6B, 0xB1, 0x61, 0xB9, 0xB1, 0x61, 0xBD, 0xB1, 0x61, 0xA1, 0xB1, 0x61, 0xAF, 0xB1, 
    0x61, 0x93, 0xB1, 0x61, 0x9B, 
  };
  APPLY_PATCH(46);

  uint32_t patch47_addr = 0x00006D99;
  uint8_t patch47_data[] = {
    0x0A, 
  };
  APPLY_PATCH(47);

  uint32_t patch48_addr = 0x00006D9D;
  uint8_t patch48_data[] = {
    0x0A, 
  };
  APPLY_PATCH(48);

  uint32_t patch49_addr = 0x0001FC58;
  uint8_t patch49_data[] = {
    0xB1, 0x61, 0xA1, 0x8D, 0x70, 0x61, 0xA3, 0xB1, 0x61, 0xB9, 0xB1, 0x61, 0xAF, 
  };
  APPLY_PATCH(49);

  uint32_t patch50_addr = 0x00021E2A;
  uint8_t patch50_data[] = {
    0xAA, 0xC8, 
  };
  APPLY_PATCH(50);

  uint32_t patch51_addr = 0x00021EB4;
  uint8_t patch51_data[] = {
    0x08, 0x61, 0x6B, 0x6B, 
  };
  APPLY_PATCH(51);

  uint32_t patch52_addr = 0x00021EDA;
  uint8_t patch52_data[] = {
    0xA0, 
  };
  APPLY_PATCH(52);

  uint32_t patch53_addr = 0x00021F30;
  uint8_t patch53_data[] = {
    0x10, 
  };
  APPLY_PATCH(53);

  uint32_t patch54_addr = 0x00021F33;
  uint8_t patch54_data[] = {
    0xD7, 0x7D, 0x97, 0x10, 0xD3, 0x18, 0x2C, 0x78, 0x46, 0xAD, 0xE9, 0x0A, 0xD0, 0x52, 0xAF, 0xA9, 
    0x9C, 0xE6, 0x7E, 0xFC, 0xA8, 0x61, 0xA3, 0x4D, 
  };
  APPLY_PATCH(54);

  uint32_t patch55_addr = 0x0002241D;
  uint8_t patch55_data[] = {
    0xAA, 0x09, 0x54, 
  };
  APPLY_PATCH(55);

  uint32_t patch56_addr = 0x00022474;
  uint8_t patch56_data[] = {
    0x60, 
  };
  APPLY_PATCH(56);

  uint32_t patch57_addr = 0x00022476;
  uint8_t patch57_data[] = {
    0x50, 
  };
  APPLY_PATCH(57);

  uint32_t patch58_addr = 0x00022491;
  uint8_t patch58_data[] = {
    0x40, 
  };
  APPLY_PATCH(58);

  uint32_t patch59_addr = 0x00022493;
  uint8_t patch59_data[] = {
    0x50, 
  };
  APPLY_PATCH(59);

  uint32_t patch60_addr = 0x0002252F;
  uint8_t patch60_data[] = {
    0x80, 0x19, 0x78, 
  };
  APPLY_PATCH(60);

  uint32_t patch61_addr = 0x00022551;
  uint8_t patch61_data[] = {
    0xC0, 0x14, 0xBC, 0xDA, 
  };
  APPLY_PATCH(61);

  uint32_t patch62_addr = 0x0002258B;
  uint8_t patch62_data[] = {
    0x80, 0x19, 0xA2, 0x7F, 
  };
  APPLY_PATCH(62);

  uint32_t patch63_addr = 0x00022611;
  uint8_t patch63_data[] = {
    0xC0, 0x19, 0xFA, 0xDA, 
  };
  APPLY_PATCH(63);

  uint32_t patch64_addr = 0x000228F6;
  uint8_t patch64_data[] = {
    0x08, 0x61, 0xA3, 
  };
  APPLY_PATCH(64);

  uint32_t patch65_addr = 0x000228FC;
  uint8_t patch65_data[] = {
    0x08, 0x61, 0xA9, 
  };
  APPLY_PATCH(65);

  uint32_t patch66_addr = 0x00022997;
  uint8_t patch66_data[] = {
    0x07, 
  };
  APPLY_PATCH(66);

  uint32_t patch67_addr = 0x00022999;
  uint8_t patch67_data[] = {
    0x07, 
  };
  APPLY_PATCH(67);

  uint32_t patch68_addr = 0x00022C9A;
  uint8_t patch68_data[] = {
    0x46, 0x3E, 
  };
  APPLY_PATCH(68);

  uint32_t patch69_addr = 0x00022C9D;
  uint8_t patch69_data[] = {
    0x04, 0x04, 0x0A, 0x08, 0x08, 0x0A, 0x16, 0x12, 0x10, 0x1E, 0x12, 0x14, 0x28, 0x28, 0x2E, 0x2C, 
    0x24, 0x26, 0x22, 0x3E, 0x3C, 0x3A, 0x26, 0x28, 0x2E, 0x2C, 0x2A, 0x2A, 0x16, 0x14, 0x1A, 0x1C, 
    0x1C, 0x1C, 0x14, 0x16, 0x14, 0x12, 0x2E, 0x2E, 0x32, 0x30, 0x30, 0x30, 0x30, 0x3E, 0x32, 0x32, 
    0x36, 0x34, 0x32, 0x0C, 0x0C, 0x0A, 0x14, 0x16, 0x1A, 0x18, 0x1E, 0x18, 0x18, 0x18, 0x08, 0x0A, 
    0x0E, 0x0E, 0x0A, 0x04, 0x04, 0x04, 0x02, 
  };
  APPLY_PATCH(69);

  uint32_t patch70_addr = 0x00024BCF;
  uint8_t patch70_data[] = {
    0xC0, 0xD9, 0x52, 
  };
  APPLY_PATCH(70);

  uint32_t patch71_addr = 0x0002577F;
  uint8_t patch71_data[] = {
    0x04, 
  };
  APPLY_PATCH(71);

  uint32_t patch72_addr = 0x000269D5;
  uint8_t patch72_data[] = {
    0x80, 0x19, 0xE4, 
  };
  APPLY_PATCH(72);

  uint32_t patch73_addr = 0x0002746C;
  uint8_t patch73_data[] = {
    0x3F, 0x16, 0xD1, 0x71, 0xF0, 0x03, 0xC0, 0xD5, 0xA0, 0x75, 0x29, 0xA1, 0x48, 0x40, 0x81, 0x77, 
    0x61, 0xFD, 0x08, 0x67, 0x61, 0x55, 0x48, 0x61, 0x55, 0xC8, 0x74, 0xC7, 0xB3, 0x61, 0x57, 0x08, 
    0x61, 0x5B, 0x48, 0x61, 0x5B, 0xC8, 0x74, 0xC7, 0xB3, 0x61, 0x5D, 0xC8, 0x74, 0xE1, 0x71, 0xF3, 
  };
  APPLY_PATCH(73);

  uint32_t patch74_addr = 0x0002BF56;
  uint8_t patch74_data[] = {
    0xA6, 0x16, 0x15, 
  };
  APPLY_PATCH(74);

  uint32_t patch75_addr = 0x00035A55;
  uint8_t patch75_data[] = {
    0x72, 0x03, 0x65, 0x03, 0x7E, 
  };
  APPLY_PATCH(75);

  uint32_t patch76_addr = 0x00035A5B;
  uint8_t patch76_data[] = {
    0x04, 0x01, 0x61, 0x01, 0x16, 0x1A, 0x6F, 
  };
  APPLY_PATCH(76);

  uint32_t patch77_addr = 0x00035A9D;
  uint8_t patch77_data[] = {
    0x6C, 0x79, 0x72, 0x12, 0x73, 0x61, 0x74, 
  };
  APPLY_PATCH(77);

  uint32_t patch78_addr = 0x00035BA8;
  uint8_t patch78_data[] = {
    0x69, 
  };
  APPLY_PATCH(78);

  uint32_t patch79_addr = 0x00035BAA;
  uint8_t patch79_data[] = {
    0x04, 0x1E, 0x61, 0x0A, 
  };
  APPLY_PATCH(79);

  uint32_t patch80_addr = 0x00035BAF;
  uint8_t patch80_data[] = {
    0x0E, 
  };
  APPLY_PATCH(80);

  uint32_t patch81_addr = 0x00035BB1;
  uint8_t patch81_data[] = {
    0x01, 0x1E, 0x03, 0x02, 0x0E, 0x6E, 0x79, 
  };
  APPLY_PATCH(81);

  uint32_t patch82_addr = 0x00035BB9;
  uint8_t patch82_data[] = {
    0x1B, 0x05, 0x61, 0x65, 0x02, 0x79, 
  };
  APPLY_PATCH(82);

  uint32_t patch83_addr = 0x00035BC0;
  uint8_t patch83_data[] = {
    0x1C, 0x19, 0x68, 0x04, 0x18, 0x61, 0x69, 
  };
  APPLY_PATCH(83);

  uint32_t patch84_addr = 0x00035BC8;
  uint8_t patch84_data[] = {
    0x6E, 0x79, 
  };
  APPLY_PATCH(84);

  uint32_t patch85_addr = 0x00035BCB;
  uint8_t patch85_data[] = {
    0x0A, 0x1E, 0x70, 0x65, 0x02, 0x79, 
  };
  APPLY_PATCH(85);

  uint32_t patch86_addr = 0x00035BD2;
  uint8_t patch86_data[] = {
    0x1A, 0x1F, 0x61, 0x0A, 
  };
  APPLY_PATCH(86);

  uint32_t patch87_addr = 0x00035BD7;
  uint8_t patch87_data[] = {
    0x0E, 
  };
  APPLY_PATCH(87);

  uint32_t patch88_addr = 0x00035BD9;
  uint8_t patch88_data[] = {
    0x0F, 0x18, 0x68, 0x02, 0x77, 
  };
  APPLY_PATCH(88);

  uint32_t patch89_addr = 0x00035BEA;
  uint8_t patch89_data[] = {
    0x6F, 0x0C, 0x06, 0x11, 
  };
  APPLY_PATCH(89);

  uint32_t patch90_addr = 0x00035BF0;
  uint8_t patch90_data[] = {
    0x18, 0x01, 0x74, 0x6F, 
  };
  APPLY_PATCH(90);

  uint32_t patch91_addr = 0x00035BF5;
  uint8_t patch91_data[] = {
    0x0C, 0x01, 0x1D, 0x1C, 0x74, 0x11, 0x6F, 0x1B, 0x6E, 
  };
  APPLY_PATCH(91);

  uint32_t patch92_addr = 0x00035BFF;
  uint8_t patch92_data[] = {
    0x6F, 0x04, 0x61, 
  };
  APPLY_PATCH(92);

  uint32_t patch93_addr = 0x00035C04;
  uint8_t patch93_data[] = {
    0x0E, 0x73, 0x17, 0x0C, 0x74, 0x01, 0x11, 0x04, 0x16, 0x13, 0x74, 0x04, 0x64, 
  };
  APPLY_PATCH(93);

  uint32_t patch94_addr = 0x00035C12;
  uint8_t patch94_data[] = {
    0x17, 0x1D, 0x0E, 0x1D, 
  };
  APPLY_PATCH(94);

  uint32_t patch95_addr = 0x00035C17;
  uint8_t patch95_data[] = {
    0x1D, 0x72, 0x1C, 0x65, 0x0C, 0x1C, 0x18, 0x64, 
  };
  APPLY_PATCH(95);

  uint32_t patch96_addr = 0x00035C20;
  uint8_t patch96_data[] = {
    0x16, 0x1C, 0x1F, 0x0D, 0x09, 0x0E, 0x16, 0x68, 0x16, 0x1A, 0x13, 
  };
  APPLY_PATCH(96);

  uint32_t patch97_addr = 0x00035C30;
  uint8_t patch97_data[] = {
    0x6F, 0x0C, 
  };
  APPLY_PATCH(97);

  uint32_t patch98_addr = 0x00035C42;
  uint8_t patch98_data[] = {
    0x01, 0x1E, 0x6C, 
  };
  APPLY_PATCH(98);

  uint32_t patch99_addr = 0x00035C46;
  uint8_t patch99_data[] = {
    0x12, 0x6F, 0x17, 0x06, 0x06, 
  };
  APPLY_PATCH(99);

  uint32_t patch100_addr = 0x00035C4C;
  uint8_t patch100_data[] = {
    0x10, 
  };
  APPLY_PATCH(100);

  uint32_t patch101_addr = 0x00035C4E;
  uint8_t patch101_data[] = {
    0x07, 0x74, 0x10, 0x0A, 0x6C, 
  };
  APPLY_PATCH(101);

  uint32_t patch102_addr = 0x00035C54;
  uint8_t patch102_data[] = {
    0x17, 0x1A, 0x0B, 0x6F, 0x66, 0x15, 0x6B, 0x6A, 0x6D, 
  };
  APPLY_PATCH(102);

  uint32_t patch103_addr = 0x00035C5F;
  uint8_t patch103_data[] = {
    0x09, 0x05, 0x02, 0x1A, 0x7F, 0x12, 0x17, 0x6E, 
  };
  APPLY_PATCH(103);

  uint32_t patch104_addr = 0x00035EE6;
  uint8_t patch104_data[] = {
    0x16, 0x01, 0x1C, 
  };
  APPLY_PATCH(104);

  uint32_t patch105_addr = 0x00035EEA;
  uint8_t patch105_data[] = {
    0x1C, 0x02, 0x7C, 0x63, 0x69, 0x75, 0x09, 0x73, 
  };
  APPLY_PATCH(105);

  uint32_t patch106_addr = 0x00035EF4;
  uint8_t patch106_data[] = {
    0x11, 0x0C, 
  };
  APPLY_PATCH(106);

  uint32_t patch107_addr = 0x00035EF7;
  uint8_t patch107_data[] = {
    0x1C, 
  };
  APPLY_PATCH(107);

  uint32_t patch108_addr = 0x00035EF9;
  uint8_t patch108_data[] = {
    0x10, 
  };
  APPLY_PATCH(108);

  uint32_t patch109_addr = 0x00035EFB;
  uint8_t patch109_data[] = {
    0x64, 0x10, 0x66, 0x62, 0x74, 
  };
  APPLY_PATCH(109);

  uint32_t patch110_addr = 0x00035F04;
  uint8_t patch110_data[] = {
    0x05, 
  };
  APPLY_PATCH(110);

  uint32_t patch111_addr = 0x0003668B;
  uint8_t patch111_data[] = {
    0x9A, 
  };
  APPLY_PATCH(111);

  uint32_t patch112_addr = 0x0003669B;
  uint8_t patch112_data[] = {
    0x8A, 
  };
  APPLY_PATCH(112);

  uint32_t patch113_addr = 0x0003669D;
  uint8_t patch113_data[] = {
    0x10, 
  };
  APPLY_PATCH(113);

  uint32_t patch114_addr = 0x000366EF;
  uint8_t patch114_data[] = {
    0x63, 
  };
  APPLY_PATCH(114);

  uint32_t patch115_addr = 0x0004BE00;
  uint8_t patch115_data[] = {
    0xFF, 0xC6, 0xEF, 0x05, 0xE3, 0x86, 0xEF, 0xE5, 0xF1, 0x86, 0xEF, 0x73, 0xF9, 0x06, 0xFB, 0xD5, 
    0x06, 0xFB, 0xBD, 0x06, 0xFB, 0xB3, 
  };
  APPLY_PATCH(115);

  uint32_t patch116_addr = 0x0004BE18;
  uint8_t patch116_data[] = {
    0xE7, 0xA6, 0x3F, 0x6F, 0xFF, 0xE7, 0xA6, 0x3F, 0x6F, 0xFD, 0xE7, 0xA6, 0x3F, 0x5F, 0xFF, 0xE7, 
    0xA6, 0x3F, 0x5F, 0xFD, 0xE7, 0xA6, 0x3F, 0x4F, 0xFF, 0xE7, 0xA6, 0x3F, 0x4F, 0xFD, 0x46, 0xF6, 
    0xFF, 0x06, 0xFF, 0x49, 
  };
  APPLY_PATCH(116);

  uint32_t patch117_addr = 0x0004BE40;
  uint8_t patch117_data[] = {
    0x86, 0xEF, 0x9B, 0x86, 0xF9, 0xEF, 0x9B, 0xF7, 0x03, 0xF9, 0xEF, 0x9B, 0x06, 0xFB, 0x4F, 
  };
  APPLY_PATCH(117);

  uint32_t patch118_addr = 0x0004BE50;
  uint8_t patch118_data[] = {
    0x86, 0xEF, 0x9B, 0x86, 0xF9, 0xEF, 0x9B, 0xF7, 0x03, 0xF9, 0xEF, 0x9B, 0x46, 0xFB, 0xCD, 0x06, 
    0xFB, 0xBF, 
  };
  APPLY_PATCH(118);

  uint32_t patch119_addr = 0x0004BE80;
  uint8_t patch119_data[] = {
    0x83, 0xFB, 0xDB, 0x83, 0xFB, 0xDA, 0x06, 0xFF, 0xE5, 
  };
  APPLY_PATCH(119);

  uint32_t patch120_addr = 0x0004BE90;
  uint8_t patch120_data[] = {
    0xD1, 0xDB, 0xFB, 0xD1, 0xDA, 0x06, 0xEF, 0x33, 0x06, 0xFF, 0xF3, 
  };
  APPLY_PATCH(120);

  uint32_t patch121_addr = 0x0004BEA0;
  uint8_t patch121_data[] = {
    0xC6, 0x2F, 0xFD, 0xBE, 0x7F, 0x06, 0xFF, 0x6F, 0xC6, 0x2F, 0xFD, 0xBF, 0x7F, 0x06, 0xFB, 0x5B, 
    0xFF, 0x3F, 0xEF, 0x87, 0xA0, 0xE0, 0x8A, 
  };
  APPLY_PATCH(121);

  uint32_t patch122_addr = 0x0004BEB8;
  uint8_t patch122_data[] = {
    0x86, 0xEF, 0xE5, 0xFF, 0xE3, 0x86, 0xEF, 0x73, 0xFF, 0xED, 0x86, 0xEF, 0x2D, 0xFF, 0xF7, 0x06, 
    0xFB, 0xE1, 0x06, 0xFB, 0xD3, 
  };
  APPLY_PATCH(122);

  uint32_t patch123_addr = 0x0004BED0;
  uint8_t patch123_data[] = {
    0x86, 0xEF, 0xE5, 0xFF, 0xED, 0x86, 0xEF, 0x73, 0xFF, 0xF7, 0x86, 0xEF, 0x27, 0x06, 0xFB, 0x9B, 
  };
  APPLY_PATCH(123);

  uint32_t patch124_addr = 0x0004C000;
  uint8_t patch124_data[] = {
    0x18, 0x01, 0x46, 0xF6, 0xEF, 0x20, 
  };
  APPLY_PATCH(124);

  uint32_t patch125_addr = 0x0004C007;
  uint8_t patch125_data[] = {
    0x8A, 0xFF, 0xC6, 0xEF, 0x2F, 0xBF, 0x8F, 0xEB, 0xC6, 0xEF, 0x15, 0x8E, 0x3F, 0xEF, 0xFF, 0x46, 
    0xF6, 0xFF, 0x8A, 
  };
  APPLY_PATCH(125);

  uint32_t patch126_addr = 0x0004F800;
  uint8_t patch126_data[] = {
    0x06, 0xEF, 0x5A, 0x06, 0xEF, 0x35, 0xEF, 0xFB, 0x06, 0xEF, 0xFF, 0xEF, 0x35, 0x46, 0xFB, 0xA7, 
    0x06, 0xEF, 0xFB, 0xEF, 0x35, 0x8A, 
  };
  APPLY_PATCH(126);

  uint32_t patch127_addr = 0x0007BC01;
  uint8_t patch127_data[] = {
    0x41, 0xA6, 0xE0, 0x20, 0xC0, 
  };
  APPLY_PATCH(127);

  uint32_t patch128_addr = 0x0007BC07;
  uint8_t patch128_data[] = {
    0x60, 0x42, 
  };
  APPLY_PATCH(128);

  uint32_t patch129_addr = 0x0007BC0A;
  uint8_t patch129_data[] = {
    0xC0, 
  };
  APPLY_PATCH(129);

  uint32_t patch130_addr = 0x0007BC0D;
  uint8_t patch130_data[] = {
    0x09, 0x07, 0x08, 
  };
  APPLY_PATCH(130);

  uint32_t patch131_addr = 0x0007BC11;
  uint8_t patch131_data[] = {
    0xE8, 0x92, 0xDC, 0x55, 0x94, 0xEF, 0xAC, 
  };
  APPLY_PATCH(131);

  uint32_t patch132_addr = 0x0007BC1D;
  uint8_t patch132_data[] = {
    0x05, 0xE1, 0x80, 
  };
  APPLY_PATCH(132);

  uint32_t patch133_addr = 0x0007BC21;
  uint8_t patch133_data[] = {
    0x2E, 0xB2, 0x35, 0xD0, 0xB7, 0x8A, 0x48, 0x21, 
  };
  APPLY_PATCH(133);

  uint32_t patch134_addr = 0x0007BC2A;
  uint8_t patch134_data[] = {
    0x21, 0x42, 0xEF, 0x39, 0xFD, 0xB0, 
  };
  APPLY_PATCH(134);

  uint32_t patch135_addr = 0x0007BC31;
  uint8_t patch135_data[] = {
    0x41, 0xA6, 0xE0, 0x20, 0xC0, 
  };
  APPLY_PATCH(135);

  uint32_t patch136_addr = 0x0007BC37;
  uint8_t patch136_data[] = {
    0x60, 0x42, 
  };
  APPLY_PATCH(136);

  uint32_t patch137_addr = 0x0007BC3A;
  uint8_t patch137_data[] = {
    0xC0, 
  };
  APPLY_PATCH(137);

  uint32_t patch138_addr = 0x0007BC3D;
  uint8_t patch138_data[] = {
    0x09, 0x07, 0x08, 
  };
  APPLY_PATCH(138);

  uint32_t patch139_addr = 0x0007BC41;
  uint8_t patch139_data[] = {
    0xE8, 0x92, 0xDC, 0x55, 0x94, 0xEF, 0xAC, 
  };
  APPLY_PATCH(139);

  uint32_t patch140_addr = 0x0007BC4D;
  uint8_t patch140_data[] = {
    0x05, 0xE1, 0x80, 
  };
  APPLY_PATCH(140);

  uint32_t patch141_addr = 0x0007BC51;
  uint8_t patch141_data[] = {
    0x2E, 0xB2, 0x35, 0xD0, 0xB7, 0x8A, 0x48, 0x21, 
  };
  APPLY_PATCH(141);

  uint32_t patch142_addr = 0x0007BC5A;
  uint8_t patch142_data[] = {
    0x21, 0x42, 0xEF, 
  };
  APPLY_PATCH(142);

  uint32_t patch143_addr = 0x0007BC5E;
  uint8_t patch143_data[] = {
    0xFD, 0xB0, 
  };
  APPLY_PATCH(143);

  uint32_t patch144_addr = 0x0007BC72;
  uint8_t patch144_data[] = {
    0x63, 0xE7, 0x6B, 0xEF, 0x95, 0x9B, 0x05, 0x3A, 0xCB, 0x68, 0x67, 0x89, 0x45, 0xCE, 
  };
  APPLY_PATCH(144);

  uint32_t patch145_addr = 0x0007BC82;
  uint8_t patch145_data[] = {
    0xA0, 0x80, 0x83, 0xC4, 0x29, 0x6C, 
  };
  APPLY_PATCH(145);

  uint32_t patch146_addr = 0x0007BC89;
  uint8_t patch146_data[] = {
    0xF4, 0x5C, 0xF4, 0xD4, 
  };
  APPLY_PATCH(146);

  uint32_t patch147_addr = 0x0007BC8E;
  uint8_t patch147_data[] = {
    0x9B, 0x74, 
  };
  APPLY_PATCH(147);

  uint32_t patch148_addr = 0x0007BE11;
  uint8_t patch148_data[] = {
    0x03, 0xCC, 0x66, 0x3E, 0xE4, 0x65, 0xAF, 0x43, 0x21, 0x02, 0x42, 0x01, 0x1F, 0x5C, 0x94, 0x14, 
    0xA6, 0x02, 0xA0, 0x07, 0xCE, 0x6A, 0xE6, 
  };
  APPLY_PATCH(148);

  uint32_t patch149_addr = 0x0007BE29;
  uint8_t patch149_data[] = {
    0x36, 0x13, 0x4A, 0xA6, 0xFF, 0xFC, 0x94, 
  };
  APPLY_PATCH(149);

  uint32_t patch150_addr = 0x0007BE60;
  uint8_t patch150_data[] = {
    0x14, 0xC0, 0xCF, 0xB9, 0xD8, 0xA6, 0x6C, 0xCD, 
  };
  APPLY_PATCH(150);

  uint32_t patch151_addr = 0x0007BE69;
  uint8_t patch151_data[] = {
    0xC1, 0xAE, 0x99, 0x18, 0x9E, 0x55, 0xCD, 
  };
  APPLY_PATCH(151);

  uint32_t patch152_addr = 0x0007BE80;
  uint8_t patch152_data[] = {
    0x10, 0xA7, 0x2A, 0xDA, 0xD4, 0xEC, 0xCB, 0x68, 
  };
  APPLY_PATCH(152);

  uint32_t patch153_addr = 0x0007BE89;
  uint8_t patch153_data[] = {
    0x62, 0x26, 0x07, 0xEE, 0x6C, 0x84, 0x80, 0x04, 0x08, 0x59, 0x98, 0xCB, 0xE9, 0xE5, 0xE2, 0x20, 
    0x02, 0xE7, 0xE7, 0x21, 0x4F, 0x86, 0x40, 0x14, 0x27, 0x0B, 0x7D, 0xD4, 0xEB, 0x89, 0x89, 
  };
  APPLY_PATCH(153);

  uint32_t patch154_addr = 0x0007BEA9;
  uint8_t patch154_data[] = {
    0x43, 0xE6, 0xC7, 0xCF, 0x67, 0xCE, 0xC7, 
  };
  APPLY_PATCH(154);

  uint32_t patch155_addr = 0x0007BEC0;
  uint8_t patch155_data[] = {
    0x14, 0x1F, 0x25, 0xAF, 0x84, 0x20, 0x40, 0xC0, 0x20, 0x21, 0x21, 0xE7, 0x40, 0xB0, 0x79, 0x5F, 
    0x04, 0x08, 0x59, 0x98, 0xCB, 0xE9, 0xE5, 0xE2, 0x20, 0x02, 0xE7, 0xE7, 0x21, 0x4F, 0x86, 0x40, 
    0x14, 0x85, 0x6F, 0x07, 0x5E, 0x46, 0xEE, 0xAB, 
  };
  APPLY_PATCH(155);

  uint32_t patch156_addr = 0x0007BEEA;
  uint8_t patch156_data[] = {
    0x21, 
  };
  APPLY_PATCH(156);

  uint32_t patch157_addr = 0x0007BEEC;
  uint8_t patch157_data[] = {
    0xEF, 0x64, 
  };
  APPLY_PATCH(157);
}

void patch_u27()
{
  uint32_t patch0_addr = 0x000003BD;
  uint8_t patch0_data[] = {
    0x7E, 0xD0, 0x4F, 0x4E, 0x4E, 0x7E, 0x9E, 0x7D, 0x4E, 0x4E, 0x7E, 0x9E, 0x7D, 0x4E, 0x4E, 0x7E, 
    0x9E, 0x7D, 0x4E, 0x4E, 0x7E, 0x9E, 0x7D, 0x4E, 0x4E, 0x7E, 0x9E, 0x7D, 0x4E, 0x4E, 
  };
  APPLY_PATCH(0);

  uint32_t patch1_addr = 0x000004C5;
  uint8_t patch1_data[] = {
    0x7C, 
  };
  APPLY_PATCH(1);

  uint32_t patch2_addr = 0x000004C7;
  uint8_t patch2_data[] = {
    0x7D, 
  };
  APPLY_PATCH(2);

  uint32_t patch3_addr = 0x000019FE;
  uint8_t patch3_data[] = {
    0x40, 0x4E, 0x57, 
  };
  APPLY_PATCH(3);

  uint32_t patch4_addr = 0x00001E8E;
  uint8_t patch4_data[] = {
    0x38, 
  };
  APPLY_PATCH(4);

  uint32_t patch5_addr = 0x00001ED8;
  uint8_t patch5_data[] = {
    0x04, 
  };
  APPLY_PATCH(5);

  uint32_t patch6_addr = 0x00001F44;
  uint8_t patch6_data[] = {
    0x03, 
  };
  APPLY_PATCH(6);

  uint32_t patch7_addr = 0x00001F4D;
  uint8_t patch7_data[] = {
    0x03, 
  };
  APPLY_PATCH(7);

  uint32_t patch8_addr = 0x00001F56;
  uint8_t patch8_data[] = {
    0x05, 
  };
  APPLY_PATCH(8);

  uint32_t patch9_addr = 0x00001F5F;
  uint8_t patch9_data[] = {
    0x07, 
  };
  APPLY_PATCH(9);

  uint32_t patch10_addr = 0x00001F68;
  uint8_t patch10_data[] = {
    0x05, 
  };
  APPLY_PATCH(10);

  uint32_t patch11_addr = 0x00002029;
  uint8_t patch11_data[] = {
    0x38, 
  };
  APPLY_PATCH(11);

  uint32_t patch12_addr = 0x000020AB;
  uint8_t patch12_data[] = {
    0x72, 0x03, 0x65, 0x03, 0x7E, 
  };
  APPLY_PATCH(12);

  uint32_t patch13_addr = 0x000020B1;
  uint8_t patch13_data[] = {
    0x04, 0x01, 0x61, 0x01, 0x16, 0x1A, 0x6F, 
  };
  APPLY_PATCH(13);

  uint32_t patch14_addr = 0x000020E4;
  uint8_t patch14_data[] = {
    0x16, 0x01, 
  };
  APPLY_PATCH(14);

  uint32_t patch15_addr = 0x000020E8;
  uint8_t patch15_data[] = {
    0x64, 0x70, 0x61, 0x75, 0x64, 0x7E, 0x70, 0x73, 
  };
  APPLY_PATCH(15);

  uint32_t patch16_addr = 0x000020F3;
  uint8_t patch16_data[] = {
    0x11, 0x10, 
  };
  APPLY_PATCH(16);

  uint32_t patch17_addr = 0x000020F7;
  uint8_t patch17_data[] = {
    0x60, 0x63, 0x74, 0x10, 0x68, 0x75, 0x74, 0x74, 
  };
  APPLY_PATCH(17);

  uint32_t patch18_addr = 0x00002104;
  uint8_t patch18_data[] = {
    0x14, 
  };
  APPLY_PATCH(18);

  uint32_t patch19_addr = 0x00002108;
  uint8_t patch19_data[] = {
    0x60, 0x07, 0x65, 0x02, 0x1C, 
  };
  APPLY_PATCH(19);

  uint32_t patch20_addr = 0x00002116;
  uint8_t patch20_data[] = {
    0x01, 
  };
  APPLY_PATCH(20);

  uint32_t patch21_addr = 0x00002125;
  uint8_t patch21_data[] = {
    0x7F, 0x04, 0x13, 0x6E, 0x6F, 0x65, 0x0D, 
  };
  APPLY_PATCH(21);

  uint32_t patch22_addr = 0x00002191;
  uint8_t patch22_data[] = {
    0x04, 
  };
  APPLY_PATCH(22);

  uint32_t patch23_addr = 0x00002194;
  uint8_t patch23_data[] = {
    0x06, 
  };
  APPLY_PATCH(23);

  uint32_t patch24_addr = 0x0000219A;
  uint8_t patch24_data[] = {
    0x04, 
  };
  APPLY_PATCH(24);

  uint32_t patch25_addr = 0x0000219D;
  uint8_t patch25_data[] = {
    0x02, 
  };
  APPLY_PATCH(25);

  uint32_t patch26_addr = 0x000021A3;
  uint8_t patch26_data[] = {
    0x04, 
  };
  APPLY_PATCH(26);

  uint32_t patch27_addr = 0x000021A6;
  uint8_t patch27_data[] = {
    0x0E, 
  };
  APPLY_PATCH(27);

  uint32_t patch28_addr = 0x000021AC;
  uint8_t patch28_data[] = {
    0x04, 
  };
  APPLY_PATCH(28);

  uint32_t patch29_addr = 0x000021AF;
  uint8_t patch29_data[] = {
    0x02, 
  };
  APPLY_PATCH(29);

  uint32_t patch30_addr = 0x000021B5;
  uint8_t patch30_data[] = {
    0x04, 
  };
  APPLY_PATCH(30);

  uint32_t patch31_addr = 0x000021B8;
  uint8_t patch31_data[] = {
    0x06, 
  };
  APPLY_PATCH(31);

  uint32_t patch32_addr = 0x000021BE;
  uint8_t patch32_data[] = {
    0x04, 
  };
  APPLY_PATCH(32);

  uint32_t patch33_addr = 0x000021C7;
  uint8_t patch33_data[] = {
    0x04, 
  };
  APPLY_PATCH(33);

  uint32_t patch34_addr = 0x000021D0;
  uint8_t patch34_data[] = {
    0x04, 
  };
  APPLY_PATCH(34);

  uint32_t patch35_addr = 0x000021D9;
  uint8_t patch35_data[] = {
    0x04, 
  };
  APPLY_PATCH(35);

  uint32_t patch36_addr = 0x000021E2;
  uint8_t patch36_data[] = {
    0x04, 
  };
  APPLY_PATCH(36);

  uint32_t patch37_addr = 0x000021EB;
  uint8_t patch37_data[] = {
    0x04, 
  };
  APPLY_PATCH(37);

  uint32_t patch38_addr = 0x000021F4;
  uint8_t patch38_data[] = {
    0x04, 
  };
  APPLY_PATCH(38);

  uint32_t patch39_addr = 0x000021F7;
  uint8_t patch39_data[] = {
    0x3E, 
  };
  APPLY_PATCH(39);

  uint32_t patch40_addr = 0x000021FD;
  uint8_t patch40_data[] = {
    0x04, 
  };
  APPLY_PATCH(40);

  uint32_t patch41_addr = 0x00002200;
  uint8_t patch41_data[] = {
    0x02, 
  };
  APPLY_PATCH(41);

  uint32_t patch42_addr = 0x00002206;
  uint8_t patch42_data[] = {
    0x04, 
  };
  APPLY_PATCH(42);

  uint32_t patch43_addr = 0x00002209;
  uint8_t patch43_data[] = {
    0x06, 
  };
  APPLY_PATCH(43);

  uint32_t patch44_addr = 0x0000220F;
  uint8_t patch44_data[] = {
    0x04, 
  };
  APPLY_PATCH(44);

  uint32_t patch45_addr = 0x00002218;
  uint8_t patch45_data[] = {
    0x04, 
  };
  APPLY_PATCH(45);

  uint32_t patch46_addr = 0x00002221;
  uint8_t patch46_data[] = {
    0x04, 
  };
  APPLY_PATCH(46);

  uint32_t patch47_addr = 0x00002224;
  uint8_t patch47_data[] = {
    0x06, 
  };
  APPLY_PATCH(47);

  uint32_t patch48_addr = 0x0000222A;
  uint8_t patch48_data[] = {
    0x04, 
  };
  APPLY_PATCH(48);

  uint32_t patch49_addr = 0x0000222D;
  uint8_t patch49_data[] = {
    0x02, 
  };
  APPLY_PATCH(49);

  uint32_t patch50_addr = 0x00002233;
  uint8_t patch50_data[] = {
    0x04, 
  };
  APPLY_PATCH(50);

  uint32_t patch51_addr = 0x00002236;
  uint8_t patch51_data[] = {
    0x1E, 
  };
  APPLY_PATCH(51);

  uint32_t patch52_addr = 0x0000223C;
  uint8_t patch52_data[] = {
    0x04, 
  };
  APPLY_PATCH(52);

  uint32_t patch53_addr = 0x0000223F;
  uint8_t patch53_data[] = {
    0x02, 
  };
  APPLY_PATCH(53);

  uint32_t patch54_addr = 0x00002245;
  uint8_t patch54_data[] = {
    0x04, 
  };
  APPLY_PATCH(54);

  uint32_t patch55_addr = 0x00002248;
  uint8_t patch55_data[] = {
    0x06, 
  };
  APPLY_PATCH(55);

  uint32_t patch56_addr = 0x0000224E;
  uint8_t patch56_data[] = {
    0x04, 
  };
  APPLY_PATCH(56);

  uint32_t patch57_addr = 0x00002251;
  uint8_t patch57_data[] = {
    0x02, 
  };
  APPLY_PATCH(57);

  uint32_t patch58_addr = 0x000029F7;
  uint8_t patch58_data[] = {
    0x7E, 0x4E, 0x1C, 0xFC, 0x28, 0x7E, 0x4E, 0x1C, 0xFA, 0x29, 0x7D, 0x4E, 0x4E, 0x41, 
  };
  APPLY_PATCH(58);

  uint32_t patch59_addr = 0x00002EE7;
  uint8_t patch59_data[] = {
    0x01, 
  };
  APPLY_PATCH(59);

  uint32_t patch60_addr = 0x000030B8;
  uint8_t patch60_data[] = {
    0x07, 
  };
  APPLY_PATCH(60);

  uint32_t patch61_addr = 0x0000318B;
  uint8_t patch61_data[] = {
    0x6D, 0x4E, 0x59, 0x6D, 0x4E, 0x59, 0x7D, 0x4E, 0x59, 0x7D, 0x4E, 0x59, 0x7D, 0x4E, 0x59, 0x7D, 
    0x4E, 0x59, 0x6D, 0x4E, 0x59, 0x6D, 0x4E, 0x59, 0x7D, 0x4E, 0x59, 
  };
  APPLY_PATCH(61);

  uint32_t patch62_addr = 0x00003209;
  uint8_t patch62_data[] = {
    0x53, 
  };
  APPLY_PATCH(62);

  uint32_t patch63_addr = 0x0000320B;
  uint8_t patch63_data[] = {
    0x60, 0x4E, 
  };
  APPLY_PATCH(63);

  uint32_t patch64_addr = 0x000032C0;
  uint8_t patch64_data[] = {
    0x01, 
  };
  APPLY_PATCH(64);

  uint32_t patch65_addr = 0x00003401;
  uint8_t patch65_data[] = {
    0x1D, 
  };
  APPLY_PATCH(65);

  uint32_t patch66_addr = 0x00003403;
  uint8_t patch66_data[] = {
    0x38, 0x4E, 0x62, 
  };
  APPLY_PATCH(66);

  uint32_t patch67_addr = 0x000037D1;
  uint8_t patch67_data[] = {
    0x04, 0x4E, 0x57, 0x29, 
  };
  APPLY_PATCH(67);

  uint32_t patch68_addr = 0x000037DF;
  uint8_t patch68_data[] = {
    0x04, 0x4E, 0x57, 0x29, 
  };
  APPLY_PATCH(68);

  uint32_t patch69_addr = 0x00006AE8;
  uint8_t patch69_data[] = {
    0x7D, 0x4E, 0x58, 0x6D, 0x4E, 0x59, 0x6D, 0x4E, 0x59, 0x7D, 0x4E, 0x59, 0x6D, 0x4E, 0x59, 0x6D, 
    0x4E, 0x59, 0x7D, 0x4E, 0x59, 
  };
  APPLY_PATCH(69);

  uint32_t patch70_addr = 0x00006E3D;
  uint8_t patch70_data[] = {
    0x01, 
  };
  APPLY_PATCH(70);

  uint32_t patch71_addr = 0x0001DE9E;
  uint8_t patch71_data[] = {
    0x06, 
  };
  APPLY_PATCH(71);

  uint32_t patch72_addr = 0x0001FC58;
  uint8_t patch72_data[] = {
    0x7D, 0x4E, 0x59, 0x7D, 0x4E, 0x4E, 0x59, 0x6D, 0x4E, 0x59, 0x6D, 0x4E, 0x59, 
  };
  APPLY_PATCH(72);

  uint32_t patch73_addr = 0x00021EB4;
  uint8_t patch73_data[] = {
    0x04, 0x4E, 0x58, 0x29, 
  };
  APPLY_PATCH(73);

  uint32_t patch74_addr = 0x00021F33;
  uint8_t patch74_data[] = {
    0x2A, 0x0C, 0x3E, 0x7C, 0x2B, 0x63, 0x24, 0x67, 0x0C, 0x5D, 0x33, 0x16, 0x71, 0x0C, 0x5D, 0x4A, 
    0x2C, 0x7D, 0x6A, 0x53, 0x0C, 0x4E, 0x59, 0x2E, 
  };
  APPLY_PATCH(74);

  uint32_t patch75_addr = 0x0002204B;
  uint8_t patch75_data[] = {
    0x07, 
  };
  APPLY_PATCH(75);

  uint32_t patch76_addr = 0x0002241D;
  uint8_t patch76_data[] = {
    0x1C, 0x61, 0x7C, 
  };
  APPLY_PATCH(76);

  uint32_t patch77_addr = 0x00022474;
  uint8_t patch77_data[] = {
    0x01, 
  };
  APPLY_PATCH(77);

  uint32_t patch78_addr = 0x00022476;
  uint8_t patch78_data[] = {
    0x03, 
  };
  APPLY_PATCH(78);

  uint32_t patch79_addr = 0x00022478;
  uint8_t patch79_data[] = {
    0x05, 
  };
  APPLY_PATCH(79);

  uint32_t patch80_addr = 0x00022491;
  uint8_t patch80_data[] = {
    0x80, 
  };
  APPLY_PATCH(80);

  uint32_t patch81_addr = 0x00022493;
  uint8_t patch81_data[] = {
    0x83, 
  };
  APPLY_PATCH(81);

  uint32_t patch82_addr = 0x00022495;
  uint8_t patch82_data[] = {
    0x05, 
  };
  APPLY_PATCH(82);

  uint32_t patch83_addr = 0x0002252F;
  uint8_t patch83_data[] = {
    0x1D, 
  };
  APPLY_PATCH(83);

  uint32_t patch84_addr = 0x00022531;
  uint8_t patch84_data[] = {
    0x6A, 
  };
  APPLY_PATCH(84);

  uint32_t patch85_addr = 0x00022551;
  uint8_t patch85_data[] = {
    0x72, 
  };
  APPLY_PATCH(85);

  uint32_t patch86_addr = 0x00022553;
  uint8_t patch86_data[] = {
    0x29, 0x07, 
  };
  APPLY_PATCH(86);

  uint32_t patch87_addr = 0x0002258B;
  uint8_t patch87_data[] = {
    0x1D, 
  };
  APPLY_PATCH(87);

  uint32_t patch88_addr = 0x0002258D;
  uint8_t patch88_data[] = {
    0x6A, 0x28, 
  };
  APPLY_PATCH(88);

  uint32_t patch89_addr = 0x00022611;
  uint8_t patch89_data[] = {
    0x72, 
  };
  APPLY_PATCH(89);

  uint32_t patch90_addr = 0x00022613;
  uint8_t patch90_data[] = {
    0x6B, 0x07, 
  };
  APPLY_PATCH(90);

  uint32_t patch91_addr = 0x000226A3;
  uint8_t patch91_data[] = {
    0x03, 
  };
  APPLY_PATCH(91);

  uint32_t patch92_addr = 0x000228F6;
  uint8_t patch92_data[] = {
    0x0C, 0x4E, 0x59, 
  };
  APPLY_PATCH(92);

  uint32_t patch93_addr = 0x000228FC;
  uint8_t patch93_data[] = {
    0x0C, 0x4E, 0x59, 
  };
  APPLY_PATCH(93);

  uint32_t patch94_addr = 0x0002297F;
  uint8_t patch94_data[] = {
    0x03, 
  };
  APPLY_PATCH(94);

  uint32_t patch95_addr = 0x00022C9B;
  uint8_t patch95_data[] = {
    0x3E, 
  };
  APPLY_PATCH(95);

  uint32_t patch96_addr = 0x00022C9D;
  uint8_t patch96_data[] = {
    0x02, 0x06, 0x04, 0x0A, 0x08, 0x0A, 0x14, 0x14, 0x12, 0x10, 0x12, 0x14, 0x16, 0x2A, 0x28, 0x2E, 
    0x24, 0x26, 0x20, 0x20, 0x3E, 0x3C, 0x26, 0x28, 0x28, 0x2E, 0x2A, 0x2A, 0x16, 0x16, 0x1A, 0x1C, 
    0x1E, 0x1C, 0x14, 0x14, 0x14, 0x12, 0x2C, 0x2E, 0x32, 0x30, 0x36, 0x30, 0x30, 0x30, 0x30, 0x32, 
    0x36, 0x36, 0x32, 0x0C, 0x0C, 0x0C, 0x14, 0x16, 0x14, 0x1A, 0x1E, 0x18, 0x1A, 0x18, 0x08, 0x0A, 
    0x08, 0x0E, 0x0A, 0x0A, 0x06, 0x04, 0x02, 0x02, 
  };
  APPLY_PATCH(96);

  uint32_t patch97_addr = 0x00024BCF;
  uint8_t patch97_data[] = {
    0x7E, 
  };
  APPLY_PATCH(97);

  uint32_t patch98_addr = 0x00024BD1;
  uint8_t patch98_data[] = {
    0x7D, 
  };
  APPLY_PATCH(98);

  uint32_t patch99_addr = 0x000269D5;
  uint8_t patch99_data[] = {
    0x1C, 
  };
  APPLY_PATCH(99);

  uint32_t patch100_addr = 0x000269D7;
  uint8_t patch100_data[] = {
    0x65, 
  };
  APPLY_PATCH(100);

  uint32_t patch101_addr = 0x0002746C;
  uint8_t patch101_data[] = {
    0xB0, 
  };
  APPLY_PATCH(101);

  uint32_t patch102_addr = 0x0002746E;
  uint8_t patch102_data[] = {
    0x4B, 0x29, 0x3A, 0x68, 0x41, 0x13, 0x2C, 0x3F, 0xBA, 0x2C, 0x62, 0x66, 0xE1, 0x4E, 0x4E, 0x62, 
    0x48, 0x4E, 0x4E, 0x57, 0x7E, 0x4E, 0x57, 
  };
  APPLY_PATCH(102);

  uint32_t patch103_addr = 0x00027486;
  uint8_t patch103_data[] = {
    0x4E, 0x38, 0x6D, 0x4E, 0x57, 0x1C, 0x4E, 0x57, 0x7E, 0x4E, 0x57, 
  };
  APPLY_PATCH(103);

  uint32_t patch104_addr = 0x00027492;
  uint8_t patch104_data[] = {
    0x4E, 0x38, 0x7D, 0x4E, 0x57, 
  };
  APPLY_PATCH(104);

  uint32_t patch105_addr = 0x00027498;
  uint8_t patch105_data[] = {
    0x4E, 0xDE, 0x2E, 0x4E, 
  };
  APPLY_PATCH(105);

  uint32_t patch106_addr = 0x0002BA01;
  uint8_t patch106_data[] = {
    0x03, 
  };
  APPLY_PATCH(106);

  uint32_t patch107_addr = 0x0002BF56;
  uint8_t patch107_data[] = {
    0x6E, 0x20, 0x33, 
  };
  APPLY_PATCH(107);

  uint32_t patch108_addr = 0x00035A55;
  uint8_t patch108_data[] = {
    0x70, 0x65, 0x01, 0x62, 
  };
  APPLY_PATCH(108);

  uint32_t patch109_addr = 0x00035A5A;
  uint8_t patch109_data[] = {
    0x02, 0x61, 0x61, 
  };
  APPLY_PATCH(109);

  uint32_t patch110_addr = 0x00035A5E;
  uint8_t patch110_data[] = {
    0x10, 0x74, 0x1A, 0x74, 0x6E, 
  };
  APPLY_PATCH(110);

  uint32_t patch111_addr = 0x00035A9D;
  uint8_t patch111_data[] = {
    0x70, 0x61, 0x65, 0x0D, 
  };
  APPLY_PATCH(111);

  uint32_t patch112_addr = 0x00035AA2;
  uint8_t patch112_data[] = {
    0x74, 0x72, 
  };
  APPLY_PATCH(112);

  uint32_t patch113_addr = 0x00035BA9;
  uint8_t patch113_data[] = {
    0x6E, 
  };
  APPLY_PATCH(113);

  uint32_t patch114_addr = 0x00035BAB;
  uint8_t patch114_data[] = {
    0x01, 0x1C, 0x68, 0x02, 0x77, 
  };
  APPLY_PATCH(114);

  uint32_t patch115_addr = 0x00035BB1;
  uint8_t patch115_data[] = {
    0x07, 0x02, 
  };
  APPLY_PATCH(115);

  uint32_t patch116_addr = 0x00035BB4;
  uint8_t patch116_data[] = {
    0x0A, 0x0B, 0x6F, 0x6C, 0x0E, 
  };
  APPLY_PATCH(116);

  uint32_t patch117_addr = 0x00035BBA;
  uint8_t patch117_data[] = {
    0x0F, 0x0E, 0x06, 0x03, 0x62, 0x0E, 
  };
  APPLY_PATCH(117);

  uint32_t patch118_addr = 0x00035BC1;
  uint8_t patch118_data[] = {
    0x01, 0x0D, 0x0D, 0x1F, 0x0E, 0x73, 0x61, 0x6F, 0x6C, 0x0E, 
  };
  APPLY_PATCH(118);

  uint32_t patch119_addr = 0x00035BCC;
  uint8_t patch119_data[] = {
    0x1B, 0x16, 0x0D, 0x03, 0x62, 0x0E, 
  };
  APPLY_PATCH(119);

  uint32_t patch120_addr = 0x00035BD3;
  uint8_t patch120_data[] = {
    0x60, 0x77, 0x68, 0x02, 0x77, 
  };
  APPLY_PATCH(120);

  uint32_t patch121_addr = 0x00035BD9;
  uint8_t patch121_data[] = {
    0x05, 0x1C, 0x6E, 0x0A, 
  };
  APPLY_PATCH(121);

  uint32_t patch122_addr = 0x00035BDE;
  uint8_t patch122_data[] = {
    0x0E, 
  };
  APPLY_PATCH(122);

  uint32_t patch123_addr = 0x00035BEA;
  uint8_t patch123_data[] = {
    0x0C, 0x10, 0x03, 0x16, 
  };
  APPLY_PATCH(123);

  uint32_t patch124_addr = 0x00035BEF;
  uint8_t patch124_data[] = {
    0x14, 0x1B, 0x0C, 0x61, 0x69, 0x6E, 
  };
  APPLY_PATCH(124);

  uint32_t patch125_addr = 0x00035BF6;
  uint8_t patch125_data[] = {
    0x1A, 0x1D, 0x16, 0x0C, 0x0D, 0x03, 0x11, 0x06, 0x1B, 0x79, 0x1D, 0x0B, 0x16, 
  };
  APPLY_PATCH(125);

  uint32_t patch126_addr = 0x00035C04;
  uint8_t patch126_data[] = {
    0x0E, 0x17, 0x16, 0x75, 0x0A, 0x04, 0x70, 0x0A, 0x1C, 0x69, 0x07, 0x62, 0x6E, 
  };
  APPLY_PATCH(126);

  uint32_t patch127_addr = 0x00035C12;
  uint8_t patch127_data[] = {
    0x02, 0x13, 0x65, 0x0E, 0x07, 0x08, 0x6A, 0x08, 0x02, 0x05, 0x09, 0x6C, 0x6E, 
  };
  APPLY_PATCH(127);

  uint32_t patch128_addr = 0x00035C20;
  uint8_t patch128_data[] = {
    0x1B, 0x63, 0x19, 0x0C, 0x10, 0x1D, 0x70, 
  };
  APPLY_PATCH(128);

  uint32_t patch129_addr = 0x00035C29;
  uint8_t patch129_data[] = {
    0x69, 0x0A, 
  };
  APPLY_PATCH(129);

  uint32_t patch130_addr = 0x00035C30;
  uint8_t patch130_data[] = {
    0x06, 0x61, 0x01, 
  };
  APPLY_PATCH(130);

  uint32_t patch131_addr = 0x00035C42;
  uint8_t patch131_data[] = {
    0x1C, 
  };
  APPLY_PATCH(131);

  uint32_t patch132_addr = 0x00035C44;
  uint8_t patch132_data[] = {
    0x07, 0x6C, 
  };
  APPLY_PATCH(132);

  uint32_t patch133_addr = 0x00035C47;
  uint8_t patch133_data[] = {
    0x17, 0x03, 0x0C, 0x11, 0x11, 0x65, 0x1B, 
  };
  APPLY_PATCH(133);

  uint32_t patch134_addr = 0x00035C4F;
  uint8_t patch134_data[] = {
    0x65, 0x0E, 0x6C, 0x75, 0x6C, 
  };
  APPLY_PATCH(134);

  uint32_t patch135_addr = 0x00035C55;
  uint8_t patch135_data[] = {
    0x19, 0x02, 0x74, 0x09, 0x6A, 0x05, 
  };
  APPLY_PATCH(135);

  uint32_t patch136_addr = 0x00035C5C;
  uint8_t patch136_data[] = {
    0x61, 0x0E, 
  };
  APPLY_PATCH(136);

  uint32_t patch137_addr = 0x00035C5F;
  uint8_t patch137_data[] = {
    0x03, 0x08, 0x0F, 0x1D, 0x11, 0x61, 0x06, 0x13, 0x11, 0x7C, 
  };
  APPLY_PATCH(137);

  uint32_t patch138_addr = 0x00035EE7;
  uint8_t patch138_data[] = {
    0x0C, 
  };
  APPLY_PATCH(138);

  uint32_t patch139_addr = 0x00035EE9;
  uint8_t patch139_data[] = {
    0x1C, 
  };
  APPLY_PATCH(139);

  uint32_t patch140_addr = 0x00035EEB;
  uint8_t patch140_data[] = {
    0x10, 
  };
  APPLY_PATCH(140);

  uint32_t patch141_addr = 0x00035EED;
  uint8_t patch141_data[] = {
    0x64, 0x10, 0x66, 0x62, 0x74, 
  };
  APPLY_PATCH(141);

  uint32_t patch142_addr = 0x00035EF5;
  uint8_t patch142_data[] = {
    0x15, 0x02, 0x1C, 
  };
  APPLY_PATCH(142);

  uint32_t patch143_addr = 0x00035EF9;
  uint8_t patch143_data[] = {
    0x1C, 0x03, 0x7C, 0x63, 0x69, 0x75, 0x09, 0x73, 
  };
  APPLY_PATCH(143);

  uint32_t patch144_addr = 0x000366EC;
  uint8_t patch144_data[] = {
    0x6F, 
  };
  APPLY_PATCH(144);

  uint32_t patch145_addr = 0x0004BE00;
  uint8_t patch145_data[] = {
    0x83, 0xC3, 0xFF, 0xE8, 0x98, 0xB5, 0xFF, 0xE9, 0x99, 0xB5, 0xFF, 0xD3, 0x95, 0xB1, 0xFF, 0xB3, 
    0xB1, 0xFF, 0xB3, 0xB1, 0xFF, 0xB3, 
  };
  APPLY_PATCH(145);

  uint32_t patch146_addr = 0x0004BE18;
  uint8_t patch146_data[] = {
    0xCF, 0x2F, 0xCC, 0xFF, 0xFF, 0xCF, 0x2F, 0xCC, 0xFF, 0xFF, 0xCF, 0x2F, 0xCC, 0xFF, 0xFF, 0xCF, 
    0x2F, 0xCC, 0xFF, 0xFF, 0xCF, 0x2F, 0xCC, 0xFF, 0xFF, 0xCF, 0x2F, 0xCC, 0xFF, 0xFF, 0xB1, 0xFF, 
    0x7F, 0xB1, 0xFF, 0xF8, 
  };
  APPLY_PATCH(146);

  uint32_t patch147_addr = 0x0004BE40;
  uint8_t patch147_data[] = {
    0xAD, 0xFF, 0xE6, 0xF3, 0xFF, 0xFF, 0xE6, 0x9C, 0xCC, 0xFF, 0xFF, 0xE6, 0xB1, 0xFF, 0x2C, 
  };
  APPLY_PATCH(147);

  uint32_t patch148_addr = 0x0004BE50;
  uint8_t patch148_data[] = {
    0xAD, 0xFF, 0xE6, 0xF3, 0xFF, 0xFF, 0xE6, 0x9C, 0xCC, 0xFF, 0xFF, 0xE6, 0xB1, 0xFF, 0xB6, 0xB1, 
    0xFF, 0xB7, 
  };
  APPLY_PATCH(148);

  uint32_t patch149_addr = 0x0004BE80;
  uint8_t patch149_data[] = {
    0xE2, 0xFF, 0xFF, 0xE2, 0xFF, 0xFF, 0xB1, 0xFF, 0x9B, 
  };
  APPLY_PATCH(149);

  uint32_t patch150_addr = 0x0004BE90;
  uint8_t patch150_data[] = {
    0xAC, 0xFF, 0x98, 0xAC, 0xFF, 0xBA, 0xFF, 0xD3, 0xB1, 0xFF, 0x97, 
  };
  APPLY_PATCH(150);

  uint32_t patch151_addr = 0x0004BEA0;
  uint8_t patch151_data[] = {
    0xCD, 0xFF, 0xFF, 0xFF, 0xFF, 0xB1, 0xFF, 0xF6, 0xCF, 0xFF, 0xFF, 0xFF, 0xFF, 0xB1, 0xFF, 0x68, 
    0x8F, 0xCC, 0xFF, 0xE6, 0xDF, 0xDF, 0xB1, 
  };
  APPLY_PATCH(151);

  uint32_t patch152_addr = 0x0004BEB8;
  uint8_t patch152_data[] = {
    0xB5, 0xFF, 0xE9, 0x99, 0xFF, 0xB5, 0xFF, 0xD3, 0x95, 0xFF, 0xAC, 0xFF, 0xE8, 0x99, 0xFF, 0xB1, 
    0xFF, 0xB4, 0xB1, 0xFF, 0xB4, 
  };
  APPLY_PATCH(152);

  uint32_t patch153_addr = 0x0004BED0;
  uint8_t patch153_data[] = {
    0xB5, 0xFF, 0xE9, 0x99, 0xFF, 0xB5, 0xFF, 0xD3, 0x95, 0xFF, 0xAC, 0xFF, 0xE8, 0xB1, 0xFF, 0xB5, 
  };
  APPLY_PATCH(153);

  uint32_t patch154_addr = 0x0004C000;
  uint8_t patch154_data[] = {
    0xB7, 
  };
  APPLY_PATCH(154);

  uint32_t patch155_addr = 0x0004C002;
  uint8_t patch155_data[] = {
    0xB1, 0xFF, 0x7F, 0xB3, 0x80, 0xB1, 0x8F, 0xCF, 0xFF, 0xE8, 0xF3, 0xFF, 0x92, 0xCF, 0xFF, 0xE8, 
    0xB1, 0xDC, 0xFF, 0xEF, 0xB1, 0xFF, 0x0F, 0xB1, 
  };
  APPLY_PATCH(155);

  uint32_t patch156_addr = 0x0004F800;
  uint8_t patch156_data[] = {
    0xB2, 0xFF, 0xE8, 0xDC, 0xFF, 0x17, 0xFF, 0xEF, 0xDC, 0xFF, 0xEF, 0xFF, 0x17, 0xB1, 0xFF, 0xB8, 
    0xDC, 0xFF, 0xEF, 0xFF, 0x17, 0xB1, 
  };
  APPLY_PATCH(156);

  uint32_t patch157_addr = 0x0007BC01;
  uint8_t patch157_data[] = {
    0x20, 0x58, 0x74, 0x4C, 0x30, 0x20, 0x18, 0x08, 
  };
  APPLY_PATCH(157);

  uint32_t patch158_addr = 0x0007BC0D;
  uint8_t patch158_data[] = {
    0x30, 0x50, 0x38, 
  };
  APPLY_PATCH(158);

  uint32_t patch159_addr = 0x0007BC11;
  uint8_t patch159_data[] = {
    0x38, 0x57, 0x72, 0x6E, 0x51, 0x38, 0x20, 0x18, 
  };
  APPLY_PATCH(159);

  uint32_t patch160_addr = 0x0007BC1D;
  uint8_t patch160_data[] = {
    0x18, 0x28, 0x10, 
  };
  APPLY_PATCH(160);

  uint32_t patch161_addr = 0x0007BC21;
  uint8_t patch161_data[] = {
    0x2E, 0x75, 0x19, 0x08, 
  };
  APPLY_PATCH(161);

  uint32_t patch162_addr = 0x0007BC26;
  uint8_t patch162_data[] = {
    0x0C, 
  };
  APPLY_PATCH(162);

  uint32_t patch163_addr = 0x0007BC28;
  uint8_t patch163_data[] = {
    0x04, 
  };
  APPLY_PATCH(163);

  uint32_t patch164_addr = 0x0007BC2A;
  uint8_t patch164_data[] = {
    0x04, 0x08, 0x3D, 0x34, 0x7C, 0x34, 
  };
  APPLY_PATCH(164);

  uint32_t patch165_addr = 0x0007BC31;
  uint8_t patch165_data[] = {
    0x20, 0x58, 0x74, 0x4C, 0x30, 0x20, 0x18, 0x08, 
  };
  APPLY_PATCH(165);

  uint32_t patch166_addr = 0x0007BC3D;
  uint8_t patch166_data[] = {
    0x30, 0x50, 0x38, 
  };
  APPLY_PATCH(166);

  uint32_t patch167_addr = 0x0007BC41;
  uint8_t patch167_data[] = {
    0x38, 0x57, 0x72, 0x6E, 0x51, 0x38, 0x20, 0x18, 
  };
  APPLY_PATCH(167);

  uint32_t patch168_addr = 0x0007BC4D;
  uint8_t patch168_data[] = {
    0x18, 0x28, 0x10, 
  };
  APPLY_PATCH(168);

  uint32_t patch169_addr = 0x0007BC51;
  uint8_t patch169_data[] = {
    0x2E, 0x75, 0x19, 0x08, 
  };
  APPLY_PATCH(169);

  uint32_t patch170_addr = 0x0007BC56;
  uint8_t patch170_data[] = {
    0x0C, 
  };
  APPLY_PATCH(170);

  uint32_t patch171_addr = 0x0007BC58;
  uint8_t patch171_data[] = {
    0x04, 
  };
  APPLY_PATCH(171);

  uint32_t patch172_addr = 0x0007BC5A;
  uint8_t patch172_data[] = {
    0x04, 0x08, 0x3D, 
  };
  APPLY_PATCH(172);

  uint32_t patch173_addr = 0x0007BC5E;
  uint8_t patch173_data[] = {
    0x7C, 0x34, 
  };
  APPLY_PATCH(173);

  uint32_t patch174_addr = 0x0007BC61;
  uint8_t patch174_data[] = {
    0x04, 0x04, 0x04, 0x1C, 0x3C, 0x20, 0x7C, 
  };
  APPLY_PATCH(174);

  uint32_t patch175_addr = 0x0007BC69;
  uint8_t patch175_data[] = {
    0x58, 0x34, 0x30, 0x24, 
  };
  APPLY_PATCH(175);

  uint32_t patch176_addr = 0x0007BC72;
  uint8_t patch176_data[] = {
    0x21, 0x42, 0x62, 0x62, 0x65, 0x5D, 0x14, 0x4D, 0x34, 0x2C, 0x1C, 0x24, 0x14, 0x01, 
  };
  APPLY_PATCH(176);

  uint32_t patch177_addr = 0x0007BC83;
  uint8_t patch177_data[] = {
    0x01, 0x01, 0x02, 0x02, 0x02, 
  };
  APPLY_PATCH(177);

  uint32_t patch178_addr = 0x0007BC89;
  uint8_t patch178_data[] = {
    0x01, 0x01, 
  };
  APPLY_PATCH(178);

  uint32_t patch179_addr = 0x0007BC8F;
  uint8_t patch179_data[] = {
    0x01, 
  };
  APPLY_PATCH(179);

  uint32_t patch180_addr = 0x0007BE10;
  uint8_t patch180_data[] = {
    0x34, 0x08, 0x21, 0x57, 0x7F, 0x64, 0x25, 0x3D, 0x08, 0x10, 0x19, 0x62, 0x1E, 0x5F, 0x62, 0x39, 
    0x34, 0x04, 0x30, 0x67, 0x10, 0x09, 
  };
  APPLY_PATCH(180);

  uint32_t patch181_addr = 0x0007BE29;
  uint8_t patch181_data[] = {
    0x10, 0x10, 0x1C, 
  };
  APPLY_PATCH(181);

  uint32_t patch182_addr = 0x0007BE2D;
  uint8_t patch182_data[] = {
    0x1F, 0x0F, 0x02, 
  };
  APPLY_PATCH(182);

  uint32_t patch183_addr = 0x0007BE60;
  uint8_t patch183_data[] = {
    0x30, 0x10, 
  };
  APPLY_PATCH(183);

  uint32_t patch184_addr = 0x0007BE63;
  uint8_t patch184_data[] = {
    0x7F, 0x10, 0x09, 0x04, 0x18, 
  };
  APPLY_PATCH(184);

  uint32_t patch185_addr = 0x0007BE69;
  uint8_t patch185_data[] = {
    0x4B, 0x76, 0x21, 0x21, 0x11, 0x7B, 0x28, 
  };
  APPLY_PATCH(185);

  uint32_t patch186_addr = 0x0007BE80;
  uint8_t patch186_data[] = {
    0x30, 0x14, 0x25, 0x18, 0x7B, 0x18, 0x3D, 
  };
  APPLY_PATCH(186);

  uint32_t patch187_addr = 0x0007BE8B;
  uint8_t patch187_data[] = {
    0x04, 0x01, 0x18, 0x19, 0x0B, 
  };
  APPLY_PATCH(187);

  uint32_t patch188_addr = 0x0007BE91;
  uint8_t patch188_data[] = {
    0x34, 0x54, 0x75, 0x5C, 0x27, 0x1C, 0x15, 0x04, 
  };
  APPLY_PATCH(188);

  uint32_t patch189_addr = 0x0007BE9A;
  uint8_t patch189_data[] = {
    0x08, 
  };
  APPLY_PATCH(189);

  uint32_t patch190_addr = 0x0007BE9D;
  uint8_t patch190_data[] = {
    0x3C, 0x60, 0x27, 0x30, 0x19, 0x37, 0x17, 0x04, 0x05, 0x3C, 0x0C, 
  };
  APPLY_PATCH(190);

  uint32_t patch191_addr = 0x0007BEAA;
  uint8_t patch191_data[] = {
    0x04, 
  };
  APPLY_PATCH(191);

  uint32_t patch192_addr = 0x0007BEAC;
  uint8_t patch192_data[] = {
    0x01, 0x0C, 0x09, 0x18, 
  };
  APPLY_PATCH(192);

  uint32_t patch193_addr = 0x0007BEC0;
  uint8_t patch193_data[] = {
    0x30, 0x24, 0x60, 0x6C, 0x2D, 0x10, 
  };
  APPLY_PATCH(193);

  uint32_t patch194_addr = 0x0007BEC7;
  uint8_t patch194_data[] = {
    0x01, 0x04, 0x04, 
  };
  APPLY_PATCH(194);

  uint32_t patch195_addr = 0x0007BECC;
  uint8_t patch195_data[] = {
    0x3C, 0x0B, 0x0E, 0x29, 
  };
  APPLY_PATCH(195);

  uint32_t patch196_addr = 0x0007BED1;
  uint8_t patch196_data[] = {
    0x34, 0x54, 0x75, 0x5C, 0x27, 0x1C, 0x15, 0x04, 
  };
  APPLY_PATCH(196);

  uint32_t patch197_addr = 0x0007BEDA;
  uint8_t patch197_data[] = {
    0x08, 
  };
  APPLY_PATCH(197);

  uint32_t patch198_addr = 0x0007BEDD;
  uint8_t patch198_data[] = {
    0x3C, 0x60, 0x27, 0x30, 0x1D, 0x37, 0x17, 0x79, 0x19, 0x3C, 0x0C, 
  };
  APPLY_PATCH(198);

  uint32_t patch199_addr = 0x0007BEEA;
  uint8_t patch199_data[] = {
    0x04, 
  };
  APPLY_PATCH(199);

  uint32_t patch200_addr = 0x0007BEEC;
  uint8_t patch200_data[] = {
    0x3D, 0x08, 0x10, 0x18, 
  };
  APPLY_PATCH(200);

  uint32_t patch201_addr = 0x0007D201;
  uint8_t patch201_data[] = {
    0x3C, 0x28, 0x68, 0x60, 0x14, 0x0C, 0x04, 
  };
  APPLY_PATCH(201);

  uint32_t patch202_addr = 0x0007D209;
  uint8_t patch202_data[] = {
    0x04, 0x0C, 0x1C, 0x0C, 0x1C, 0x0C, 0x30, 0x10, 0x14, 0x14, 0x14, 0x28, 0x28, 0x14, 0x28, 0x28, 
    0x28, 0x28, 0x28, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 
    0x3C, 0x20, 0x3C, 0x3C, 0x3C, 0x38, 0x24, 0x24, 0x24, 0x24, 0x28, 0x28, 0x28, 0x28, 0x2C, 0x2C, 
    0x50, 0x2C, 0x2C, 0x50, 0x2C, 0x50, 0x50, 0x50, 0x50, 0x50, 0x50, 0x5C, 0x5C, 0x5C, 0x5C, 0x58, 
    0x54, 0x58, 0x58, 0x44, 0x68, 0x44, 0x44, 0x48, 0x4C, 0x4C, 0x4C, 0x4C, 0x70, 0x40, 0x4C, 0x40, 
    0x44, 0x40, 0x44, 0x44, 0x74, 0x44, 0x44, 0x44, 0x78, 0x40, 0x40, 0x7C, 0x7C, 0x78, 0x78, 0x7C, 
    0x78, 0x70, 0x7C, 0x7C, 0x7C, 0x78, 0x78, 0x78, 0x40, 0x74, 0x78, 0x44, 0x74, 0x74, 0x48, 0x74, 
    0x44, 0x44, 0x6C, 0x48, 0x4C, 0x40, 0x4C, 0x48, 0x4C, 0x6C, 0x6C, 0x4C, 0x4C, 0x4C, 0x48, 0x48, 
    0x40, 0x48, 0x48, 0x44, 0x44, 0x50, 0x54, 0x44, 0x44, 0x54, 0x40, 0x58, 0x58, 0x54, 0x5C, 0x58, 
    0x50, 0x58, 0x58, 0x5C, 0x5C, 0x5C, 0x20, 0x40, 0x5C, 0x54, 0x5C, 0x58, 0x40, 0x5C, 0x54, 0x58, 
    0x44, 0x54, 0x54, 0x44, 0x44, 0x50, 0x48, 0x40, 0x48, 0x48, 0x4C, 0x4C, 0x4C, 0x50, 0x28, 0x24, 
    0x4C, 0x4C, 0x30, 0x40, 0x48, 0x30, 0x48, 0x48, 0x34, 0x44, 0x34, 0x34, 0x44, 0x44, 0x30, 0x30, 
    0x3C, 0x40, 0x38, 0x30, 0x3C, 0x3C, 0x3C, 0x3C, 0x30, 0x3C, 0x28, 0x30, 0x38, 0x38, 0x30, 0x24, 
    0x34, 0x34, 0x34, 0x34, 0x24, 0x2C, 0x30, 0x28, 0x2C, 0x30, 0x2C, 0x2C, 0x2C, 0x2C, 0x28, 0x28, 
    0x20, 0x24, 0x24, 0x24, 0x18, 0x20, 0x18, 0x18, 0x1C, 0x1C, 0x18, 0x10, 0x18, 0x14, 0x14, 0x10, 
    0x0C, 0x0C, 0x04, 0x08, 0x04, 
  };
  APPLY_PATCH(202);

  uint32_t patch203_addr = 0x0007D301;
  uint8_t patch203_data[] = {
    0x58, 0x04, 0x1C, 0x04, 0x0C, 0x04, 0x3C, 
  };
  APPLY_PATCH(203);

  uint32_t patch204_addr = 0x0007D309;
  uint8_t patch204_data[] = {
    0x18, 0x38, 0x14, 0x6C, 0x70, 0x10, 0x3C, 
  };
  APPLY_PATCH(204);

  uint32_t patch205_addr = 0x0007D313;
  uint8_t patch205_data[] = {
    0x0C, 0x0C, 0x0C, 0x10, 0x1C, 0x1C, 0x28, 0x14, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x24, 0x24, 
    0x24, 0x38, 0x24, 0x28, 0x24, 0x20, 0x20, 0x20, 0x3C, 0x20, 0x3C, 0x20, 0x3C, 0x3C, 0x3C, 0x3C, 
    0x24, 0x20, 0x24, 0x38, 0x24, 0x24, 0x24, 0x24, 0x28, 0x28, 0x28, 0x28, 0x2C, 0x28, 0x2C, 0x2C, 
    0x50, 0x2C, 0x2C, 0x50, 0x50, 0x50, 0x50, 0x50, 0x50, 0x50, 0x50, 0x50, 0x50, 0x5C, 0x50, 0x50, 
    0x50, 0x5C, 0x5C, 0x50, 0x50, 0x58, 0x58, 0x58, 0x54, 0x44, 0x44, 0x4C, 0x48, 0x44, 0x48, 0x4C, 
    0x4C, 0x70, 0x4C, 0x40, 0x40, 0x70, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0x40, 0x7C, 0x7C, 0x78, 
    0x7C, 0x70, 0x78, 0x78, 0x7C, 0x40, 0x7C, 0x70, 0x78, 0x78, 0x40, 0x74, 0x78, 0x44, 0x48, 0x70, 
    0x74, 0x44, 0x44, 0x70, 0x48, 0x6C, 0x48, 0x40, 0x48, 0x70, 0x48, 0x4C, 0x4C, 0x4C, 0x4C, 0x44, 
    0x6C, 0x48, 0x40, 0x6C, 0x48, 0x50, 0x48, 0x44, 0x50, 0x44, 0x54, 0x54, 0x58, 0x44, 0x40, 0x54, 
    0x58, 0x50, 0x5C, 0x58, 0x50, 0x58, 0x5C, 0x5C, 0x5C, 0x5C, 0x5C, 0x5C, 0x5C, 0x58, 0x58, 0x40, 
    0x58, 0x50, 0x58, 0x44, 0x54, 0x50, 0x54, 0x44, 0x44, 0x54, 0x48, 0x40, 0x4C, 0x48, 0x2C, 0x50, 
    0x48, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x30, 0x48, 0x40, 0x48, 0x48, 0x38, 0x44, 0x34, 0x44, 0x44, 
    0x30, 0x40, 0x38, 0x30, 0x3C, 0x3C, 0x3C, 0x3C, 0x20, 0x3C, 0x30, 0x38, 0x38, 0x30, 0x24, 0x34, 
    0x34, 0x30, 0x28, 0x28, 0x30, 0x2C, 0x14, 0x2C, 0x2C, 0x28, 0x14, 0x20, 0x24, 0x24, 0x24, 0x18, 
    0x20, 0x1C, 0x18, 0x14, 0x18, 0x14, 0x10, 0x0C, 0x0C, 0x08, 0x04, 
  };
  APPLY_PATCH(205);
}

void patch_u51()
{
  uint32_t patch0_addr = 0x0001362C;
  uint8_t patch0_data[] = {
    0x0A, 0x0A, 0x90, 0x99, 
  };
  APPLY_PATCH(0);

  uint32_t patch1_addr = 0x00013644;
  uint8_t patch1_data[] = {
    0x0A, 0x0A, 0x90, 0x90, 
  };
  APPLY_PATCH(1);

  uint32_t patch2_addr = 0x0001365C;
  uint8_t patch2_data[] = {
    0x0A, 0x0A, 0x90, 0x90, 0x44, 0x04, 0x20, 0x22, 
  };
  APPLY_PATCH(2);

  uint32_t patch3_addr = 0x00013674;
  uint8_t patch3_data[] = {
    0xA0, 
  };
  APPLY_PATCH(3);

  uint32_t patch4_addr = 0x00013677;
  uint8_t patch4_data[] = {
    0x09, 0x04, 
  };
  APPLY_PATCH(4);

  uint32_t patch5_addr = 0x0001367A;
  uint8_t patch5_data[] = {
    0x20, 0x22, 
  };
  APPLY_PATCH(5);

  uint32_t patch6_addr = 0x0001368C;
  uint8_t patch6_data[] = {
    0x0A, 0x0A, 0x90, 0x90, 0x04, 0x04, 
  };
  APPLY_PATCH(6);

  uint32_t patch7_addr = 0x000136A4;
  uint8_t patch7_data[] = {
    0x0A, 0x0A, 
  };
  APPLY_PATCH(7);

  uint32_t patch8_addr = 0x000136A7;
  uint8_t patch8_data[] = {
    0x99, 0x40, 0x04, 
  };
  APPLY_PATCH(8);

  uint32_t patch9_addr = 0x000136AB;
  uint8_t patch9_data[] = {
    0x20, 
  };
  APPLY_PATCH(9);

  uint32_t patch10_addr = 0x000136BC;
  uint8_t patch10_data[] = {
    0x0A, 0x0A, 
  };
  APPLY_PATCH(10);

  uint32_t patch11_addr = 0x000136BF;
  uint8_t patch11_data[] = {
    0x99, 0x44, 
  };
  APPLY_PATCH(11);

  uint32_t patch12_addr = 0x000136D7;
  uint8_t patch12_data[] = {
    0x09, 
  };
  APPLY_PATCH(12);

  uint32_t patch13_addr = 0x000136EE;
  uint8_t patch13_data[] = {
    0x90, 0x09, 0x04, 
  };
  APPLY_PATCH(13);

  uint32_t patch14_addr = 0x000136F2;
  uint8_t patch14_data[] = {
    0x20, 0x20, 
  };
  APPLY_PATCH(14);

  uint32_t patch15_addr = 0x00013704;
  uint8_t patch15_data[] = {
    0xAA, 0x0A, 
  };
  APPLY_PATCH(15);

  uint32_t patch16_addr = 0x00013707;
  uint8_t patch16_data[] = {
    0x90, 0x40, 0x04, 
  };
  APPLY_PATCH(16);

  uint32_t patch17_addr = 0x0001370B;
  uint8_t patch17_data[] = {
    0x02, 
  };
  APPLY_PATCH(17);

  uint32_t patch18_addr = 0x0001371C;
  uint8_t patch18_data[] = {
    0x0A, 
  };
  APPLY_PATCH(18);

  uint32_t patch19_addr = 0x0001371F;
  uint8_t patch19_data[] = {
    0x90, 0x04, 
  };
  APPLY_PATCH(19);

  uint32_t patch20_addr = 0x00013723;
  uint8_t patch20_data[] = {
    0x02, 
  };
  APPLY_PATCH(20);

  uint32_t patch21_addr = 0x00013734;
  uint8_t patch21_data[] = {
    0xA0, 0x0A, 0x90, 0x09, 0x40, 0x04, 0x20, 0x20, 
  };
  APPLY_PATCH(21);

  uint32_t patch22_addr = 0x0001374E;
  uint8_t patch22_data[] = {
    0x90, 0x90, 0x04, 
  };
  APPLY_PATCH(22);

  uint32_t patch23_addr = 0x00013753;
  uint8_t patch23_data[] = {
    0x20, 
  };
  APPLY_PATCH(23);

  uint32_t patch24_addr = 0x00013767;
  uint8_t patch24_data[] = {
    0x99, 0x44, 
  };
  APPLY_PATCH(24);

  uint32_t patch25_addr = 0x0001376B;
  uint8_t patch25_data[] = {
    0x20, 
  };
  APPLY_PATCH(25);

  uint32_t patch26_addr = 0x0001377C;
  uint8_t patch26_data[] = {
    0x0A, 0x0A, 0x90, 0x99, 0x04, 0x04, 0x20, 0x20, 
  };
  APPLY_PATCH(26);

  uint32_t patch27_addr = 0x00013798;
  uint8_t patch27_data[] = {
    0x40, 
  };
  APPLY_PATCH(27);

  uint32_t patch28_addr = 0x000137B0;
  uint8_t patch28_data[] = {
    0x04, 
  };
  APPLY_PATCH(28);

  uint32_t patch29_addr = 0x000137B2;
  uint8_t patch29_data[] = {
    0x20, 0x20, 
  };
  APPLY_PATCH(29);

  uint32_t patch30_addr = 0x000137C8;
  uint8_t patch30_data[] = {
    0x40, 0x04, 
  };
  APPLY_PATCH(30);

  uint32_t patch31_addr = 0x000137CB;
  uint8_t patch31_data[] = {
    0x02, 
  };
  APPLY_PATCH(31);

  uint32_t patch32_addr = 0x000137E0;
  uint8_t patch32_data[] = {
    0x44, 0x04, 
  };
  APPLY_PATCH(32);

  uint32_t patch33_addr = 0x000137F4;
  uint8_t patch33_data[] = {
    0x0A, 
  };
  APPLY_PATCH(33);

  uint32_t patch34_addr = 0x000137F7;
  uint8_t patch34_data[] = {
    0x99, 0x04, 
  };
  APPLY_PATCH(34);

  uint32_t patch35_addr = 0x000137FB;
  uint8_t patch35_data[] = {
    0x02, 
  };
  APPLY_PATCH(35);

  uint32_t patch36_addr = 0x0001380C;
  uint8_t patch36_data[] = {
    0xAA, 0x0A, 0x90, 0x99, 0x40, 0x04, 0x20, 0x20, 
  };
  APPLY_PATCH(36);

  uint32_t patch37_addr = 0x00013824;
  uint8_t patch37_data[] = {
    0xAA, 0x0A, 0x90, 0x99, 0x44, 0x04, 0x20, 0x22, 
  };
  APPLY_PATCH(37);

  uint32_t patch38_addr = 0x0001383E;
  uint8_t patch38_data[] = {
    0x90, 0x90, 0x40, 0x04, 0x20, 0x02, 
  };
  APPLY_PATCH(38);

  uint32_t patch39_addr = 0x00013854;
  uint8_t patch39_data[] = {
    0xAA, 
  };
  APPLY_PATCH(39);

  uint32_t patch40_addr = 0x00013856;
  uint8_t patch40_data[] = {
    0x90, 0x09, 0x44, 0x04, 0x20, 0x02, 
  };
  APPLY_PATCH(40);

  uint32_t patch41_addr = 0x00013870;
  uint8_t patch41_data[] = {
    0x44, 
  };
  APPLY_PATCH(41);

  uint32_t patch42_addr = 0x00013886;
  uint8_t patch42_data[] = {
    0x90, 0x09, 0x04, 0x04, 0x20, 0x22, 
  };
  APPLY_PATCH(42);

  uint32_t patch43_addr = 0x0001389C;
  uint8_t patch43_data[] = {
    0xAA, 0x0A, 
  };
  APPLY_PATCH(43);

  uint32_t patch44_addr = 0x0001389F;
  uint8_t patch44_data[] = {
    0x90, 
  };
  APPLY_PATCH(44);

  uint32_t patch45_addr = 0x000138B5;
  uint8_t patch45_data[] = {
    0x0A, 0x90, 
  };
  APPLY_PATCH(45);

  uint32_t patch46_addr = 0x000138CC;
  uint8_t patch46_data[] = {
    0x0A, 0x0A, 0x90, 
  };
  APPLY_PATCH(46);

  uint32_t patch47_addr = 0x000138E4;
  uint8_t patch47_data[] = {
    0xAA, 0x0A, 0x90, 
  };
  APPLY_PATCH(47);

  uint32_t patch48_addr = 0x001BCE56;
  uint8_t patch48_data[] = {
    0xE0, 
  };
  APPLY_PATCH(48);

  uint32_t patch49_addr = 0x001BCE7E;
  uint8_t patch49_data[] = {
    0xE0, 
  };
  APPLY_PATCH(49);

  uint32_t patch50_addr = 0x001BCEA6;
  uint8_t patch50_data[] = {
    0x0D, 
  };
  APPLY_PATCH(50);

  uint32_t patch51_addr = 0x001BCEAB;
  uint8_t patch51_data[] = {
    0x90, 
  };
  APPLY_PATCH(51);

  uint32_t patch52_addr = 0x001BCED0;
  uint8_t patch52_data[] = {
    0x0A, 0xC0, 
  };
  APPLY_PATCH(52);

  uint32_t patch53_addr = 0x001BCEF8;
  uint8_t patch53_data[] = {
    0xAA, 0x0B, 
  };
  APPLY_PATCH(53);

  uint32_t patch54_addr = 0x001BCF21;
  uint8_t patch54_data[] = {
    0x0B, 0x99, 0x99, 
  };
  APPLY_PATCH(54);

  uint32_t patch55_addr = 0x001BCF25;
  uint8_t patch55_data[] = {
    0x90, 
  };
  APPLY_PATCH(55);

  uint32_t patch56_addr = 0x001BCF46;
  uint8_t patch56_data[] = {
    0x0D, 
  };
  APPLY_PATCH(56);

  uint32_t patch57_addr = 0x001BCF49;
  uint8_t patch57_data[] = {
    0xC0, 
  };
  APPLY_PATCH(57);

  uint32_t patch58_addr = 0x001BCF98;
  uint8_t patch58_data[] = {
    0xA0, 
  };
  APPLY_PATCH(58);

  uint32_t patch59_addr = 0x001BCFA8;
  uint8_t patch59_data[] = {
    0x0F, 
  };
  APPLY_PATCH(59);

  uint32_t patch60_addr = 0x001BCFAA;
  uint8_t patch60_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(60);

  uint32_t patch61_addr = 0x001BCFC0;
  uint8_t patch61_data[] = {
    0x0A, 
  };
  APPLY_PATCH(61);

  uint32_t patch62_addr = 0x001BCFD0;
  uint8_t patch62_data[] = {
    0xF0, 
  };
  APPLY_PATCH(62);

  uint32_t patch63_addr = 0x001BCFD2;
  uint8_t patch63_data[] = {
    0x0D, 
  };
  APPLY_PATCH(63);

  uint32_t patch64_addr = 0x001BCFD4;
  uint8_t patch64_data[] = {
    0xC0, 0x0C, 
  };
  APPLY_PATCH(64);

  uint32_t patch65_addr = 0x001BCFE3;
  uint8_t patch65_data[] = {
    0x0A, 
  };
  APPLY_PATCH(65);

  uint32_t patch66_addr = 0x001BCFEB;
  uint8_t patch66_data[] = {
    0x90, 
  };
  APPLY_PATCH(66);

  uint32_t patch67_addr = 0x001BCFF8;
  uint8_t patch67_data[] = {
    0xF0, 
  };
  APPLY_PATCH(67);

  uint32_t patch68_addr = 0x001BCFFA;
  uint8_t patch68_data[] = {
    0x0D, 
  };
  APPLY_PATCH(68);

  uint32_t patch69_addr = 0x001BD00A;
  uint8_t patch69_data[] = {
    0x90, 
  };
  APPLY_PATCH(69);

  uint32_t patch70_addr = 0x001BD00E;
  uint8_t patch70_data[] = {
    0xED, 
  };
  APPLY_PATCH(70);

  uint32_t patch71_addr = 0x001BD010;
  uint8_t patch71_data[] = {
    0xAA, 0xCB, 
  };
  APPLY_PATCH(71);

  uint32_t patch72_addr = 0x001BD013;
  uint8_t patch72_data[] = {
    0x09, 
  };
  APPLY_PATCH(72);

  uint32_t patch73_addr = 0x001BD030;
  uint8_t patch73_data[] = {
    0xCB, 0xED, 0x09, 0xAA, 
  };
  APPLY_PATCH(73);

  uint32_t patch74_addr = 0x001BD035;
  uint8_t patch74_data[] = {
    0x90, 
  };
  APPLY_PATCH(74);

  uint32_t patch75_addr = 0x001BD03A;
  uint8_t patch75_data[] = {
    0x99, 
  };
  APPLY_PATCH(75);

  uint32_t patch76_addr = 0x001BD03D;
  uint8_t patch76_data[] = {
    0x90, 
  };
  APPLY_PATCH(76);

  uint32_t patch77_addr = 0x001BD04A;
  uint8_t patch77_data[] = {
    0x0D, 
  };
  APPLY_PATCH(77);

  uint32_t patch78_addr = 0x001BD05C;
  uint8_t patch78_data[] = {
    0x90, 0x09, 
  };
  APPLY_PATCH(78);

  uint32_t patch79_addr = 0x001BD074;
  uint8_t patch79_data[] = {
    0x0C, 
  };
  APPLY_PATCH(79);

  uint32_t patch80_addr = 0x001BD082;
  uint8_t patch80_data[] = {
    0x90, 
  };
  APPLY_PATCH(80);

  uint32_t patch81_addr = 0x001BD09A;
  uint8_t patch81_data[] = {
    0x0D, 
  };
  APPLY_PATCH(81);

  uint32_t patch82_addr = 0x001BD09C;
  uint8_t patch82_data[] = {
    0x0C, 
  };
  APPLY_PATCH(82);

  uint32_t patch83_addr = 0x001BD0AA;
  uint8_t patch83_data[] = {
    0x90, 
  };
  APPLY_PATCH(83);

  uint32_t patch84_addr = 0x001BD0AD;
  uint8_t patch84_data[] = {
    0x09, 0xE0, 
  };
  APPLY_PATCH(84);

  uint32_t patch85_addr = 0x001BD0B2;
  uint8_t patch85_data[] = {
    0x90, 
  };
  APPLY_PATCH(85);

  uint32_t patch86_addr = 0x001BD0D0;
  uint8_t patch86_data[] = {
    0xCB, 0xED, 0x99, 0xA0, 
  };
  APPLY_PATCH(86);

  uint32_t patch87_addr = 0x001BD0D5;
  uint8_t patch87_data[] = {
    0x99, 0xE0, 
  };
  APPLY_PATCH(87);

  uint32_t patch88_addr = 0x001BD0DA;
  uint8_t patch88_data[] = {
    0x90, 
  };
  APPLY_PATCH(88);

  uint32_t patch89_addr = 0x001BD0EA;
  uint8_t patch89_data[] = {
    0xDD, 0xEE, 
  };
  APPLY_PATCH(89);

  uint32_t patch90_addr = 0x001BD0ED;
  uint8_t patch90_data[] = {
    0xCC, 
  };
  APPLY_PATCH(90);

  uint32_t patch91_addr = 0x001BD0F9;
  uint8_t patch91_data[] = {
    0xE0, 0x90, 0xA0, 0x99, 0x09, 0xE0, 
  };
  APPLY_PATCH(91);

  uint32_t patch92_addr = 0x001BD110;
  uint8_t patch92_data[] = {
    0xFF, 
  };
  APPLY_PATCH(92);

  uint32_t patch93_addr = 0x001BD112;
  uint8_t patch93_data[] = {
    0xD0, 0xEE, 
  };
  APPLY_PATCH(93);

  uint32_t patch94_addr = 0x001BD121;
  uint8_t patch94_data[] = {
    0xE0, 0x90, 0xA0, 
  };
  APPLY_PATCH(94);

  uint32_t patch95_addr = 0x001BD125;
  uint8_t patch95_data[] = {
    0x09, 0x0D, 
  };
  APPLY_PATCH(95);

  uint32_t patch96_addr = 0x001BD138;
  uint8_t patch96_data[] = {
    0xFF, 
  };
  APPLY_PATCH(96);

  uint32_t patch97_addr = 0x001BD13A;
  uint8_t patch97_data[] = {
    0xD0, 0xEE, 0xC0, 0x0C, 
  };
  APPLY_PATCH(97);

  uint32_t patch98_addr = 0x001BD148;
  uint8_t patch98_data[] = {
    0xCB, 0xED, 0x99, 0xA0, 
  };
  APPLY_PATCH(98);

  uint32_t patch99_addr = 0x001BD14D;
  uint8_t patch99_data[] = {
    0x99, 
  };
  APPLY_PATCH(99);

  uint32_t patch100_addr = 0x001BD151;
  uint8_t patch100_data[] = {
    0xC0, 
  };
  APPLY_PATCH(100);

  uint32_t patch101_addr = 0x001BD160;
  uint8_t patch101_data[] = {
    0x0F, 
  };
  APPLY_PATCH(101);

  uint32_t patch102_addr = 0x001BD162;
  uint8_t patch102_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(102);

  uint32_t patch103_addr = 0x001BD172;
  uint8_t patch103_data[] = {
    0x90, 
  };
  APPLY_PATCH(103);

  uint32_t patch104_addr = 0x001BD175;
  uint8_t patch104_data[] = {
    0x09, 
  };
  APPLY_PATCH(104);

  uint32_t patch105_addr = 0x001BD178;
  uint8_t patch105_data[] = {
    0xAA, 0x0B, 
  };
  APPLY_PATCH(105);

  uint32_t patch106_addr = 0x001BD17B;
  uint8_t patch106_data[] = {
    0x99, 
  };
  APPLY_PATCH(106);

  uint32_t patch107_addr = 0x001BD188;
  uint8_t patch107_data[] = {
    0x0F, 
  };
  APPLY_PATCH(107);

  uint32_t patch108_addr = 0x001BD18A;
  uint8_t patch108_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(108);

  uint32_t patch109_addr = 0x001BD19A;
  uint8_t patch109_data[] = {
    0x90, 
  };
  APPLY_PATCH(109);

  uint32_t patch110_addr = 0x001BD1B0;
  uint8_t patch110_data[] = {
    0xF0, 
  };
  APPLY_PATCH(110);

  uint32_t patch111_addr = 0x001BD1B4;
  uint8_t patch111_data[] = {
    0x0C, 
  };
  APPLY_PATCH(111);

  uint32_t patch112_addr = 0x001BD1C6;
  uint8_t patch112_data[] = {
    0xE0, 
  };
  APPLY_PATCH(112);

  uint32_t patch113_addr = 0x001BD1CA;
  uint8_t patch113_data[] = {
    0x09, 0x90, 
  };
  APPLY_PATCH(113);

  uint32_t patch114_addr = 0x001BD1EE;
  uint8_t patch114_data[] = {
    0xE0, 
  };
  APPLY_PATCH(114);

  uint32_t patch115_addr = 0x001BD1F2;
  uint8_t patch115_data[] = {
    0x09, 0x90, 
  };
  APPLY_PATCH(115);

  uint32_t patch116_addr = 0x001BD200;
  uint8_t patch116_data[] = {
    0xF0, 
  };
  APPLY_PATCH(116);

  uint32_t patch117_addr = 0x001BD202;
  uint8_t patch117_data[] = {
    0xD0, 0x0E, 0xC0, 
  };
  APPLY_PATCH(117);

  uint32_t patch118_addr = 0x001BD210;
  uint8_t patch118_data[] = {
    0xCB, 
  };
  APPLY_PATCH(118);

  uint32_t patch119_addr = 0x001BD213;
  uint8_t patch119_data[] = {
    0xAA, 
  };
  APPLY_PATCH(119);

  uint32_t patch120_addr = 0x001BD215;
  uint8_t patch120_data[] = {
    0x09, 0xE0, 
  };
  APPLY_PATCH(120);

  uint32_t patch121_addr = 0x001BD21A;
  uint8_t patch121_data[] = {
    0x09, 0x90, 
  };
  APPLY_PATCH(121);

  uint32_t patch122_addr = 0x001BD228;
  uint8_t patch122_data[] = {
    0x0F, 
  };
  APPLY_PATCH(122);

  uint32_t patch123_addr = 0x001BD22A;
  uint8_t patch123_data[] = {
    0xD0, 0xEE, 0xC0, 0x0C, 
  };
  APPLY_PATCH(123);

  uint32_t patch124_addr = 0x001BD239;
  uint8_t patch124_data[] = {
    0x0D, 0x99, 
  };
  APPLY_PATCH(124);

  uint32_t patch125_addr = 0x001BD23D;
  uint8_t patch125_data[] = {
    0x90, 0x0D, 
  };
  APPLY_PATCH(125);

  uint32_t patch126_addr = 0x001BD269;
  uint8_t patch126_data[] = {
    0xC0, 
  };
  APPLY_PATCH(126);

  uint32_t patch127_addr = 0x001BD288;
  uint8_t patch127_data[] = {
    0x0B, 
  };
  APPLY_PATCH(127);

  uint32_t patch128_addr = 0x001BD28A;
  uint8_t patch128_data[] = {
    0x09, 
  };
  APPLY_PATCH(128);

  uint32_t patch129_addr = 0x001BD290;
  uint8_t patch129_data[] = {
    0xAA, 0x0B, 
  };
  APPLY_PATCH(129);

  uint32_t patch130_addr = 0x001BD293;
  uint8_t patch130_data[] = {
    0x99, 
  };
  APPLY_PATCH(130);

  uint32_t patch131_addr = 0x001BD2A0;
  uint8_t patch131_data[] = {
    0xF0, 
  };
  APPLY_PATCH(131);

  uint32_t patch132_addr = 0x001BD2B0;
  uint8_t patch132_data[] = {
    0xC0, 
  };
  APPLY_PATCH(132);

  uint32_t patch133_addr = 0x001BD2B2;
  uint8_t patch133_data[] = {
    0x09, 
  };
  APPLY_PATCH(133);

  uint32_t patch134_addr = 0x001BD2C8;
  uint8_t patch134_data[] = {
    0xF0, 
  };
  APPLY_PATCH(134);

  uint32_t patch135_addr = 0x001BD2D9;
  uint8_t patch135_data[] = {
    0x0D, 
  };
  APPLY_PATCH(135);

  uint32_t patch136_addr = 0x001BD2DD;
  uint8_t patch136_data[] = {
    0x90, 0xE0, 
  };
  APPLY_PATCH(136);

  uint32_t patch137_addr = 0x001BD2E1;
  uint8_t patch137_data[] = {
    0x0B, 
  };
  APPLY_PATCH(137);

  uint32_t patch138_addr = 0x001BD2E3;
  uint8_t patch138_data[] = {
    0x90, 
  };
  APPLY_PATCH(138);

  uint32_t patch139_addr = 0x001BD301;
  uint8_t patch139_data[] = {
    0x0D, 
  };
  APPLY_PATCH(139);

  uint32_t patch140_addr = 0x001BD305;
  uint8_t patch140_data[] = {
    0x90, 0xE0, 
  };
  APPLY_PATCH(140);

  uint32_t patch141_addr = 0x001BD309;
  uint8_t patch141_data[] = {
    0x0B, 
  };
  APPLY_PATCH(141);

  uint32_t patch142_addr = 0x001BD30B;
  uint8_t patch142_data[] = {
    0x90, 
  };
  APPLY_PATCH(142);

  uint32_t patch143_addr = 0x001BD329;
  uint8_t patch143_data[] = {
    0x0D, 
  };
  APPLY_PATCH(143);

  uint32_t patch144_addr = 0x001BD32D;
  uint8_t patch144_data[] = {
    0x90, 0xE0, 
  };
  APPLY_PATCH(144);

  uint32_t patch145_addr = 0x001BD331;
  uint8_t patch145_data[] = {
    0x0B, 
  };
  APPLY_PATCH(145);

  uint32_t patch146_addr = 0x001BD333;
  uint8_t patch146_data[] = {
    0x90, 
  };
  APPLY_PATCH(146);

  uint32_t patch147_addr = 0x001BD342;
  uint8_t patch147_data[] = {
    0xD0, 0x0E, 
  };
  APPLY_PATCH(147);

  uint32_t patch148_addr = 0x001BD356;
  uint8_t patch148_data[] = {
    0xED, 
  };
  APPLY_PATCH(148);

  uint32_t patch149_addr = 0x001BD358;
  uint8_t patch149_data[] = {
    0xAA, 0xCB, 
  };
  APPLY_PATCH(149);

  uint32_t patch150_addr = 0x001BD35B;
  uint8_t patch150_data[] = {
    0x90, 
  };
  APPLY_PATCH(150);

  uint32_t patch151_addr = 0x001BD368;
  uint8_t patch151_data[] = {
    0x0F, 
  };
  APPLY_PATCH(151);

  uint32_t patch152_addr = 0x001BD36B;
  uint8_t patch152_data[] = {
    0xF0, 0x0C, 
  };
  APPLY_PATCH(152);

  uint32_t patch153_addr = 0x001BD394;
  uint8_t patch153_data[] = {
    0xCC, 0x0C, 
  };
  APPLY_PATCH(153);

  uint32_t patch154_addr = 0x001BD3A1;
  uint8_t patch154_data[] = {
    0x60, 0x10, 0x22, 
  };
  APPLY_PATCH(154);

  uint32_t patch155_addr = 0x001BD3A5;
  uint8_t patch155_data[] = {
    0x01, 
  };
  APPLY_PATCH(155);

  uint32_t patch156_addr = 0x001BD3A8;
  uint8_t patch156_data[] = {
    0xAA, 
  };
  APPLY_PATCH(156);

  uint32_t patch157_addr = 0x001BD3AB;
  uint8_t patch157_data[] = {
    0x90, 
  };
  APPLY_PATCH(157);

  uint32_t patch158_addr = 0x001BD3B8;
  uint8_t patch158_data[] = {
    0x0F, 
  };
  APPLY_PATCH(158);

  uint32_t patch159_addr = 0x001BD3BB;
  uint8_t patch159_data[] = {
    0x0E, 
  };
  APPLY_PATCH(159);

  uint32_t patch160_addr = 0x001BD3C9;
  uint8_t patch160_data[] = {
    0x60, 0x10, 0x20, 
  };
  APPLY_PATCH(160);

  uint32_t patch161_addr = 0x001BD3CD;
  uint8_t patch161_data[] = {
    0x01, 
  };
  APPLY_PATCH(161);

  uint32_t patch162_addr = 0x001BD3E0;
  uint8_t patch162_data[] = {
    0xF0, 
  };
  APPLY_PATCH(162);

  uint32_t patch163_addr = 0x001BD3E2;
  uint8_t patch163_data[] = {
    0x0D, 0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(163);

  uint32_t patch164_addr = 0x001BD3F0;
  uint8_t patch164_data[] = {
    0x43, 0x05, 0x11, 0x20, 
  };
  APPLY_PATCH(164);

  uint32_t patch165_addr = 0x001BD3F5;
  uint8_t patch165_data[] = {
    0x11, 0xE0, 
  };
  APPLY_PATCH(165);

  uint32_t patch166_addr = 0x001BD3F8;
  uint8_t patch166_data[] = {
    0xAA, 
  };
  APPLY_PATCH(166);

  uint32_t patch167_addr = 0x001BD3FB;
  uint8_t patch167_data[] = {
    0x90, 
  };
  APPLY_PATCH(167);

  uint32_t patch168_addr = 0x001BD408;
  uint8_t patch168_data[] = {
    0x0F, 
  };
  APPLY_PATCH(168);

  uint32_t patch169_addr = 0x001BD40B;
  uint8_t patch169_data[] = {
    0x03, 0xCC, 0x2C, 
  };
  APPLY_PATCH(169);

  uint32_t patch170_addr = 0x001BD41E;
  uint8_t patch170_data[] = {
    0x0D, 
  };
  APPLY_PATCH(170);

  uint32_t patch171_addr = 0x001BD432;
  uint8_t patch171_data[] = {
    0xDD, 0x0E, 0x0C, 
  };
  APPLY_PATCH(171);

  uint32_t patch172_addr = 0x001BD441;
  uint8_t patch172_data[] = {
    0x60, 0x10, 0x22, 
  };
  APPLY_PATCH(172);

  uint32_t patch173_addr = 0x001BD445;
  uint8_t patch173_data[] = {
    0x10, 
  };
  APPLY_PATCH(173);

  uint32_t patch174_addr = 0x001BD448;
  uint8_t patch174_data[] = {
    0xAA, 0xCB, 
  };
  APPLY_PATCH(174);

  uint32_t patch175_addr = 0x001BD44B;
  uint8_t patch175_data[] = {
    0x90, 
  };
  APPLY_PATCH(175);

  uint32_t patch176_addr = 0x001BD458;
  uint8_t patch176_data[] = {
    0xFF, 
  };
  APPLY_PATCH(176);

  uint32_t patch177_addr = 0x001BD45B;
  uint8_t patch177_data[] = {
    0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(177);

  uint32_t patch178_addr = 0x001BD469;
  uint8_t patch178_data[] = {
    0x60, 0x10, 0x20, 
  };
  APPLY_PATCH(178);

  uint32_t patch179_addr = 0x001BD46D;
  uint8_t patch179_data[] = {
    0x11, 
  };
  APPLY_PATCH(179);

  uint32_t patch180_addr = 0x001BD484;
  uint8_t patch180_data[] = {
    0xC0, 
  };
  APPLY_PATCH(180);

  uint32_t patch181_addr = 0x001BD490;
  uint8_t patch181_data[] = {
    0x43, 0x65, 0x11, 0x22, 0x10, 0x10, 0xED, 
  };
  APPLY_PATCH(181);

  uint32_t patch182_addr = 0x001BD498;
  uint8_t patch182_data[] = {
    0xAA, 0xCB, 0x99, 0x99, 
  };
  APPLY_PATCH(182);

  uint32_t patch183_addr = 0x001BD4A8;
  uint8_t patch183_data[] = {
    0x0F, 
  };
  APPLY_PATCH(183);

  uint32_t patch184_addr = 0x001BD4AA;
  uint8_t patch184_data[] = {
    0xD0, 0xE0, 0xC0, 
  };
  APPLY_PATCH(184);

  uint32_t patch185_addr = 0x001BD4B9;
  uint8_t patch185_data[] = {
    0x05, 0x10, 0x20, 
  };
  APPLY_PATCH(185);

  uint32_t patch186_addr = 0x001BD4BD;
  uint8_t patch186_data[] = {
    0x10, 
  };
  APPLY_PATCH(186);

  uint32_t patch187_addr = 0x001BD4C0;
  uint8_t patch187_data[] = {
    0x0A, 
  };
  APPLY_PATCH(187);

  uint32_t patch188_addr = 0x001BD4D0;
  uint8_t patch188_data[] = {
    0xF0, 
  };
  APPLY_PATCH(188);

  uint32_t patch189_addr = 0x001BD4D2;
  uint8_t patch189_data[] = {
    0xDD, 
  };
  APPLY_PATCH(189);

  uint32_t patch190_addr = 0x001BD4D4;
  uint8_t patch190_data[] = {
    0xCC, 0xCC, 
  };
  APPLY_PATCH(190);

  uint32_t patch191_addr = 0x001BD4E0;
  uint8_t patch191_data[] = {
    0x40, 0x05, 0x10, 0x22, 
  };
  APPLY_PATCH(191);

  uint32_t patch192_addr = 0x001BD4E5;
  uint8_t patch192_data[] = {
    0x11, 
  };
  APPLY_PATCH(192);

  uint32_t patch193_addr = 0x001BD4E8;
  uint8_t patch193_data[] = {
    0xA0, 
  };
  APPLY_PATCH(193);

  uint32_t patch194_addr = 0x001BD4F8;
  uint8_t patch194_data[] = {
    0xF0, 
  };
  APPLY_PATCH(194);

  uint32_t patch195_addr = 0x001BD4FA;
  uint8_t patch195_data[] = {
    0xDD, 0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(195);

  uint32_t patch196_addr = 0x001BD509;
  uint8_t patch196_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(196);

  uint32_t patch197_addr = 0x001BD511;
  uint8_t patch197_data[] = {
    0x0B, 
  };
  APPLY_PATCH(197);

  uint32_t patch198_addr = 0x001BD520;
  uint8_t patch198_data[] = {
    0x0F, 
  };
  APPLY_PATCH(198);

  uint32_t patch199_addr = 0x001BD523;
  uint8_t patch199_data[] = {
    0x0E, 
  };
  APPLY_PATCH(199);

  uint32_t patch200_addr = 0x001BD533;
  uint8_t patch200_data[] = {
    0x20, 
  };
  APPLY_PATCH(200);

  uint32_t patch201_addr = 0x001BD54C;
  uint8_t patch201_data[] = {
    0xCC, 0x0C, 
  };
  APPLY_PATCH(201);

  uint32_t patch202_addr = 0x001BD55B;
  uint8_t patch202_data[] = {
    0x02, 
  };
  APPLY_PATCH(202);

  uint32_t patch203_addr = 0x001BD560;
  uint8_t patch203_data[] = {
    0x0A, 
  };
  APPLY_PATCH(203);

  uint32_t patch204_addr = 0x001BD562;
  uint8_t patch204_data[] = {
    0x90, 
  };
  APPLY_PATCH(204);

  uint32_t patch205_addr = 0x001BD570;
  uint8_t patch205_data[] = {
    0x0F, 
  };
  APPLY_PATCH(205);

  uint32_t patch206_addr = 0x001BD572;
  uint8_t patch206_data[] = {
    0x0D, 0xEE, 0x0C, 
  };
  APPLY_PATCH(206);

  uint32_t patch207_addr = 0x001BD580;
  uint8_t patch207_data[] = {
    0x43, 0x65, 0x11, 0x20, 
  };
  APPLY_PATCH(207);

  uint32_t patch208_addr = 0x001BD586;
  uint8_t patch208_data[] = {
    0xED, 
  };
  APPLY_PATCH(208);

  uint32_t patch209_addr = 0x001BD589;
  uint8_t patch209_data[] = {
    0xC0, 0x90, 0x90, 
  };
  APPLY_PATCH(209);

  uint32_t patch210_addr = 0x001BD598;
  uint8_t patch210_data[] = {
    0x0F, 
  };
  APPLY_PATCH(210);

  uint32_t patch211_addr = 0x001BD59A;
  uint8_t patch211_data[] = {
    0xDD, 
  };
  APPLY_PATCH(211);

  uint32_t patch212_addr = 0x001BD59C;
  uint8_t patch212_data[] = {
    0xC0, 0xC0, 
  };
  APPLY_PATCH(212);

  uint32_t patch213_addr = 0x001BD5AD;
  uint8_t patch213_data[] = {
    0x11, 0xE0, 
  };
  APPLY_PATCH(213);

  uint32_t patch214_addr = 0x001BD5B0;
  uint8_t patch214_data[] = {
    0x0A, 0x0B, 0x99, 0x09, 
  };
  APPLY_PATCH(214);

  uint32_t patch215_addr = 0x001BD5B5;
  uint8_t patch215_data[] = {
    0x90, 
  };
  APPLY_PATCH(215);

  uint32_t patch216_addr = 0x001BD5C0;
  uint8_t patch216_data[] = {
    0x0F, 
  };
  APPLY_PATCH(216);

  uint32_t patch217_addr = 0x001BD5C2;
  uint8_t patch217_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(217);

  uint32_t patch218_addr = 0x001BD5D6;
  uint8_t patch218_data[] = {
    0xE0, 
  };
  APPLY_PATCH(218);

  uint32_t patch219_addr = 0x001BD5D8;
  uint8_t patch219_data[] = {
    0xA0, 
  };
  APPLY_PATCH(219);

  uint32_t patch220_addr = 0x001BD5DA;
  uint8_t patch220_data[] = {
    0x09, 
  };
  APPLY_PATCH(220);

  uint32_t patch221_addr = 0x001BD5F8;
  uint8_t patch221_data[] = {
    0x43, 0x05, 0x11, 0x22, 
  };
  APPLY_PATCH(221);

  uint32_t patch222_addr = 0x001BD5FD;
  uint8_t patch222_data[] = {
    0x11, 0xE0, 
  };
  APPLY_PATCH(222);

  uint32_t patch223_addr = 0x001BD600;
  uint8_t patch223_data[] = {
    0x0A, 0x0B, 0x09, 
  };
  APPLY_PATCH(223);

  uint32_t patch224_addr = 0x001BD610;
  uint8_t patch224_data[] = {
    0xF0, 
  };
  APPLY_PATCH(224);

  uint32_t patch225_addr = 0x001BD612;
  uint8_t patch225_data[] = {
    0xD0, 
  };
  APPLY_PATCH(225);

  uint32_t patch226_addr = 0x001BD614;
  uint8_t patch226_data[] = {
    0x0C, 
  };
  APPLY_PATCH(226);

  uint32_t patch227_addr = 0x001BD621;
  uint8_t patch227_data[] = {
    0x60, 
  };
  APPLY_PATCH(227);

  uint32_t patch228_addr = 0x001BD623;
  uint8_t patch228_data[] = {
    0x02, 
  };
  APPLY_PATCH(228);

  uint32_t patch229_addr = 0x001BD626;
  uint8_t patch229_data[] = {
    0xE0, 
  };
  APPLY_PATCH(229);

  uint32_t patch230_addr = 0x001BD638;
  uint8_t patch230_data[] = {
    0x0F, 
  };
  APPLY_PATCH(230);

  uint32_t patch231_addr = 0x001BD63C;
  uint8_t patch231_data[] = {
    0xCC, 
  };
  APPLY_PATCH(231);

  uint32_t patch232_addr = 0x001BD649;
  uint8_t patch232_data[] = {
    0x60, 
  };
  APPLY_PATCH(232);

  uint32_t patch233_addr = 0x001BD64B;
  uint8_t patch233_data[] = {
    0x02, 
  };
  APPLY_PATCH(233);

  uint32_t patch234_addr = 0x001BD662;
  uint8_t patch234_data[] = {
    0xD0, 0x0E, 0x0C, 0xC0, 
  };
  APPLY_PATCH(234);

  uint32_t patch235_addr = 0x001BD671;
  uint8_t patch235_data[] = {
    0x60, 0x10, 
  };
  APPLY_PATCH(235);

  uint32_t patch236_addr = 0x001BD68C;
  uint8_t patch236_data[] = {
    0x0C, 
  };
  APPLY_PATCH(236);

  uint32_t patch237_addr = 0x001BD698;
  uint8_t patch237_data[] = {
    0x40, 0x65, 
  };
  APPLY_PATCH(237);

  uint32_t patch238_addr = 0x001BD856;
  uint8_t patch238_data[] = {
    0xE0, 
  };
  APPLY_PATCH(238);

  uint32_t patch239_addr = 0x001BD87E;
  uint8_t patch239_data[] = {
    0xE0, 
  };
  APPLY_PATCH(239);

  uint32_t patch240_addr = 0x001BD8A6;
  uint8_t patch240_data[] = {
    0x0D, 
  };
  APPLY_PATCH(240);

  uint32_t patch241_addr = 0x001BD8AB;
  uint8_t patch241_data[] = {
    0x90, 
  };
  APPLY_PATCH(241);

  uint32_t patch242_addr = 0x001BD8D0;
  uint8_t patch242_data[] = {
    0x0A, 0xC0, 
  };
  APPLY_PATCH(242);

  uint32_t patch243_addr = 0x001BD8F8;
  uint8_t patch243_data[] = {
    0xAA, 0x0B, 
  };
  APPLY_PATCH(243);

  uint32_t patch244_addr = 0x001BD921;
  uint8_t patch244_data[] = {
    0x0B, 0x99, 0x99, 
  };
  APPLY_PATCH(244);

  uint32_t patch245_addr = 0x001BD925;
  uint8_t patch245_data[] = {
    0x90, 
  };
  APPLY_PATCH(245);

  uint32_t patch246_addr = 0x001BD946;
  uint8_t patch246_data[] = {
    0x0D, 
  };
  APPLY_PATCH(246);

  uint32_t patch247_addr = 0x001BD949;
  uint8_t patch247_data[] = {
    0xC0, 
  };
  APPLY_PATCH(247);

  uint32_t patch248_addr = 0x001BD998;
  uint8_t patch248_data[] = {
    0xA0, 
  };
  APPLY_PATCH(248);

  uint32_t patch249_addr = 0x001BD9A8;
  uint8_t patch249_data[] = {
    0x0F, 
  };
  APPLY_PATCH(249);

  uint32_t patch250_addr = 0x001BD9AA;
  uint8_t patch250_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(250);

  uint32_t patch251_addr = 0x001BD9C0;
  uint8_t patch251_data[] = {
    0x0A, 
  };
  APPLY_PATCH(251);

  uint32_t patch252_addr = 0x001BD9D0;
  uint8_t patch252_data[] = {
    0xF0, 
  };
  APPLY_PATCH(252);

  uint32_t patch253_addr = 0x001BD9D2;
  uint8_t patch253_data[] = {
    0x0D, 
  };
  APPLY_PATCH(253);

  uint32_t patch254_addr = 0x001BD9D4;
  uint8_t patch254_data[] = {
    0xC0, 0x0C, 
  };
  APPLY_PATCH(254);

  uint32_t patch255_addr = 0x001BD9E3;
  uint8_t patch255_data[] = {
    0x0A, 
  };
  APPLY_PATCH(255);

  uint32_t patch256_addr = 0x001BD9EB;
  uint8_t patch256_data[] = {
    0x90, 
  };
  APPLY_PATCH(256);

  uint32_t patch257_addr = 0x001BD9F8;
  uint8_t patch257_data[] = {
    0xF0, 
  };
  APPLY_PATCH(257);

  uint32_t patch258_addr = 0x001BD9FA;
  uint8_t patch258_data[] = {
    0x0D, 
  };
  APPLY_PATCH(258);

  uint32_t patch259_addr = 0x001BDA0A;
  uint8_t patch259_data[] = {
    0x90, 
  };
  APPLY_PATCH(259);

  uint32_t patch260_addr = 0x001BDA0E;
  uint8_t patch260_data[] = {
    0xED, 
  };
  APPLY_PATCH(260);

  uint32_t patch261_addr = 0x001BDA10;
  uint8_t patch261_data[] = {
    0xAA, 0xCB, 
  };
  APPLY_PATCH(261);

  uint32_t patch262_addr = 0x001BDA13;
  uint8_t patch262_data[] = {
    0x09, 
  };
  APPLY_PATCH(262);

  uint32_t patch263_addr = 0x001BDA30;
  uint8_t patch263_data[] = {
    0xCB, 0xED, 0x09, 0xAA, 
  };
  APPLY_PATCH(263);

  uint32_t patch264_addr = 0x001BDA35;
  uint8_t patch264_data[] = {
    0x90, 
  };
  APPLY_PATCH(264);

  uint32_t patch265_addr = 0x001BDA3A;
  uint8_t patch265_data[] = {
    0x99, 
  };
  APPLY_PATCH(265);

  uint32_t patch266_addr = 0x001BDA3D;
  uint8_t patch266_data[] = {
    0x90, 
  };
  APPLY_PATCH(266);

  uint32_t patch267_addr = 0x001BDA4A;
  uint8_t patch267_data[] = {
    0x0D, 
  };
  APPLY_PATCH(267);

  uint32_t patch268_addr = 0x001BDA5C;
  uint8_t patch268_data[] = {
    0x90, 0x09, 
  };
  APPLY_PATCH(268);

  uint32_t patch269_addr = 0x001BDA74;
  uint8_t patch269_data[] = {
    0x0C, 
  };
  APPLY_PATCH(269);

  uint32_t patch270_addr = 0x001BDA82;
  uint8_t patch270_data[] = {
    0x90, 
  };
  APPLY_PATCH(270);

  uint32_t patch271_addr = 0x001BDA9A;
  uint8_t patch271_data[] = {
    0x0D, 
  };
  APPLY_PATCH(271);

  uint32_t patch272_addr = 0x001BDA9C;
  uint8_t patch272_data[] = {
    0x0C, 
  };
  APPLY_PATCH(272);

  uint32_t patch273_addr = 0x001BDAAA;
  uint8_t patch273_data[] = {
    0x90, 
  };
  APPLY_PATCH(273);

  uint32_t patch274_addr = 0x001BDAAD;
  uint8_t patch274_data[] = {
    0x09, 0xE0, 
  };
  APPLY_PATCH(274);

  uint32_t patch275_addr = 0x001BDAB2;
  uint8_t patch275_data[] = {
    0x90, 
  };
  APPLY_PATCH(275);

  uint32_t patch276_addr = 0x001BDAD0;
  uint8_t patch276_data[] = {
    0xCB, 0xED, 0x99, 0xA0, 
  };
  APPLY_PATCH(276);

  uint32_t patch277_addr = 0x001BDAD5;
  uint8_t patch277_data[] = {
    0x99, 0xE0, 
  };
  APPLY_PATCH(277);

  uint32_t patch278_addr = 0x001BDADA;
  uint8_t patch278_data[] = {
    0x90, 
  };
  APPLY_PATCH(278);

  uint32_t patch279_addr = 0x001BDAEA;
  uint8_t patch279_data[] = {
    0xDD, 0xEE, 
  };
  APPLY_PATCH(279);

  uint32_t patch280_addr = 0x001BDAED;
  uint8_t patch280_data[] = {
    0xCC, 
  };
  APPLY_PATCH(280);

  uint32_t patch281_addr = 0x001BDAF9;
  uint8_t patch281_data[] = {
    0xE0, 0x90, 0xA0, 0x99, 0x09, 0xE0, 
  };
  APPLY_PATCH(281);

  uint32_t patch282_addr = 0x001BDB10;
  uint8_t patch282_data[] = {
    0xFF, 
  };
  APPLY_PATCH(282);

  uint32_t patch283_addr = 0x001BDB12;
  uint8_t patch283_data[] = {
    0xD0, 0xEE, 
  };
  APPLY_PATCH(283);

  uint32_t patch284_addr = 0x001BDB21;
  uint8_t patch284_data[] = {
    0xE0, 0x90, 0xA0, 
  };
  APPLY_PATCH(284);

  uint32_t patch285_addr = 0x001BDB25;
  uint8_t patch285_data[] = {
    0x09, 0x0D, 
  };
  APPLY_PATCH(285);

  uint32_t patch286_addr = 0x001BDB38;
  uint8_t patch286_data[] = {
    0xFF, 
  };
  APPLY_PATCH(286);

  uint32_t patch287_addr = 0x001BDB3A;
  uint8_t patch287_data[] = {
    0xD0, 0xEE, 0xC0, 0x0C, 
  };
  APPLY_PATCH(287);

  uint32_t patch288_addr = 0x001BDB48;
  uint8_t patch288_data[] = {
    0xCB, 0xED, 0x99, 0xA0, 
  };
  APPLY_PATCH(288);

  uint32_t patch289_addr = 0x001BDB4D;
  uint8_t patch289_data[] = {
    0x99, 
  };
  APPLY_PATCH(289);

  uint32_t patch290_addr = 0x001BDB51;
  uint8_t patch290_data[] = {
    0xC0, 
  };
  APPLY_PATCH(290);

  uint32_t patch291_addr = 0x001BDB60;
  uint8_t patch291_data[] = {
    0x0F, 
  };
  APPLY_PATCH(291);

  uint32_t patch292_addr = 0x001BDB62;
  uint8_t patch292_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(292);

  uint32_t patch293_addr = 0x001BDB72;
  uint8_t patch293_data[] = {
    0x90, 
  };
  APPLY_PATCH(293);

  uint32_t patch294_addr = 0x001BDB75;
  uint8_t patch294_data[] = {
    0x09, 
  };
  APPLY_PATCH(294);

  uint32_t patch295_addr = 0x001BDB78;
  uint8_t patch295_data[] = {
    0xAA, 0x0B, 
  };
  APPLY_PATCH(295);

  uint32_t patch296_addr = 0x001BDB7B;
  uint8_t patch296_data[] = {
    0x99, 
  };
  APPLY_PATCH(296);

  uint32_t patch297_addr = 0x001BDB88;
  uint8_t patch297_data[] = {
    0x0F, 
  };
  APPLY_PATCH(297);

  uint32_t patch298_addr = 0x001BDB8A;
  uint8_t patch298_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(298);

  uint32_t patch299_addr = 0x001BDB9A;
  uint8_t patch299_data[] = {
    0x90, 
  };
  APPLY_PATCH(299);

  uint32_t patch300_addr = 0x001BDBB0;
  uint8_t patch300_data[] = {
    0xF0, 
  };
  APPLY_PATCH(300);

  uint32_t patch301_addr = 0x001BDBB4;
  uint8_t patch301_data[] = {
    0x0C, 
  };
  APPLY_PATCH(301);

  uint32_t patch302_addr = 0x001BDBC6;
  uint8_t patch302_data[] = {
    0xE0, 
  };
  APPLY_PATCH(302);

  uint32_t patch303_addr = 0x001BDBCA;
  uint8_t patch303_data[] = {
    0x09, 0x90, 
  };
  APPLY_PATCH(303);

  uint32_t patch304_addr = 0x001BDBEE;
  uint8_t patch304_data[] = {
    0xE0, 
  };
  APPLY_PATCH(304);

  uint32_t patch305_addr = 0x001BDBF2;
  uint8_t patch305_data[] = {
    0x09, 0x90, 
  };
  APPLY_PATCH(305);

  uint32_t patch306_addr = 0x001BDC00;
  uint8_t patch306_data[] = {
    0xF0, 
  };
  APPLY_PATCH(306);

  uint32_t patch307_addr = 0x001BDC02;
  uint8_t patch307_data[] = {
    0xD0, 0x0E, 0xC0, 
  };
  APPLY_PATCH(307);

  uint32_t patch308_addr = 0x001BDC10;
  uint8_t patch308_data[] = {
    0xCB, 
  };
  APPLY_PATCH(308);

  uint32_t patch309_addr = 0x001BDC13;
  uint8_t patch309_data[] = {
    0xAA, 
  };
  APPLY_PATCH(309);

  uint32_t patch310_addr = 0x001BDC15;
  uint8_t patch310_data[] = {
    0x09, 0xE0, 
  };
  APPLY_PATCH(310);

  uint32_t patch311_addr = 0x001BDC1A;
  uint8_t patch311_data[] = {
    0x09, 0x90, 
  };
  APPLY_PATCH(311);

  uint32_t patch312_addr = 0x001BDC28;
  uint8_t patch312_data[] = {
    0x0F, 
  };
  APPLY_PATCH(312);

  uint32_t patch313_addr = 0x001BDC2A;
  uint8_t patch313_data[] = {
    0xD0, 0xEE, 0xC0, 0x0C, 
  };
  APPLY_PATCH(313);

  uint32_t patch314_addr = 0x001BDC39;
  uint8_t patch314_data[] = {
    0x0D, 0x99, 
  };
  APPLY_PATCH(314);

  uint32_t patch315_addr = 0x001BDC3D;
  uint8_t patch315_data[] = {
    0x90, 0x0D, 
  };
  APPLY_PATCH(315);

  uint32_t patch316_addr = 0x001BDC69;
  uint8_t patch316_data[] = {
    0xC0, 
  };
  APPLY_PATCH(316);

  uint32_t patch317_addr = 0x001BDC88;
  uint8_t patch317_data[] = {
    0x0B, 
  };
  APPLY_PATCH(317);

  uint32_t patch318_addr = 0x001BDC8A;
  uint8_t patch318_data[] = {
    0x09, 
  };
  APPLY_PATCH(318);

  uint32_t patch319_addr = 0x001BDC90;
  uint8_t patch319_data[] = {
    0xAA, 0x0B, 
  };
  APPLY_PATCH(319);

  uint32_t patch320_addr = 0x001BDC93;
  uint8_t patch320_data[] = {
    0x99, 
  };
  APPLY_PATCH(320);

  uint32_t patch321_addr = 0x001BDCA0;
  uint8_t patch321_data[] = {
    0xF0, 
  };
  APPLY_PATCH(321);

  uint32_t patch322_addr = 0x001BDCB0;
  uint8_t patch322_data[] = {
    0xC0, 
  };
  APPLY_PATCH(322);

  uint32_t patch323_addr = 0x001BDCB2;
  uint8_t patch323_data[] = {
    0x09, 
  };
  APPLY_PATCH(323);

  uint32_t patch324_addr = 0x001BDCC8;
  uint8_t patch324_data[] = {
    0xF0, 
  };
  APPLY_PATCH(324);

  uint32_t patch325_addr = 0x001BDCD9;
  uint8_t patch325_data[] = {
    0x0D, 
  };
  APPLY_PATCH(325);

  uint32_t patch326_addr = 0x001BDCDD;
  uint8_t patch326_data[] = {
    0x90, 0xE0, 
  };
  APPLY_PATCH(326);

  uint32_t patch327_addr = 0x001BDCE1;
  uint8_t patch327_data[] = {
    0x0B, 
  };
  APPLY_PATCH(327);

  uint32_t patch328_addr = 0x001BDCE3;
  uint8_t patch328_data[] = {
    0x90, 
  };
  APPLY_PATCH(328);

  uint32_t patch329_addr = 0x001BDD01;
  uint8_t patch329_data[] = {
    0x0D, 
  };
  APPLY_PATCH(329);

  uint32_t patch330_addr = 0x001BDD05;
  uint8_t patch330_data[] = {
    0x90, 0xE0, 
  };
  APPLY_PATCH(330);

  uint32_t patch331_addr = 0x001BDD09;
  uint8_t patch331_data[] = {
    0x0B, 
  };
  APPLY_PATCH(331);

  uint32_t patch332_addr = 0x001BDD0B;
  uint8_t patch332_data[] = {
    0x90, 
  };
  APPLY_PATCH(332);

  uint32_t patch333_addr = 0x001BDD29;
  uint8_t patch333_data[] = {
    0x0D, 
  };
  APPLY_PATCH(333);

  uint32_t patch334_addr = 0x001BDD2D;
  uint8_t patch334_data[] = {
    0x90, 0xE0, 
  };
  APPLY_PATCH(334);

  uint32_t patch335_addr = 0x001BDD31;
  uint8_t patch335_data[] = {
    0x0B, 
  };
  APPLY_PATCH(335);

  uint32_t patch336_addr = 0x001BDD33;
  uint8_t patch336_data[] = {
    0x90, 
  };
  APPLY_PATCH(336);

  uint32_t patch337_addr = 0x001BDD42;
  uint8_t patch337_data[] = {
    0xD0, 0x0E, 
  };
  APPLY_PATCH(337);

  uint32_t patch338_addr = 0x001BDD56;
  uint8_t patch338_data[] = {
    0xED, 
  };
  APPLY_PATCH(338);

  uint32_t patch339_addr = 0x001BDD58;
  uint8_t patch339_data[] = {
    0xAA, 0xCB, 
  };
  APPLY_PATCH(339);

  uint32_t patch340_addr = 0x001BDD5B;
  uint8_t patch340_data[] = {
    0x90, 
  };
  APPLY_PATCH(340);

  uint32_t patch341_addr = 0x001BDD68;
  uint8_t patch341_data[] = {
    0x0F, 
  };
  APPLY_PATCH(341);

  uint32_t patch342_addr = 0x001BDD6B;
  uint8_t patch342_data[] = {
    0xF0, 0x0C, 
  };
  APPLY_PATCH(342);

  uint32_t patch343_addr = 0x001BDD94;
  uint8_t patch343_data[] = {
    0xCC, 0x0C, 
  };
  APPLY_PATCH(343);

  uint32_t patch344_addr = 0x001BDDA1;
  uint8_t patch344_data[] = {
    0x60, 0x10, 0x22, 
  };
  APPLY_PATCH(344);

  uint32_t patch345_addr = 0x001BDDA5;
  uint8_t patch345_data[] = {
    0x01, 
  };
  APPLY_PATCH(345);

  uint32_t patch346_addr = 0x001BDDA8;
  uint8_t patch346_data[] = {
    0xAA, 
  };
  APPLY_PATCH(346);

  uint32_t patch347_addr = 0x001BDDAB;
  uint8_t patch347_data[] = {
    0x90, 
  };
  APPLY_PATCH(347);

  uint32_t patch348_addr = 0x001BDDB8;
  uint8_t patch348_data[] = {
    0x0F, 
  };
  APPLY_PATCH(348);

  uint32_t patch349_addr = 0x001BDDBB;
  uint8_t patch349_data[] = {
    0x0E, 
  };
  APPLY_PATCH(349);

  uint32_t patch350_addr = 0x001BDDC9;
  uint8_t patch350_data[] = {
    0x60, 0x10, 0x20, 
  };
  APPLY_PATCH(350);

  uint32_t patch351_addr = 0x001BDDCD;
  uint8_t patch351_data[] = {
    0x01, 
  };
  APPLY_PATCH(351);

  uint32_t patch352_addr = 0x001BDDE0;
  uint8_t patch352_data[] = {
    0xF0, 
  };
  APPLY_PATCH(352);

  uint32_t patch353_addr = 0x001BDDE2;
  uint8_t patch353_data[] = {
    0x0D, 0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(353);

  uint32_t patch354_addr = 0x001BDDF0;
  uint8_t patch354_data[] = {
    0x43, 0x05, 0x11, 0x20, 
  };
  APPLY_PATCH(354);

  uint32_t patch355_addr = 0x001BDDF5;
  uint8_t patch355_data[] = {
    0x11, 0xE0, 
  };
  APPLY_PATCH(355);

  uint32_t patch356_addr = 0x001BDDF8;
  uint8_t patch356_data[] = {
    0xAA, 
  };
  APPLY_PATCH(356);

  uint32_t patch357_addr = 0x001BDDFB;
  uint8_t patch357_data[] = {
    0x90, 
  };
  APPLY_PATCH(357);

  uint32_t patch358_addr = 0x001BDE08;
  uint8_t patch358_data[] = {
    0x0F, 
  };
  APPLY_PATCH(358);

  uint32_t patch359_addr = 0x001BDE0B;
  uint8_t patch359_data[] = {
    0x03, 0xCC, 0x2C, 
  };
  APPLY_PATCH(359);

  uint32_t patch360_addr = 0x001BDE1E;
  uint8_t patch360_data[] = {
    0x0D, 
  };
  APPLY_PATCH(360);

  uint32_t patch361_addr = 0x001BDE32;
  uint8_t patch361_data[] = {
    0xDD, 0x0E, 0x0C, 
  };
  APPLY_PATCH(361);

  uint32_t patch362_addr = 0x001BDE41;
  uint8_t patch362_data[] = {
    0x60, 0x10, 0x22, 
  };
  APPLY_PATCH(362);

  uint32_t patch363_addr = 0x001BDE45;
  uint8_t patch363_data[] = {
    0x10, 
  };
  APPLY_PATCH(363);

  uint32_t patch364_addr = 0x001BDE48;
  uint8_t patch364_data[] = {
    0xAA, 0xCB, 
  };
  APPLY_PATCH(364);

  uint32_t patch365_addr = 0x001BDE4B;
  uint8_t patch365_data[] = {
    0x90, 
  };
  APPLY_PATCH(365);

  uint32_t patch366_addr = 0x001BDE58;
  uint8_t patch366_data[] = {
    0xFF, 
  };
  APPLY_PATCH(366);

  uint32_t patch367_addr = 0x001BDE5B;
  uint8_t patch367_data[] = {
    0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(367);

  uint32_t patch368_addr = 0x001BDE69;
  uint8_t patch368_data[] = {
    0x60, 0x10, 0x20, 
  };
  APPLY_PATCH(368);

  uint32_t patch369_addr = 0x001BDE6D;
  uint8_t patch369_data[] = {
    0x11, 
  };
  APPLY_PATCH(369);

  uint32_t patch370_addr = 0x001BDE84;
  uint8_t patch370_data[] = {
    0xC0, 
  };
  APPLY_PATCH(370);

  uint32_t patch371_addr = 0x001BDE90;
  uint8_t patch371_data[] = {
    0x43, 0x65, 0x11, 0x22, 0x10, 0x10, 0xED, 
  };
  APPLY_PATCH(371);

  uint32_t patch372_addr = 0x001BDE98;
  uint8_t patch372_data[] = {
    0xAA, 0xCB, 0x99, 0x99, 
  };
  APPLY_PATCH(372);

  uint32_t patch373_addr = 0x001BDEA8;
  uint8_t patch373_data[] = {
    0x0F, 
  };
  APPLY_PATCH(373);

  uint32_t patch374_addr = 0x001BDEAA;
  uint8_t patch374_data[] = {
    0xD0, 0xE0, 0xC0, 
  };
  APPLY_PATCH(374);

  uint32_t patch375_addr = 0x001BDEB9;
  uint8_t patch375_data[] = {
    0x05, 0x10, 0x20, 
  };
  APPLY_PATCH(375);

  uint32_t patch376_addr = 0x001BDEBD;
  uint8_t patch376_data[] = {
    0x10, 
  };
  APPLY_PATCH(376);

  uint32_t patch377_addr = 0x001BDEC0;
  uint8_t patch377_data[] = {
    0x0A, 
  };
  APPLY_PATCH(377);

  uint32_t patch378_addr = 0x001BDED0;
  uint8_t patch378_data[] = {
    0xF0, 
  };
  APPLY_PATCH(378);

  uint32_t patch379_addr = 0x001BDED2;
  uint8_t patch379_data[] = {
    0xDD, 
  };
  APPLY_PATCH(379);

  uint32_t patch380_addr = 0x001BDED4;
  uint8_t patch380_data[] = {
    0xCC, 0xCC, 
  };
  APPLY_PATCH(380);

  uint32_t patch381_addr = 0x001BDEE0;
  uint8_t patch381_data[] = {
    0x40, 0x05, 0x10, 0x22, 
  };
  APPLY_PATCH(381);

  uint32_t patch382_addr = 0x001BDEE5;
  uint8_t patch382_data[] = {
    0x11, 
  };
  APPLY_PATCH(382);

  uint32_t patch383_addr = 0x001BDEE8;
  uint8_t patch383_data[] = {
    0xA0, 
  };
  APPLY_PATCH(383);

  uint32_t patch384_addr = 0x001BDEF8;
  uint8_t patch384_data[] = {
    0xF0, 
  };
  APPLY_PATCH(384);

  uint32_t patch385_addr = 0x001BDEFA;
  uint8_t patch385_data[] = {
    0xDD, 0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(385);

  uint32_t patch386_addr = 0x001BDF09;
  uint8_t patch386_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(386);

  uint32_t patch387_addr = 0x001BDF11;
  uint8_t patch387_data[] = {
    0x0B, 
  };
  APPLY_PATCH(387);

  uint32_t patch388_addr = 0x001BDF20;
  uint8_t patch388_data[] = {
    0x0F, 
  };
  APPLY_PATCH(388);

  uint32_t patch389_addr = 0x001BDF23;
  uint8_t patch389_data[] = {
    0x0E, 
  };
  APPLY_PATCH(389);

  uint32_t patch390_addr = 0x001BDF33;
  uint8_t patch390_data[] = {
    0x20, 
  };
  APPLY_PATCH(390);

  uint32_t patch391_addr = 0x001BDF4C;
  uint8_t patch391_data[] = {
    0xCC, 0x0C, 
  };
  APPLY_PATCH(391);

  uint32_t patch392_addr = 0x001BDF5B;
  uint8_t patch392_data[] = {
    0x02, 
  };
  APPLY_PATCH(392);

  uint32_t patch393_addr = 0x001BDF60;
  uint8_t patch393_data[] = {
    0x0A, 
  };
  APPLY_PATCH(393);

  uint32_t patch394_addr = 0x001BDF62;
  uint8_t patch394_data[] = {
    0x90, 
  };
  APPLY_PATCH(394);

  uint32_t patch395_addr = 0x001BDF70;
  uint8_t patch395_data[] = {
    0x0F, 
  };
  APPLY_PATCH(395);

  uint32_t patch396_addr = 0x001BDF72;
  uint8_t patch396_data[] = {
    0x0D, 0xEE, 0x0C, 
  };
  APPLY_PATCH(396);

  uint32_t patch397_addr = 0x001BDF80;
  uint8_t patch397_data[] = {
    0x43, 0x65, 0x11, 0x20, 
  };
  APPLY_PATCH(397);

  uint32_t patch398_addr = 0x001BDF86;
  uint8_t patch398_data[] = {
    0xED, 
  };
  APPLY_PATCH(398);

  uint32_t patch399_addr = 0x001BDF89;
  uint8_t patch399_data[] = {
    0xC0, 0x90, 0x90, 
  };
  APPLY_PATCH(399);

  uint32_t patch400_addr = 0x001BDF98;
  uint8_t patch400_data[] = {
    0x0F, 
  };
  APPLY_PATCH(400);

  uint32_t patch401_addr = 0x001BDF9A;
  uint8_t patch401_data[] = {
    0xDD, 
  };
  APPLY_PATCH(401);

  uint32_t patch402_addr = 0x001BDF9C;
  uint8_t patch402_data[] = {
    0xC0, 0xC0, 
  };
  APPLY_PATCH(402);

  uint32_t patch403_addr = 0x001BDFAD;
  uint8_t patch403_data[] = {
    0x11, 0xE0, 
  };
  APPLY_PATCH(403);

  uint32_t patch404_addr = 0x001BDFB0;
  uint8_t patch404_data[] = {
    0x0A, 0x0B, 0x99, 0x09, 
  };
  APPLY_PATCH(404);

  uint32_t patch405_addr = 0x001BDFB5;
  uint8_t patch405_data[] = {
    0x90, 
  };
  APPLY_PATCH(405);

  uint32_t patch406_addr = 0x001BDFC0;
  uint8_t patch406_data[] = {
    0x0F, 
  };
  APPLY_PATCH(406);

  uint32_t patch407_addr = 0x001BDFC2;
  uint8_t patch407_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(407);

  uint32_t patch408_addr = 0x001BDFD6;
  uint8_t patch408_data[] = {
    0xE0, 
  };
  APPLY_PATCH(408);

  uint32_t patch409_addr = 0x001BDFD8;
  uint8_t patch409_data[] = {
    0xA0, 
  };
  APPLY_PATCH(409);

  uint32_t patch410_addr = 0x001BDFDA;
  uint8_t patch410_data[] = {
    0x09, 
  };
  APPLY_PATCH(410);

  uint32_t patch411_addr = 0x001BDFF8;
  uint8_t patch411_data[] = {
    0x43, 0x05, 0x11, 0x22, 
  };
  APPLY_PATCH(411);

  uint32_t patch412_addr = 0x001BDFFD;
  uint8_t patch412_data[] = {
    0x11, 0xE0, 
  };
  APPLY_PATCH(412);

  uint32_t patch413_addr = 0x001BE000;
  uint8_t patch413_data[] = {
    0x0A, 0x0B, 0x09, 
  };
  APPLY_PATCH(413);

  uint32_t patch414_addr = 0x001BE010;
  uint8_t patch414_data[] = {
    0xF0, 
  };
  APPLY_PATCH(414);

  uint32_t patch415_addr = 0x001BE012;
  uint8_t patch415_data[] = {
    0xD0, 
  };
  APPLY_PATCH(415);

  uint32_t patch416_addr = 0x001BE014;
  uint8_t patch416_data[] = {
    0x0C, 
  };
  APPLY_PATCH(416);

  uint32_t patch417_addr = 0x001BE021;
  uint8_t patch417_data[] = {
    0x60, 
  };
  APPLY_PATCH(417);

  uint32_t patch418_addr = 0x001BE023;
  uint8_t patch418_data[] = {
    0x02, 
  };
  APPLY_PATCH(418);

  uint32_t patch419_addr = 0x001BE026;
  uint8_t patch419_data[] = {
    0xE0, 
  };
  APPLY_PATCH(419);

  uint32_t patch420_addr = 0x001BE038;
  uint8_t patch420_data[] = {
    0x0F, 
  };
  APPLY_PATCH(420);

  uint32_t patch421_addr = 0x001BE03C;
  uint8_t patch421_data[] = {
    0xCC, 
  };
  APPLY_PATCH(421);

  uint32_t patch422_addr = 0x001BE049;
  uint8_t patch422_data[] = {
    0x60, 
  };
  APPLY_PATCH(422);

  uint32_t patch423_addr = 0x001BE04B;
  uint8_t patch423_data[] = {
    0x02, 
  };
  APPLY_PATCH(423);

  uint32_t patch424_addr = 0x001BE062;
  uint8_t patch424_data[] = {
    0xD0, 0x0E, 0x0C, 0xC0, 
  };
  APPLY_PATCH(424);

  uint32_t patch425_addr = 0x001BE071;
  uint8_t patch425_data[] = {
    0x60, 0x10, 
  };
  APPLY_PATCH(425);

  uint32_t patch426_addr = 0x001BE08C;
  uint8_t patch426_data[] = {
    0x0C, 
  };
  APPLY_PATCH(426);

  uint32_t patch427_addr = 0x001BE098;
  uint8_t patch427_data[] = {
    0x40, 0x65, 
  };
  APPLY_PATCH(427);

  uint32_t patch428_addr = 0x001BE256;
  uint8_t patch428_data[] = {
    0xE0, 
  };
  APPLY_PATCH(428);

  uint32_t patch429_addr = 0x001BE27E;
  uint8_t patch429_data[] = {
    0xE0, 
  };
  APPLY_PATCH(429);

  uint32_t patch430_addr = 0x001BE2A6;
  uint8_t patch430_data[] = {
    0x0D, 
  };
  APPLY_PATCH(430);

  uint32_t patch431_addr = 0x001BE2AB;
  uint8_t patch431_data[] = {
    0x90, 
  };
  APPLY_PATCH(431);

  uint32_t patch432_addr = 0x001BE2D0;
  uint8_t patch432_data[] = {
    0x0A, 0xC0, 
  };
  APPLY_PATCH(432);

  uint32_t patch433_addr = 0x001BE2F8;
  uint8_t patch433_data[] = {
    0xAA, 0x0B, 
  };
  APPLY_PATCH(433);

  uint32_t patch434_addr = 0x001BE321;
  uint8_t patch434_data[] = {
    0x0B, 0x99, 0x99, 
  };
  APPLY_PATCH(434);

  uint32_t patch435_addr = 0x001BE325;
  uint8_t patch435_data[] = {
    0x90, 
  };
  APPLY_PATCH(435);

  uint32_t patch436_addr = 0x001BE346;
  uint8_t patch436_data[] = {
    0x0D, 
  };
  APPLY_PATCH(436);

  uint32_t patch437_addr = 0x001BE349;
  uint8_t patch437_data[] = {
    0xC0, 
  };
  APPLY_PATCH(437);

  uint32_t patch438_addr = 0x001BE398;
  uint8_t patch438_data[] = {
    0xA0, 
  };
  APPLY_PATCH(438);

  uint32_t patch439_addr = 0x001BE3A8;
  uint8_t patch439_data[] = {
    0x0F, 
  };
  APPLY_PATCH(439);

  uint32_t patch440_addr = 0x001BE3AA;
  uint8_t patch440_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(440);

  uint32_t patch441_addr = 0x001BE3C0;
  uint8_t patch441_data[] = {
    0x0A, 
  };
  APPLY_PATCH(441);

  uint32_t patch442_addr = 0x001BE3D0;
  uint8_t patch442_data[] = {
    0xF0, 
  };
  APPLY_PATCH(442);

  uint32_t patch443_addr = 0x001BE3D2;
  uint8_t patch443_data[] = {
    0x0D, 
  };
  APPLY_PATCH(443);

  uint32_t patch444_addr = 0x001BE3D4;
  uint8_t patch444_data[] = {
    0xC0, 0x0C, 
  };
  APPLY_PATCH(444);

  uint32_t patch445_addr = 0x001BE3E3;
  uint8_t patch445_data[] = {
    0x0A, 
  };
  APPLY_PATCH(445);

  uint32_t patch446_addr = 0x001BE3EB;
  uint8_t patch446_data[] = {
    0x90, 
  };
  APPLY_PATCH(446);

  uint32_t patch447_addr = 0x001BE3F8;
  uint8_t patch447_data[] = {
    0xF0, 
  };
  APPLY_PATCH(447);

  uint32_t patch448_addr = 0x001BE3FA;
  uint8_t patch448_data[] = {
    0x0D, 
  };
  APPLY_PATCH(448);

  uint32_t patch449_addr = 0x001BE40A;
  uint8_t patch449_data[] = {
    0x90, 
  };
  APPLY_PATCH(449);

  uint32_t patch450_addr = 0x001BE40E;
  uint8_t patch450_data[] = {
    0xED, 
  };
  APPLY_PATCH(450);

  uint32_t patch451_addr = 0x001BE410;
  uint8_t patch451_data[] = {
    0xAA, 0xCB, 
  };
  APPLY_PATCH(451);

  uint32_t patch452_addr = 0x001BE413;
  uint8_t patch452_data[] = {
    0x09, 
  };
  APPLY_PATCH(452);

  uint32_t patch453_addr = 0x001BE430;
  uint8_t patch453_data[] = {
    0xCB, 0xED, 0x09, 0xAA, 
  };
  APPLY_PATCH(453);

  uint32_t patch454_addr = 0x001BE435;
  uint8_t patch454_data[] = {
    0x90, 
  };
  APPLY_PATCH(454);

  uint32_t patch455_addr = 0x001BE43A;
  uint8_t patch455_data[] = {
    0x99, 
  };
  APPLY_PATCH(455);

  uint32_t patch456_addr = 0x001BE43D;
  uint8_t patch456_data[] = {
    0x90, 
  };
  APPLY_PATCH(456);

  uint32_t patch457_addr = 0x001BE44A;
  uint8_t patch457_data[] = {
    0x0D, 
  };
  APPLY_PATCH(457);

  uint32_t patch458_addr = 0x001BE45C;
  uint8_t patch458_data[] = {
    0x90, 0x09, 
  };
  APPLY_PATCH(458);

  uint32_t patch459_addr = 0x001BE474;
  uint8_t patch459_data[] = {
    0x0C, 
  };
  APPLY_PATCH(459);

  uint32_t patch460_addr = 0x001BE482;
  uint8_t patch460_data[] = {
    0x90, 
  };
  APPLY_PATCH(460);

  uint32_t patch461_addr = 0x001BE49A;
  uint8_t patch461_data[] = {
    0x0D, 
  };
  APPLY_PATCH(461);

  uint32_t patch462_addr = 0x001BE49C;
  uint8_t patch462_data[] = {
    0x0C, 
  };
  APPLY_PATCH(462);

  uint32_t patch463_addr = 0x001BE4AA;
  uint8_t patch463_data[] = {
    0x90, 
  };
  APPLY_PATCH(463);

  uint32_t patch464_addr = 0x001BE4AD;
  uint8_t patch464_data[] = {
    0x09, 0xE0, 
  };
  APPLY_PATCH(464);

  uint32_t patch465_addr = 0x001BE4B2;
  uint8_t patch465_data[] = {
    0x90, 
  };
  APPLY_PATCH(465);

  uint32_t patch466_addr = 0x001BE4D0;
  uint8_t patch466_data[] = {
    0xCB, 0xED, 0x99, 0xA0, 
  };
  APPLY_PATCH(466);

  uint32_t patch467_addr = 0x001BE4D5;
  uint8_t patch467_data[] = {
    0x99, 0xE0, 
  };
  APPLY_PATCH(467);

  uint32_t patch468_addr = 0x001BE4DA;
  uint8_t patch468_data[] = {
    0x90, 
  };
  APPLY_PATCH(468);

  uint32_t patch469_addr = 0x001BE4EA;
  uint8_t patch469_data[] = {
    0xDD, 0xEE, 
  };
  APPLY_PATCH(469);

  uint32_t patch470_addr = 0x001BE4ED;
  uint8_t patch470_data[] = {
    0xCC, 
  };
  APPLY_PATCH(470);

  uint32_t patch471_addr = 0x001BE4F9;
  uint8_t patch471_data[] = {
    0xE0, 0x90, 0xA0, 0x99, 0x09, 0xE0, 
  };
  APPLY_PATCH(471);

  uint32_t patch472_addr = 0x001BE510;
  uint8_t patch472_data[] = {
    0xFF, 
  };
  APPLY_PATCH(472);

  uint32_t patch473_addr = 0x001BE512;
  uint8_t patch473_data[] = {
    0xD0, 0xEE, 
  };
  APPLY_PATCH(473);

  uint32_t patch474_addr = 0x001BE521;
  uint8_t patch474_data[] = {
    0xE0, 0x90, 0xA0, 
  };
  APPLY_PATCH(474);

  uint32_t patch475_addr = 0x001BE525;
  uint8_t patch475_data[] = {
    0x09, 0x0D, 
  };
  APPLY_PATCH(475);

  uint32_t patch476_addr = 0x001BE538;
  uint8_t patch476_data[] = {
    0xFF, 
  };
  APPLY_PATCH(476);

  uint32_t patch477_addr = 0x001BE53A;
  uint8_t patch477_data[] = {
    0xD0, 0xEE, 0xC0, 0x0C, 
  };
  APPLY_PATCH(477);

  uint32_t patch478_addr = 0x001BE548;
  uint8_t patch478_data[] = {
    0xCB, 0xED, 0x99, 0xA0, 
  };
  APPLY_PATCH(478);

  uint32_t patch479_addr = 0x001BE54D;
  uint8_t patch479_data[] = {
    0x99, 
  };
  APPLY_PATCH(479);

  uint32_t patch480_addr = 0x001BE551;
  uint8_t patch480_data[] = {
    0xC0, 
  };
  APPLY_PATCH(480);

  uint32_t patch481_addr = 0x001BE560;
  uint8_t patch481_data[] = {
    0x0F, 
  };
  APPLY_PATCH(481);

  uint32_t patch482_addr = 0x001BE562;
  uint8_t patch482_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(482);

  uint32_t patch483_addr = 0x001BE572;
  uint8_t patch483_data[] = {
    0x90, 
  };
  APPLY_PATCH(483);

  uint32_t patch484_addr = 0x001BE575;
  uint8_t patch484_data[] = {
    0x09, 
  };
  APPLY_PATCH(484);

  uint32_t patch485_addr = 0x001BE578;
  uint8_t patch485_data[] = {
    0xAA, 0x0B, 
  };
  APPLY_PATCH(485);

  uint32_t patch486_addr = 0x001BE57B;
  uint8_t patch486_data[] = {
    0x99, 
  };
  APPLY_PATCH(486);

  uint32_t patch487_addr = 0x001BE588;
  uint8_t patch487_data[] = {
    0x0F, 
  };
  APPLY_PATCH(487);

  uint32_t patch488_addr = 0x001BE58A;
  uint8_t patch488_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(488);

  uint32_t patch489_addr = 0x001BE59A;
  uint8_t patch489_data[] = {
    0x90, 
  };
  APPLY_PATCH(489);

  uint32_t patch490_addr = 0x001BE5B0;
  uint8_t patch490_data[] = {
    0xF0, 
  };
  APPLY_PATCH(490);

  uint32_t patch491_addr = 0x001BE5B4;
  uint8_t patch491_data[] = {
    0x0C, 
  };
  APPLY_PATCH(491);

  uint32_t patch492_addr = 0x001BE5C6;
  uint8_t patch492_data[] = {
    0xE0, 
  };
  APPLY_PATCH(492);

  uint32_t patch493_addr = 0x001BE5CA;
  uint8_t patch493_data[] = {
    0x09, 0x90, 
  };
  APPLY_PATCH(493);

  uint32_t patch494_addr = 0x001BE5EE;
  uint8_t patch494_data[] = {
    0xE0, 
  };
  APPLY_PATCH(494);

  uint32_t patch495_addr = 0x001BE5F2;
  uint8_t patch495_data[] = {
    0x09, 0x90, 
  };
  APPLY_PATCH(495);

  uint32_t patch496_addr = 0x001BE600;
  uint8_t patch496_data[] = {
    0xF0, 
  };
  APPLY_PATCH(496);

  uint32_t patch497_addr = 0x001BE602;
  uint8_t patch497_data[] = {
    0xD0, 0x0E, 0xC0, 
  };
  APPLY_PATCH(497);

  uint32_t patch498_addr = 0x001BE610;
  uint8_t patch498_data[] = {
    0xCB, 
  };
  APPLY_PATCH(498);

  uint32_t patch499_addr = 0x001BE613;
  uint8_t patch499_data[] = {
    0xAA, 
  };
  APPLY_PATCH(499);

  uint32_t patch500_addr = 0x001BE615;
  uint8_t patch500_data[] = {
    0x09, 0xE0, 
  };
  APPLY_PATCH(500);

  uint32_t patch501_addr = 0x001BE61A;
  uint8_t patch501_data[] = {
    0x09, 0x90, 
  };
  APPLY_PATCH(501);

  uint32_t patch502_addr = 0x001BE628;
  uint8_t patch502_data[] = {
    0x0F, 
  };
  APPLY_PATCH(502);

  uint32_t patch503_addr = 0x001BE62A;
  uint8_t patch503_data[] = {
    0xD0, 0xEE, 0xC0, 0x0C, 
  };
  APPLY_PATCH(503);

  uint32_t patch504_addr = 0x001BE639;
  uint8_t patch504_data[] = {
    0x0D, 0x99, 
  };
  APPLY_PATCH(504);

  uint32_t patch505_addr = 0x001BE63D;
  uint8_t patch505_data[] = {
    0x90, 0x0D, 
  };
  APPLY_PATCH(505);

  uint32_t patch506_addr = 0x001BE669;
  uint8_t patch506_data[] = {
    0xC0, 
  };
  APPLY_PATCH(506);

  uint32_t patch507_addr = 0x001BE688;
  uint8_t patch507_data[] = {
    0x0B, 
  };
  APPLY_PATCH(507);

  uint32_t patch508_addr = 0x001BE68A;
  uint8_t patch508_data[] = {
    0x09, 
  };
  APPLY_PATCH(508);

  uint32_t patch509_addr = 0x001BE690;
  uint8_t patch509_data[] = {
    0xAA, 0x0B, 
  };
  APPLY_PATCH(509);

  uint32_t patch510_addr = 0x001BE693;
  uint8_t patch510_data[] = {
    0x99, 
  };
  APPLY_PATCH(510);

  uint32_t patch511_addr = 0x001BE6A0;
  uint8_t patch511_data[] = {
    0xF0, 
  };
  APPLY_PATCH(511);

  uint32_t patch512_addr = 0x001BE6B0;
  uint8_t patch512_data[] = {
    0xC0, 
  };
  APPLY_PATCH(512);

  uint32_t patch513_addr = 0x001BE6B2;
  uint8_t patch513_data[] = {
    0x09, 
  };
  APPLY_PATCH(513);

  uint32_t patch514_addr = 0x001BE6C8;
  uint8_t patch514_data[] = {
    0xF0, 
  };
  APPLY_PATCH(514);

  uint32_t patch515_addr = 0x001BE6D9;
  uint8_t patch515_data[] = {
    0x0D, 
  };
  APPLY_PATCH(515);

  uint32_t patch516_addr = 0x001BE6DD;
  uint8_t patch516_data[] = {
    0x90, 0xE0, 
  };
  APPLY_PATCH(516);

  uint32_t patch517_addr = 0x001BE6E1;
  uint8_t patch517_data[] = {
    0x0B, 
  };
  APPLY_PATCH(517);

  uint32_t patch518_addr = 0x001BE6E3;
  uint8_t patch518_data[] = {
    0x90, 
  };
  APPLY_PATCH(518);

  uint32_t patch519_addr = 0x001BE701;
  uint8_t patch519_data[] = {
    0x0D, 
  };
  APPLY_PATCH(519);

  uint32_t patch520_addr = 0x001BE705;
  uint8_t patch520_data[] = {
    0x90, 0xE0, 
  };
  APPLY_PATCH(520);

  uint32_t patch521_addr = 0x001BE709;
  uint8_t patch521_data[] = {
    0x0B, 
  };
  APPLY_PATCH(521);

  uint32_t patch522_addr = 0x001BE70B;
  uint8_t patch522_data[] = {
    0x90, 
  };
  APPLY_PATCH(522);

  uint32_t patch523_addr = 0x001BE729;
  uint8_t patch523_data[] = {
    0x0D, 
  };
  APPLY_PATCH(523);

  uint32_t patch524_addr = 0x001BE72D;
  uint8_t patch524_data[] = {
    0x90, 0xE0, 
  };
  APPLY_PATCH(524);

  uint32_t patch525_addr = 0x001BE731;
  uint8_t patch525_data[] = {
    0x0B, 
  };
  APPLY_PATCH(525);

  uint32_t patch526_addr = 0x001BE733;
  uint8_t patch526_data[] = {
    0x90, 
  };
  APPLY_PATCH(526);

  uint32_t patch527_addr = 0x001BE742;
  uint8_t patch527_data[] = {
    0xD0, 0x0E, 
  };
  APPLY_PATCH(527);

  uint32_t patch528_addr = 0x001BE756;
  uint8_t patch528_data[] = {
    0xED, 
  };
  APPLY_PATCH(528);

  uint32_t patch529_addr = 0x001BE758;
  uint8_t patch529_data[] = {
    0xAA, 0xCB, 
  };
  APPLY_PATCH(529);

  uint32_t patch530_addr = 0x001BE75B;
  uint8_t patch530_data[] = {
    0x90, 
  };
  APPLY_PATCH(530);

  uint32_t patch531_addr = 0x001BE768;
  uint8_t patch531_data[] = {
    0x0F, 
  };
  APPLY_PATCH(531);

  uint32_t patch532_addr = 0x001BE76B;
  uint8_t patch532_data[] = {
    0xF0, 0x0C, 
  };
  APPLY_PATCH(532);

  uint32_t patch533_addr = 0x001BE794;
  uint8_t patch533_data[] = {
    0xCC, 0x0C, 
  };
  APPLY_PATCH(533);

  uint32_t patch534_addr = 0x001BE7A1;
  uint8_t patch534_data[] = {
    0x60, 0x10, 0x22, 
  };
  APPLY_PATCH(534);

  uint32_t patch535_addr = 0x001BE7A5;
  uint8_t patch535_data[] = {
    0x01, 
  };
  APPLY_PATCH(535);

  uint32_t patch536_addr = 0x001BE7A8;
  uint8_t patch536_data[] = {
    0xAA, 
  };
  APPLY_PATCH(536);

  uint32_t patch537_addr = 0x001BE7AB;
  uint8_t patch537_data[] = {
    0x90, 
  };
  APPLY_PATCH(537);

  uint32_t patch538_addr = 0x001BE7B8;
  uint8_t patch538_data[] = {
    0x0F, 
  };
  APPLY_PATCH(538);

  uint32_t patch539_addr = 0x001BE7BB;
  uint8_t patch539_data[] = {
    0x0E, 
  };
  APPLY_PATCH(539);

  uint32_t patch540_addr = 0x001BE7C9;
  uint8_t patch540_data[] = {
    0x60, 0x10, 0x20, 
  };
  APPLY_PATCH(540);

  uint32_t patch541_addr = 0x001BE7CD;
  uint8_t patch541_data[] = {
    0x01, 
  };
  APPLY_PATCH(541);

  uint32_t patch542_addr = 0x001BE7E0;
  uint8_t patch542_data[] = {
    0xF0, 
  };
  APPLY_PATCH(542);

  uint32_t patch543_addr = 0x001BE7E2;
  uint8_t patch543_data[] = {
    0x0D, 0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(543);

  uint32_t patch544_addr = 0x001BE7F0;
  uint8_t patch544_data[] = {
    0x43, 0x05, 0x11, 0x20, 
  };
  APPLY_PATCH(544);

  uint32_t patch545_addr = 0x001BE7F5;
  uint8_t patch545_data[] = {
    0x11, 0xE0, 
  };
  APPLY_PATCH(545);

  uint32_t patch546_addr = 0x001BE7F8;
  uint8_t patch546_data[] = {
    0xAA, 
  };
  APPLY_PATCH(546);

  uint32_t patch547_addr = 0x001BE7FB;
  uint8_t patch547_data[] = {
    0x90, 
  };
  APPLY_PATCH(547);

  uint32_t patch548_addr = 0x001BE808;
  uint8_t patch548_data[] = {
    0x0F, 
  };
  APPLY_PATCH(548);

  uint32_t patch549_addr = 0x001BE80B;
  uint8_t patch549_data[] = {
    0x03, 0xCC, 0x2C, 
  };
  APPLY_PATCH(549);

  uint32_t patch550_addr = 0x001BE81E;
  uint8_t patch550_data[] = {
    0x0D, 
  };
  APPLY_PATCH(550);

  uint32_t patch551_addr = 0x001BE832;
  uint8_t patch551_data[] = {
    0xDD, 0x0E, 0x0C, 
  };
  APPLY_PATCH(551);

  uint32_t patch552_addr = 0x001BE841;
  uint8_t patch552_data[] = {
    0x60, 0x10, 0x22, 
  };
  APPLY_PATCH(552);

  uint32_t patch553_addr = 0x001BE845;
  uint8_t patch553_data[] = {
    0x10, 
  };
  APPLY_PATCH(553);

  uint32_t patch554_addr = 0x001BE848;
  uint8_t patch554_data[] = {
    0xAA, 0xCB, 
  };
  APPLY_PATCH(554);

  uint32_t patch555_addr = 0x001BE84B;
  uint8_t patch555_data[] = {
    0x90, 
  };
  APPLY_PATCH(555);

  uint32_t patch556_addr = 0x001BE858;
  uint8_t patch556_data[] = {
    0xFF, 
  };
  APPLY_PATCH(556);

  uint32_t patch557_addr = 0x001BE85B;
  uint8_t patch557_data[] = {
    0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(557);

  uint32_t patch558_addr = 0x001BE869;
  uint8_t patch558_data[] = {
    0x60, 0x10, 0x20, 
  };
  APPLY_PATCH(558);

  uint32_t patch559_addr = 0x001BE86D;
  uint8_t patch559_data[] = {
    0x11, 
  };
  APPLY_PATCH(559);

  uint32_t patch560_addr = 0x001BE884;
  uint8_t patch560_data[] = {
    0xC0, 
  };
  APPLY_PATCH(560);

  uint32_t patch561_addr = 0x001BE890;
  uint8_t patch561_data[] = {
    0x43, 0x65, 0x11, 0x22, 0x10, 0x10, 0xED, 
  };
  APPLY_PATCH(561);

  uint32_t patch562_addr = 0x001BE898;
  uint8_t patch562_data[] = {
    0xAA, 0xCB, 0x99, 0x99, 
  };
  APPLY_PATCH(562);

  uint32_t patch563_addr = 0x001BE8A8;
  uint8_t patch563_data[] = {
    0x0F, 
  };
  APPLY_PATCH(563);

  uint32_t patch564_addr = 0x001BE8AA;
  uint8_t patch564_data[] = {
    0xD0, 0xE0, 0xC0, 
  };
  APPLY_PATCH(564);

  uint32_t patch565_addr = 0x001BE8B9;
  uint8_t patch565_data[] = {
    0x05, 0x10, 0x20, 
  };
  APPLY_PATCH(565);

  uint32_t patch566_addr = 0x001BE8BD;
  uint8_t patch566_data[] = {
    0x10, 
  };
  APPLY_PATCH(566);

  uint32_t patch567_addr = 0x001BE8C0;
  uint8_t patch567_data[] = {
    0x0A, 
  };
  APPLY_PATCH(567);

  uint32_t patch568_addr = 0x001BE8D0;
  uint8_t patch568_data[] = {
    0xF0, 
  };
  APPLY_PATCH(568);

  uint32_t patch569_addr = 0x001BE8D2;
  uint8_t patch569_data[] = {
    0xDD, 
  };
  APPLY_PATCH(569);

  uint32_t patch570_addr = 0x001BE8D4;
  uint8_t patch570_data[] = {
    0xCC, 0xCC, 
  };
  APPLY_PATCH(570);

  uint32_t patch571_addr = 0x001BE8E0;
  uint8_t patch571_data[] = {
    0x40, 0x05, 0x10, 0x22, 
  };
  APPLY_PATCH(571);

  uint32_t patch572_addr = 0x001BE8E5;
  uint8_t patch572_data[] = {
    0x11, 
  };
  APPLY_PATCH(572);

  uint32_t patch573_addr = 0x001BE8E8;
  uint8_t patch573_data[] = {
    0xA0, 
  };
  APPLY_PATCH(573);

  uint32_t patch574_addr = 0x001BE8F8;
  uint8_t patch574_data[] = {
    0xF0, 
  };
  APPLY_PATCH(574);

  uint32_t patch575_addr = 0x001BE8FA;
  uint8_t patch575_data[] = {
    0xDD, 0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(575);

  uint32_t patch576_addr = 0x001BE909;
  uint8_t patch576_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(576);

  uint32_t patch577_addr = 0x001BE911;
  uint8_t patch577_data[] = {
    0x0B, 
  };
  APPLY_PATCH(577);

  uint32_t patch578_addr = 0x001BE920;
  uint8_t patch578_data[] = {
    0x0F, 
  };
  APPLY_PATCH(578);

  uint32_t patch579_addr = 0x001BE923;
  uint8_t patch579_data[] = {
    0x0E, 
  };
  APPLY_PATCH(579);

  uint32_t patch580_addr = 0x001BE933;
  uint8_t patch580_data[] = {
    0x20, 
  };
  APPLY_PATCH(580);

  uint32_t patch581_addr = 0x001BE94C;
  uint8_t patch581_data[] = {
    0xCC, 0x0C, 
  };
  APPLY_PATCH(581);

  uint32_t patch582_addr = 0x001BE95B;
  uint8_t patch582_data[] = {
    0x02, 
  };
  APPLY_PATCH(582);

  uint32_t patch583_addr = 0x001BE960;
  uint8_t patch583_data[] = {
    0x0A, 
  };
  APPLY_PATCH(583);

  uint32_t patch584_addr = 0x001BE962;
  uint8_t patch584_data[] = {
    0x90, 
  };
  APPLY_PATCH(584);

  uint32_t patch585_addr = 0x001BE970;
  uint8_t patch585_data[] = {
    0x0F, 
  };
  APPLY_PATCH(585);

  uint32_t patch586_addr = 0x001BE972;
  uint8_t patch586_data[] = {
    0x0D, 0xEE, 0x0C, 
  };
  APPLY_PATCH(586);

  uint32_t patch587_addr = 0x001BE980;
  uint8_t patch587_data[] = {
    0x43, 0x65, 0x11, 0x20, 
  };
  APPLY_PATCH(587);

  uint32_t patch588_addr = 0x001BE986;
  uint8_t patch588_data[] = {
    0xED, 
  };
  APPLY_PATCH(588);

  uint32_t patch589_addr = 0x001BE989;
  uint8_t patch589_data[] = {
    0xC0, 0x90, 0x90, 
  };
  APPLY_PATCH(589);

  uint32_t patch590_addr = 0x001BE998;
  uint8_t patch590_data[] = {
    0x0F, 
  };
  APPLY_PATCH(590);

  uint32_t patch591_addr = 0x001BE99A;
  uint8_t patch591_data[] = {
    0xDD, 
  };
  APPLY_PATCH(591);

  uint32_t patch592_addr = 0x001BE99C;
  uint8_t patch592_data[] = {
    0xC0, 0xC0, 
  };
  APPLY_PATCH(592);

  uint32_t patch593_addr = 0x001BE9AD;
  uint8_t patch593_data[] = {
    0x11, 0xE0, 
  };
  APPLY_PATCH(593);

  uint32_t patch594_addr = 0x001BE9B0;
  uint8_t patch594_data[] = {
    0x0A, 0x0B, 0x99, 0x09, 
  };
  APPLY_PATCH(594);

  uint32_t patch595_addr = 0x001BE9B5;
  uint8_t patch595_data[] = {
    0x90, 
  };
  APPLY_PATCH(595);

  uint32_t patch596_addr = 0x001BE9C0;
  uint8_t patch596_data[] = {
    0x0F, 
  };
  APPLY_PATCH(596);

  uint32_t patch597_addr = 0x001BE9C2;
  uint8_t patch597_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(597);

  uint32_t patch598_addr = 0x001BE9D6;
  uint8_t patch598_data[] = {
    0xE0, 
  };
  APPLY_PATCH(598);

  uint32_t patch599_addr = 0x001BE9D8;
  uint8_t patch599_data[] = {
    0xA0, 
  };
  APPLY_PATCH(599);

  uint32_t patch600_addr = 0x001BE9DA;
  uint8_t patch600_data[] = {
    0x09, 
  };
  APPLY_PATCH(600);

  uint32_t patch601_addr = 0x001BE9F8;
  uint8_t patch601_data[] = {
    0x43, 0x05, 0x11, 0x22, 
  };
  APPLY_PATCH(601);

  uint32_t patch602_addr = 0x001BE9FD;
  uint8_t patch602_data[] = {
    0x11, 0xE0, 
  };
  APPLY_PATCH(602);

  uint32_t patch603_addr = 0x001BEA00;
  uint8_t patch603_data[] = {
    0x0A, 0x0B, 0x09, 
  };
  APPLY_PATCH(603);

  uint32_t patch604_addr = 0x001BEA10;
  uint8_t patch604_data[] = {
    0xF0, 
  };
  APPLY_PATCH(604);

  uint32_t patch605_addr = 0x001BEA12;
  uint8_t patch605_data[] = {
    0xD0, 
  };
  APPLY_PATCH(605);

  uint32_t patch606_addr = 0x001BEA14;
  uint8_t patch606_data[] = {
    0x0C, 
  };
  APPLY_PATCH(606);

  uint32_t patch607_addr = 0x001BEA21;
  uint8_t patch607_data[] = {
    0x60, 
  };
  APPLY_PATCH(607);

  uint32_t patch608_addr = 0x001BEA23;
  uint8_t patch608_data[] = {
    0x02, 
  };
  APPLY_PATCH(608);

  uint32_t patch609_addr = 0x001BEA26;
  uint8_t patch609_data[] = {
    0xE0, 
  };
  APPLY_PATCH(609);

  uint32_t patch610_addr = 0x001BEA38;
  uint8_t patch610_data[] = {
    0x0F, 
  };
  APPLY_PATCH(610);

  uint32_t patch611_addr = 0x001BEA3C;
  uint8_t patch611_data[] = {
    0xCC, 
  };
  APPLY_PATCH(611);

  uint32_t patch612_addr = 0x001BEA49;
  uint8_t patch612_data[] = {
    0x60, 
  };
  APPLY_PATCH(612);

  uint32_t patch613_addr = 0x001BEA4B;
  uint8_t patch613_data[] = {
    0x02, 
  };
  APPLY_PATCH(613);

  uint32_t patch614_addr = 0x001BEA62;
  uint8_t patch614_data[] = {
    0xD0, 0x0E, 0x0C, 0xC0, 
  };
  APPLY_PATCH(614);

  uint32_t patch615_addr = 0x001BEA71;
  uint8_t patch615_data[] = {
    0x60, 0x10, 
  };
  APPLY_PATCH(615);

  uint32_t patch616_addr = 0x001BEA8C;
  uint8_t patch616_data[] = {
    0x0C, 
  };
  APPLY_PATCH(616);

  uint32_t patch617_addr = 0x001BEA98;
  uint8_t patch617_data[] = {
    0x40, 0x65, 
  };
  APPLY_PATCH(617);

  uint32_t patch618_addr = 0x001BEC50;
  uint8_t patch618_data[] = {
    0xCB, 0x0D, 0x99, 0xAA, 
  };
  APPLY_PATCH(618);

  uint32_t patch619_addr = 0x001BEC55;
  uint8_t patch619_data[] = {
    0x99, 
  };
  APPLY_PATCH(619);

  uint32_t patch620_addr = 0x001BEC5B;
  uint8_t patch620_data[] = {
    0x09, 
  };
  APPLY_PATCH(620);

  uint32_t patch621_addr = 0x001BEC79;
  uint8_t patch621_data[] = {
    0x0D, 
  };
  APPLY_PATCH(621);

  uint32_t patch622_addr = 0x001BEC80;
  uint8_t patch622_data[] = {
    0xA9, 
  };
  APPLY_PATCH(622);

  uint32_t patch623_addr = 0x001BEC82;
  uint8_t patch623_data[] = {
    0x99, 0x99, 
  };
  APPLY_PATCH(623);

  uint32_t patch624_addr = 0x001BECA1;
  uint8_t patch624_data[] = {
    0x0D, 
  };
  APPLY_PATCH(624);

  uint32_t patch625_addr = 0x001BECA7;
  uint8_t patch625_data[] = {
    0x0E, 
  };
  APPLY_PATCH(625);

  uint32_t patch626_addr = 0x001BECAB;
  uint8_t patch626_data[] = {
    0x09, 
  };
  APPLY_PATCH(626);

  uint32_t patch627_addr = 0x001BECC8;
  uint8_t patch627_data[] = {
    0xC0, 
  };
  APPLY_PATCH(627);

  uint32_t patch628_addr = 0x001BECCE;
  uint8_t patch628_data[] = {
    0xDC, 
  };
  APPLY_PATCH(628);

  uint32_t patch629_addr = 0x001BECD3;
  uint8_t patch629_data[] = {
    0x09, 
  };
  APPLY_PATCH(629);

  uint32_t patch630_addr = 0x001BECF0;
  uint8_t patch630_data[] = {
    0x0B, 
  };
  APPLY_PATCH(630);

  uint32_t patch631_addr = 0x001BECF3;
  uint8_t patch631_data[] = {
    0xB0, 
  };
  APPLY_PATCH(631);

  uint32_t patch632_addr = 0x001BECF8;
  uint8_t patch632_data[] = {
    0xA9, 0xBA, 0x99, 0x99, 
  };
  APPLY_PATCH(632);

  uint32_t patch633_addr = 0x001BED22;
  uint8_t patch633_data[] = {
    0x09, 0x09, 
  };
  APPLY_PATCH(633);

  uint32_t patch634_addr = 0x001BED25;
  uint8_t patch634_data[] = {
    0x90, 
  };
  APPLY_PATCH(634);

  uint32_t patch635_addr = 0x001BED43;
  uint8_t patch635_data[] = {
    0x0A, 
  };
  APPLY_PATCH(635);

  uint32_t patch636_addr = 0x001BED6B;
  uint8_t patch636_data[] = {
    0xA0, 
  };
  APPLY_PATCH(636);

  uint32_t patch637_addr = 0x001BED6E;
  uint8_t patch637_data[] = {
    0xD0, 
  };
  APPLY_PATCH(637);

  uint32_t patch638_addr = 0x001BED72;
  uint8_t patch638_data[] = {
    0x09, 0x09, 
  };
  APPLY_PATCH(638);

  uint32_t patch639_addr = 0x001BED75;
  uint8_t patch639_data[] = {
    0x90, 
  };
  APPLY_PATCH(639);

  uint32_t patch640_addr = 0x001BED93;
  uint8_t patch640_data[] = {
    0xA0, 
  };
  APPLY_PATCH(640);

  uint32_t patch641_addr = 0x001BED96;
  uint8_t patch641_data[] = {
    0xD0, 
  };
  APPLY_PATCH(641);

  uint32_t patch642_addr = 0x001BED9B;
  uint8_t patch642_data[] = {
    0x09, 
  };
  APPLY_PATCH(642);

  uint32_t patch643_addr = 0x001BEDA8;
  uint8_t patch643_data[] = {
    0x0F, 
  };
  APPLY_PATCH(643);

  uint32_t patch644_addr = 0x001BEDAA;
  uint8_t patch644_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(644);

  uint32_t patch645_addr = 0x001BEDBB;
  uint8_t patch645_data[] = {
    0x0A, 
  };
  APPLY_PATCH(645);

  uint32_t patch646_addr = 0x001BEDBE;
  uint8_t patch646_data[] = {
    0xD0, 
  };
  APPLY_PATCH(646);

  uint32_t patch647_addr = 0x001BEDC3;
  uint8_t patch647_data[] = {
    0x09, 
  };
  APPLY_PATCH(647);

  uint32_t patch648_addr = 0x001BEDD0;
  uint8_t patch648_data[] = {
    0xF0, 
  };
  APPLY_PATCH(648);

  uint32_t patch649_addr = 0x001BEDD2;
  uint8_t patch649_data[] = {
    0x0D, 
  };
  APPLY_PATCH(649);

  uint32_t patch650_addr = 0x001BEDD4;
  uint8_t patch650_data[] = {
    0xC0, 0x0C, 
  };
  APPLY_PATCH(650);

  uint32_t patch651_addr = 0x001BEDE3;
  uint8_t patch651_data[] = {
    0x0A, 
  };
  APPLY_PATCH(651);

  uint32_t patch652_addr = 0x001BEDE6;
  uint8_t patch652_data[] = {
    0xD0, 
  };
  APPLY_PATCH(652);

  uint32_t patch653_addr = 0x001BEDEB;
  uint8_t patch653_data[] = {
    0x09, 
  };
  APPLY_PATCH(653);

  uint32_t patch654_addr = 0x001BEDF8;
  uint8_t patch654_data[] = {
    0xF0, 
  };
  APPLY_PATCH(654);

  uint32_t patch655_addr = 0x001BEDFA;
  uint8_t patch655_data[] = {
    0x0D, 
  };
  APPLY_PATCH(655);

  uint32_t patch656_addr = 0x001BEE0B;
  uint8_t patch656_data[] = {
    0x0A, 
  };
  APPLY_PATCH(656);

  uint32_t patch657_addr = 0x001BEE0E;
  uint8_t patch657_data[] = {
    0xDC, 
  };
  APPLY_PATCH(657);

  uint32_t patch658_addr = 0x001BEE10;
  uint8_t patch658_data[] = {
    0xA9, 0xBA, 
  };
  APPLY_PATCH(658);

  uint32_t patch659_addr = 0x001BEE13;
  uint8_t patch659_data[] = {
    0x99, 
  };
  APPLY_PATCH(659);

  uint32_t patch660_addr = 0x001BEE32;
  uint8_t patch660_data[] = {
    0x09, 
  };
  APPLY_PATCH(660);

  uint32_t patch661_addr = 0x001BEE4A;
  uint8_t patch661_data[] = {
    0x0D, 
  };
  APPLY_PATCH(661);

  uint32_t patch662_addr = 0x001BEE5A;
  uint8_t patch662_data[] = {
    0x99, 0xAA, 
  };
  APPLY_PATCH(662);

  uint32_t patch663_addr = 0x001BEE5D;
  uint8_t patch663_data[] = {
    0x99, 
  };
  APPLY_PATCH(663);

  uint32_t patch664_addr = 0x001BEE74;
  uint8_t patch664_data[] = {
    0x0C, 
  };
  APPLY_PATCH(664);

  uint32_t patch665_addr = 0x001BEE81;
  uint8_t patch665_data[] = {
    0xE0, 0x09, 
  };
  APPLY_PATCH(665);

  uint32_t patch666_addr = 0x001BEE86;
  uint8_t patch666_data[] = {
    0xDC, 
  };
  APPLY_PATCH(666);

  uint32_t patch667_addr = 0x001BEE88;
  uint8_t patch667_data[] = {
    0x09, 
  };
  APPLY_PATCH(667);

  uint32_t patch668_addr = 0x001BEE8B;
  uint8_t patch668_data[] = {
    0x09, 
  };
  APPLY_PATCH(668);

  uint32_t patch669_addr = 0x001BEE9A;
  uint8_t patch669_data[] = {
    0x0D, 
  };
  APPLY_PATCH(669);

  uint32_t patch670_addr = 0x001BEE9C;
  uint8_t patch670_data[] = {
    0x0C, 
  };
  APPLY_PATCH(670);

  uint32_t patch671_addr = 0x001BEEA8;
  uint8_t patch671_data[] = {
    0xD0, 0x0D, 0x09, 
  };
  APPLY_PATCH(671);

  uint32_t patch672_addr = 0x001BEEAF;
  uint8_t patch672_data[] = {
    0x0E, 0x09, 0xBA, 
  };
  APPLY_PATCH(672);

  uint32_t patch673_addr = 0x001BEEB3;
  uint8_t patch673_data[] = {
    0x99, 
  };
  APPLY_PATCH(673);

  uint32_t patch674_addr = 0x001BEED0;
  uint8_t patch674_data[] = {
    0x0B, 
  };
  APPLY_PATCH(674);

  uint32_t patch675_addr = 0x001BEED2;
  uint8_t patch675_data[] = {
    0x99, 0xAA, 
  };
  APPLY_PATCH(675);

  uint32_t patch676_addr = 0x001BEED5;
  uint8_t patch676_data[] = {
    0x99, 
  };
  APPLY_PATCH(676);

  uint32_t patch677_addr = 0x001BEED7;
  uint8_t patch677_data[] = {
    0x0E, 0xA0, 
  };
  APPLY_PATCH(677);

  uint32_t patch678_addr = 0x001BEEDA;
  uint8_t patch678_data[] = {
    0x99, 0x09, 
  };
  APPLY_PATCH(678);

  uint32_t patch679_addr = 0x001BEEEA;
  uint8_t patch679_data[] = {
    0xDD, 0xEE, 
  };
  APPLY_PATCH(679);

  uint32_t patch680_addr = 0x001BEEED;
  uint8_t patch680_data[] = {
    0xCC, 
  };
  APPLY_PATCH(680);

  uint32_t patch681_addr = 0x001BEEFA;
  uint8_t patch681_data[] = {
    0x09, 
  };
  APPLY_PATCH(681);

  uint32_t patch682_addr = 0x001BEEFC;
  uint8_t patch682_data[] = {
    0x90, 0x09, 
  };
  APPLY_PATCH(682);

  uint32_t patch683_addr = 0x001BEEFF;
  uint8_t patch683_data[] = {
    0x0E, 0x09, 0x0A, 
  };
  APPLY_PATCH(683);

  uint32_t patch684_addr = 0x001BEF03;
  uint8_t patch684_data[] = {
    0x09, 
  };
  APPLY_PATCH(684);

  uint32_t patch685_addr = 0x001BEF10;
  uint8_t patch685_data[] = {
    0xFF, 
  };
  APPLY_PATCH(685);

  uint32_t patch686_addr = 0x001BEF12;
  uint8_t patch686_data[] = {
    0xD0, 0xEE, 
  };
  APPLY_PATCH(686);

  uint32_t patch687_addr = 0x001BEF23;
  uint8_t patch687_data[] = {
    0x0A, 
  };
  APPLY_PATCH(687);

  uint32_t patch688_addr = 0x001BEF27;
  uint8_t patch688_data[] = {
    0x0E, 
  };
  APPLY_PATCH(688);

  uint32_t patch689_addr = 0x001BEF2A;
  uint8_t patch689_data[] = {
    0x90, 
  };
  APPLY_PATCH(689);

  uint32_t patch690_addr = 0x001BEF38;
  uint8_t patch690_data[] = {
    0xFF, 
  };
  APPLY_PATCH(690);

  uint32_t patch691_addr = 0x001BEF3A;
  uint8_t patch691_data[] = {
    0xD0, 0xEE, 0xC0, 0x0C, 
  };
  APPLY_PATCH(691);

  uint32_t patch692_addr = 0x001BEF4B;
  uint8_t patch692_data[] = {
    0xA0, 0x90, 0x09, 
  };
  APPLY_PATCH(692);

  uint32_t patch693_addr = 0x001BEF60;
  uint8_t patch693_data[] = {
    0x0F, 
  };
  APPLY_PATCH(693);

  uint32_t patch694_addr = 0x001BEF62;
  uint8_t patch694_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(694);

  uint32_t patch695_addr = 0x001BEF73;
  uint8_t patch695_data[] = {
    0xA0, 
  };
  APPLY_PATCH(695);

  uint32_t patch696_addr = 0x001BEF7A;
  uint8_t patch696_data[] = {
    0x90, 
  };
  APPLY_PATCH(696);

  uint32_t patch697_addr = 0x001BEF88;
  uint8_t patch697_data[] = {
    0x0F, 
  };
  APPLY_PATCH(697);

  uint32_t patch698_addr = 0x001BEF8A;
  uint8_t patch698_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(698);

  uint32_t patch699_addr = 0x001BEF9B;
  uint8_t patch699_data[] = {
    0x0A, 
  };
  APPLY_PATCH(699);

  uint32_t patch700_addr = 0x001BEF9F;
  uint8_t patch700_data[] = {
    0x0E, 
  };
  APPLY_PATCH(700);

  uint32_t patch701_addr = 0x001BEFA2;
  uint8_t patch701_data[] = {
    0x90, 
  };
  APPLY_PATCH(701);

  uint32_t patch702_addr = 0x001BEFB0;
  uint8_t patch702_data[] = {
    0xF0, 
  };
  APPLY_PATCH(702);

  uint32_t patch703_addr = 0x001BEFB4;
  uint8_t patch703_data[] = {
    0x0C, 
  };
  APPLY_PATCH(703);

  uint32_t patch704_addr = 0x001BEFC3;
  uint8_t patch704_data[] = {
    0x0A, 
  };
  APPLY_PATCH(704);

  uint32_t patch705_addr = 0x001BEFC6;
  uint8_t patch705_data[] = {
    0x0C, 0x0E, 0xA9, 0xBA, 0x99, 0x09, 
  };
  APPLY_PATCH(705);

  uint32_t patch706_addr = 0x001BEFEB;
  uint8_t patch706_data[] = {
    0x0A, 
  };
  APPLY_PATCH(706);

  uint32_t patch707_addr = 0x001BEFEE;
  uint8_t patch707_data[] = {
    0xDC, 
  };
  APPLY_PATCH(707);

  uint32_t patch708_addr = 0x001BEFF0;
  uint8_t patch708_data[] = {
    0x09, 0x0A, 0x09, 0x09, 
  };
  APPLY_PATCH(708);

  uint32_t patch709_addr = 0x001BF000;
  uint8_t patch709_data[] = {
    0xF0, 
  };
  APPLY_PATCH(709);

  uint32_t patch710_addr = 0x001BF002;
  uint8_t patch710_data[] = {
    0xD0, 0x0E, 0xC0, 
  };
  APPLY_PATCH(710);

  uint32_t patch711_addr = 0x001BF016;
  uint8_t patch711_data[] = {
    0x0C, 
  };
  APPLY_PATCH(711);

  uint32_t patch712_addr = 0x001BF018;
  uint8_t patch712_data[] = {
    0x09, 0x0A, 0x99, 0x09, 
  };
  APPLY_PATCH(712);

  uint32_t patch713_addr = 0x001BF028;
  uint8_t patch713_data[] = {
    0x0F, 
  };
  APPLY_PATCH(713);

  uint32_t patch714_addr = 0x001BF02A;
  uint8_t patch714_data[] = {
    0xD0, 0xEE, 0xC0, 0x0C, 
  };
  APPLY_PATCH(714);

  uint32_t patch715_addr = 0x001BF038;
  uint8_t patch715_data[] = {
    0xCB, 
  };
  APPLY_PATCH(715);

  uint32_t patch716_addr = 0x001BF03B;
  uint8_t patch716_data[] = {
    0xAA, 
  };
  APPLY_PATCH(716);

  uint32_t patch717_addr = 0x001BF03D;
  uint8_t patch717_data[] = {
    0x09, 0xDC, 
  };
  APPLY_PATCH(717);

  uint32_t patch718_addr = 0x001BF040;
  uint8_t patch718_data[] = {
    0x09, 0x0A, 0x09, 0x09, 
  };
  APPLY_PATCH(718);

  uint32_t patch719_addr = 0x001BF061;
  uint8_t patch719_data[] = {
    0x0D, 0x99, 
  };
  APPLY_PATCH(719);

  uint32_t patch720_addr = 0x001BF065;
  uint8_t patch720_data[] = {
    0x90, 0x0C, 0x0E, 0xA9, 0xBA, 0x99, 0x09, 
  };
  APPLY_PATCH(720);

  uint32_t patch721_addr = 0x001BF092;
  uint8_t patch721_data[] = {
    0x90, 
  };
  APPLY_PATCH(721);

  uint32_t patch722_addr = 0x001BF0A0;
  uint8_t patch722_data[] = {
    0xF0, 
  };
  APPLY_PATCH(722);

  uint32_t patch723_addr = 0x001BF0B0;
  uint8_t patch723_data[] = {
    0x0B, 
  };
  APPLY_PATCH(723);

  uint32_t patch724_addr = 0x001BF0B2;
  uint8_t patch724_data[] = {
    0x09, 
  };
  APPLY_PATCH(724);

  uint32_t patch725_addr = 0x001BF0BA;
  uint8_t patch725_data[] = {
    0x90, 
  };
  APPLY_PATCH(725);

  uint32_t patch726_addr = 0x001BF0C8;
  uint8_t patch726_data[] = {
    0xF0, 
  };
  APPLY_PATCH(726);

  uint32_t patch727_addr = 0x001BF0D8;
  uint8_t patch727_data[] = {
    0xC0, 
  };
  APPLY_PATCH(727);

  uint32_t patch728_addr = 0x001BF0DA;
  uint8_t patch728_data[] = {
    0x09, 
  };
  APPLY_PATCH(728);

  uint32_t patch729_addr = 0x001BF0DF;
  uint8_t patch729_data[] = {
    0x0E, 0x09, 
  };
  APPLY_PATCH(729);

  uint32_t patch730_addr = 0x001BF101;
  uint8_t patch730_data[] = {
    0x0D, 
  };
  APPLY_PATCH(730);

  uint32_t patch731_addr = 0x001BF105;
  uint8_t patch731_data[] = {
    0x90, 0xD0, 
  };
  APPLY_PATCH(731);

  uint32_t patch732_addr = 0x001BF108;
  uint8_t patch732_data[] = {
    0x09, 0x0A, 0x90, 
  };
  APPLY_PATCH(732);

  uint32_t patch733_addr = 0x001BF129;
  uint8_t patch733_data[] = {
    0x0D, 
  };
  APPLY_PATCH(733);

  uint32_t patch734_addr = 0x001BF12D;
  uint8_t patch734_data[] = {
    0x90, 0xDC, 
  };
  APPLY_PATCH(734);

  uint32_t patch735_addr = 0x001BF130;
  uint8_t patch735_data[] = {
    0xA9, 0xBA, 
  };
  APPLY_PATCH(735);

  uint32_t patch736_addr = 0x001BF133;
  uint8_t patch736_data[] = {
    0x09, 
  };
  APPLY_PATCH(736);

  uint32_t patch737_addr = 0x001BF142;
  uint8_t patch737_data[] = {
    0xD0, 0x0E, 
  };
  APPLY_PATCH(737);

  uint32_t patch738_addr = 0x001BF151;
  uint8_t patch738_data[] = {
    0x0D, 
  };
  APPLY_PATCH(738);

  uint32_t patch739_addr = 0x001BF155;
  uint8_t patch739_data[] = {
    0x90, 0xD0, 
  };
  APPLY_PATCH(739);

  uint32_t patch740_addr = 0x001BF168;
  uint8_t patch740_data[] = {
    0x0F, 
  };
  APPLY_PATCH(740);

  uint32_t patch741_addr = 0x001BF16B;
  uint8_t patch741_data[] = {
    0xF0, 0x0C, 
  };
  APPLY_PATCH(741);

  uint32_t patch742_addr = 0x001BF17E;
  uint8_t patch742_data[] = {
    0xDC, 
  };
  APPLY_PATCH(742);

  uint32_t patch743_addr = 0x001BF180;
  uint8_t patch743_data[] = {
    0xA9, 0xBA, 0x09, 0x90, 
  };
  APPLY_PATCH(743);

  uint32_t patch744_addr = 0x001BF194;
  uint8_t patch744_data[] = {
    0xCC, 0x0C, 
  };
  APPLY_PATCH(744);

  uint32_t patch745_addr = 0x001BF1A7;
  uint8_t patch745_data[] = {
    0x0E, 0xA0, 0xB0, 0x99, 0x90, 
  };
  APPLY_PATCH(745);

  uint32_t patch746_addr = 0x001BF1B8;
  uint8_t patch746_data[] = {
    0x0F, 
  };
  APPLY_PATCH(746);

  uint32_t patch747_addr = 0x001BF1BB;
  uint8_t patch747_data[] = {
    0x0E, 
  };
  APPLY_PATCH(747);

  uint32_t patch748_addr = 0x001BF1C9;
  uint8_t patch748_data[] = {
    0x60, 0x10, 0x22, 
  };
  APPLY_PATCH(748);

  uint32_t patch749_addr = 0x001BF1CD;
  uint8_t patch749_data[] = {
    0x01, 0x0C, 0x0E, 0xA9, 0xBA, 0x09, 0x99, 
  };
  APPLY_PATCH(749);

  uint32_t patch750_addr = 0x001BF1E0;
  uint8_t patch750_data[] = {
    0xF0, 
  };
  APPLY_PATCH(750);

  uint32_t patch751_addr = 0x001BF1E2;
  uint8_t patch751_data[] = {
    0x0D, 0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(751);

  uint32_t patch752_addr = 0x001BF1F1;
  uint8_t patch752_data[] = {
    0x60, 0x10, 0x20, 
  };
  APPLY_PATCH(752);

  uint32_t patch753_addr = 0x001BF1F5;
  uint8_t patch753_data[] = {
    0x01, 
  };
  APPLY_PATCH(753);

  uint32_t patch754_addr = 0x001BF1F7;
  uint8_t patch754_data[] = {
    0x0E, 0xA0, 0xB0, 0x99, 0x90, 
  };
  APPLY_PATCH(754);

  uint32_t patch755_addr = 0x001BF208;
  uint8_t patch755_data[] = {
    0x0F, 
  };
  APPLY_PATCH(755);

  uint32_t patch756_addr = 0x001BF20B;
  uint8_t patch756_data[] = {
    0x03, 0xCC, 0x2C, 
  };
  APPLY_PATCH(756);

  uint32_t patch757_addr = 0x001BF218;
  uint8_t patch757_data[] = {
    0x43, 0x05, 0x11, 0x20, 
  };
  APPLY_PATCH(757);

  uint32_t patch758_addr = 0x001BF21D;
  uint8_t patch758_data[] = {
    0x11, 0x0C, 0x0E, 0xA9, 0xBA, 
  };
  APPLY_PATCH(758);

  uint32_t patch759_addr = 0x001BF223;
  uint8_t patch759_data[] = {
    0x90, 
  };
  APPLY_PATCH(759);

  uint32_t patch760_addr = 0x001BF232;
  uint8_t patch760_data[] = {
    0xDD, 0x0E, 0x0C, 
  };
  APPLY_PATCH(760);

  uint32_t patch761_addr = 0x001BF246;
  uint8_t patch761_data[] = {
    0xD0, 
  };
  APPLY_PATCH(761);

  uint32_t patch762_addr = 0x001BF258;
  uint8_t patch762_data[] = {
    0xFF, 
  };
  APPLY_PATCH(762);

  uint32_t patch763_addr = 0x001BF25B;
  uint8_t patch763_data[] = {
    0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(763);

  uint32_t patch764_addr = 0x001BF269;
  uint8_t patch764_data[] = {
    0x60, 0x10, 0x22, 
  };
  APPLY_PATCH(764);

  uint32_t patch765_addr = 0x001BF26D;
  uint8_t patch765_data[] = {
    0x10, 
  };
  APPLY_PATCH(765);

  uint32_t patch766_addr = 0x001BF273;
  uint8_t patch766_data[] = {
    0x09, 
  };
  APPLY_PATCH(766);

  uint32_t patch767_addr = 0x001BF284;
  uint8_t patch767_data[] = {
    0xC0, 
  };
  APPLY_PATCH(767);

  uint32_t patch768_addr = 0x001BF291;
  uint8_t patch768_data[] = {
    0x60, 0x10, 0x20, 
  };
  APPLY_PATCH(768);

  uint32_t patch769_addr = 0x001BF295;
  uint8_t patch769_data[] = {
    0x11, 
  };
  APPLY_PATCH(769);

  uint32_t patch770_addr = 0x001BF29B;
  uint8_t patch770_data[] = {
    0x90, 
  };
  APPLY_PATCH(770);

  uint32_t patch771_addr = 0x001BF2A8;
  uint8_t patch771_data[] = {
    0x0F, 
  };
  APPLY_PATCH(771);

  uint32_t patch772_addr = 0x001BF2AA;
  uint8_t patch772_data[] = {
    0xD0, 0xE0, 0xC0, 
  };
  APPLY_PATCH(772);

  uint32_t patch773_addr = 0x001BF2B8;
  uint8_t patch773_data[] = {
    0x43, 0x65, 0x11, 0x22, 0x10, 0x10, 
  };
  APPLY_PATCH(773);

  uint32_t patch774_addr = 0x001BF2C0;
  uint8_t patch774_data[] = {
    0xA0, 0x0A, 
  };
  APPLY_PATCH(774);

  uint32_t patch775_addr = 0x001BF2C3;
  uint8_t patch775_data[] = {
    0x90, 
  };
  APPLY_PATCH(775);

  uint32_t patch776_addr = 0x001BF2D0;
  uint8_t patch776_data[] = {
    0xF0, 
  };
  APPLY_PATCH(776);

  uint32_t patch777_addr = 0x001BF2D2;
  uint8_t patch777_data[] = {
    0xDD, 
  };
  APPLY_PATCH(777);

  uint32_t patch778_addr = 0x001BF2D4;
  uint8_t patch778_data[] = {
    0xCC, 0xCC, 
  };
  APPLY_PATCH(778);

  uint32_t patch779_addr = 0x001BF2E1;
  uint8_t patch779_data[] = {
    0x05, 0x10, 0x20, 
  };
  APPLY_PATCH(779);

  uint32_t patch780_addr = 0x001BF2E5;
  uint8_t patch780_data[] = {
    0x10, 
  };
  APPLY_PATCH(780);

  uint32_t patch781_addr = 0x001BF2E7;
  uint8_t patch781_data[] = {
    0x0E, 0x09, 0xB0, 
  };
  APPLY_PATCH(781);

  uint32_t patch782_addr = 0x001BF2EB;
  uint8_t patch782_data[] = {
    0x90, 
  };
  APPLY_PATCH(782);

  uint32_t patch783_addr = 0x001BF2F8;
  uint8_t patch783_data[] = {
    0xF0, 
  };
  APPLY_PATCH(783);

  uint32_t patch784_addr = 0x001BF2FA;
  uint8_t patch784_data[] = {
    0xDD, 0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(784);

  uint32_t patch785_addr = 0x001BF308;
  uint8_t patch785_data[] = {
    0x40, 0x05, 0x10, 0x22, 
  };
  APPLY_PATCH(785);

  uint32_t patch786_addr = 0x001BF30D;
  uint8_t patch786_data[] = {
    0x11, 0xDC, 
  };
  APPLY_PATCH(786);

  uint32_t patch787_addr = 0x001BF310;
  uint8_t patch787_data[] = {
    0xA9, 0xBA, 0x99, 0x99, 
  };
  APPLY_PATCH(787);

  uint32_t patch788_addr = 0x001BF320;
  uint8_t patch788_data[] = {
    0x0F, 
  };
  APPLY_PATCH(788);

  uint32_t patch789_addr = 0x001BF323;
  uint8_t patch789_data[] = {
    0x0E, 
  };
  APPLY_PATCH(789);

  uint32_t patch790_addr = 0x001BF331;
  uint8_t patch790_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(790);

  uint32_t patch791_addr = 0x001BF33B;
  uint8_t patch791_data[] = {
    0x09, 
  };
  APPLY_PATCH(791);

  uint32_t patch792_addr = 0x001BF34C;
  uint8_t patch792_data[] = {
    0xCC, 0x0C, 
  };
  APPLY_PATCH(792);

  uint32_t patch793_addr = 0x001BF35B;
  uint8_t patch793_data[] = {
    0x20, 
  };
  APPLY_PATCH(793);

  uint32_t patch794_addr = 0x001BF363;
  uint8_t patch794_data[] = {
    0x09, 
  };
  APPLY_PATCH(794);

  uint32_t patch795_addr = 0x001BF370;
  uint8_t patch795_data[] = {
    0x0F, 
  };
  APPLY_PATCH(795);

  uint32_t patch796_addr = 0x001BF372;
  uint8_t patch796_data[] = {
    0x0D, 0xEE, 0x0C, 
  };
  APPLY_PATCH(796);

  uint32_t patch797_addr = 0x001BF383;
  uint8_t patch797_data[] = {
    0x02, 
  };
  APPLY_PATCH(797);

  uint32_t patch798_addr = 0x001BF389;
  uint8_t patch798_data[] = {
    0x0A, 
  };
  APPLY_PATCH(798);

  uint32_t patch799_addr = 0x001BF398;
  uint8_t patch799_data[] = {
    0x0F, 
  };
  APPLY_PATCH(799);

  uint32_t patch800_addr = 0x001BF39A;
  uint8_t patch800_data[] = {
    0xDD, 
  };
  APPLY_PATCH(800);

  uint32_t patch801_addr = 0x001BF39C;
  uint8_t patch801_data[] = {
    0xC0, 0xC0, 
  };
  APPLY_PATCH(801);

  uint32_t patch802_addr = 0x001BF3A8;
  uint8_t patch802_data[] = {
    0x43, 0x65, 0x11, 0x20, 
  };
  APPLY_PATCH(802);

  uint32_t patch803_addr = 0x001BF3B0;
  uint8_t patch803_data[] = {
    0xA0, 
  };
  APPLY_PATCH(803);

  uint32_t patch804_addr = 0x001BF3C0;
  uint8_t patch804_data[] = {
    0x0F, 
  };
  APPLY_PATCH(804);

  uint32_t patch805_addr = 0x001BF3C2;
  uint8_t patch805_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(805);

  uint32_t patch806_addr = 0x001BF3D5;
  uint8_t patch806_data[] = {
    0x11, 0xD0, 
  };
  APPLY_PATCH(806);

  uint32_t patch807_addr = 0x001BF3D8;
  uint8_t patch807_data[] = {
    0xA9, 
  };
  APPLY_PATCH(807);

  uint32_t patch808_addr = 0x001BF3DA;
  uint8_t patch808_data[] = {
    0x09, 
  };
  APPLY_PATCH(808);

  uint32_t patch809_addr = 0x001BF3FE;
  uint8_t patch809_data[] = {
    0x0C, 0x0E, 0xA0, 
  };
  APPLY_PATCH(809);

  uint32_t patch810_addr = 0x001BF402;
  uint8_t patch810_data[] = {
    0x90, 0x90, 
  };
  APPLY_PATCH(810);

  uint32_t patch811_addr = 0x001BF410;
  uint8_t patch811_data[] = {
    0xF0, 
  };
  APPLY_PATCH(811);

  uint32_t patch812_addr = 0x001BF412;
  uint8_t patch812_data[] = {
    0xD0, 
  };
  APPLY_PATCH(812);

  uint32_t patch813_addr = 0x001BF414;
  uint8_t patch813_data[] = {
    0x0C, 
  };
  APPLY_PATCH(813);

  uint32_t patch814_addr = 0x001BF420;
  uint8_t patch814_data[] = {
    0x43, 0x05, 0x11, 0x22, 
  };
  APPLY_PATCH(814);

  uint32_t patch815_addr = 0x001BF425;
  uint8_t patch815_data[] = {
    0x11, 0x0C, 0x0E, 0xA0, 
  };
  APPLY_PATCH(815);

  uint32_t patch816_addr = 0x001BF42A;
  uint8_t patch816_data[] = {
    0x90, 0x09, 
  };
  APPLY_PATCH(816);

  uint32_t patch817_addr = 0x001BF438;
  uint8_t patch817_data[] = {
    0x0F, 
  };
  APPLY_PATCH(817);

  uint32_t patch818_addr = 0x001BF43C;
  uint8_t patch818_data[] = {
    0xCC, 
  };
  APPLY_PATCH(818);

  uint32_t patch819_addr = 0x001BF449;
  uint8_t patch819_data[] = {
    0x60, 
  };
  APPLY_PATCH(819);

  uint32_t patch820_addr = 0x001BF44B;
  uint8_t patch820_data[] = {
    0x02, 
  };
  APPLY_PATCH(820);

  uint32_t patch821_addr = 0x001BF44E;
  uint8_t patch821_data[] = {
    0xD0, 0x0E, 0xA0, 
  };
  APPLY_PATCH(821);

  uint32_t patch822_addr = 0x001BF452;
  uint8_t patch822_data[] = {
    0x99, 
  };
  APPLY_PATCH(822);

  uint32_t patch823_addr = 0x001BF462;
  uint8_t patch823_data[] = {
    0xD0, 0x0E, 0x0C, 0xC0, 
  };
  APPLY_PATCH(823);

  uint32_t patch824_addr = 0x001BF471;
  uint8_t patch824_data[] = {
    0x60, 
  };
  APPLY_PATCH(824);

  uint32_t patch825_addr = 0x001BF473;
  uint8_t patch825_data[] = {
    0x02, 
  };
  APPLY_PATCH(825);

  uint32_t patch826_addr = 0x001BF476;
  uint8_t patch826_data[] = {
    0x0C, 
  };
  APPLY_PATCH(826);

  uint32_t patch827_addr = 0x001BF479;
  uint8_t patch827_data[] = {
    0xBA, 
  };
  APPLY_PATCH(827);

  uint32_t patch828_addr = 0x001BF48C;
  uint8_t patch828_data[] = {
    0x0C, 
  };
  APPLY_PATCH(828);

  uint32_t patch829_addr = 0x001BF499;
  uint8_t patch829_data[] = {
    0x60, 0x10, 
  };
  APPLY_PATCH(829);

  uint32_t patch830_addr = 0x001BF4C0;
  uint8_t patch830_data[] = {
    0x40, 0x65, 
  };
  APPLY_PATCH(830);

  uint32_t patch831_addr = 0x001BF650;
  uint8_t patch831_data[] = {
    0xCB, 0x0D, 0x99, 0xAA, 
  };
  APPLY_PATCH(831);

  uint32_t patch832_addr = 0x001BF655;
  uint8_t patch832_data[] = {
    0x99, 
  };
  APPLY_PATCH(832);

  uint32_t patch833_addr = 0x001BF65B;
  uint8_t patch833_data[] = {
    0x09, 
  };
  APPLY_PATCH(833);

  uint32_t patch834_addr = 0x001BF679;
  uint8_t patch834_data[] = {
    0x0D, 
  };
  APPLY_PATCH(834);

  uint32_t patch835_addr = 0x001BF680;
  uint8_t patch835_data[] = {
    0xA9, 
  };
  APPLY_PATCH(835);

  uint32_t patch836_addr = 0x001BF682;
  uint8_t patch836_data[] = {
    0x99, 0x99, 
  };
  APPLY_PATCH(836);

  uint32_t patch837_addr = 0x001BF6A1;
  uint8_t patch837_data[] = {
    0x0D, 
  };
  APPLY_PATCH(837);

  uint32_t patch838_addr = 0x001BF6A7;
  uint8_t patch838_data[] = {
    0x0E, 
  };
  APPLY_PATCH(838);

  uint32_t patch839_addr = 0x001BF6AB;
  uint8_t patch839_data[] = {
    0x09, 
  };
  APPLY_PATCH(839);

  uint32_t patch840_addr = 0x001BF6C8;
  uint8_t patch840_data[] = {
    0xC0, 
  };
  APPLY_PATCH(840);

  uint32_t patch841_addr = 0x001BF6CE;
  uint8_t patch841_data[] = {
    0xDC, 
  };
  APPLY_PATCH(841);

  uint32_t patch842_addr = 0x001BF6D3;
  uint8_t patch842_data[] = {
    0x09, 
  };
  APPLY_PATCH(842);

  uint32_t patch843_addr = 0x001BF6F0;
  uint8_t patch843_data[] = {
    0x0B, 
  };
  APPLY_PATCH(843);

  uint32_t patch844_addr = 0x001BF6F3;
  uint8_t patch844_data[] = {
    0xB0, 
  };
  APPLY_PATCH(844);

  uint32_t patch845_addr = 0x001BF6F8;
  uint8_t patch845_data[] = {
    0xA9, 0xBA, 0x99, 0x99, 
  };
  APPLY_PATCH(845);

  uint32_t patch846_addr = 0x001BF722;
  uint8_t patch846_data[] = {
    0x09, 0x09, 
  };
  APPLY_PATCH(846);

  uint32_t patch847_addr = 0x001BF725;
  uint8_t patch847_data[] = {
    0x90, 
  };
  APPLY_PATCH(847);

  uint32_t patch848_addr = 0x001BF743;
  uint8_t patch848_data[] = {
    0x0A, 
  };
  APPLY_PATCH(848);

  uint32_t patch849_addr = 0x001BF76B;
  uint8_t patch849_data[] = {
    0xA0, 
  };
  APPLY_PATCH(849);

  uint32_t patch850_addr = 0x001BF76E;
  uint8_t patch850_data[] = {
    0xD0, 
  };
  APPLY_PATCH(850);

  uint32_t patch851_addr = 0x001BF772;
  uint8_t patch851_data[] = {
    0x09, 0x09, 
  };
  APPLY_PATCH(851);

  uint32_t patch852_addr = 0x001BF775;
  uint8_t patch852_data[] = {
    0x90, 
  };
  APPLY_PATCH(852);

  uint32_t patch853_addr = 0x001BF793;
  uint8_t patch853_data[] = {
    0xA0, 
  };
  APPLY_PATCH(853);

  uint32_t patch854_addr = 0x001BF796;
  uint8_t patch854_data[] = {
    0xD0, 
  };
  APPLY_PATCH(854);

  uint32_t patch855_addr = 0x001BF79B;
  uint8_t patch855_data[] = {
    0x09, 
  };
  APPLY_PATCH(855);

  uint32_t patch856_addr = 0x001BF7A8;
  uint8_t patch856_data[] = {
    0x0F, 
  };
  APPLY_PATCH(856);

  uint32_t patch857_addr = 0x001BF7AA;
  uint8_t patch857_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(857);

  uint32_t patch858_addr = 0x001BF7BB;
  uint8_t patch858_data[] = {
    0x0A, 
  };
  APPLY_PATCH(858);

  uint32_t patch859_addr = 0x001BF7BE;
  uint8_t patch859_data[] = {
    0xD0, 
  };
  APPLY_PATCH(859);

  uint32_t patch860_addr = 0x001BF7C3;
  uint8_t patch860_data[] = {
    0x09, 
  };
  APPLY_PATCH(860);

  uint32_t patch861_addr = 0x001BF7D0;
  uint8_t patch861_data[] = {
    0xF0, 
  };
  APPLY_PATCH(861);

  uint32_t patch862_addr = 0x001BF7D2;
  uint8_t patch862_data[] = {
    0x0D, 
  };
  APPLY_PATCH(862);

  uint32_t patch863_addr = 0x001BF7D4;
  uint8_t patch863_data[] = {
    0xC0, 0x0C, 
  };
  APPLY_PATCH(863);

  uint32_t patch864_addr = 0x001BF7E3;
  uint8_t patch864_data[] = {
    0x0A, 
  };
  APPLY_PATCH(864);

  uint32_t patch865_addr = 0x001BF7E6;
  uint8_t patch865_data[] = {
    0xD0, 
  };
  APPLY_PATCH(865);

  uint32_t patch866_addr = 0x001BF7EB;
  uint8_t patch866_data[] = {
    0x09, 
  };
  APPLY_PATCH(866);

  uint32_t patch867_addr = 0x001BF7F8;
  uint8_t patch867_data[] = {
    0xF0, 
  };
  APPLY_PATCH(867);

  uint32_t patch868_addr = 0x001BF7FA;
  uint8_t patch868_data[] = {
    0x0D, 
  };
  APPLY_PATCH(868);

  uint32_t patch869_addr = 0x001BF80B;
  uint8_t patch869_data[] = {
    0x0A, 
  };
  APPLY_PATCH(869);

  uint32_t patch870_addr = 0x001BF80E;
  uint8_t patch870_data[] = {
    0xDC, 
  };
  APPLY_PATCH(870);

  uint32_t patch871_addr = 0x001BF810;
  uint8_t patch871_data[] = {
    0xA9, 0xBA, 
  };
  APPLY_PATCH(871);

  uint32_t patch872_addr = 0x001BF813;
  uint8_t patch872_data[] = {
    0x99, 
  };
  APPLY_PATCH(872);

  uint32_t patch873_addr = 0x001BF832;
  uint8_t patch873_data[] = {
    0x09, 
  };
  APPLY_PATCH(873);

  uint32_t patch874_addr = 0x001BF84A;
  uint8_t patch874_data[] = {
    0x0D, 
  };
  APPLY_PATCH(874);

  uint32_t patch875_addr = 0x001BF85A;
  uint8_t patch875_data[] = {
    0x99, 0xAA, 
  };
  APPLY_PATCH(875);

  uint32_t patch876_addr = 0x001BF85D;
  uint8_t patch876_data[] = {
    0x99, 
  };
  APPLY_PATCH(876);

  uint32_t patch877_addr = 0x001BF874;
  uint8_t patch877_data[] = {
    0x0C, 
  };
  APPLY_PATCH(877);

  uint32_t patch878_addr = 0x001BF881;
  uint8_t patch878_data[] = {
    0xE0, 0x09, 
  };
  APPLY_PATCH(878);

  uint32_t patch879_addr = 0x001BF886;
  uint8_t patch879_data[] = {
    0xDC, 
  };
  APPLY_PATCH(879);

  uint32_t patch880_addr = 0x001BF888;
  uint8_t patch880_data[] = {
    0x09, 
  };
  APPLY_PATCH(880);

  uint32_t patch881_addr = 0x001BF88B;
  uint8_t patch881_data[] = {
    0x09, 
  };
  APPLY_PATCH(881);

  uint32_t patch882_addr = 0x001BF89A;
  uint8_t patch882_data[] = {
    0x0D, 
  };
  APPLY_PATCH(882);

  uint32_t patch883_addr = 0x001BF89C;
  uint8_t patch883_data[] = {
    0x0C, 
  };
  APPLY_PATCH(883);

  uint32_t patch884_addr = 0x001BF8A8;
  uint8_t patch884_data[] = {
    0xD0, 0x0D, 0x09, 
  };
  APPLY_PATCH(884);

  uint32_t patch885_addr = 0x001BF8AF;
  uint8_t patch885_data[] = {
    0x0E, 0x09, 0xBA, 
  };
  APPLY_PATCH(885);

  uint32_t patch886_addr = 0x001BF8B3;
  uint8_t patch886_data[] = {
    0x99, 
  };
  APPLY_PATCH(886);

  uint32_t patch887_addr = 0x001BF8D0;
  uint8_t patch887_data[] = {
    0x0B, 
  };
  APPLY_PATCH(887);

  uint32_t patch888_addr = 0x001BF8D2;
  uint8_t patch888_data[] = {
    0x99, 0xAA, 
  };
  APPLY_PATCH(888);

  uint32_t patch889_addr = 0x001BF8D5;
  uint8_t patch889_data[] = {
    0x99, 
  };
  APPLY_PATCH(889);

  uint32_t patch890_addr = 0x001BF8D7;
  uint8_t patch890_data[] = {
    0x0E, 0xA0, 
  };
  APPLY_PATCH(890);

  uint32_t patch891_addr = 0x001BF8DA;
  uint8_t patch891_data[] = {
    0x99, 0x09, 
  };
  APPLY_PATCH(891);

  uint32_t patch892_addr = 0x001BF8EA;
  uint8_t patch892_data[] = {
    0xDD, 0xEE, 
  };
  APPLY_PATCH(892);

  uint32_t patch893_addr = 0x001BF8ED;
  uint8_t patch893_data[] = {
    0xCC, 
  };
  APPLY_PATCH(893);

  uint32_t patch894_addr = 0x001BF8FA;
  uint8_t patch894_data[] = {
    0x09, 
  };
  APPLY_PATCH(894);

  uint32_t patch895_addr = 0x001BF8FC;
  uint8_t patch895_data[] = {
    0x90, 0x09, 
  };
  APPLY_PATCH(895);

  uint32_t patch896_addr = 0x001BF8FF;
  uint8_t patch896_data[] = {
    0x0E, 0x09, 0x0A, 
  };
  APPLY_PATCH(896);

  uint32_t patch897_addr = 0x001BF903;
  uint8_t patch897_data[] = {
    0x09, 
  };
  APPLY_PATCH(897);

  uint32_t patch898_addr = 0x001BF910;
  uint8_t patch898_data[] = {
    0xFF, 
  };
  APPLY_PATCH(898);

  uint32_t patch899_addr = 0x001BF912;
  uint8_t patch899_data[] = {
    0xD0, 0xEE, 
  };
  APPLY_PATCH(899);

  uint32_t patch900_addr = 0x001BF923;
  uint8_t patch900_data[] = {
    0x0A, 
  };
  APPLY_PATCH(900);

  uint32_t patch901_addr = 0x001BF927;
  uint8_t patch901_data[] = {
    0x0E, 
  };
  APPLY_PATCH(901);

  uint32_t patch902_addr = 0x001BF92A;
  uint8_t patch902_data[] = {
    0x90, 
  };
  APPLY_PATCH(902);

  uint32_t patch903_addr = 0x001BF938;
  uint8_t patch903_data[] = {
    0xFF, 
  };
  APPLY_PATCH(903);

  uint32_t patch904_addr = 0x001BF93A;
  uint8_t patch904_data[] = {
    0xD0, 0xEE, 0xC0, 0x0C, 
  };
  APPLY_PATCH(904);

  uint32_t patch905_addr = 0x001BF94B;
  uint8_t patch905_data[] = {
    0xA0, 0x90, 0x09, 
  };
  APPLY_PATCH(905);

  uint32_t patch906_addr = 0x001BF960;
  uint8_t patch906_data[] = {
    0x0F, 
  };
  APPLY_PATCH(906);

  uint32_t patch907_addr = 0x001BF962;
  uint8_t patch907_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(907);

  uint32_t patch908_addr = 0x001BF973;
  uint8_t patch908_data[] = {
    0xA0, 
  };
  APPLY_PATCH(908);

  uint32_t patch909_addr = 0x001BF97A;
  uint8_t patch909_data[] = {
    0x90, 
  };
  APPLY_PATCH(909);

  uint32_t patch910_addr = 0x001BF988;
  uint8_t patch910_data[] = {
    0x0F, 
  };
  APPLY_PATCH(910);

  uint32_t patch911_addr = 0x001BF98A;
  uint8_t patch911_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(911);

  uint32_t patch912_addr = 0x001BF99B;
  uint8_t patch912_data[] = {
    0x0A, 
  };
  APPLY_PATCH(912);

  uint32_t patch913_addr = 0x001BF99F;
  uint8_t patch913_data[] = {
    0x0E, 
  };
  APPLY_PATCH(913);

  uint32_t patch914_addr = 0x001BF9A2;
  uint8_t patch914_data[] = {
    0x90, 
  };
  APPLY_PATCH(914);

  uint32_t patch915_addr = 0x001BF9B0;
  uint8_t patch915_data[] = {
    0xF0, 
  };
  APPLY_PATCH(915);

  uint32_t patch916_addr = 0x001BF9B4;
  uint8_t patch916_data[] = {
    0x0C, 
  };
  APPLY_PATCH(916);

  uint32_t patch917_addr = 0x001BF9C3;
  uint8_t patch917_data[] = {
    0x0A, 
  };
  APPLY_PATCH(917);

  uint32_t patch918_addr = 0x001BF9C6;
  uint8_t patch918_data[] = {
    0x0C, 0x0E, 0xA9, 0xBA, 0x99, 0x09, 
  };
  APPLY_PATCH(918);

  uint32_t patch919_addr = 0x001BF9EB;
  uint8_t patch919_data[] = {
    0x0A, 
  };
  APPLY_PATCH(919);

  uint32_t patch920_addr = 0x001BF9EE;
  uint8_t patch920_data[] = {
    0xDC, 
  };
  APPLY_PATCH(920);

  uint32_t patch921_addr = 0x001BF9F0;
  uint8_t patch921_data[] = {
    0x09, 0x0A, 0x09, 0x09, 
  };
  APPLY_PATCH(921);

  uint32_t patch922_addr = 0x001BFA00;
  uint8_t patch922_data[] = {
    0xF0, 
  };
  APPLY_PATCH(922);

  uint32_t patch923_addr = 0x001BFA02;
  uint8_t patch923_data[] = {
    0xD0, 0x0E, 0xC0, 
  };
  APPLY_PATCH(923);

  uint32_t patch924_addr = 0x001BFA16;
  uint8_t patch924_data[] = {
    0x0C, 
  };
  APPLY_PATCH(924);

  uint32_t patch925_addr = 0x001BFA18;
  uint8_t patch925_data[] = {
    0x09, 0x0A, 0x99, 0x09, 
  };
  APPLY_PATCH(925);

  uint32_t patch926_addr = 0x001BFA28;
  uint8_t patch926_data[] = {
    0x0F, 
  };
  APPLY_PATCH(926);

  uint32_t patch927_addr = 0x001BFA2A;
  uint8_t patch927_data[] = {
    0xD0, 0xEE, 0xC0, 0x0C, 
  };
  APPLY_PATCH(927);

  uint32_t patch928_addr = 0x001BFA38;
  uint8_t patch928_data[] = {
    0xCB, 
  };
  APPLY_PATCH(928);

  uint32_t patch929_addr = 0x001BFA3B;
  uint8_t patch929_data[] = {
    0xAA, 
  };
  APPLY_PATCH(929);

  uint32_t patch930_addr = 0x001BFA3D;
  uint8_t patch930_data[] = {
    0x09, 0xDC, 
  };
  APPLY_PATCH(930);

  uint32_t patch931_addr = 0x001BFA40;
  uint8_t patch931_data[] = {
    0x09, 0x0A, 0x09, 0x09, 
  };
  APPLY_PATCH(931);

  uint32_t patch932_addr = 0x001BFA61;
  uint8_t patch932_data[] = {
    0x0D, 0x99, 
  };
  APPLY_PATCH(932);

  uint32_t patch933_addr = 0x001BFA65;
  uint8_t patch933_data[] = {
    0x90, 0x0C, 0x0E, 0xA9, 0xBA, 0x99, 0x09, 
  };
  APPLY_PATCH(933);

  uint32_t patch934_addr = 0x001BFA92;
  uint8_t patch934_data[] = {
    0x90, 
  };
  APPLY_PATCH(934);

  uint32_t patch935_addr = 0x001BFAA0;
  uint8_t patch935_data[] = {
    0xF0, 
  };
  APPLY_PATCH(935);

  uint32_t patch936_addr = 0x001BFAB0;
  uint8_t patch936_data[] = {
    0x0B, 
  };
  APPLY_PATCH(936);

  uint32_t patch937_addr = 0x001BFAB2;
  uint8_t patch937_data[] = {
    0x09, 
  };
  APPLY_PATCH(937);

  uint32_t patch938_addr = 0x001BFABA;
  uint8_t patch938_data[] = {
    0x90, 
  };
  APPLY_PATCH(938);

  uint32_t patch939_addr = 0x001BFAC8;
  uint8_t patch939_data[] = {
    0xF0, 
  };
  APPLY_PATCH(939);

  uint32_t patch940_addr = 0x001BFAD8;
  uint8_t patch940_data[] = {
    0xC0, 
  };
  APPLY_PATCH(940);

  uint32_t patch941_addr = 0x001BFADA;
  uint8_t patch941_data[] = {
    0x09, 
  };
  APPLY_PATCH(941);

  uint32_t patch942_addr = 0x001BFADF;
  uint8_t patch942_data[] = {
    0x0E, 0x09, 
  };
  APPLY_PATCH(942);

  uint32_t patch943_addr = 0x001BFB01;
  uint8_t patch943_data[] = {
    0x0D, 
  };
  APPLY_PATCH(943);

  uint32_t patch944_addr = 0x001BFB05;
  uint8_t patch944_data[] = {
    0x90, 0xD0, 
  };
  APPLY_PATCH(944);

  uint32_t patch945_addr = 0x001BFB08;
  uint8_t patch945_data[] = {
    0x09, 0x0A, 0x90, 
  };
  APPLY_PATCH(945);

  uint32_t patch946_addr = 0x001BFB29;
  uint8_t patch946_data[] = {
    0x0D, 
  };
  APPLY_PATCH(946);

  uint32_t patch947_addr = 0x001BFB2D;
  uint8_t patch947_data[] = {
    0x90, 0xDC, 
  };
  APPLY_PATCH(947);

  uint32_t patch948_addr = 0x001BFB30;
  uint8_t patch948_data[] = {
    0xA9, 0xBA, 
  };
  APPLY_PATCH(948);

  uint32_t patch949_addr = 0x001BFB33;
  uint8_t patch949_data[] = {
    0x09, 
  };
  APPLY_PATCH(949);

  uint32_t patch950_addr = 0x001BFB42;
  uint8_t patch950_data[] = {
    0xD0, 0x0E, 
  };
  APPLY_PATCH(950);

  uint32_t patch951_addr = 0x001BFB51;
  uint8_t patch951_data[] = {
    0x0D, 
  };
  APPLY_PATCH(951);

  uint32_t patch952_addr = 0x001BFB55;
  uint8_t patch952_data[] = {
    0x90, 0xD0, 
  };
  APPLY_PATCH(952);

  uint32_t patch953_addr = 0x001BFB68;
  uint8_t patch953_data[] = {
    0x0F, 
  };
  APPLY_PATCH(953);

  uint32_t patch954_addr = 0x001BFB6B;
  uint8_t patch954_data[] = {
    0xF0, 0x0C, 
  };
  APPLY_PATCH(954);

  uint32_t patch955_addr = 0x001BFB7E;
  uint8_t patch955_data[] = {
    0xDC, 
  };
  APPLY_PATCH(955);

  uint32_t patch956_addr = 0x001BFB80;
  uint8_t patch956_data[] = {
    0xA9, 0xBA, 0x09, 0x90, 
  };
  APPLY_PATCH(956);

  uint32_t patch957_addr = 0x001BFB94;
  uint8_t patch957_data[] = {
    0xCC, 0x0C, 
  };
  APPLY_PATCH(957);

  uint32_t patch958_addr = 0x001BFBA7;
  uint8_t patch958_data[] = {
    0x0E, 0xA0, 0xB0, 0x99, 0x90, 
  };
  APPLY_PATCH(958);

  uint32_t patch959_addr = 0x001BFBB8;
  uint8_t patch959_data[] = {
    0x0F, 
  };
  APPLY_PATCH(959);

  uint32_t patch960_addr = 0x001BFBBB;
  uint8_t patch960_data[] = {
    0x0E, 
  };
  APPLY_PATCH(960);

  uint32_t patch961_addr = 0x001BFBC9;
  uint8_t patch961_data[] = {
    0x60, 0x10, 0x22, 
  };
  APPLY_PATCH(961);

  uint32_t patch962_addr = 0x001BFBCD;
  uint8_t patch962_data[] = {
    0x01, 0x0C, 0x0E, 0xA9, 0xBA, 0x09, 0x99, 
  };
  APPLY_PATCH(962);

  uint32_t patch963_addr = 0x001BFBE0;
  uint8_t patch963_data[] = {
    0xF0, 
  };
  APPLY_PATCH(963);

  uint32_t patch964_addr = 0x001BFBE2;
  uint8_t patch964_data[] = {
    0x0D, 0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(964);

  uint32_t patch965_addr = 0x001BFBF1;
  uint8_t patch965_data[] = {
    0x60, 0x10, 0x20, 
  };
  APPLY_PATCH(965);

  uint32_t patch966_addr = 0x001BFBF5;
  uint8_t patch966_data[] = {
    0x01, 
  };
  APPLY_PATCH(966);

  uint32_t patch967_addr = 0x001BFBF7;
  uint8_t patch967_data[] = {
    0x0E, 0xA0, 0xB0, 0x99, 0x90, 
  };
  APPLY_PATCH(967);

  uint32_t patch968_addr = 0x001BFC08;
  uint8_t patch968_data[] = {
    0x0F, 
  };
  APPLY_PATCH(968);

  uint32_t patch969_addr = 0x001BFC0B;
  uint8_t patch969_data[] = {
    0x03, 0xCC, 0x2C, 
  };
  APPLY_PATCH(969);

  uint32_t patch970_addr = 0x001BFC18;
  uint8_t patch970_data[] = {
    0x43, 0x05, 0x11, 0x20, 
  };
  APPLY_PATCH(970);

  uint32_t patch971_addr = 0x001BFC1D;
  uint8_t patch971_data[] = {
    0x11, 0x0C, 0x0E, 0xA9, 0xBA, 
  };
  APPLY_PATCH(971);

  uint32_t patch972_addr = 0x001BFC23;
  uint8_t patch972_data[] = {
    0x90, 
  };
  APPLY_PATCH(972);

  uint32_t patch973_addr = 0x001BFC32;
  uint8_t patch973_data[] = {
    0xDD, 0x0E, 0x0C, 
  };
  APPLY_PATCH(973);

  uint32_t patch974_addr = 0x001BFC46;
  uint8_t patch974_data[] = {
    0xD0, 
  };
  APPLY_PATCH(974);

  uint32_t patch975_addr = 0x001BFC58;
  uint8_t patch975_data[] = {
    0xFF, 
  };
  APPLY_PATCH(975);

  uint32_t patch976_addr = 0x001BFC5B;
  uint8_t patch976_data[] = {
    0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(976);

  uint32_t patch977_addr = 0x001BFC69;
  uint8_t patch977_data[] = {
    0x60, 0x10, 0x22, 
  };
  APPLY_PATCH(977);

  uint32_t patch978_addr = 0x001BFC6D;
  uint8_t patch978_data[] = {
    0x10, 
  };
  APPLY_PATCH(978);

  uint32_t patch979_addr = 0x001BFC73;
  uint8_t patch979_data[] = {
    0x09, 
  };
  APPLY_PATCH(979);

  uint32_t patch980_addr = 0x001BFC84;
  uint8_t patch980_data[] = {
    0xC0, 
  };
  APPLY_PATCH(980);

  uint32_t patch981_addr = 0x001BFC91;
  uint8_t patch981_data[] = {
    0x60, 0x10, 0x20, 
  };
  APPLY_PATCH(981);

  uint32_t patch982_addr = 0x001BFC95;
  uint8_t patch982_data[] = {
    0x11, 
  };
  APPLY_PATCH(982);

  uint32_t patch983_addr = 0x001BFC9B;
  uint8_t patch983_data[] = {
    0x90, 
  };
  APPLY_PATCH(983);

  uint32_t patch984_addr = 0x001BFCA8;
  uint8_t patch984_data[] = {
    0x0F, 
  };
  APPLY_PATCH(984);

  uint32_t patch985_addr = 0x001BFCAA;
  uint8_t patch985_data[] = {
    0xD0, 0xE0, 0xC0, 
  };
  APPLY_PATCH(985);

  uint32_t patch986_addr = 0x001BFCB8;
  uint8_t patch986_data[] = {
    0x43, 0x65, 0x11, 0x22, 0x10, 0x10, 
  };
  APPLY_PATCH(986);

  uint32_t patch987_addr = 0x001BFCC0;
  uint8_t patch987_data[] = {
    0xA0, 0x0A, 
  };
  APPLY_PATCH(987);

  uint32_t patch988_addr = 0x001BFCC3;
  uint8_t patch988_data[] = {
    0x90, 
  };
  APPLY_PATCH(988);

  uint32_t patch989_addr = 0x001BFCD0;
  uint8_t patch989_data[] = {
    0xF0, 
  };
  APPLY_PATCH(989);

  uint32_t patch990_addr = 0x001BFCD2;
  uint8_t patch990_data[] = {
    0xDD, 
  };
  APPLY_PATCH(990);

  uint32_t patch991_addr = 0x001BFCD4;
  uint8_t patch991_data[] = {
    0xCC, 0xCC, 
  };
  APPLY_PATCH(991);

  uint32_t patch992_addr = 0x001BFCE1;
  uint8_t patch992_data[] = {
    0x05, 0x10, 0x20, 
  };
  APPLY_PATCH(992);

  uint32_t patch993_addr = 0x001BFCE5;
  uint8_t patch993_data[] = {
    0x10, 
  };
  APPLY_PATCH(993);

  uint32_t patch994_addr = 0x001BFCE7;
  uint8_t patch994_data[] = {
    0x0E, 0x09, 0xB0, 
  };
  APPLY_PATCH(994);

  uint32_t patch995_addr = 0x001BFCEB;
  uint8_t patch995_data[] = {
    0x90, 
  };
  APPLY_PATCH(995);

  uint32_t patch996_addr = 0x001BFCF8;
  uint8_t patch996_data[] = {
    0xF0, 
  };
  APPLY_PATCH(996);

  uint32_t patch997_addr = 0x001BFCFA;
  uint8_t patch997_data[] = {
    0xDD, 0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(997);

  uint32_t patch998_addr = 0x001BFD08;
  uint8_t patch998_data[] = {
    0x40, 0x05, 0x10, 0x22, 
  };
  APPLY_PATCH(998);

  uint32_t patch999_addr = 0x001BFD0D;
  uint8_t patch999_data[] = {
    0x11, 0xDC, 
  };
  APPLY_PATCH(999);

  uint32_t patch1000_addr = 0x001BFD10;
  uint8_t patch1000_data[] = {
    0xA9, 0xBA, 0x99, 0x99, 
  };
  APPLY_PATCH(1000);

  uint32_t patch1001_addr = 0x001BFD20;
  uint8_t patch1001_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1001);

  uint32_t patch1002_addr = 0x001BFD23;
  uint8_t patch1002_data[] = {
    0x0E, 
  };
  APPLY_PATCH(1002);

  uint32_t patch1003_addr = 0x001BFD31;
  uint8_t patch1003_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(1003);

  uint32_t patch1004_addr = 0x001BFD3B;
  uint8_t patch1004_data[] = {
    0x09, 
  };
  APPLY_PATCH(1004);

  uint32_t patch1005_addr = 0x001BFD4C;
  uint8_t patch1005_data[] = {
    0xCC, 0x0C, 
  };
  APPLY_PATCH(1005);

  uint32_t patch1006_addr = 0x001BFD5B;
  uint8_t patch1006_data[] = {
    0x20, 
  };
  APPLY_PATCH(1006);

  uint32_t patch1007_addr = 0x001BFD63;
  uint8_t patch1007_data[] = {
    0x09, 
  };
  APPLY_PATCH(1007);

  uint32_t patch1008_addr = 0x001BFD70;
  uint8_t patch1008_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1008);

  uint32_t patch1009_addr = 0x001BFD72;
  uint8_t patch1009_data[] = {
    0x0D, 0xEE, 0x0C, 
  };
  APPLY_PATCH(1009);

  uint32_t patch1010_addr = 0x001BFD83;
  uint8_t patch1010_data[] = {
    0x02, 
  };
  APPLY_PATCH(1010);

  uint32_t patch1011_addr = 0x001BFD89;
  uint8_t patch1011_data[] = {
    0x0A, 
  };
  APPLY_PATCH(1011);

  uint32_t patch1012_addr = 0x001BFD98;
  uint8_t patch1012_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1012);

  uint32_t patch1013_addr = 0x001BFD9A;
  uint8_t patch1013_data[] = {
    0xDD, 
  };
  APPLY_PATCH(1013);

  uint32_t patch1014_addr = 0x001BFD9C;
  uint8_t patch1014_data[] = {
    0xC0, 0xC0, 
  };
  APPLY_PATCH(1014);

  uint32_t patch1015_addr = 0x001BFDA8;
  uint8_t patch1015_data[] = {
    0x43, 0x65, 0x11, 0x20, 
  };
  APPLY_PATCH(1015);

  uint32_t patch1016_addr = 0x001BFDB0;
  uint8_t patch1016_data[] = {
    0xA0, 
  };
  APPLY_PATCH(1016);

  uint32_t patch1017_addr = 0x001BFDC0;
  uint8_t patch1017_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1017);

  uint32_t patch1018_addr = 0x001BFDC2;
  uint8_t patch1018_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(1018);

  uint32_t patch1019_addr = 0x001BFDD5;
  uint8_t patch1019_data[] = {
    0x11, 0xD0, 
  };
  APPLY_PATCH(1019);

  uint32_t patch1020_addr = 0x001BFDD8;
  uint8_t patch1020_data[] = {
    0xA9, 
  };
  APPLY_PATCH(1020);

  uint32_t patch1021_addr = 0x001BFDDA;
  uint8_t patch1021_data[] = {
    0x09, 
  };
  APPLY_PATCH(1021);

  uint32_t patch1022_addr = 0x001BFDFE;
  uint8_t patch1022_data[] = {
    0x0C, 0x0E, 0xA0, 
  };
  APPLY_PATCH(1022);

  uint32_t patch1023_addr = 0x001BFE02;
  uint8_t patch1023_data[] = {
    0x90, 0x90, 
  };
  APPLY_PATCH(1023);

  uint32_t patch1024_addr = 0x001BFE10;
  uint8_t patch1024_data[] = {
    0xF0, 
  };
  APPLY_PATCH(1024);

  uint32_t patch1025_addr = 0x001BFE12;
  uint8_t patch1025_data[] = {
    0xD0, 
  };
  APPLY_PATCH(1025);

  uint32_t patch1026_addr = 0x001BFE14;
  uint8_t patch1026_data[] = {
    0x0C, 
  };
  APPLY_PATCH(1026);

  uint32_t patch1027_addr = 0x001BFE20;
  uint8_t patch1027_data[] = {
    0x43, 0x05, 0x11, 0x22, 
  };
  APPLY_PATCH(1027);

  uint32_t patch1028_addr = 0x001BFE25;
  uint8_t patch1028_data[] = {
    0x11, 0x0C, 0x0E, 0xA0, 
  };
  APPLY_PATCH(1028);

  uint32_t patch1029_addr = 0x001BFE2A;
  uint8_t patch1029_data[] = {
    0x90, 0x09, 
  };
  APPLY_PATCH(1029);

  uint32_t patch1030_addr = 0x001BFE38;
  uint8_t patch1030_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1030);

  uint32_t patch1031_addr = 0x001BFE3C;
  uint8_t patch1031_data[] = {
    0xCC, 
  };
  APPLY_PATCH(1031);

  uint32_t patch1032_addr = 0x001BFE49;
  uint8_t patch1032_data[] = {
    0x60, 
  };
  APPLY_PATCH(1032);

  uint32_t patch1033_addr = 0x001BFE4B;
  uint8_t patch1033_data[] = {
    0x02, 
  };
  APPLY_PATCH(1033);

  uint32_t patch1034_addr = 0x001BFE4E;
  uint8_t patch1034_data[] = {
    0xD0, 0x0E, 0xA0, 
  };
  APPLY_PATCH(1034);

  uint32_t patch1035_addr = 0x001BFE52;
  uint8_t patch1035_data[] = {
    0x99, 
  };
  APPLY_PATCH(1035);

  uint32_t patch1036_addr = 0x001BFE62;
  uint8_t patch1036_data[] = {
    0xD0, 0x0E, 0x0C, 0xC0, 
  };
  APPLY_PATCH(1036);

  uint32_t patch1037_addr = 0x001BFE71;
  uint8_t patch1037_data[] = {
    0x60, 
  };
  APPLY_PATCH(1037);

  uint32_t patch1038_addr = 0x001BFE73;
  uint8_t patch1038_data[] = {
    0x02, 
  };
  APPLY_PATCH(1038);

  uint32_t patch1039_addr = 0x001BFE76;
  uint8_t patch1039_data[] = {
    0x0C, 
  };
  APPLY_PATCH(1039);

  uint32_t patch1040_addr = 0x001BFE79;
  uint8_t patch1040_data[] = {
    0xBA, 
  };
  APPLY_PATCH(1040);

  uint32_t patch1041_addr = 0x001BFE8C;
  uint8_t patch1041_data[] = {
    0x0C, 
  };
  APPLY_PATCH(1041);

  uint32_t patch1042_addr = 0x001BFE99;
  uint8_t patch1042_data[] = {
    0x60, 0x10, 
  };
  APPLY_PATCH(1042);

  uint32_t patch1043_addr = 0x001BFEC0;
  uint8_t patch1043_data[] = {
    0x40, 0x65, 
  };
  APPLY_PATCH(1043);

  uint32_t patch1044_addr = 0x001C0050;
  uint8_t patch1044_data[] = {
    0xCB, 0x0D, 0x99, 0xAA, 
  };
  APPLY_PATCH(1044);

  uint32_t patch1045_addr = 0x001C0055;
  uint8_t patch1045_data[] = {
    0x99, 
  };
  APPLY_PATCH(1045);

  uint32_t patch1046_addr = 0x001C005B;
  uint8_t patch1046_data[] = {
    0x09, 
  };
  APPLY_PATCH(1046);

  uint32_t patch1047_addr = 0x001C0079;
  uint8_t patch1047_data[] = {
    0x0D, 
  };
  APPLY_PATCH(1047);

  uint32_t patch1048_addr = 0x001C0080;
  uint8_t patch1048_data[] = {
    0xA9, 
  };
  APPLY_PATCH(1048);

  uint32_t patch1049_addr = 0x001C0082;
  uint8_t patch1049_data[] = {
    0x99, 0x99, 
  };
  APPLY_PATCH(1049);

  uint32_t patch1050_addr = 0x001C00A1;
  uint8_t patch1050_data[] = {
    0x0D, 
  };
  APPLY_PATCH(1050);

  uint32_t patch1051_addr = 0x001C00A7;
  uint8_t patch1051_data[] = {
    0x0E, 
  };
  APPLY_PATCH(1051);

  uint32_t patch1052_addr = 0x001C00AB;
  uint8_t patch1052_data[] = {
    0x09, 
  };
  APPLY_PATCH(1052);

  uint32_t patch1053_addr = 0x001C00C8;
  uint8_t patch1053_data[] = {
    0xC0, 
  };
  APPLY_PATCH(1053);

  uint32_t patch1054_addr = 0x001C00CE;
  uint8_t patch1054_data[] = {
    0xDC, 
  };
  APPLY_PATCH(1054);

  uint32_t patch1055_addr = 0x001C00D3;
  uint8_t patch1055_data[] = {
    0x09, 
  };
  APPLY_PATCH(1055);

  uint32_t patch1056_addr = 0x001C00F0;
  uint8_t patch1056_data[] = {
    0x0B, 
  };
  APPLY_PATCH(1056);

  uint32_t patch1057_addr = 0x001C00F3;
  uint8_t patch1057_data[] = {
    0xB0, 
  };
  APPLY_PATCH(1057);

  uint32_t patch1058_addr = 0x001C00F8;
  uint8_t patch1058_data[] = {
    0xA9, 0xBA, 0x99, 0x99, 
  };
  APPLY_PATCH(1058);

  uint32_t patch1059_addr = 0x001C0122;
  uint8_t patch1059_data[] = {
    0x09, 0x09, 
  };
  APPLY_PATCH(1059);

  uint32_t patch1060_addr = 0x001C0125;
  uint8_t patch1060_data[] = {
    0x90, 
  };
  APPLY_PATCH(1060);

  uint32_t patch1061_addr = 0x001C0143;
  uint8_t patch1061_data[] = {
    0x0A, 
  };
  APPLY_PATCH(1061);

  uint32_t patch1062_addr = 0x001C016B;
  uint8_t patch1062_data[] = {
    0xA0, 
  };
  APPLY_PATCH(1062);

  uint32_t patch1063_addr = 0x001C016E;
  uint8_t patch1063_data[] = {
    0xD0, 
  };
  APPLY_PATCH(1063);

  uint32_t patch1064_addr = 0x001C0172;
  uint8_t patch1064_data[] = {
    0x09, 0x09, 
  };
  APPLY_PATCH(1064);

  uint32_t patch1065_addr = 0x001C0175;
  uint8_t patch1065_data[] = {
    0x90, 
  };
  APPLY_PATCH(1065);

  uint32_t patch1066_addr = 0x001C0193;
  uint8_t patch1066_data[] = {
    0xA0, 
  };
  APPLY_PATCH(1066);

  uint32_t patch1067_addr = 0x001C0196;
  uint8_t patch1067_data[] = {
    0xD0, 
  };
  APPLY_PATCH(1067);

  uint32_t patch1068_addr = 0x001C019B;
  uint8_t patch1068_data[] = {
    0x09, 
  };
  APPLY_PATCH(1068);

  uint32_t patch1069_addr = 0x001C01A8;
  uint8_t patch1069_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1069);

  uint32_t patch1070_addr = 0x001C01AA;
  uint8_t patch1070_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(1070);

  uint32_t patch1071_addr = 0x001C01BB;
  uint8_t patch1071_data[] = {
    0x0A, 
  };
  APPLY_PATCH(1071);

  uint32_t patch1072_addr = 0x001C01BE;
  uint8_t patch1072_data[] = {
    0xD0, 
  };
  APPLY_PATCH(1072);

  uint32_t patch1073_addr = 0x001C01C3;
  uint8_t patch1073_data[] = {
    0x09, 
  };
  APPLY_PATCH(1073);

  uint32_t patch1074_addr = 0x001C01D0;
  uint8_t patch1074_data[] = {
    0xF0, 
  };
  APPLY_PATCH(1074);

  uint32_t patch1075_addr = 0x001C01D2;
  uint8_t patch1075_data[] = {
    0x0D, 
  };
  APPLY_PATCH(1075);

  uint32_t patch1076_addr = 0x001C01D4;
  uint8_t patch1076_data[] = {
    0xC0, 0x0C, 
  };
  APPLY_PATCH(1076);

  uint32_t patch1077_addr = 0x001C01E3;
  uint8_t patch1077_data[] = {
    0x0A, 
  };
  APPLY_PATCH(1077);

  uint32_t patch1078_addr = 0x001C01E6;
  uint8_t patch1078_data[] = {
    0xD0, 
  };
  APPLY_PATCH(1078);

  uint32_t patch1079_addr = 0x001C01EB;
  uint8_t patch1079_data[] = {
    0x09, 
  };
  APPLY_PATCH(1079);

  uint32_t patch1080_addr = 0x001C01F8;
  uint8_t patch1080_data[] = {
    0xF0, 
  };
  APPLY_PATCH(1080);

  uint32_t patch1081_addr = 0x001C01FA;
  uint8_t patch1081_data[] = {
    0x0D, 
  };
  APPLY_PATCH(1081);

  uint32_t patch1082_addr = 0x001C020B;
  uint8_t patch1082_data[] = {
    0x0A, 
  };
  APPLY_PATCH(1082);

  uint32_t patch1083_addr = 0x001C020E;
  uint8_t patch1083_data[] = {
    0xDC, 
  };
  APPLY_PATCH(1083);

  uint32_t patch1084_addr = 0x001C0210;
  uint8_t patch1084_data[] = {
    0xA9, 0xBA, 
  };
  APPLY_PATCH(1084);

  uint32_t patch1085_addr = 0x001C0213;
  uint8_t patch1085_data[] = {
    0x99, 
  };
  APPLY_PATCH(1085);

  uint32_t patch1086_addr = 0x001C0232;
  uint8_t patch1086_data[] = {
    0x09, 
  };
  APPLY_PATCH(1086);

  uint32_t patch1087_addr = 0x001C024A;
  uint8_t patch1087_data[] = {
    0x0D, 
  };
  APPLY_PATCH(1087);

  uint32_t patch1088_addr = 0x001C025A;
  uint8_t patch1088_data[] = {
    0x99, 0xAA, 
  };
  APPLY_PATCH(1088);

  uint32_t patch1089_addr = 0x001C025D;
  uint8_t patch1089_data[] = {
    0x99, 
  };
  APPLY_PATCH(1089);

  uint32_t patch1090_addr = 0x001C0274;
  uint8_t patch1090_data[] = {
    0x0C, 
  };
  APPLY_PATCH(1090);

  uint32_t patch1091_addr = 0x001C0281;
  uint8_t patch1091_data[] = {
    0xE0, 0x09, 
  };
  APPLY_PATCH(1091);

  uint32_t patch1092_addr = 0x001C0286;
  uint8_t patch1092_data[] = {
    0xDC, 
  };
  APPLY_PATCH(1092);

  uint32_t patch1093_addr = 0x001C0288;
  uint8_t patch1093_data[] = {
    0x09, 
  };
  APPLY_PATCH(1093);

  uint32_t patch1094_addr = 0x001C028B;
  uint8_t patch1094_data[] = {
    0x09, 
  };
  APPLY_PATCH(1094);

  uint32_t patch1095_addr = 0x001C029A;
  uint8_t patch1095_data[] = {
    0x0D, 
  };
  APPLY_PATCH(1095);

  uint32_t patch1096_addr = 0x001C029C;
  uint8_t patch1096_data[] = {
    0x0C, 
  };
  APPLY_PATCH(1096);

  uint32_t patch1097_addr = 0x001C02A8;
  uint8_t patch1097_data[] = {
    0xD0, 0x0D, 0x09, 
  };
  APPLY_PATCH(1097);

  uint32_t patch1098_addr = 0x001C02AF;
  uint8_t patch1098_data[] = {
    0x0E, 0x09, 0xBA, 
  };
  APPLY_PATCH(1098);

  uint32_t patch1099_addr = 0x001C02B3;
  uint8_t patch1099_data[] = {
    0x99, 
  };
  APPLY_PATCH(1099);

  uint32_t patch1100_addr = 0x001C02D0;
  uint8_t patch1100_data[] = {
    0x0B, 
  };
  APPLY_PATCH(1100);

  uint32_t patch1101_addr = 0x001C02D2;
  uint8_t patch1101_data[] = {
    0x99, 0xAA, 
  };
  APPLY_PATCH(1101);

  uint32_t patch1102_addr = 0x001C02D5;
  uint8_t patch1102_data[] = {
    0x99, 
  };
  APPLY_PATCH(1102);

  uint32_t patch1103_addr = 0x001C02D7;
  uint8_t patch1103_data[] = {
    0x0E, 0xA0, 
  };
  APPLY_PATCH(1103);

  uint32_t patch1104_addr = 0x001C02DA;
  uint8_t patch1104_data[] = {
    0x99, 0x09, 
  };
  APPLY_PATCH(1104);

  uint32_t patch1105_addr = 0x001C02EA;
  uint8_t patch1105_data[] = {
    0xDD, 0xEE, 
  };
  APPLY_PATCH(1105);

  uint32_t patch1106_addr = 0x001C02ED;
  uint8_t patch1106_data[] = {
    0xCC, 
  };
  APPLY_PATCH(1106);

  uint32_t patch1107_addr = 0x001C02FA;
  uint8_t patch1107_data[] = {
    0x09, 
  };
  APPLY_PATCH(1107);

  uint32_t patch1108_addr = 0x001C02FC;
  uint8_t patch1108_data[] = {
    0x90, 0x09, 
  };
  APPLY_PATCH(1108);

  uint32_t patch1109_addr = 0x001C02FF;
  uint8_t patch1109_data[] = {
    0x0E, 0x09, 0x0A, 
  };
  APPLY_PATCH(1109);

  uint32_t patch1110_addr = 0x001C0303;
  uint8_t patch1110_data[] = {
    0x09, 
  };
  APPLY_PATCH(1110);

  uint32_t patch1111_addr = 0x001C0310;
  uint8_t patch1111_data[] = {
    0xFF, 
  };
  APPLY_PATCH(1111);

  uint32_t patch1112_addr = 0x001C0312;
  uint8_t patch1112_data[] = {
    0xD0, 0xEE, 
  };
  APPLY_PATCH(1112);

  uint32_t patch1113_addr = 0x001C0323;
  uint8_t patch1113_data[] = {
    0x0A, 
  };
  APPLY_PATCH(1113);

  uint32_t patch1114_addr = 0x001C0327;
  uint8_t patch1114_data[] = {
    0x0E, 
  };
  APPLY_PATCH(1114);

  uint32_t patch1115_addr = 0x001C032A;
  uint8_t patch1115_data[] = {
    0x90, 
  };
  APPLY_PATCH(1115);

  uint32_t patch1116_addr = 0x001C0338;
  uint8_t patch1116_data[] = {
    0xFF, 
  };
  APPLY_PATCH(1116);

  uint32_t patch1117_addr = 0x001C033A;
  uint8_t patch1117_data[] = {
    0xD0, 0xEE, 0xC0, 0x0C, 
  };
  APPLY_PATCH(1117);

  uint32_t patch1118_addr = 0x001C034B;
  uint8_t patch1118_data[] = {
    0xA0, 0x90, 0x09, 
  };
  APPLY_PATCH(1118);

  uint32_t patch1119_addr = 0x001C0360;
  uint8_t patch1119_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1119);

  uint32_t patch1120_addr = 0x001C0362;
  uint8_t patch1120_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(1120);

  uint32_t patch1121_addr = 0x001C0373;
  uint8_t patch1121_data[] = {
    0xA0, 
  };
  APPLY_PATCH(1121);

  uint32_t patch1122_addr = 0x001C037A;
  uint8_t patch1122_data[] = {
    0x90, 
  };
  APPLY_PATCH(1122);

  uint32_t patch1123_addr = 0x001C0388;
  uint8_t patch1123_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1123);

  uint32_t patch1124_addr = 0x001C038A;
  uint8_t patch1124_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(1124);

  uint32_t patch1125_addr = 0x001C039B;
  uint8_t patch1125_data[] = {
    0x0A, 
  };
  APPLY_PATCH(1125);

  uint32_t patch1126_addr = 0x001C039F;
  uint8_t patch1126_data[] = {
    0x0E, 
  };
  APPLY_PATCH(1126);

  uint32_t patch1127_addr = 0x001C03A2;
  uint8_t patch1127_data[] = {
    0x90, 
  };
  APPLY_PATCH(1127);

  uint32_t patch1128_addr = 0x001C03B0;
  uint8_t patch1128_data[] = {
    0xF0, 
  };
  APPLY_PATCH(1128);

  uint32_t patch1129_addr = 0x001C03B4;
  uint8_t patch1129_data[] = {
    0x0C, 
  };
  APPLY_PATCH(1129);

  uint32_t patch1130_addr = 0x001C03C3;
  uint8_t patch1130_data[] = {
    0x0A, 
  };
  APPLY_PATCH(1130);

  uint32_t patch1131_addr = 0x001C03C6;
  uint8_t patch1131_data[] = {
    0x0C, 0x0E, 0xA9, 0xBA, 0x99, 0x09, 
  };
  APPLY_PATCH(1131);

  uint32_t patch1132_addr = 0x001C03EB;
  uint8_t patch1132_data[] = {
    0x0A, 
  };
  APPLY_PATCH(1132);

  uint32_t patch1133_addr = 0x001C03EE;
  uint8_t patch1133_data[] = {
    0xDC, 
  };
  APPLY_PATCH(1133);

  uint32_t patch1134_addr = 0x001C03F0;
  uint8_t patch1134_data[] = {
    0x09, 0x0A, 0x09, 0x09, 
  };
  APPLY_PATCH(1134);

  uint32_t patch1135_addr = 0x001C0400;
  uint8_t patch1135_data[] = {
    0xF0, 
  };
  APPLY_PATCH(1135);

  uint32_t patch1136_addr = 0x001C0402;
  uint8_t patch1136_data[] = {
    0xD0, 0x0E, 0xC0, 
  };
  APPLY_PATCH(1136);

  uint32_t patch1137_addr = 0x001C0416;
  uint8_t patch1137_data[] = {
    0x0C, 
  };
  APPLY_PATCH(1137);

  uint32_t patch1138_addr = 0x001C0418;
  uint8_t patch1138_data[] = {
    0x09, 0x0A, 0x99, 0x09, 
  };
  APPLY_PATCH(1138);

  uint32_t patch1139_addr = 0x001C0428;
  uint8_t patch1139_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1139);

  uint32_t patch1140_addr = 0x001C042A;
  uint8_t patch1140_data[] = {
    0xD0, 0xEE, 0xC0, 0x0C, 
  };
  APPLY_PATCH(1140);

  uint32_t patch1141_addr = 0x001C0438;
  uint8_t patch1141_data[] = {
    0xCB, 
  };
  APPLY_PATCH(1141);

  uint32_t patch1142_addr = 0x001C043B;
  uint8_t patch1142_data[] = {
    0xAA, 
  };
  APPLY_PATCH(1142);

  uint32_t patch1143_addr = 0x001C043D;
  uint8_t patch1143_data[] = {
    0x09, 0xDC, 
  };
  APPLY_PATCH(1143);

  uint32_t patch1144_addr = 0x001C0440;
  uint8_t patch1144_data[] = {
    0x09, 0x0A, 0x09, 0x09, 
  };
  APPLY_PATCH(1144);

  uint32_t patch1145_addr = 0x001C0461;
  uint8_t patch1145_data[] = {
    0x0D, 0x99, 
  };
  APPLY_PATCH(1145);

  uint32_t patch1146_addr = 0x001C0465;
  uint8_t patch1146_data[] = {
    0x90, 0x0C, 0x0E, 0xA9, 0xBA, 0x99, 0x09, 
  };
  APPLY_PATCH(1146);

  uint32_t patch1147_addr = 0x001C0492;
  uint8_t patch1147_data[] = {
    0x90, 
  };
  APPLY_PATCH(1147);

  uint32_t patch1148_addr = 0x001C04A0;
  uint8_t patch1148_data[] = {
    0xF0, 
  };
  APPLY_PATCH(1148);

  uint32_t patch1149_addr = 0x001C04B0;
  uint8_t patch1149_data[] = {
    0x0B, 
  };
  APPLY_PATCH(1149);

  uint32_t patch1150_addr = 0x001C04B2;
  uint8_t patch1150_data[] = {
    0x09, 
  };
  APPLY_PATCH(1150);

  uint32_t patch1151_addr = 0x001C04BA;
  uint8_t patch1151_data[] = {
    0x90, 
  };
  APPLY_PATCH(1151);

  uint32_t patch1152_addr = 0x001C04C8;
  uint8_t patch1152_data[] = {
    0xF0, 
  };
  APPLY_PATCH(1152);

  uint32_t patch1153_addr = 0x001C04D8;
  uint8_t patch1153_data[] = {
    0xC0, 
  };
  APPLY_PATCH(1153);

  uint32_t patch1154_addr = 0x001C04DA;
  uint8_t patch1154_data[] = {
    0x09, 
  };
  APPLY_PATCH(1154);

  uint32_t patch1155_addr = 0x001C04DF;
  uint8_t patch1155_data[] = {
    0x0E, 0x09, 
  };
  APPLY_PATCH(1155);

  uint32_t patch1156_addr = 0x001C0501;
  uint8_t patch1156_data[] = {
    0x0D, 
  };
  APPLY_PATCH(1156);

  uint32_t patch1157_addr = 0x001C0505;
  uint8_t patch1157_data[] = {
    0x90, 0xD0, 
  };
  APPLY_PATCH(1157);

  uint32_t patch1158_addr = 0x001C0508;
  uint8_t patch1158_data[] = {
    0x09, 0x0A, 0x90, 
  };
  APPLY_PATCH(1158);

  uint32_t patch1159_addr = 0x001C0529;
  uint8_t patch1159_data[] = {
    0x0D, 
  };
  APPLY_PATCH(1159);

  uint32_t patch1160_addr = 0x001C052D;
  uint8_t patch1160_data[] = {
    0x90, 0xDC, 
  };
  APPLY_PATCH(1160);

  uint32_t patch1161_addr = 0x001C0530;
  uint8_t patch1161_data[] = {
    0xA9, 0xBA, 
  };
  APPLY_PATCH(1161);

  uint32_t patch1162_addr = 0x001C0533;
  uint8_t patch1162_data[] = {
    0x09, 
  };
  APPLY_PATCH(1162);

  uint32_t patch1163_addr = 0x001C0542;
  uint8_t patch1163_data[] = {
    0xD0, 0x0E, 
  };
  APPLY_PATCH(1163);

  uint32_t patch1164_addr = 0x001C0551;
  uint8_t patch1164_data[] = {
    0x0D, 
  };
  APPLY_PATCH(1164);

  uint32_t patch1165_addr = 0x001C0555;
  uint8_t patch1165_data[] = {
    0x90, 0xD0, 
  };
  APPLY_PATCH(1165);

  uint32_t patch1166_addr = 0x001C0568;
  uint8_t patch1166_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1166);

  uint32_t patch1167_addr = 0x001C056B;
  uint8_t patch1167_data[] = {
    0xF0, 0x0C, 
  };
  APPLY_PATCH(1167);

  uint32_t patch1168_addr = 0x001C057E;
  uint8_t patch1168_data[] = {
    0xDC, 
  };
  APPLY_PATCH(1168);

  uint32_t patch1169_addr = 0x001C0580;
  uint8_t patch1169_data[] = {
    0xA9, 0xBA, 0x09, 0x90, 
  };
  APPLY_PATCH(1169);

  uint32_t patch1170_addr = 0x001C0594;
  uint8_t patch1170_data[] = {
    0xCC, 0x0C, 
  };
  APPLY_PATCH(1170);

  uint32_t patch1171_addr = 0x001C05A7;
  uint8_t patch1171_data[] = {
    0x0E, 0xA0, 0xB0, 0x99, 0x90, 
  };
  APPLY_PATCH(1171);

  uint32_t patch1172_addr = 0x001C05B8;
  uint8_t patch1172_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1172);

  uint32_t patch1173_addr = 0x001C05BB;
  uint8_t patch1173_data[] = {
    0x0E, 
  };
  APPLY_PATCH(1173);

  uint32_t patch1174_addr = 0x001C05C9;
  uint8_t patch1174_data[] = {
    0x60, 0x10, 0x22, 
  };
  APPLY_PATCH(1174);

  uint32_t patch1175_addr = 0x001C05CD;
  uint8_t patch1175_data[] = {
    0x01, 0x0C, 0x0E, 0xA9, 0xBA, 0x09, 0x99, 
  };
  APPLY_PATCH(1175);

  uint32_t patch1176_addr = 0x001C05E0;
  uint8_t patch1176_data[] = {
    0xF0, 
  };
  APPLY_PATCH(1176);

  uint32_t patch1177_addr = 0x001C05E2;
  uint8_t patch1177_data[] = {
    0x0D, 0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(1177);

  uint32_t patch1178_addr = 0x001C05F1;
  uint8_t patch1178_data[] = {
    0x60, 0x10, 0x20, 
  };
  APPLY_PATCH(1178);

  uint32_t patch1179_addr = 0x001C05F5;
  uint8_t patch1179_data[] = {
    0x01, 
  };
  APPLY_PATCH(1179);

  uint32_t patch1180_addr = 0x001C05F7;
  uint8_t patch1180_data[] = {
    0x0E, 0xA0, 0xB0, 0x99, 0x90, 
  };
  APPLY_PATCH(1180);

  uint32_t patch1181_addr = 0x001C0608;
  uint8_t patch1181_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1181);

  uint32_t patch1182_addr = 0x001C060B;
  uint8_t patch1182_data[] = {
    0x03, 0xCC, 0x2C, 
  };
  APPLY_PATCH(1182);

  uint32_t patch1183_addr = 0x001C0618;
  uint8_t patch1183_data[] = {
    0x43, 0x05, 0x11, 0x20, 
  };
  APPLY_PATCH(1183);

  uint32_t patch1184_addr = 0x001C061D;
  uint8_t patch1184_data[] = {
    0x11, 0x0C, 0x0E, 0xA9, 0xBA, 
  };
  APPLY_PATCH(1184);

  uint32_t patch1185_addr = 0x001C0623;
  uint8_t patch1185_data[] = {
    0x90, 
  };
  APPLY_PATCH(1185);

  uint32_t patch1186_addr = 0x001C0632;
  uint8_t patch1186_data[] = {
    0xDD, 0x0E, 0x0C, 
  };
  APPLY_PATCH(1186);

  uint32_t patch1187_addr = 0x001C0646;
  uint8_t patch1187_data[] = {
    0xD0, 
  };
  APPLY_PATCH(1187);

  uint32_t patch1188_addr = 0x001C0658;
  uint8_t patch1188_data[] = {
    0xFF, 
  };
  APPLY_PATCH(1188);

  uint32_t patch1189_addr = 0x001C065B;
  uint8_t patch1189_data[] = {
    0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(1189);

  uint32_t patch1190_addr = 0x001C0669;
  uint8_t patch1190_data[] = {
    0x60, 0x10, 0x22, 
  };
  APPLY_PATCH(1190);

  uint32_t patch1191_addr = 0x001C066D;
  uint8_t patch1191_data[] = {
    0x10, 
  };
  APPLY_PATCH(1191);

  uint32_t patch1192_addr = 0x001C0673;
  uint8_t patch1192_data[] = {
    0x09, 
  };
  APPLY_PATCH(1192);

  uint32_t patch1193_addr = 0x001C0684;
  uint8_t patch1193_data[] = {
    0xC0, 
  };
  APPLY_PATCH(1193);

  uint32_t patch1194_addr = 0x001C0691;
  uint8_t patch1194_data[] = {
    0x60, 0x10, 0x20, 
  };
  APPLY_PATCH(1194);

  uint32_t patch1195_addr = 0x001C0695;
  uint8_t patch1195_data[] = {
    0x11, 
  };
  APPLY_PATCH(1195);

  uint32_t patch1196_addr = 0x001C069B;
  uint8_t patch1196_data[] = {
    0x90, 
  };
  APPLY_PATCH(1196);

  uint32_t patch1197_addr = 0x001C06A8;
  uint8_t patch1197_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1197);

  uint32_t patch1198_addr = 0x001C06AA;
  uint8_t patch1198_data[] = {
    0xD0, 0xE0, 0xC0, 
  };
  APPLY_PATCH(1198);

  uint32_t patch1199_addr = 0x001C06B8;
  uint8_t patch1199_data[] = {
    0x43, 0x65, 0x11, 0x22, 0x10, 0x10, 
  };
  APPLY_PATCH(1199);

  uint32_t patch1200_addr = 0x001C06C0;
  uint8_t patch1200_data[] = {
    0xA0, 0x0A, 
  };
  APPLY_PATCH(1200);

  uint32_t patch1201_addr = 0x001C06C3;
  uint8_t patch1201_data[] = {
    0x90, 
  };
  APPLY_PATCH(1201);

  uint32_t patch1202_addr = 0x001C06D0;
  uint8_t patch1202_data[] = {
    0xF0, 
  };
  APPLY_PATCH(1202);

  uint32_t patch1203_addr = 0x001C06D2;
  uint8_t patch1203_data[] = {
    0xDD, 
  };
  APPLY_PATCH(1203);

  uint32_t patch1204_addr = 0x001C06D4;
  uint8_t patch1204_data[] = {
    0xCC, 0xCC, 
  };
  APPLY_PATCH(1204);

  uint32_t patch1205_addr = 0x001C06E1;
  uint8_t patch1205_data[] = {
    0x05, 0x10, 0x20, 
  };
  APPLY_PATCH(1205);

  uint32_t patch1206_addr = 0x001C06E5;
  uint8_t patch1206_data[] = {
    0x10, 
  };
  APPLY_PATCH(1206);

  uint32_t patch1207_addr = 0x001C06E7;
  uint8_t patch1207_data[] = {
    0x0E, 0x09, 0xB0, 
  };
  APPLY_PATCH(1207);

  uint32_t patch1208_addr = 0x001C06EB;
  uint8_t patch1208_data[] = {
    0x90, 
  };
  APPLY_PATCH(1208);

  uint32_t patch1209_addr = 0x001C06F8;
  uint8_t patch1209_data[] = {
    0xF0, 
  };
  APPLY_PATCH(1209);

  uint32_t patch1210_addr = 0x001C06FA;
  uint8_t patch1210_data[] = {
    0xDD, 0xE0, 0xC0, 0xCC, 
  };
  APPLY_PATCH(1210);

  uint32_t patch1211_addr = 0x001C0708;
  uint8_t patch1211_data[] = {
    0x40, 0x05, 0x10, 0x22, 
  };
  APPLY_PATCH(1211);

  uint32_t patch1212_addr = 0x001C070D;
  uint8_t patch1212_data[] = {
    0x11, 0xDC, 
  };
  APPLY_PATCH(1212);

  uint32_t patch1213_addr = 0x001C0710;
  uint8_t patch1213_data[] = {
    0xA9, 0xBA, 0x99, 0x99, 
  };
  APPLY_PATCH(1213);

  uint32_t patch1214_addr = 0x001C0720;
  uint8_t patch1214_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1214);

  uint32_t patch1215_addr = 0x001C0723;
  uint8_t patch1215_data[] = {
    0x0E, 
  };
  APPLY_PATCH(1215);

  uint32_t patch1216_addr = 0x001C0731;
  uint8_t patch1216_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(1216);

  uint32_t patch1217_addr = 0x001C073B;
  uint8_t patch1217_data[] = {
    0x09, 
  };
  APPLY_PATCH(1217);

  uint32_t patch1218_addr = 0x001C074C;
  uint8_t patch1218_data[] = {
    0xCC, 0x0C, 
  };
  APPLY_PATCH(1218);

  uint32_t patch1219_addr = 0x001C075B;
  uint8_t patch1219_data[] = {
    0x20, 
  };
  APPLY_PATCH(1219);

  uint32_t patch1220_addr = 0x001C0763;
  uint8_t patch1220_data[] = {
    0x09, 
  };
  APPLY_PATCH(1220);

  uint32_t patch1221_addr = 0x001C0770;
  uint8_t patch1221_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1221);

  uint32_t patch1222_addr = 0x001C0772;
  uint8_t patch1222_data[] = {
    0x0D, 0xEE, 0x0C, 
  };
  APPLY_PATCH(1222);

  uint32_t patch1223_addr = 0x001C0783;
  uint8_t patch1223_data[] = {
    0x02, 
  };
  APPLY_PATCH(1223);

  uint32_t patch1224_addr = 0x001C0789;
  uint8_t patch1224_data[] = {
    0x0A, 
  };
  APPLY_PATCH(1224);

  uint32_t patch1225_addr = 0x001C0798;
  uint8_t patch1225_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1225);

  uint32_t patch1226_addr = 0x001C079A;
  uint8_t patch1226_data[] = {
    0xDD, 
  };
  APPLY_PATCH(1226);

  uint32_t patch1227_addr = 0x001C079C;
  uint8_t patch1227_data[] = {
    0xC0, 0xC0, 
  };
  APPLY_PATCH(1227);

  uint32_t patch1228_addr = 0x001C07A8;
  uint8_t patch1228_data[] = {
    0x43, 0x65, 0x11, 0x20, 
  };
  APPLY_PATCH(1228);

  uint32_t patch1229_addr = 0x001C07B0;
  uint8_t patch1229_data[] = {
    0xA0, 
  };
  APPLY_PATCH(1229);

  uint32_t patch1230_addr = 0x001C07C0;
  uint8_t patch1230_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1230);

  uint32_t patch1231_addr = 0x001C07C2;
  uint8_t patch1231_data[] = {
    0xDD, 0xEE, 0xC0, 0xCC, 
  };
  APPLY_PATCH(1231);

  uint32_t patch1232_addr = 0x001C07D5;
  uint8_t patch1232_data[] = {
    0x11, 0xD0, 
  };
  APPLY_PATCH(1232);

  uint32_t patch1233_addr = 0x001C07D8;
  uint8_t patch1233_data[] = {
    0xA9, 
  };
  APPLY_PATCH(1233);

  uint32_t patch1234_addr = 0x001C07DA;
  uint8_t patch1234_data[] = {
    0x09, 
  };
  APPLY_PATCH(1234);

  uint32_t patch1235_addr = 0x001C07FE;
  uint8_t patch1235_data[] = {
    0x0C, 0x0E, 0xA0, 
  };
  APPLY_PATCH(1235);

  uint32_t patch1236_addr = 0x001C0802;
  uint8_t patch1236_data[] = {
    0x90, 0x90, 
  };
  APPLY_PATCH(1236);

  uint32_t patch1237_addr = 0x001C0810;
  uint8_t patch1237_data[] = {
    0xF0, 
  };
  APPLY_PATCH(1237);

  uint32_t patch1238_addr = 0x001C0812;
  uint8_t patch1238_data[] = {
    0xD0, 
  };
  APPLY_PATCH(1238);

  uint32_t patch1239_addr = 0x001C0814;
  uint8_t patch1239_data[] = {
    0x0C, 
  };
  APPLY_PATCH(1239);

  uint32_t patch1240_addr = 0x001C0820;
  uint8_t patch1240_data[] = {
    0x43, 0x05, 0x11, 0x22, 
  };
  APPLY_PATCH(1240);

  uint32_t patch1241_addr = 0x001C0825;
  uint8_t patch1241_data[] = {
    0x11, 0x0C, 0x0E, 0xA0, 
  };
  APPLY_PATCH(1241);

  uint32_t patch1242_addr = 0x001C082A;
  uint8_t patch1242_data[] = {
    0x90, 0x09, 
  };
  APPLY_PATCH(1242);

  uint32_t patch1243_addr = 0x001C0838;
  uint8_t patch1243_data[] = {
    0x0F, 
  };
  APPLY_PATCH(1243);

  uint32_t patch1244_addr = 0x001C083C;
  uint8_t patch1244_data[] = {
    0xCC, 
  };
  APPLY_PATCH(1244);

  uint32_t patch1245_addr = 0x001C0849;
  uint8_t patch1245_data[] = {
    0x60, 
  };
  APPLY_PATCH(1245);

  uint32_t patch1246_addr = 0x001C084B;
  uint8_t patch1246_data[] = {
    0x02, 
  };
  APPLY_PATCH(1246);

  uint32_t patch1247_addr = 0x001C084E;
  uint8_t patch1247_data[] = {
    0xD0, 0x0E, 0xA0, 
  };
  APPLY_PATCH(1247);

  uint32_t patch1248_addr = 0x001C0852;
  uint8_t patch1248_data[] = {
    0x99, 
  };
  APPLY_PATCH(1248);

  uint32_t patch1249_addr = 0x001C0862;
  uint8_t patch1249_data[] = {
    0xD0, 0x0E, 0x0C, 0xC0, 
  };
  APPLY_PATCH(1249);

  uint32_t patch1250_addr = 0x001C0871;
  uint8_t patch1250_data[] = {
    0x60, 
  };
  APPLY_PATCH(1250);

  uint32_t patch1251_addr = 0x001C0873;
  uint8_t patch1251_data[] = {
    0x02, 
  };
  APPLY_PATCH(1251);

  uint32_t patch1252_addr = 0x001C0876;
  uint8_t patch1252_data[] = {
    0x0C, 
  };
  APPLY_PATCH(1252);

  uint32_t patch1253_addr = 0x001C0879;
  uint8_t patch1253_data[] = {
    0xBA, 
  };
  APPLY_PATCH(1253);

  uint32_t patch1254_addr = 0x001C088C;
  uint8_t patch1254_data[] = {
    0x0C, 
  };
  APPLY_PATCH(1254);

  uint32_t patch1255_addr = 0x001C0899;
  uint8_t patch1255_data[] = {
    0x60, 0x10, 
  };
  APPLY_PATCH(1255);

  uint32_t patch1256_addr = 0x001C08C0;
  uint8_t patch1256_data[] = {
    0x40, 0x65, 
  };
  APPLY_PATCH(1256);

  uint32_t patch1257_addr = 0x001C7058;
  uint8_t patch1257_data[] = {
    0x05, 
  };
  APPLY_PATCH(1257);

  uint32_t patch1258_addr = 0x001C705A;
  uint8_t patch1258_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1258);

  uint32_t patch1259_addr = 0x001C7068;
  uint8_t patch1259_data[] = {
    0x60, 
  };
  APPLY_PATCH(1259);

  uint32_t patch1260_addr = 0x001C706A;
  uint8_t patch1260_data[] = {
    0x02, 
  };
  APPLY_PATCH(1260);

  uint32_t patch1261_addr = 0x001C706C;
  uint8_t patch1261_data[] = {
    0x10, 0x01, 
  };
  APPLY_PATCH(1261);

  uint32_t patch1262_addr = 0x001C7078;
  uint8_t patch1262_data[] = {
    0x60, 
  };
  APPLY_PATCH(1262);

  uint32_t patch1263_addr = 0x001C707A;
  uint8_t patch1263_data[] = {
    0x02, 
  };
  APPLY_PATCH(1263);

  uint32_t patch1264_addr = 0x001C709A;
  uint8_t patch1264_data[] = {
    0x02, 
  };
  APPLY_PATCH(1264);

  uint32_t patch1265_addr = 0x001C70AC;
  uint8_t patch1265_data[] = {
    0x01, 
  };
  APPLY_PATCH(1265);

  uint32_t patch1266_addr = 0x001C70BA;
  uint8_t patch1266_data[] = {
    0x02, 
  };
  APPLY_PATCH(1266);

  uint32_t patch1267_addr = 0x001C70BC;
  uint8_t patch1267_data[] = {
    0x01, 
  };
  APPLY_PATCH(1267);

  uint32_t patch1268_addr = 0x001C70DA;
  uint8_t patch1268_data[] = {
    0x22, 0x43, 
  };
  APPLY_PATCH(1268);

  uint32_t patch1269_addr = 0x001C70DD;
  uint8_t patch1269_data[] = {
    0x11, 
  };
  APPLY_PATCH(1269);

  uint32_t patch1270_addr = 0x001C70E8;
  uint8_t patch1270_data[] = {
    0x65, 
  };
  APPLY_PATCH(1270);

  uint32_t patch1271_addr = 0x001C70EA;
  uint8_t patch1271_data[] = {
    0x20, 0x43, 
  };
  APPLY_PATCH(1271);

  uint32_t patch1272_addr = 0x001C70F8;
  uint8_t patch1272_data[] = {
    0x65, 
  };
  APPLY_PATCH(1272);

  uint32_t patch1273_addr = 0x001C70FA;
  uint8_t patch1273_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1273);

  uint32_t patch1274_addr = 0x001C7108;
  uint8_t patch1274_data[] = {
    0x05, 
  };
  APPLY_PATCH(1274);

  uint32_t patch1275_addr = 0x001C710A;
  uint8_t patch1275_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1275);

  uint32_t patch1276_addr = 0x001C7118;
  uint8_t patch1276_data[] = {
    0x05, 
  };
  APPLY_PATCH(1276);

  uint32_t patch1277_addr = 0x001C711A;
  uint8_t patch1277_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1277);

  uint32_t patch1278_addr = 0x001C7128;
  uint8_t patch1278_data[] = {
    0x60, 
  };
  APPLY_PATCH(1278);

  uint32_t patch1279_addr = 0x001C712C;
  uint8_t patch1279_data[] = {
    0x01, 
  };
  APPLY_PATCH(1279);

  uint32_t patch1280_addr = 0x001C7148;
  uint8_t patch1280_data[] = {
    0x60, 
  };
  APPLY_PATCH(1280);

  uint32_t patch1281_addr = 0x001C714A;
  uint8_t patch1281_data[] = {
    0x20, 0x03, 0x10, 
  };
  APPLY_PATCH(1281);

  uint32_t patch1282_addr = 0x001C715A;
  uint8_t patch1282_data[] = {
    0x20, 0x03, 0x10, 0x01, 
  };
  APPLY_PATCH(1282);

  uint32_t patch1283_addr = 0x001C7458;
  uint8_t patch1283_data[] = {
    0x05, 
  };
  APPLY_PATCH(1283);

  uint32_t patch1284_addr = 0x001C745A;
  uint8_t patch1284_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1284);

  uint32_t patch1285_addr = 0x001C7468;
  uint8_t patch1285_data[] = {
    0x60, 
  };
  APPLY_PATCH(1285);

  uint32_t patch1286_addr = 0x001C746A;
  uint8_t patch1286_data[] = {
    0x02, 
  };
  APPLY_PATCH(1286);

  uint32_t patch1287_addr = 0x001C746C;
  uint8_t patch1287_data[] = {
    0x10, 0x01, 
  };
  APPLY_PATCH(1287);

  uint32_t patch1288_addr = 0x001C7478;
  uint8_t patch1288_data[] = {
    0x60, 
  };
  APPLY_PATCH(1288);

  uint32_t patch1289_addr = 0x001C747A;
  uint8_t patch1289_data[] = {
    0x02, 
  };
  APPLY_PATCH(1289);

  uint32_t patch1290_addr = 0x001C749A;
  uint8_t patch1290_data[] = {
    0x02, 
  };
  APPLY_PATCH(1290);

  uint32_t patch1291_addr = 0x001C74AC;
  uint8_t patch1291_data[] = {
    0x01, 
  };
  APPLY_PATCH(1291);

  uint32_t patch1292_addr = 0x001C74BA;
  uint8_t patch1292_data[] = {
    0x02, 
  };
  APPLY_PATCH(1292);

  uint32_t patch1293_addr = 0x001C74BC;
  uint8_t patch1293_data[] = {
    0x01, 
  };
  APPLY_PATCH(1293);

  uint32_t patch1294_addr = 0x001C74DA;
  uint8_t patch1294_data[] = {
    0x22, 0x43, 
  };
  APPLY_PATCH(1294);

  uint32_t patch1295_addr = 0x001C74DD;
  uint8_t patch1295_data[] = {
    0x11, 
  };
  APPLY_PATCH(1295);

  uint32_t patch1296_addr = 0x001C74E8;
  uint8_t patch1296_data[] = {
    0x65, 
  };
  APPLY_PATCH(1296);

  uint32_t patch1297_addr = 0x001C74EA;
  uint8_t patch1297_data[] = {
    0x20, 0x43, 
  };
  APPLY_PATCH(1297);

  uint32_t patch1298_addr = 0x001C74F8;
  uint8_t patch1298_data[] = {
    0x65, 
  };
  APPLY_PATCH(1298);

  uint32_t patch1299_addr = 0x001C74FA;
  uint8_t patch1299_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1299);

  uint32_t patch1300_addr = 0x001C7508;
  uint8_t patch1300_data[] = {
    0x05, 
  };
  APPLY_PATCH(1300);

  uint32_t patch1301_addr = 0x001C750A;
  uint8_t patch1301_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1301);

  uint32_t patch1302_addr = 0x001C7518;
  uint8_t patch1302_data[] = {
    0x05, 
  };
  APPLY_PATCH(1302);

  uint32_t patch1303_addr = 0x001C751A;
  uint8_t patch1303_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1303);

  uint32_t patch1304_addr = 0x001C7528;
  uint8_t patch1304_data[] = {
    0x60, 
  };
  APPLY_PATCH(1304);

  uint32_t patch1305_addr = 0x001C752C;
  uint8_t patch1305_data[] = {
    0x01, 
  };
  APPLY_PATCH(1305);

  uint32_t patch1306_addr = 0x001C7548;
  uint8_t patch1306_data[] = {
    0x60, 
  };
  APPLY_PATCH(1306);

  uint32_t patch1307_addr = 0x001C754A;
  uint8_t patch1307_data[] = {
    0x20, 0x03, 0x10, 
  };
  APPLY_PATCH(1307);

  uint32_t patch1308_addr = 0x001C755A;
  uint8_t patch1308_data[] = {
    0x20, 0x03, 0x10, 0x01, 
  };
  APPLY_PATCH(1308);

  uint32_t patch1309_addr = 0x001C7858;
  uint8_t patch1309_data[] = {
    0x05, 
  };
  APPLY_PATCH(1309);

  uint32_t patch1310_addr = 0x001C785A;
  uint8_t patch1310_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1310);

  uint32_t patch1311_addr = 0x001C7868;
  uint8_t patch1311_data[] = {
    0x60, 
  };
  APPLY_PATCH(1311);

  uint32_t patch1312_addr = 0x001C786A;
  uint8_t patch1312_data[] = {
    0x02, 
  };
  APPLY_PATCH(1312);

  uint32_t patch1313_addr = 0x001C786C;
  uint8_t patch1313_data[] = {
    0x10, 0x01, 
  };
  APPLY_PATCH(1313);

  uint32_t patch1314_addr = 0x001C7878;
  uint8_t patch1314_data[] = {
    0x60, 
  };
  APPLY_PATCH(1314);

  uint32_t patch1315_addr = 0x001C787A;
  uint8_t patch1315_data[] = {
    0x02, 
  };
  APPLY_PATCH(1315);

  uint32_t patch1316_addr = 0x001C789A;
  uint8_t patch1316_data[] = {
    0x02, 
  };
  APPLY_PATCH(1316);

  uint32_t patch1317_addr = 0x001C78AC;
  uint8_t patch1317_data[] = {
    0x01, 
  };
  APPLY_PATCH(1317);

  uint32_t patch1318_addr = 0x001C78BA;
  uint8_t patch1318_data[] = {
    0x02, 
  };
  APPLY_PATCH(1318);

  uint32_t patch1319_addr = 0x001C78BC;
  uint8_t patch1319_data[] = {
    0x01, 
  };
  APPLY_PATCH(1319);

  uint32_t patch1320_addr = 0x001C78DA;
  uint8_t patch1320_data[] = {
    0x22, 0x43, 
  };
  APPLY_PATCH(1320);

  uint32_t patch1321_addr = 0x001C78DD;
  uint8_t patch1321_data[] = {
    0x11, 
  };
  APPLY_PATCH(1321);

  uint32_t patch1322_addr = 0x001C78E8;
  uint8_t patch1322_data[] = {
    0x65, 
  };
  APPLY_PATCH(1322);

  uint32_t patch1323_addr = 0x001C78EA;
  uint8_t patch1323_data[] = {
    0x20, 0x43, 
  };
  APPLY_PATCH(1323);

  uint32_t patch1324_addr = 0x001C78F8;
  uint8_t patch1324_data[] = {
    0x65, 
  };
  APPLY_PATCH(1324);

  uint32_t patch1325_addr = 0x001C78FA;
  uint8_t patch1325_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1325);

  uint32_t patch1326_addr = 0x001C7908;
  uint8_t patch1326_data[] = {
    0x05, 
  };
  APPLY_PATCH(1326);

  uint32_t patch1327_addr = 0x001C790A;
  uint8_t patch1327_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1327);

  uint32_t patch1328_addr = 0x001C7918;
  uint8_t patch1328_data[] = {
    0x05, 
  };
  APPLY_PATCH(1328);

  uint32_t patch1329_addr = 0x001C791A;
  uint8_t patch1329_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1329);

  uint32_t patch1330_addr = 0x001C7928;
  uint8_t patch1330_data[] = {
    0x60, 
  };
  APPLY_PATCH(1330);

  uint32_t patch1331_addr = 0x001C792C;
  uint8_t patch1331_data[] = {
    0x01, 
  };
  APPLY_PATCH(1331);

  uint32_t patch1332_addr = 0x001C7948;
  uint8_t patch1332_data[] = {
    0x60, 
  };
  APPLY_PATCH(1332);

  uint32_t patch1333_addr = 0x001C794A;
  uint8_t patch1333_data[] = {
    0x20, 0x03, 0x10, 
  };
  APPLY_PATCH(1333);

  uint32_t patch1334_addr = 0x001C795A;
  uint8_t patch1334_data[] = {
    0x20, 0x03, 0x10, 0x01, 
  };
  APPLY_PATCH(1334);

  uint32_t patch1335_addr = 0x001C7C58;
  uint8_t patch1335_data[] = {
    0x05, 
  };
  APPLY_PATCH(1335);

  uint32_t patch1336_addr = 0x001C7C5A;
  uint8_t patch1336_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1336);

  uint32_t patch1337_addr = 0x001C7C68;
  uint8_t patch1337_data[] = {
    0x60, 
  };
  APPLY_PATCH(1337);

  uint32_t patch1338_addr = 0x001C7C6A;
  uint8_t patch1338_data[] = {
    0x02, 
  };
  APPLY_PATCH(1338);

  uint32_t patch1339_addr = 0x001C7C6C;
  uint8_t patch1339_data[] = {
    0x10, 0x01, 
  };
  APPLY_PATCH(1339);

  uint32_t patch1340_addr = 0x001C7C78;
  uint8_t patch1340_data[] = {
    0x60, 
  };
  APPLY_PATCH(1340);

  uint32_t patch1341_addr = 0x001C7C7A;
  uint8_t patch1341_data[] = {
    0x02, 
  };
  APPLY_PATCH(1341);

  uint32_t patch1342_addr = 0x001C7C9A;
  uint8_t patch1342_data[] = {
    0x02, 
  };
  APPLY_PATCH(1342);

  uint32_t patch1343_addr = 0x001C7CAC;
  uint8_t patch1343_data[] = {
    0x01, 
  };
  APPLY_PATCH(1343);

  uint32_t patch1344_addr = 0x001C7CBA;
  uint8_t patch1344_data[] = {
    0x02, 
  };
  APPLY_PATCH(1344);

  uint32_t patch1345_addr = 0x001C7CBC;
  uint8_t patch1345_data[] = {
    0x01, 
  };
  APPLY_PATCH(1345);

  uint32_t patch1346_addr = 0x001C7CDA;
  uint8_t patch1346_data[] = {
    0x22, 0x43, 
  };
  APPLY_PATCH(1346);

  uint32_t patch1347_addr = 0x001C7CDD;
  uint8_t patch1347_data[] = {
    0x11, 
  };
  APPLY_PATCH(1347);

  uint32_t patch1348_addr = 0x001C7CE8;
  uint8_t patch1348_data[] = {
    0x65, 
  };
  APPLY_PATCH(1348);

  uint32_t patch1349_addr = 0x001C7CEA;
  uint8_t patch1349_data[] = {
    0x20, 0x43, 
  };
  APPLY_PATCH(1349);

  uint32_t patch1350_addr = 0x001C7CF8;
  uint8_t patch1350_data[] = {
    0x65, 
  };
  APPLY_PATCH(1350);

  uint32_t patch1351_addr = 0x001C7CFA;
  uint8_t patch1351_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1351);

  uint32_t patch1352_addr = 0x001C7D08;
  uint8_t patch1352_data[] = {
    0x05, 
  };
  APPLY_PATCH(1352);

  uint32_t patch1353_addr = 0x001C7D0A;
  uint8_t patch1353_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1353);

  uint32_t patch1354_addr = 0x001C7D18;
  uint8_t patch1354_data[] = {
    0x05, 
  };
  APPLY_PATCH(1354);

  uint32_t patch1355_addr = 0x001C7D1A;
  uint8_t patch1355_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1355);

  uint32_t patch1356_addr = 0x001C7D28;
  uint8_t patch1356_data[] = {
    0x60, 
  };
  APPLY_PATCH(1356);

  uint32_t patch1357_addr = 0x001C7D2C;
  uint8_t patch1357_data[] = {
    0x01, 
  };
  APPLY_PATCH(1357);

  uint32_t patch1358_addr = 0x001C7D48;
  uint8_t patch1358_data[] = {
    0x60, 
  };
  APPLY_PATCH(1358);

  uint32_t patch1359_addr = 0x001C7D4A;
  uint8_t patch1359_data[] = {
    0x20, 0x03, 0x10, 
  };
  APPLY_PATCH(1359);

  uint32_t patch1360_addr = 0x001C7D58;
  uint8_t patch1360_data[] = {
    0x05, 
  };
  APPLY_PATCH(1360);

  uint32_t patch1361_addr = 0x001C7D5A;
  uint8_t patch1361_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1361);

  uint32_t patch1362_addr = 0x001C8058;
  uint8_t patch1362_data[] = {
    0x05, 
  };
  APPLY_PATCH(1362);

  uint32_t patch1363_addr = 0x001C805A;
  uint8_t patch1363_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1363);

  uint32_t patch1364_addr = 0x001C8068;
  uint8_t patch1364_data[] = {
    0x60, 
  };
  APPLY_PATCH(1364);

  uint32_t patch1365_addr = 0x001C806A;
  uint8_t patch1365_data[] = {
    0x02, 
  };
  APPLY_PATCH(1365);

  uint32_t patch1366_addr = 0x001C806C;
  uint8_t patch1366_data[] = {
    0x10, 0x01, 
  };
  APPLY_PATCH(1366);

  uint32_t patch1367_addr = 0x001C8078;
  uint8_t patch1367_data[] = {
    0x60, 
  };
  APPLY_PATCH(1367);

  uint32_t patch1368_addr = 0x001C807A;
  uint8_t patch1368_data[] = {
    0x02, 
  };
  APPLY_PATCH(1368);

  uint32_t patch1369_addr = 0x001C809A;
  uint8_t patch1369_data[] = {
    0x02, 
  };
  APPLY_PATCH(1369);

  uint32_t patch1370_addr = 0x001C80AC;
  uint8_t patch1370_data[] = {
    0x01, 
  };
  APPLY_PATCH(1370);

  uint32_t patch1371_addr = 0x001C80BA;
  uint8_t patch1371_data[] = {
    0x02, 
  };
  APPLY_PATCH(1371);

  uint32_t patch1372_addr = 0x001C80BC;
  uint8_t patch1372_data[] = {
    0x01, 
  };
  APPLY_PATCH(1372);

  uint32_t patch1373_addr = 0x001C80DA;
  uint8_t patch1373_data[] = {
    0x22, 0x43, 
  };
  APPLY_PATCH(1373);

  uint32_t patch1374_addr = 0x001C80DD;
  uint8_t patch1374_data[] = {
    0x11, 
  };
  APPLY_PATCH(1374);

  uint32_t patch1375_addr = 0x001C80E8;
  uint8_t patch1375_data[] = {
    0x65, 
  };
  APPLY_PATCH(1375);

  uint32_t patch1376_addr = 0x001C80EA;
  uint8_t patch1376_data[] = {
    0x20, 0x43, 
  };
  APPLY_PATCH(1376);

  uint32_t patch1377_addr = 0x001C80F8;
  uint8_t patch1377_data[] = {
    0x65, 
  };
  APPLY_PATCH(1377);

  uint32_t patch1378_addr = 0x001C80FA;
  uint8_t patch1378_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1378);

  uint32_t patch1379_addr = 0x001C8108;
  uint8_t patch1379_data[] = {
    0x05, 
  };
  APPLY_PATCH(1379);

  uint32_t patch1380_addr = 0x001C810A;
  uint8_t patch1380_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1380);

  uint32_t patch1381_addr = 0x001C8118;
  uint8_t patch1381_data[] = {
    0x05, 
  };
  APPLY_PATCH(1381);

  uint32_t patch1382_addr = 0x001C811A;
  uint8_t patch1382_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1382);

  uint32_t patch1383_addr = 0x001C8128;
  uint8_t patch1383_data[] = {
    0x60, 
  };
  APPLY_PATCH(1383);

  uint32_t patch1384_addr = 0x001C812C;
  uint8_t patch1384_data[] = {
    0x01, 
  };
  APPLY_PATCH(1384);

  uint32_t patch1385_addr = 0x001C8148;
  uint8_t patch1385_data[] = {
    0x60, 
  };
  APPLY_PATCH(1385);

  uint32_t patch1386_addr = 0x001C814A;
  uint8_t patch1386_data[] = {
    0x20, 0x03, 0x10, 
  };
  APPLY_PATCH(1386);

  uint32_t patch1387_addr = 0x001C8158;
  uint8_t patch1387_data[] = {
    0x05, 
  };
  APPLY_PATCH(1387);

  uint32_t patch1388_addr = 0x001C815A;
  uint8_t patch1388_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1388);

  uint32_t patch1389_addr = 0x001C8458;
  uint8_t patch1389_data[] = {
    0x05, 
  };
  APPLY_PATCH(1389);

  uint32_t patch1390_addr = 0x001C845A;
  uint8_t patch1390_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1390);

  uint32_t patch1391_addr = 0x001C8468;
  uint8_t patch1391_data[] = {
    0x60, 
  };
  APPLY_PATCH(1391);

  uint32_t patch1392_addr = 0x001C846A;
  uint8_t patch1392_data[] = {
    0x02, 
  };
  APPLY_PATCH(1392);

  uint32_t patch1393_addr = 0x001C846C;
  uint8_t patch1393_data[] = {
    0x10, 0x01, 
  };
  APPLY_PATCH(1393);

  uint32_t patch1394_addr = 0x001C8478;
  uint8_t patch1394_data[] = {
    0x60, 
  };
  APPLY_PATCH(1394);

  uint32_t patch1395_addr = 0x001C847A;
  uint8_t patch1395_data[] = {
    0x02, 
  };
  APPLY_PATCH(1395);

  uint32_t patch1396_addr = 0x001C849A;
  uint8_t patch1396_data[] = {
    0x02, 
  };
  APPLY_PATCH(1396);

  uint32_t patch1397_addr = 0x001C84AC;
  uint8_t patch1397_data[] = {
    0x01, 
  };
  APPLY_PATCH(1397);

  uint32_t patch1398_addr = 0x001C84BA;
  uint8_t patch1398_data[] = {
    0x02, 
  };
  APPLY_PATCH(1398);

  uint32_t patch1399_addr = 0x001C84BC;
  uint8_t patch1399_data[] = {
    0x01, 
  };
  APPLY_PATCH(1399);

  uint32_t patch1400_addr = 0x001C84DA;
  uint8_t patch1400_data[] = {
    0x22, 0x43, 
  };
  APPLY_PATCH(1400);

  uint32_t patch1401_addr = 0x001C84DD;
  uint8_t patch1401_data[] = {
    0x11, 
  };
  APPLY_PATCH(1401);

  uint32_t patch1402_addr = 0x001C84E8;
  uint8_t patch1402_data[] = {
    0x65, 
  };
  APPLY_PATCH(1402);

  uint32_t patch1403_addr = 0x001C84EA;
  uint8_t patch1403_data[] = {
    0x20, 0x43, 
  };
  APPLY_PATCH(1403);

  uint32_t patch1404_addr = 0x001C84F8;
  uint8_t patch1404_data[] = {
    0x65, 
  };
  APPLY_PATCH(1404);

  uint32_t patch1405_addr = 0x001C84FA;
  uint8_t patch1405_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1405);

  uint32_t patch1406_addr = 0x001C8508;
  uint8_t patch1406_data[] = {
    0x05, 
  };
  APPLY_PATCH(1406);

  uint32_t patch1407_addr = 0x001C850A;
  uint8_t patch1407_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1407);

  uint32_t patch1408_addr = 0x001C8518;
  uint8_t patch1408_data[] = {
    0x05, 
  };
  APPLY_PATCH(1408);

  uint32_t patch1409_addr = 0x001C851A;
  uint8_t patch1409_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1409);

  uint32_t patch1410_addr = 0x001C8528;
  uint8_t patch1410_data[] = {
    0x60, 
  };
  APPLY_PATCH(1410);

  uint32_t patch1411_addr = 0x001C852C;
  uint8_t patch1411_data[] = {
    0x01, 
  };
  APPLY_PATCH(1411);

  uint32_t patch1412_addr = 0x001C8548;
  uint8_t patch1412_data[] = {
    0x60, 
  };
  APPLY_PATCH(1412);

  uint32_t patch1413_addr = 0x001C854A;
  uint8_t patch1413_data[] = {
    0x20, 0x03, 0x10, 
  };
  APPLY_PATCH(1413);

  uint32_t patch1414_addr = 0x001C8558;
  uint8_t patch1414_data[] = {
    0x05, 
  };
  APPLY_PATCH(1414);

  uint32_t patch1415_addr = 0x001C855A;
  uint8_t patch1415_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1415);

  uint32_t patch1416_addr = 0x001C8588;
  uint8_t patch1416_data[] = {
    0x60, 
  };
  APPLY_PATCH(1416);

  uint32_t patch1417_addr = 0x001C8598;
  uint8_t patch1417_data[] = {
    0x60, 
  };
  APPLY_PATCH(1417);

  uint32_t patch1418_addr = 0x001C85CA;
  uint8_t patch1418_data[] = {
    0x20, 0x03, 
  };
  APPLY_PATCH(1418);

  uint32_t patch1419_addr = 0x001C85DC;
  uint8_t patch1419_data[] = {
    0x01, 
  };
  APPLY_PATCH(1419);

  uint32_t patch1420_addr = 0x001C85F8;
  uint8_t patch1420_data[] = {
    0x05, 
  };
  APPLY_PATCH(1420);

  uint32_t patch1421_addr = 0x001C8908;
  uint8_t patch1421_data[] = {
    0x05, 
  };
  APPLY_PATCH(1421);

  uint32_t patch1422_addr = 0x001C890A;
  uint8_t patch1422_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1422);

  uint32_t patch1423_addr = 0x001C8918;
  uint8_t patch1423_data[] = {
    0x05, 
  };
  APPLY_PATCH(1423);

  uint32_t patch1424_addr = 0x001C891A;
  uint8_t patch1424_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1424);

  uint32_t patch1425_addr = 0x001C8928;
  uint8_t patch1425_data[] = {
    0x60, 
  };
  APPLY_PATCH(1425);

  uint32_t patch1426_addr = 0x001C892C;
  uint8_t patch1426_data[] = {
    0x01, 
  };
  APPLY_PATCH(1426);

  uint32_t patch1427_addr = 0x001C8948;
  uint8_t patch1427_data[] = {
    0x60, 
  };
  APPLY_PATCH(1427);

  uint32_t patch1428_addr = 0x001C894A;
  uint8_t patch1428_data[] = {
    0x20, 0x03, 0x10, 
  };
  APPLY_PATCH(1428);

  uint32_t patch1429_addr = 0x001C8958;
  uint8_t patch1429_data[] = {
    0x05, 
  };
  APPLY_PATCH(1429);

  uint32_t patch1430_addr = 0x001C895A;
  uint8_t patch1430_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1430);

  uint32_t patch1431_addr = 0x001C8988;
  uint8_t patch1431_data[] = {
    0x60, 
  };
  APPLY_PATCH(1431);

  uint32_t patch1432_addr = 0x001C8998;
  uint8_t patch1432_data[] = {
    0x60, 
  };
  APPLY_PATCH(1432);

  uint32_t patch1433_addr = 0x001C89CA;
  uint8_t patch1433_data[] = {
    0x20, 0x03, 
  };
  APPLY_PATCH(1433);

  uint32_t patch1434_addr = 0x001C89D8;
  uint8_t patch1434_data[] = {
    0x05, 
  };
  APPLY_PATCH(1434);

  uint32_t patch1435_addr = 0x001C89DB;
  uint8_t patch1435_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(1435);

  uint32_t patch1436_addr = 0x001C89EC;
  uint8_t patch1436_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1436);

  uint32_t patch1437_addr = 0x001C89F8;
  uint8_t patch1437_data[] = {
    0x05, 
  };
  APPLY_PATCH(1437);

  uint32_t patch1438_addr = 0x001C89FB;
  uint8_t patch1438_data[] = {
    0x03, 
  };
  APPLY_PATCH(1438);

  uint32_t patch1439_addr = 0x001C8A08;
  uint8_t patch1439_data[] = {
    0x60, 
  };
  APPLY_PATCH(1439);

  uint32_t patch1440_addr = 0x001C8A0A;
  uint8_t patch1440_data[] = {
    0x02, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1440);

  uint32_t patch1441_addr = 0x001C8A18;
  uint8_t patch1441_data[] = {
    0x05, 
  };
  APPLY_PATCH(1441);

  uint32_t patch1442_addr = 0x001C8A1B;
  uint8_t patch1442_data[] = {
    0x01, 0x11, 0x71, 
  };
  APPLY_PATCH(1442);

  uint32_t patch1443_addr = 0x001C8A2A;
  uint8_t patch1443_data[] = {
    0x22, 0x03, 0x01, 
  };
  APPLY_PATCH(1443);

  uint32_t patch1444_addr = 0x001C8A38;
  uint8_t patch1444_data[] = {
    0x65, 
  };
  APPLY_PATCH(1444);

  uint32_t patch1445_addr = 0x001C8A3B;
  uint8_t patch1445_data[] = {
    0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1445);

  uint32_t patch1446_addr = 0x001C8A4C;
  uint8_t patch1446_data[] = {
    0x10, 
  };
  APPLY_PATCH(1446);

  uint32_t patch1447_addr = 0x001C8A58;
  uint8_t patch1447_data[] = {
    0x05, 
  };
  APPLY_PATCH(1447);

  uint32_t patch1448_addr = 0x001C8A5A;
  uint8_t patch1448_data[] = {
    0x20, 0x40, 0x10, 
  };
  APPLY_PATCH(1448);

  uint32_t patch1449_addr = 0x001C8A68;
  uint8_t patch1449_data[] = {
    0x60, 
  };
  APPLY_PATCH(1449);

  uint32_t patch1450_addr = 0x001C8A6A;
  uint8_t patch1450_data[] = {
    0x22, 
  };
  APPLY_PATCH(1450);

  uint32_t patch1451_addr = 0x001C8A6C;
  uint8_t patch1451_data[] = {
    0x11, 0x11, 
  };
  APPLY_PATCH(1451);

  uint32_t patch1452_addr = 0x001C8A78;
  uint8_t patch1452_data[] = {
    0x60, 
  };
  APPLY_PATCH(1452);

  uint32_t patch1453_addr = 0x001C8A7A;
  uint8_t patch1453_data[] = {
    0x22, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1453);

  uint32_t patch1454_addr = 0x001C8A8B;
  uint8_t patch1454_data[] = {
    0x03, 
  };
  APPLY_PATCH(1454);

  uint32_t patch1455_addr = 0x001C8AA8;
  uint8_t patch1455_data[] = {
    0x05, 
  };
  APPLY_PATCH(1455);

  uint32_t patch1456_addr = 0x001C8AAB;
  uint8_t patch1456_data[] = {
    0x40, 
  };
  APPLY_PATCH(1456);

  uint32_t patch1457_addr = 0x001C8D58;
  uint8_t patch1457_data[] = {
    0x05, 
  };
  APPLY_PATCH(1457);

  uint32_t patch1458_addr = 0x001C8D5A;
  uint8_t patch1458_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1458);

  uint32_t patch1459_addr = 0x001C8D88;
  uint8_t patch1459_data[] = {
    0x60, 
  };
  APPLY_PATCH(1459);

  uint32_t patch1460_addr = 0x001C8D98;
  uint8_t patch1460_data[] = {
    0x60, 
  };
  APPLY_PATCH(1460);

  uint32_t patch1461_addr = 0x001C8DCA;
  uint8_t patch1461_data[] = {
    0x20, 0x03, 
  };
  APPLY_PATCH(1461);

  uint32_t patch1462_addr = 0x001C8DD8;
  uint8_t patch1462_data[] = {
    0x05, 
  };
  APPLY_PATCH(1462);

  uint32_t patch1463_addr = 0x001C8DDB;
  uint8_t patch1463_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(1463);

  uint32_t patch1464_addr = 0x001C8DEC;
  uint8_t patch1464_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1464);

  uint32_t patch1465_addr = 0x001C8DF8;
  uint8_t patch1465_data[] = {
    0x05, 
  };
  APPLY_PATCH(1465);

  uint32_t patch1466_addr = 0x001C8DFB;
  uint8_t patch1466_data[] = {
    0x03, 
  };
  APPLY_PATCH(1466);

  uint32_t patch1467_addr = 0x001C8E08;
  uint8_t patch1467_data[] = {
    0x60, 
  };
  APPLY_PATCH(1467);

  uint32_t patch1468_addr = 0x001C8E0A;
  uint8_t patch1468_data[] = {
    0x02, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1468);

  uint32_t patch1469_addr = 0x001C8E18;
  uint8_t patch1469_data[] = {
    0x05, 
  };
  APPLY_PATCH(1469);

  uint32_t patch1470_addr = 0x001C8E1B;
  uint8_t patch1470_data[] = {
    0x01, 0x11, 0x71, 
  };
  APPLY_PATCH(1470);

  uint32_t patch1471_addr = 0x001C8E2A;
  uint8_t patch1471_data[] = {
    0x22, 0x03, 0x01, 
  };
  APPLY_PATCH(1471);

  uint32_t patch1472_addr = 0x001C8E38;
  uint8_t patch1472_data[] = {
    0x65, 
  };
  APPLY_PATCH(1472);

  uint32_t patch1473_addr = 0x001C8E3B;
  uint8_t patch1473_data[] = {
    0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1473);

  uint32_t patch1474_addr = 0x001C8E4C;
  uint8_t patch1474_data[] = {
    0x10, 
  };
  APPLY_PATCH(1474);

  uint32_t patch1475_addr = 0x001C8E58;
  uint8_t patch1475_data[] = {
    0x05, 
  };
  APPLY_PATCH(1475);

  uint32_t patch1476_addr = 0x001C8E5A;
  uint8_t patch1476_data[] = {
    0x20, 0x40, 0x10, 
  };
  APPLY_PATCH(1476);

  uint32_t patch1477_addr = 0x001C8E68;
  uint8_t patch1477_data[] = {
    0x60, 
  };
  APPLY_PATCH(1477);

  uint32_t patch1478_addr = 0x001C8E6A;
  uint8_t patch1478_data[] = {
    0x22, 
  };
  APPLY_PATCH(1478);

  uint32_t patch1479_addr = 0x001C8E6C;
  uint8_t patch1479_data[] = {
    0x11, 0x11, 
  };
  APPLY_PATCH(1479);

  uint32_t patch1480_addr = 0x001C8E78;
  uint8_t patch1480_data[] = {
    0x60, 
  };
  APPLY_PATCH(1480);

  uint32_t patch1481_addr = 0x001C8E7A;
  uint8_t patch1481_data[] = {
    0x22, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1481);

  uint32_t patch1482_addr = 0x001C8E88;
  uint8_t patch1482_data[] = {
    0x05, 
  };
  APPLY_PATCH(1482);

  uint32_t patch1483_addr = 0x001C8E8B;
  uint8_t patch1483_data[] = {
    0x03, 
  };
  APPLY_PATCH(1483);

  uint32_t patch1484_addr = 0x001C8E9C;
  uint8_t patch1484_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1484);

  uint32_t patch1485_addr = 0x001C8EA8;
  uint8_t patch1485_data[] = {
    0x05, 
  };
  APPLY_PATCH(1485);

  uint32_t patch1486_addr = 0x001C8EAA;
  uint8_t patch1486_data[] = {
    0x02, 0x43, 0x01, 
  };
  APPLY_PATCH(1486);

  uint32_t patch1487_addr = 0x001C8EB8;
  uint8_t patch1487_data[] = {
    0x05, 
  };
  APPLY_PATCH(1487);

  uint32_t patch1488_addr = 0x001C8EBA;
  uint8_t patch1488_data[] = {
    0x22, 
  };
  APPLY_PATCH(1488);

  uint32_t patch1489_addr = 0x001C8EBC;
  uint8_t patch1489_data[] = {
    0x10, 0x10, 
  };
  APPLY_PATCH(1489);

  uint32_t patch1490_addr = 0x001C8EC8;
  uint8_t patch1490_data[] = {
    0x05, 
  };
  APPLY_PATCH(1490);

  uint32_t patch1491_addr = 0x001C8ECA;
  uint8_t patch1491_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1491);

  uint32_t patch1492_addr = 0x001C8EF8;
  uint8_t patch1492_data[] = {
    0x05, 
  };
  APPLY_PATCH(1492);

  uint32_t patch1493_addr = 0x001C9188;
  uint8_t patch1493_data[] = {
    0x60, 
  };
  APPLY_PATCH(1493);

  uint32_t patch1494_addr = 0x001C9198;
  uint8_t patch1494_data[] = {
    0x60, 
  };
  APPLY_PATCH(1494);

  uint32_t patch1495_addr = 0x001C91CA;
  uint8_t patch1495_data[] = {
    0x20, 0x03, 
  };
  APPLY_PATCH(1495);

  uint32_t patch1496_addr = 0x001C91D8;
  uint8_t patch1496_data[] = {
    0x05, 
  };
  APPLY_PATCH(1496);

  uint32_t patch1497_addr = 0x001C91DB;
  uint8_t patch1497_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(1497);

  uint32_t patch1498_addr = 0x001C91EC;
  uint8_t patch1498_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1498);

  uint32_t patch1499_addr = 0x001C91F8;
  uint8_t patch1499_data[] = {
    0x05, 
  };
  APPLY_PATCH(1499);

  uint32_t patch1500_addr = 0x001C91FB;
  uint8_t patch1500_data[] = {
    0x03, 
  };
  APPLY_PATCH(1500);

  uint32_t patch1501_addr = 0x001C9208;
  uint8_t patch1501_data[] = {
    0x60, 
  };
  APPLY_PATCH(1501);

  uint32_t patch1502_addr = 0x001C920A;
  uint8_t patch1502_data[] = {
    0x02, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1502);

  uint32_t patch1503_addr = 0x001C9218;
  uint8_t patch1503_data[] = {
    0x05, 
  };
  APPLY_PATCH(1503);

  uint32_t patch1504_addr = 0x001C921B;
  uint8_t patch1504_data[] = {
    0x01, 0x11, 0x71, 
  };
  APPLY_PATCH(1504);

  uint32_t patch1505_addr = 0x001C922A;
  uint8_t patch1505_data[] = {
    0x22, 0x03, 0x01, 
  };
  APPLY_PATCH(1505);

  uint32_t patch1506_addr = 0x001C9238;
  uint8_t patch1506_data[] = {
    0x65, 
  };
  APPLY_PATCH(1506);

  uint32_t patch1507_addr = 0x001C923B;
  uint8_t patch1507_data[] = {
    0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1507);

  uint32_t patch1508_addr = 0x001C924C;
  uint8_t patch1508_data[] = {
    0x10, 
  };
  APPLY_PATCH(1508);

  uint32_t patch1509_addr = 0x001C9258;
  uint8_t patch1509_data[] = {
    0x05, 
  };
  APPLY_PATCH(1509);

  uint32_t patch1510_addr = 0x001C925A;
  uint8_t patch1510_data[] = {
    0x20, 0x40, 0x10, 
  };
  APPLY_PATCH(1510);

  uint32_t patch1511_addr = 0x001C9268;
  uint8_t patch1511_data[] = {
    0x60, 
  };
  APPLY_PATCH(1511);

  uint32_t patch1512_addr = 0x001C926A;
  uint8_t patch1512_data[] = {
    0x22, 
  };
  APPLY_PATCH(1512);

  uint32_t patch1513_addr = 0x001C926C;
  uint8_t patch1513_data[] = {
    0x11, 0x11, 
  };
  APPLY_PATCH(1513);

  uint32_t patch1514_addr = 0x001C9278;
  uint8_t patch1514_data[] = {
    0x60, 
  };
  APPLY_PATCH(1514);

  uint32_t patch1515_addr = 0x001C927A;
  uint8_t patch1515_data[] = {
    0x22, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1515);

  uint32_t patch1516_addr = 0x001C9288;
  uint8_t patch1516_data[] = {
    0x05, 
  };
  APPLY_PATCH(1516);

  uint32_t patch1517_addr = 0x001C928B;
  uint8_t patch1517_data[] = {
    0x03, 
  };
  APPLY_PATCH(1517);

  uint32_t patch1518_addr = 0x001C929C;
  uint8_t patch1518_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1518);

  uint32_t patch1519_addr = 0x001C92A8;
  uint8_t patch1519_data[] = {
    0x05, 
  };
  APPLY_PATCH(1519);

  uint32_t patch1520_addr = 0x001C92AA;
  uint8_t patch1520_data[] = {
    0x02, 0x43, 0x01, 
  };
  APPLY_PATCH(1520);

  uint32_t patch1521_addr = 0x001C92B8;
  uint8_t patch1521_data[] = {
    0x05, 
  };
  APPLY_PATCH(1521);

  uint32_t patch1522_addr = 0x001C92BA;
  uint8_t patch1522_data[] = {
    0x22, 
  };
  APPLY_PATCH(1522);

  uint32_t patch1523_addr = 0x001C92BC;
  uint8_t patch1523_data[] = {
    0x10, 0x10, 
  };
  APPLY_PATCH(1523);

  uint32_t patch1524_addr = 0x001C92C8;
  uint8_t patch1524_data[] = {
    0x05, 
  };
  APPLY_PATCH(1524);

  uint32_t patch1525_addr = 0x001C92CA;
  uint8_t patch1525_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1525);

  uint32_t patch1526_addr = 0x001C92E8;
  uint8_t patch1526_data[] = {
    0x60, 
  };
  APPLY_PATCH(1526);

  uint32_t patch1527_addr = 0x001C92EA;
  uint8_t patch1527_data[] = {
    0x20, 
  };
  APPLY_PATCH(1527);

  uint32_t patch1528_addr = 0x001C92EC;
  uint8_t patch1528_data[] = {
    0x01, 
  };
  APPLY_PATCH(1528);

  uint32_t patch1529_addr = 0x001C92FC;
  uint8_t patch1529_data[] = {
    0x11, 
  };
  APPLY_PATCH(1529);

  uint32_t patch1530_addr = 0x001C930B;
  uint8_t patch1530_data[] = {
    0x40, 
  };
  APPLY_PATCH(1530);

  uint32_t patch1531_addr = 0x001C9598;
  uint8_t patch1531_data[] = {
    0x60, 
  };
  APPLY_PATCH(1531);

  uint32_t patch1532_addr = 0x001C95CA;
  uint8_t patch1532_data[] = {
    0x20, 0x03, 
  };
  APPLY_PATCH(1532);

  uint32_t patch1533_addr = 0x001C95D8;
  uint8_t patch1533_data[] = {
    0x05, 
  };
  APPLY_PATCH(1533);

  uint32_t patch1534_addr = 0x001C95DB;
  uint8_t patch1534_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(1534);

  uint32_t patch1535_addr = 0x001C95EC;
  uint8_t patch1535_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1535);

  uint32_t patch1536_addr = 0x001C95F8;
  uint8_t patch1536_data[] = {
    0x05, 
  };
  APPLY_PATCH(1536);

  uint32_t patch1537_addr = 0x001C95FB;
  uint8_t patch1537_data[] = {
    0x03, 
  };
  APPLY_PATCH(1537);

  uint32_t patch1538_addr = 0x001C9608;
  uint8_t patch1538_data[] = {
    0x60, 
  };
  APPLY_PATCH(1538);

  uint32_t patch1539_addr = 0x001C960A;
  uint8_t patch1539_data[] = {
    0x02, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1539);

  uint32_t patch1540_addr = 0x001C9618;
  uint8_t patch1540_data[] = {
    0x05, 
  };
  APPLY_PATCH(1540);

  uint32_t patch1541_addr = 0x001C961B;
  uint8_t patch1541_data[] = {
    0x01, 0x11, 0x71, 
  };
  APPLY_PATCH(1541);

  uint32_t patch1542_addr = 0x001C962A;
  uint8_t patch1542_data[] = {
    0x22, 0x03, 0x01, 
  };
  APPLY_PATCH(1542);

  uint32_t patch1543_addr = 0x001C9638;
  uint8_t patch1543_data[] = {
    0x65, 
  };
  APPLY_PATCH(1543);

  uint32_t patch1544_addr = 0x001C963B;
  uint8_t patch1544_data[] = {
    0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1544);

  uint32_t patch1545_addr = 0x001C964C;
  uint8_t patch1545_data[] = {
    0x10, 
  };
  APPLY_PATCH(1545);

  uint32_t patch1546_addr = 0x001C9658;
  uint8_t patch1546_data[] = {
    0x05, 
  };
  APPLY_PATCH(1546);

  uint32_t patch1547_addr = 0x001C965A;
  uint8_t patch1547_data[] = {
    0x20, 0x40, 0x10, 
  };
  APPLY_PATCH(1547);

  uint32_t patch1548_addr = 0x001C9668;
  uint8_t patch1548_data[] = {
    0x60, 
  };
  APPLY_PATCH(1548);

  uint32_t patch1549_addr = 0x001C966A;
  uint8_t patch1549_data[] = {
    0x22, 
  };
  APPLY_PATCH(1549);

  uint32_t patch1550_addr = 0x001C966C;
  uint8_t patch1550_data[] = {
    0x11, 0x11, 
  };
  APPLY_PATCH(1550);

  uint32_t patch1551_addr = 0x001C9678;
  uint8_t patch1551_data[] = {
    0x60, 
  };
  APPLY_PATCH(1551);

  uint32_t patch1552_addr = 0x001C967A;
  uint8_t patch1552_data[] = {
    0x22, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1552);

  uint32_t patch1553_addr = 0x001C9688;
  uint8_t patch1553_data[] = {
    0x05, 
  };
  APPLY_PATCH(1553);

  uint32_t patch1554_addr = 0x001C968B;
  uint8_t patch1554_data[] = {
    0x03, 
  };
  APPLY_PATCH(1554);

  uint32_t patch1555_addr = 0x001C969C;
  uint8_t patch1555_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1555);

  uint32_t patch1556_addr = 0x001C96A8;
  uint8_t patch1556_data[] = {
    0x05, 
  };
  APPLY_PATCH(1556);

  uint32_t patch1557_addr = 0x001C96AA;
  uint8_t patch1557_data[] = {
    0x02, 0x43, 0x01, 
  };
  APPLY_PATCH(1557);

  uint32_t patch1558_addr = 0x001C96B8;
  uint8_t patch1558_data[] = {
    0x05, 
  };
  APPLY_PATCH(1558);

  uint32_t patch1559_addr = 0x001C96BA;
  uint8_t patch1559_data[] = {
    0x22, 
  };
  APPLY_PATCH(1559);

  uint32_t patch1560_addr = 0x001C96BC;
  uint8_t patch1560_data[] = {
    0x10, 0x10, 
  };
  APPLY_PATCH(1560);

  uint32_t patch1561_addr = 0x001C96C8;
  uint8_t patch1561_data[] = {
    0x05, 
  };
  APPLY_PATCH(1561);

  uint32_t patch1562_addr = 0x001C96CA;
  uint8_t patch1562_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1562);

  uint32_t patch1563_addr = 0x001C96E8;
  uint8_t patch1563_data[] = {
    0x60, 
  };
  APPLY_PATCH(1563);

  uint32_t patch1564_addr = 0x001C96EA;
  uint8_t patch1564_data[] = {
    0x20, 
  };
  APPLY_PATCH(1564);

  uint32_t patch1565_addr = 0x001C96EC;
  uint8_t patch1565_data[] = {
    0x01, 
  };
  APPLY_PATCH(1565);

  uint32_t patch1566_addr = 0x001C96F8;
  uint8_t patch1566_data[] = {
    0x05, 
  };
  APPLY_PATCH(1566);

  uint32_t patch1567_addr = 0x001C96FC;
  uint8_t patch1567_data[] = {
    0x11, 
  };
  APPLY_PATCH(1567);

  uint32_t patch1568_addr = 0x001C970A;
  uint8_t patch1568_data[] = {
    0x20, 0x03, 0x01, 0x10, 
  };
  APPLY_PATCH(1568);

  uint32_t patch1569_addr = 0x001C971C;
  uint8_t patch1569_data[] = {
    0x01, 
  };
  APPLY_PATCH(1569);

  uint32_t patch1570_addr = 0x001C9998;
  uint8_t patch1570_data[] = {
    0x60, 
  };
  APPLY_PATCH(1570);

  uint32_t patch1571_addr = 0x001C99CA;
  uint8_t patch1571_data[] = {
    0x20, 0x03, 
  };
  APPLY_PATCH(1571);

  uint32_t patch1572_addr = 0x001C99D8;
  uint8_t patch1572_data[] = {
    0x05, 
  };
  APPLY_PATCH(1572);

  uint32_t patch1573_addr = 0x001C99DB;
  uint8_t patch1573_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(1573);

  uint32_t patch1574_addr = 0x001C99EC;
  uint8_t patch1574_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1574);

  uint32_t patch1575_addr = 0x001C99F8;
  uint8_t patch1575_data[] = {
    0x05, 
  };
  APPLY_PATCH(1575);

  uint32_t patch1576_addr = 0x001C99FB;
  uint8_t patch1576_data[] = {
    0x03, 
  };
  APPLY_PATCH(1576);

  uint32_t patch1577_addr = 0x001C9A08;
  uint8_t patch1577_data[] = {
    0x60, 
  };
  APPLY_PATCH(1577);

  uint32_t patch1578_addr = 0x001C9A0A;
  uint8_t patch1578_data[] = {
    0x02, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1578);

  uint32_t patch1579_addr = 0x001C9A18;
  uint8_t patch1579_data[] = {
    0x05, 
  };
  APPLY_PATCH(1579);

  uint32_t patch1580_addr = 0x001C9A1B;
  uint8_t patch1580_data[] = {
    0x01, 0x11, 0x71, 
  };
  APPLY_PATCH(1580);

  uint32_t patch1581_addr = 0x001C9A2A;
  uint8_t patch1581_data[] = {
    0x22, 0x03, 0x01, 
  };
  APPLY_PATCH(1581);

  uint32_t patch1582_addr = 0x001C9A38;
  uint8_t patch1582_data[] = {
    0x65, 
  };
  APPLY_PATCH(1582);

  uint32_t patch1583_addr = 0x001C9A3B;
  uint8_t patch1583_data[] = {
    0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1583);

  uint32_t patch1584_addr = 0x001C9A4C;
  uint8_t patch1584_data[] = {
    0x10, 
  };
  APPLY_PATCH(1584);

  uint32_t patch1585_addr = 0x001C9A58;
  uint8_t patch1585_data[] = {
    0x05, 
  };
  APPLY_PATCH(1585);

  uint32_t patch1586_addr = 0x001C9A5A;
  uint8_t patch1586_data[] = {
    0x20, 0x40, 0x10, 
  };
  APPLY_PATCH(1586);

  uint32_t patch1587_addr = 0x001C9A68;
  uint8_t patch1587_data[] = {
    0x60, 
  };
  APPLY_PATCH(1587);

  uint32_t patch1588_addr = 0x001C9A6A;
  uint8_t patch1588_data[] = {
    0x22, 
  };
  APPLY_PATCH(1588);

  uint32_t patch1589_addr = 0x001C9A6C;
  uint8_t patch1589_data[] = {
    0x11, 0x11, 
  };
  APPLY_PATCH(1589);

  uint32_t patch1590_addr = 0x001C9A78;
  uint8_t patch1590_data[] = {
    0x60, 
  };
  APPLY_PATCH(1590);

  uint32_t patch1591_addr = 0x001C9A7A;
  uint8_t patch1591_data[] = {
    0x22, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1591);

  uint32_t patch1592_addr = 0x001C9A88;
  uint8_t patch1592_data[] = {
    0x05, 
  };
  APPLY_PATCH(1592);

  uint32_t patch1593_addr = 0x001C9A8B;
  uint8_t patch1593_data[] = {
    0x03, 
  };
  APPLY_PATCH(1593);

  uint32_t patch1594_addr = 0x001C9A9C;
  uint8_t patch1594_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1594);

  uint32_t patch1595_addr = 0x001C9AA8;
  uint8_t patch1595_data[] = {
    0x05, 
  };
  APPLY_PATCH(1595);

  uint32_t patch1596_addr = 0x001C9AAA;
  uint8_t patch1596_data[] = {
    0x02, 0x43, 0x01, 
  };
  APPLY_PATCH(1596);

  uint32_t patch1597_addr = 0x001C9AB8;
  uint8_t patch1597_data[] = {
    0x05, 
  };
  APPLY_PATCH(1597);

  uint32_t patch1598_addr = 0x001C9ABA;
  uint8_t patch1598_data[] = {
    0x22, 
  };
  APPLY_PATCH(1598);

  uint32_t patch1599_addr = 0x001C9ABC;
  uint8_t patch1599_data[] = {
    0x10, 0x10, 
  };
  APPLY_PATCH(1599);

  uint32_t patch1600_addr = 0x001C9AC8;
  uint8_t patch1600_data[] = {
    0x05, 
  };
  APPLY_PATCH(1600);

  uint32_t patch1601_addr = 0x001C9ACA;
  uint8_t patch1601_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1601);

  uint32_t patch1602_addr = 0x001C9AE8;
  uint8_t patch1602_data[] = {
    0x60, 
  };
  APPLY_PATCH(1602);

  uint32_t patch1603_addr = 0x001C9AEA;
  uint8_t patch1603_data[] = {
    0x20, 
  };
  APPLY_PATCH(1603);

  uint32_t patch1604_addr = 0x001C9AEC;
  uint8_t patch1604_data[] = {
    0x01, 
  };
  APPLY_PATCH(1604);

  uint32_t patch1605_addr = 0x001C9AF8;
  uint8_t patch1605_data[] = {
    0x05, 
  };
  APPLY_PATCH(1605);

  uint32_t patch1606_addr = 0x001C9AFC;
  uint8_t patch1606_data[] = {
    0x11, 
  };
  APPLY_PATCH(1606);

  uint32_t patch1607_addr = 0x001C9B0A;
  uint8_t patch1607_data[] = {
    0x20, 0x03, 0x01, 0x10, 
  };
  APPLY_PATCH(1607);

  uint32_t patch1608_addr = 0x001C9B1C;
  uint8_t patch1608_data[] = {
    0x01, 
  };
  APPLY_PATCH(1608);

  uint32_t patch1609_addr = 0x001C9D98;
  uint8_t patch1609_data[] = {
    0x60, 
  };
  APPLY_PATCH(1609);

  uint32_t patch1610_addr = 0x001C9DCA;
  uint8_t patch1610_data[] = {
    0x20, 0x03, 
  };
  APPLY_PATCH(1610);

  uint32_t patch1611_addr = 0x001C9DD8;
  uint8_t patch1611_data[] = {
    0x05, 
  };
  APPLY_PATCH(1611);

  uint32_t patch1612_addr = 0x001C9DDB;
  uint8_t patch1612_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(1612);

  uint32_t patch1613_addr = 0x001C9DEC;
  uint8_t patch1613_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1613);

  uint32_t patch1614_addr = 0x001C9DF8;
  uint8_t patch1614_data[] = {
    0x05, 
  };
  APPLY_PATCH(1614);

  uint32_t patch1615_addr = 0x001C9DFB;
  uint8_t patch1615_data[] = {
    0x03, 
  };
  APPLY_PATCH(1615);

  uint32_t patch1616_addr = 0x001C9E08;
  uint8_t patch1616_data[] = {
    0x60, 
  };
  APPLY_PATCH(1616);

  uint32_t patch1617_addr = 0x001C9E0A;
  uint8_t patch1617_data[] = {
    0x02, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1617);

  uint32_t patch1618_addr = 0x001C9E18;
  uint8_t patch1618_data[] = {
    0x05, 
  };
  APPLY_PATCH(1618);

  uint32_t patch1619_addr = 0x001C9E1B;
  uint8_t patch1619_data[] = {
    0x01, 0x11, 0x71, 
  };
  APPLY_PATCH(1619);

  uint32_t patch1620_addr = 0x001C9E2A;
  uint8_t patch1620_data[] = {
    0x22, 0x03, 0x01, 
  };
  APPLY_PATCH(1620);

  uint32_t patch1621_addr = 0x001C9E38;
  uint8_t patch1621_data[] = {
    0x65, 
  };
  APPLY_PATCH(1621);

  uint32_t patch1622_addr = 0x001C9E3B;
  uint8_t patch1622_data[] = {
    0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1622);

  uint32_t patch1623_addr = 0x001C9E4C;
  uint8_t patch1623_data[] = {
    0x10, 
  };
  APPLY_PATCH(1623);

  uint32_t patch1624_addr = 0x001C9E58;
  uint8_t patch1624_data[] = {
    0x05, 
  };
  APPLY_PATCH(1624);

  uint32_t patch1625_addr = 0x001C9E5A;
  uint8_t patch1625_data[] = {
    0x20, 0x40, 0x10, 
  };
  APPLY_PATCH(1625);

  uint32_t patch1626_addr = 0x001C9E68;
  uint8_t patch1626_data[] = {
    0x60, 
  };
  APPLY_PATCH(1626);

  uint32_t patch1627_addr = 0x001C9E6A;
  uint8_t patch1627_data[] = {
    0x22, 
  };
  APPLY_PATCH(1627);

  uint32_t patch1628_addr = 0x001C9E6C;
  uint8_t patch1628_data[] = {
    0x11, 0x11, 
  };
  APPLY_PATCH(1628);

  uint32_t patch1629_addr = 0x001C9E78;
  uint8_t patch1629_data[] = {
    0x60, 
  };
  APPLY_PATCH(1629);

  uint32_t patch1630_addr = 0x001C9E7A;
  uint8_t patch1630_data[] = {
    0x22, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1630);

  uint32_t patch1631_addr = 0x001C9E88;
  uint8_t patch1631_data[] = {
    0x05, 
  };
  APPLY_PATCH(1631);

  uint32_t patch1632_addr = 0x001C9E8B;
  uint8_t patch1632_data[] = {
    0x03, 
  };
  APPLY_PATCH(1632);

  uint32_t patch1633_addr = 0x001C9E9C;
  uint8_t patch1633_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1633);

  uint32_t patch1634_addr = 0x001C9EA8;
  uint8_t patch1634_data[] = {
    0x05, 
  };
  APPLY_PATCH(1634);

  uint32_t patch1635_addr = 0x001C9EAA;
  uint8_t patch1635_data[] = {
    0x02, 0x43, 0x01, 
  };
  APPLY_PATCH(1635);

  uint32_t patch1636_addr = 0x001C9EB8;
  uint8_t patch1636_data[] = {
    0x05, 
  };
  APPLY_PATCH(1636);

  uint32_t patch1637_addr = 0x001C9EBA;
  uint8_t patch1637_data[] = {
    0x22, 
  };
  APPLY_PATCH(1637);

  uint32_t patch1638_addr = 0x001C9EBC;
  uint8_t patch1638_data[] = {
    0x10, 0x10, 
  };
  APPLY_PATCH(1638);

  uint32_t patch1639_addr = 0x001C9EC8;
  uint8_t patch1639_data[] = {
    0x05, 
  };
  APPLY_PATCH(1639);

  uint32_t patch1640_addr = 0x001C9ECA;
  uint8_t patch1640_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1640);

  uint32_t patch1641_addr = 0x001C9EE8;
  uint8_t patch1641_data[] = {
    0x60, 
  };
  APPLY_PATCH(1641);

  uint32_t patch1642_addr = 0x001C9EEA;
  uint8_t patch1642_data[] = {
    0x20, 
  };
  APPLY_PATCH(1642);

  uint32_t patch1643_addr = 0x001C9EEC;
  uint8_t patch1643_data[] = {
    0x01, 
  };
  APPLY_PATCH(1643);

  uint32_t patch1644_addr = 0x001C9EF8;
  uint8_t patch1644_data[] = {
    0x05, 
  };
  APPLY_PATCH(1644);

  uint32_t patch1645_addr = 0x001C9EFC;
  uint8_t patch1645_data[] = {
    0x11, 
  };
  APPLY_PATCH(1645);

  uint32_t patch1646_addr = 0x001C9F0A;
  uint8_t patch1646_data[] = {
    0x20, 0x03, 0x01, 0x10, 
  };
  APPLY_PATCH(1646);

  uint32_t patch1647_addr = 0x001C9F1C;
  uint8_t patch1647_data[] = {
    0x01, 
  };
  APPLY_PATCH(1647);

  uint32_t patch1648_addr = 0x001CA158;
  uint8_t patch1648_data[] = {
    0x05, 
  };
  APPLY_PATCH(1648);

  uint32_t patch1649_addr = 0x001CA15B;
  uint8_t patch1649_data[] = {
    0x40, 
  };
  APPLY_PATCH(1649);

  uint32_t patch1650_addr = 0x001CA188;
  uint8_t patch1650_data[] = {
    0x60, 
  };
  APPLY_PATCH(1650);

  uint32_t patch1651_addr = 0x001CA198;
  uint8_t patch1651_data[] = {
    0x60, 
  };
  APPLY_PATCH(1651);

  uint32_t patch1652_addr = 0x001CA1CA;
  uint8_t patch1652_data[] = {
    0x20, 0x03, 
  };
  APPLY_PATCH(1652);

  uint32_t patch1653_addr = 0x001CA1D8;
  uint8_t patch1653_data[] = {
    0x05, 
  };
  APPLY_PATCH(1653);

  uint32_t patch1654_addr = 0x001CA1DB;
  uint8_t patch1654_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(1654);

  uint32_t patch1655_addr = 0x001CA1EC;
  uint8_t patch1655_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1655);

  uint32_t patch1656_addr = 0x001CA1F8;
  uint8_t patch1656_data[] = {
    0x05, 
  };
  APPLY_PATCH(1656);

  uint32_t patch1657_addr = 0x001CA1FB;
  uint8_t patch1657_data[] = {
    0x03, 
  };
  APPLY_PATCH(1657);

  uint32_t patch1658_addr = 0x001CA208;
  uint8_t patch1658_data[] = {
    0x60, 
  };
  APPLY_PATCH(1658);

  uint32_t patch1659_addr = 0x001CA20A;
  uint8_t patch1659_data[] = {
    0x02, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1659);

  uint32_t patch1660_addr = 0x001CA218;
  uint8_t patch1660_data[] = {
    0x05, 
  };
  APPLY_PATCH(1660);

  uint32_t patch1661_addr = 0x001CA21B;
  uint8_t patch1661_data[] = {
    0x01, 0x11, 0x71, 
  };
  APPLY_PATCH(1661);

  uint32_t patch1662_addr = 0x001CA22A;
  uint8_t patch1662_data[] = {
    0x22, 0x03, 0x01, 
  };
  APPLY_PATCH(1662);

  uint32_t patch1663_addr = 0x001CA238;
  uint8_t patch1663_data[] = {
    0x65, 
  };
  APPLY_PATCH(1663);

  uint32_t patch1664_addr = 0x001CA23B;
  uint8_t patch1664_data[] = {
    0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1664);

  uint32_t patch1665_addr = 0x001CA24C;
  uint8_t patch1665_data[] = {
    0x10, 
  };
  APPLY_PATCH(1665);

  uint32_t patch1666_addr = 0x001CA258;
  uint8_t patch1666_data[] = {
    0x05, 
  };
  APPLY_PATCH(1666);

  uint32_t patch1667_addr = 0x001CA25A;
  uint8_t patch1667_data[] = {
    0x20, 0x40, 0x10, 
  };
  APPLY_PATCH(1667);

  uint32_t patch1668_addr = 0x001CA268;
  uint8_t patch1668_data[] = {
    0x60, 
  };
  APPLY_PATCH(1668);

  uint32_t patch1669_addr = 0x001CA26A;
  uint8_t patch1669_data[] = {
    0x22, 
  };
  APPLY_PATCH(1669);

  uint32_t patch1670_addr = 0x001CA26C;
  uint8_t patch1670_data[] = {
    0x11, 0x11, 
  };
  APPLY_PATCH(1670);

  uint32_t patch1671_addr = 0x001CA278;
  uint8_t patch1671_data[] = {
    0x60, 
  };
  APPLY_PATCH(1671);

  uint32_t patch1672_addr = 0x001CA27A;
  uint8_t patch1672_data[] = {
    0x22, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1672);

  uint32_t patch1673_addr = 0x001CA288;
  uint8_t patch1673_data[] = {
    0x05, 
  };
  APPLY_PATCH(1673);

  uint32_t patch1674_addr = 0x001CA28B;
  uint8_t patch1674_data[] = {
    0x03, 
  };
  APPLY_PATCH(1674);

  uint32_t patch1675_addr = 0x001CA29C;
  uint8_t patch1675_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1675);

  uint32_t patch1676_addr = 0x001CA2A8;
  uint8_t patch1676_data[] = {
    0x05, 
  };
  APPLY_PATCH(1676);

  uint32_t patch1677_addr = 0x001CA2AA;
  uint8_t patch1677_data[] = {
    0x02, 0x43, 0x01, 
  };
  APPLY_PATCH(1677);

  uint32_t patch1678_addr = 0x001CA2B8;
  uint8_t patch1678_data[] = {
    0x05, 
  };
  APPLY_PATCH(1678);

  uint32_t patch1679_addr = 0x001CA2BA;
  uint8_t patch1679_data[] = {
    0x22, 
  };
  APPLY_PATCH(1679);

  uint32_t patch1680_addr = 0x001CA2BC;
  uint8_t patch1680_data[] = {
    0x10, 0x10, 
  };
  APPLY_PATCH(1680);

  uint32_t patch1681_addr = 0x001CA2C8;
  uint8_t patch1681_data[] = {
    0x05, 
  };
  APPLY_PATCH(1681);

  uint32_t patch1682_addr = 0x001CA2CA;
  uint8_t patch1682_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1682);

  uint32_t patch1683_addr = 0x001CA2E8;
  uint8_t patch1683_data[] = {
    0x60, 
  };
  APPLY_PATCH(1683);

  uint32_t patch1684_addr = 0x001CA2EA;
  uint8_t patch1684_data[] = {
    0x20, 
  };
  APPLY_PATCH(1684);

  uint32_t patch1685_addr = 0x001CA2EC;
  uint8_t patch1685_data[] = {
    0x01, 
  };
  APPLY_PATCH(1685);

  uint32_t patch1686_addr = 0x001CA2F8;
  uint8_t patch1686_data[] = {
    0x05, 
  };
  APPLY_PATCH(1686);

  uint32_t patch1687_addr = 0x001CA2FC;
  uint8_t patch1687_data[] = {
    0x11, 
  };
  APPLY_PATCH(1687);

  uint32_t patch1688_addr = 0x001CA30A;
  uint8_t patch1688_data[] = {
    0x20, 0x03, 0x01, 0x10, 
  };
  APPLY_PATCH(1688);

  uint32_t patch1689_addr = 0x001CA54A;
  uint8_t patch1689_data[] = {
    0x20, 0x03, 0x10, 
  };
  APPLY_PATCH(1689);

  uint32_t patch1690_addr = 0x001CA558;
  uint8_t patch1690_data[] = {
    0x05, 
  };
  APPLY_PATCH(1690);

  uint32_t patch1691_addr = 0x001CA55A;
  uint8_t patch1691_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1691);

  uint32_t patch1692_addr = 0x001CA588;
  uint8_t patch1692_data[] = {
    0x60, 
  };
  APPLY_PATCH(1692);

  uint32_t patch1693_addr = 0x001CA598;
  uint8_t patch1693_data[] = {
    0x60, 
  };
  APPLY_PATCH(1693);

  uint32_t patch1694_addr = 0x001CA5CA;
  uint8_t patch1694_data[] = {
    0x20, 0x03, 
  };
  APPLY_PATCH(1694);

  uint32_t patch1695_addr = 0x001CA5D8;
  uint8_t patch1695_data[] = {
    0x05, 
  };
  APPLY_PATCH(1695);

  uint32_t patch1696_addr = 0x001CA5DB;
  uint8_t patch1696_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(1696);

  uint32_t patch1697_addr = 0x001CA5EC;
  uint8_t patch1697_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1697);

  uint32_t patch1698_addr = 0x001CA5F8;
  uint8_t patch1698_data[] = {
    0x05, 
  };
  APPLY_PATCH(1698);

  uint32_t patch1699_addr = 0x001CA5FB;
  uint8_t patch1699_data[] = {
    0x03, 
  };
  APPLY_PATCH(1699);

  uint32_t patch1700_addr = 0x001CA608;
  uint8_t patch1700_data[] = {
    0x60, 
  };
  APPLY_PATCH(1700);

  uint32_t patch1701_addr = 0x001CA60A;
  uint8_t patch1701_data[] = {
    0x02, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1701);

  uint32_t patch1702_addr = 0x001CA618;
  uint8_t patch1702_data[] = {
    0x05, 
  };
  APPLY_PATCH(1702);

  uint32_t patch1703_addr = 0x001CA61B;
  uint8_t patch1703_data[] = {
    0x01, 0x11, 0x71, 
  };
  APPLY_PATCH(1703);

  uint32_t patch1704_addr = 0x001CA620;
  uint8_t patch1704_data[] = {
    0x50, 
  };
  APPLY_PATCH(1704);

  uint32_t patch1705_addr = 0x001CA62A;
  uint8_t patch1705_data[] = {
    0x22, 0x03, 0x01, 
  };
  APPLY_PATCH(1705);

  uint32_t patch1706_addr = 0x001CA630;
  uint8_t patch1706_data[] = {
    0x55, 
  };
  APPLY_PATCH(1706);

  uint32_t patch1707_addr = 0x001CA638;
  uint8_t patch1707_data[] = {
    0x65, 
  };
  APPLY_PATCH(1707);

  uint32_t patch1708_addr = 0x001CA63B;
  uint8_t patch1708_data[] = {
    0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1708);

  uint32_t patch1709_addr = 0x001CA640;
  uint8_t patch1709_data[] = {
    0x55, 
  };
  APPLY_PATCH(1709);

  uint32_t patch1710_addr = 0x001CA64C;
  uint8_t patch1710_data[] = {
    0x10, 
  };
  APPLY_PATCH(1710);

  uint32_t patch1711_addr = 0x001CA650;
  uint8_t patch1711_data[] = {
    0x55, 
  };
  APPLY_PATCH(1711);

  uint32_t patch1712_addr = 0x001CA658;
  uint8_t patch1712_data[] = {
    0x05, 
  };
  APPLY_PATCH(1712);

  uint32_t patch1713_addr = 0x001CA65A;
  uint8_t patch1713_data[] = {
    0x20, 0x40, 0x10, 
  };
  APPLY_PATCH(1713);

  uint32_t patch1714_addr = 0x001CA660;
  uint8_t patch1714_data[] = {
    0x55, 
  };
  APPLY_PATCH(1714);

  uint32_t patch1715_addr = 0x001CA668;
  uint8_t patch1715_data[] = {
    0x60, 
  };
  APPLY_PATCH(1715);

  uint32_t patch1716_addr = 0x001CA66A;
  uint8_t patch1716_data[] = {
    0x22, 
  };
  APPLY_PATCH(1716);

  uint32_t patch1717_addr = 0x001CA66C;
  uint8_t patch1717_data[] = {
    0x11, 0x11, 
  };
  APPLY_PATCH(1717);

  uint32_t patch1718_addr = 0x001CA670;
  uint8_t patch1718_data[] = {
    0x55, 
  };
  APPLY_PATCH(1718);

  uint32_t patch1719_addr = 0x001CA678;
  uint8_t patch1719_data[] = {
    0x60, 
  };
  APPLY_PATCH(1719);

  uint32_t patch1720_addr = 0x001CA67A;
  uint8_t patch1720_data[] = {
    0x22, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1720);

  uint32_t patch1721_addr = 0x001CA680;
  uint8_t patch1721_data[] = {
    0x55, 
  };
  APPLY_PATCH(1721);

  uint32_t patch1722_addr = 0x001CA688;
  uint8_t patch1722_data[] = {
    0x05, 
  };
  APPLY_PATCH(1722);

  uint32_t patch1723_addr = 0x001CA68B;
  uint8_t patch1723_data[] = {
    0x03, 
  };
  APPLY_PATCH(1723);

  uint32_t patch1724_addr = 0x001CA690;
  uint8_t patch1724_data[] = {
    0x55, 
  };
  APPLY_PATCH(1724);

  uint32_t patch1725_addr = 0x001CA69C;
  uint8_t patch1725_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1725);

  uint32_t patch1726_addr = 0x001CA6A0;
  uint8_t patch1726_data[] = {
    0x55, 
  };
  APPLY_PATCH(1726);

  uint32_t patch1727_addr = 0x001CA6A8;
  uint8_t patch1727_data[] = {
    0x05, 
  };
  APPLY_PATCH(1727);

  uint32_t patch1728_addr = 0x001CA6AA;
  uint8_t patch1728_data[] = {
    0x02, 0x43, 0x01, 
  };
  APPLY_PATCH(1728);

  uint32_t patch1729_addr = 0x001CA6B0;
  uint8_t patch1729_data[] = {
    0x55, 
  };
  APPLY_PATCH(1729);

  uint32_t patch1730_addr = 0x001CA6B8;
  uint8_t patch1730_data[] = {
    0x05, 
  };
  APPLY_PATCH(1730);

  uint32_t patch1731_addr = 0x001CA6BA;
  uint8_t patch1731_data[] = {
    0x22, 
  };
  APPLY_PATCH(1731);

  uint32_t patch1732_addr = 0x001CA6BC;
  uint8_t patch1732_data[] = {
    0x10, 0x10, 
  };
  APPLY_PATCH(1732);

  uint32_t patch1733_addr = 0x001CA6C0;
  uint8_t patch1733_data[] = {
    0x05, 
  };
  APPLY_PATCH(1733);

  uint32_t patch1734_addr = 0x001CA6C8;
  uint8_t patch1734_data[] = {
    0x05, 
  };
  APPLY_PATCH(1734);

  uint32_t patch1735_addr = 0x001CA6CA;
  uint8_t patch1735_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1735);

  uint32_t patch1736_addr = 0x001CA8D6;
  uint8_t patch1736_data[] = {
    0x60, 
  };
  APPLY_PATCH(1736);

  uint32_t patch1737_addr = 0x001CA8DB;
  uint8_t patch1737_data[] = {
    0x40, 
  };
  APPLY_PATCH(1737);

  uint32_t patch1738_addr = 0x001CA8EB;
  uint8_t patch1738_data[] = {
    0x43, 
  };
  APPLY_PATCH(1738);

  uint32_t patch1739_addr = 0x001CA8FA;
  uint8_t patch1739_data[] = {
    0x20, 0x03, 0x10, 0x01, 
  };
  APPLY_PATCH(1739);

  uint32_t patch1740_addr = 0x001CA908;
  uint8_t patch1740_data[] = {
    0x05, 
  };
  APPLY_PATCH(1740);

  uint32_t patch1741_addr = 0x001CA90A;
  uint8_t patch1741_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1741);

  uint32_t patch1742_addr = 0x001CA918;
  uint8_t patch1742_data[] = {
    0x05, 
  };
  APPLY_PATCH(1742);

  uint32_t patch1743_addr = 0x001CA91A;
  uint8_t patch1743_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1743);

  uint32_t patch1744_addr = 0x001CA928;
  uint8_t patch1744_data[] = {
    0x60, 
  };
  APPLY_PATCH(1744);

  uint32_t patch1745_addr = 0x001CA92C;
  uint8_t patch1745_data[] = {
    0x01, 
  };
  APPLY_PATCH(1745);

  uint32_t patch1746_addr = 0x001CA948;
  uint8_t patch1746_data[] = {
    0x60, 
  };
  APPLY_PATCH(1746);

  uint32_t patch1747_addr = 0x001CA94A;
  uint8_t patch1747_data[] = {
    0x20, 0x03, 0x10, 
  };
  APPLY_PATCH(1747);

  uint32_t patch1748_addr = 0x001CA958;
  uint8_t patch1748_data[] = {
    0x05, 
  };
  APPLY_PATCH(1748);

  uint32_t patch1749_addr = 0x001CA95A;
  uint8_t patch1749_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1749);

  uint32_t patch1750_addr = 0x001CA988;
  uint8_t patch1750_data[] = {
    0x60, 
  };
  APPLY_PATCH(1750);

  uint32_t patch1751_addr = 0x001CA998;
  uint8_t patch1751_data[] = {
    0x60, 
  };
  APPLY_PATCH(1751);

  uint32_t patch1752_addr = 0x001CA9CA;
  uint8_t patch1752_data[] = {
    0x20, 0x03, 
  };
  APPLY_PATCH(1752);

  uint32_t patch1753_addr = 0x001CA9D8;
  uint8_t patch1753_data[] = {
    0x05, 
  };
  APPLY_PATCH(1753);

  uint32_t patch1754_addr = 0x001CA9DB;
  uint8_t patch1754_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(1754);

  uint32_t patch1755_addr = 0x001CA9EC;
  uint8_t patch1755_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1755);

  uint32_t patch1756_addr = 0x001CA9F8;
  uint8_t patch1756_data[] = {
    0x05, 
  };
  APPLY_PATCH(1756);

  uint32_t patch1757_addr = 0x001CA9FB;
  uint8_t patch1757_data[] = {
    0x03, 
  };
  APPLY_PATCH(1757);

  uint32_t patch1758_addr = 0x001CAA08;
  uint8_t patch1758_data[] = {
    0x60, 
  };
  APPLY_PATCH(1758);

  uint32_t patch1759_addr = 0x001CAA0A;
  uint8_t patch1759_data[] = {
    0x02, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1759);

  uint32_t patch1760_addr = 0x001CAA18;
  uint8_t patch1760_data[] = {
    0x05, 
  };
  APPLY_PATCH(1760);

  uint32_t patch1761_addr = 0x001CAA1B;
  uint8_t patch1761_data[] = {
    0x01, 0x11, 0x71, 
  };
  APPLY_PATCH(1761);

  uint32_t patch1762_addr = 0x001CAA2A;
  uint8_t patch1762_data[] = {
    0x22, 0x03, 0x01, 
  };
  APPLY_PATCH(1762);

  uint32_t patch1763_addr = 0x001CAA38;
  uint8_t patch1763_data[] = {
    0x65, 
  };
  APPLY_PATCH(1763);

  uint32_t patch1764_addr = 0x001CAA3B;
  uint8_t patch1764_data[] = {
    0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1764);

  uint32_t patch1765_addr = 0x001CAA4C;
  uint8_t patch1765_data[] = {
    0x10, 
  };
  APPLY_PATCH(1765);

  uint32_t patch1766_addr = 0x001CAA58;
  uint8_t patch1766_data[] = {
    0x05, 
  };
  APPLY_PATCH(1766);

  uint32_t patch1767_addr = 0x001CAA5A;
  uint8_t patch1767_data[] = {
    0x20, 0x40, 0x10, 
  };
  APPLY_PATCH(1767);

  uint32_t patch1768_addr = 0x001CAA68;
  uint8_t patch1768_data[] = {
    0x60, 
  };
  APPLY_PATCH(1768);

  uint32_t patch1769_addr = 0x001CAA6A;
  uint8_t patch1769_data[] = {
    0x22, 
  };
  APPLY_PATCH(1769);

  uint32_t patch1770_addr = 0x001CAA6C;
  uint8_t patch1770_data[] = {
    0x11, 0x11, 
  };
  APPLY_PATCH(1770);

  uint32_t patch1771_addr = 0x001CAA78;
  uint8_t patch1771_data[] = {
    0x60, 
  };
  APPLY_PATCH(1771);

  uint32_t patch1772_addr = 0x001CAA7A;
  uint8_t patch1772_data[] = {
    0x22, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1772);

  uint32_t patch1773_addr = 0x001CAA88;
  uint8_t patch1773_data[] = {
    0x05, 
  };
  APPLY_PATCH(1773);

  uint32_t patch1774_addr = 0x001CAA8B;
  uint8_t patch1774_data[] = {
    0x03, 
  };
  APPLY_PATCH(1774);

  uint32_t patch1775_addr = 0x001CAC58;
  uint8_t patch1775_data[] = {
    0x05, 
  };
  APPLY_PATCH(1775);

  uint32_t patch1776_addr = 0x001CAC5B;
  uint8_t patch1776_data[] = {
    0x40, 
  };
  APPLY_PATCH(1776);

  uint32_t patch1777_addr = 0x001CAC7A;
  uint8_t patch1777_data[] = {
    0x02, 
  };
  APPLY_PATCH(1777);

  uint32_t patch1778_addr = 0x001CAC9A;
  uint8_t patch1778_data[] = {
    0x02, 
  };
  APPLY_PATCH(1778);

  uint32_t patch1779_addr = 0x001CACAC;
  uint8_t patch1779_data[] = {
    0x01, 
  };
  APPLY_PATCH(1779);

  uint32_t patch1780_addr = 0x001CACBA;
  uint8_t patch1780_data[] = {
    0x02, 
  };
  APPLY_PATCH(1780);

  uint32_t patch1781_addr = 0x001CACBC;
  uint8_t patch1781_data[] = {
    0x01, 
  };
  APPLY_PATCH(1781);

  uint32_t patch1782_addr = 0x001CACDA;
  uint8_t patch1782_data[] = {
    0x22, 0x43, 
  };
  APPLY_PATCH(1782);

  uint32_t patch1783_addr = 0x001CACDD;
  uint8_t patch1783_data[] = {
    0x11, 
  };
  APPLY_PATCH(1783);

  uint32_t patch1784_addr = 0x001CACE8;
  uint8_t patch1784_data[] = {
    0x65, 
  };
  APPLY_PATCH(1784);

  uint32_t patch1785_addr = 0x001CACEA;
  uint8_t patch1785_data[] = {
    0x20, 0x43, 
  };
  APPLY_PATCH(1785);

  uint32_t patch1786_addr = 0x001CACF8;
  uint8_t patch1786_data[] = {
    0x65, 
  };
  APPLY_PATCH(1786);

  uint32_t patch1787_addr = 0x001CACFA;
  uint8_t patch1787_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1787);

  uint32_t patch1788_addr = 0x001CAD08;
  uint8_t patch1788_data[] = {
    0x05, 
  };
  APPLY_PATCH(1788);

  uint32_t patch1789_addr = 0x001CAD0A;
  uint8_t patch1789_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1789);

  uint32_t patch1790_addr = 0x001CAD18;
  uint8_t patch1790_data[] = {
    0x05, 
  };
  APPLY_PATCH(1790);

  uint32_t patch1791_addr = 0x001CAD1A;
  uint8_t patch1791_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1791);

  uint32_t patch1792_addr = 0x001CAD28;
  uint8_t patch1792_data[] = {
    0x60, 
  };
  APPLY_PATCH(1792);

  uint32_t patch1793_addr = 0x001CAD2C;
  uint8_t patch1793_data[] = {
    0x01, 
  };
  APPLY_PATCH(1793);

  uint32_t patch1794_addr = 0x001CAD48;
  uint8_t patch1794_data[] = {
    0x60, 
  };
  APPLY_PATCH(1794);

  uint32_t patch1795_addr = 0x001CAD4A;
  uint8_t patch1795_data[] = {
    0x20, 0x03, 0x10, 
  };
  APPLY_PATCH(1795);

  uint32_t patch1796_addr = 0x001CAD58;
  uint8_t patch1796_data[] = {
    0x05, 
  };
  APPLY_PATCH(1796);

  uint32_t patch1797_addr = 0x001CAD5A;
  uint8_t patch1797_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1797);

  uint32_t patch1798_addr = 0x001CAD88;
  uint8_t patch1798_data[] = {
    0x60, 
  };
  APPLY_PATCH(1798);

  uint32_t patch1799_addr = 0x001CAD98;
  uint8_t patch1799_data[] = {
    0x60, 
  };
  APPLY_PATCH(1799);

  uint32_t patch1800_addr = 0x001CADCA;
  uint8_t patch1800_data[] = {
    0x20, 0x03, 
  };
  APPLY_PATCH(1800);

  uint32_t patch1801_addr = 0x001CADD8;
  uint8_t patch1801_data[] = {
    0x05, 
  };
  APPLY_PATCH(1801);

  uint32_t patch1802_addr = 0x001CADDB;
  uint8_t patch1802_data[] = {
    0x60, 0x01, 
  };
  APPLY_PATCH(1802);

  uint32_t patch1803_addr = 0x001CADEC;
  uint8_t patch1803_data[] = {
    0x11, 0x01, 
  };
  APPLY_PATCH(1803);

  uint32_t patch1804_addr = 0x001CADF8;
  uint8_t patch1804_data[] = {
    0x05, 
  };
  APPLY_PATCH(1804);

  uint32_t patch1805_addr = 0x001CADFB;
  uint8_t patch1805_data[] = {
    0x03, 
  };
  APPLY_PATCH(1805);

  uint32_t patch1806_addr = 0x001CAE08;
  uint8_t patch1806_data[] = {
    0x60, 
  };
  APPLY_PATCH(1806);

  uint32_t patch1807_addr = 0x001CAE0A;
  uint8_t patch1807_data[] = {
    0x02, 0x40, 0x10, 0x11, 
  };
  APPLY_PATCH(1807);

  uint32_t patch1808_addr = 0x001CB058;
  uint8_t patch1808_data[] = {
    0x05, 
  };
  APPLY_PATCH(1808);

  uint32_t patch1809_addr = 0x001CB05A;
  uint8_t patch1809_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1809);

  uint32_t patch1810_addr = 0x001CB068;
  uint8_t patch1810_data[] = {
    0x60, 
  };
  APPLY_PATCH(1810);

  uint32_t patch1811_addr = 0x001CB06A;
  uint8_t patch1811_data[] = {
    0x02, 
  };
  APPLY_PATCH(1811);

  uint32_t patch1812_addr = 0x001CB06C;
  uint8_t patch1812_data[] = {
    0x10, 0x01, 
  };
  APPLY_PATCH(1812);

  uint32_t patch1813_addr = 0x001CB078;
  uint8_t patch1813_data[] = {
    0x60, 
  };
  APPLY_PATCH(1813);

  uint32_t patch1814_addr = 0x001CB07A;
  uint8_t patch1814_data[] = {
    0x02, 
  };
  APPLY_PATCH(1814);

  uint32_t patch1815_addr = 0x001CB09A;
  uint8_t patch1815_data[] = {
    0x02, 
  };
  APPLY_PATCH(1815);

  uint32_t patch1816_addr = 0x001CB0AC;
  uint8_t patch1816_data[] = {
    0x01, 
  };
  APPLY_PATCH(1816);

  uint32_t patch1817_addr = 0x001CB0BA;
  uint8_t patch1817_data[] = {
    0x02, 
  };
  APPLY_PATCH(1817);

  uint32_t patch1818_addr = 0x001CB0BC;
  uint8_t patch1818_data[] = {
    0x01, 
  };
  APPLY_PATCH(1818);

  uint32_t patch1819_addr = 0x001CB0DA;
  uint8_t patch1819_data[] = {
    0x22, 0x43, 
  };
  APPLY_PATCH(1819);

  uint32_t patch1820_addr = 0x001CB0DD;
  uint8_t patch1820_data[] = {
    0x11, 
  };
  APPLY_PATCH(1820);

  uint32_t patch1821_addr = 0x001CB0E8;
  uint8_t patch1821_data[] = {
    0x65, 
  };
  APPLY_PATCH(1821);

  uint32_t patch1822_addr = 0x001CB0EA;
  uint8_t patch1822_data[] = {
    0x20, 0x43, 
  };
  APPLY_PATCH(1822);

  uint32_t patch1823_addr = 0x001CB0F8;
  uint8_t patch1823_data[] = {
    0x65, 
  };
  APPLY_PATCH(1823);

  uint32_t patch1824_addr = 0x001CB0FA;
  uint8_t patch1824_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1824);

  uint32_t patch1825_addr = 0x001CB108;
  uint8_t patch1825_data[] = {
    0x05, 
  };
  APPLY_PATCH(1825);

  uint32_t patch1826_addr = 0x001CB10A;
  uint8_t patch1826_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1826);

  uint32_t patch1827_addr = 0x001CB118;
  uint8_t patch1827_data[] = {
    0x05, 
  };
  APPLY_PATCH(1827);

  uint32_t patch1828_addr = 0x001CB11A;
  uint8_t patch1828_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1828);

  uint32_t patch1829_addr = 0x001CB128;
  uint8_t patch1829_data[] = {
    0x60, 
  };
  APPLY_PATCH(1829);

  uint32_t patch1830_addr = 0x001CB12C;
  uint8_t patch1830_data[] = {
    0x01, 
  };
  APPLY_PATCH(1830);

  uint32_t patch1831_addr = 0x001CB148;
  uint8_t patch1831_data[] = {
    0x60, 
  };
  APPLY_PATCH(1831);

  uint32_t patch1832_addr = 0x001CB14A;
  uint8_t patch1832_data[] = {
    0x20, 0x03, 0x10, 
  };
  APPLY_PATCH(1832);

  uint32_t patch1833_addr = 0x001CB158;
  uint8_t patch1833_data[] = {
    0x05, 
  };
  APPLY_PATCH(1833);

  uint32_t patch1834_addr = 0x001CB15A;
  uint8_t patch1834_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1834);

  uint32_t patch1835_addr = 0x001CB188;
  uint8_t patch1835_data[] = {
    0x60, 
  };
  APPLY_PATCH(1835);

  uint32_t patch1836_addr = 0x001CB198;
  uint8_t patch1836_data[] = {
    0x60, 
  };
  APPLY_PATCH(1836);

  uint32_t patch1837_addr = 0x001CB458;
  uint8_t patch1837_data[] = {
    0x05, 
  };
  APPLY_PATCH(1837);

  uint32_t patch1838_addr = 0x001CB45A;
  uint8_t patch1838_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1838);

  uint32_t patch1839_addr = 0x001CB468;
  uint8_t patch1839_data[] = {
    0x60, 
  };
  APPLY_PATCH(1839);

  uint32_t patch1840_addr = 0x001CB46A;
  uint8_t patch1840_data[] = {
    0x02, 
  };
  APPLY_PATCH(1840);

  uint32_t patch1841_addr = 0x001CB46C;
  uint8_t patch1841_data[] = {
    0x10, 0x01, 
  };
  APPLY_PATCH(1841);

  uint32_t patch1842_addr = 0x001CB478;
  uint8_t patch1842_data[] = {
    0x60, 
  };
  APPLY_PATCH(1842);

  uint32_t patch1843_addr = 0x001CB47A;
  uint8_t patch1843_data[] = {
    0x02, 
  };
  APPLY_PATCH(1843);

  uint32_t patch1844_addr = 0x001CB49A;
  uint8_t patch1844_data[] = {
    0x02, 
  };
  APPLY_PATCH(1844);

  uint32_t patch1845_addr = 0x001CB4AC;
  uint8_t patch1845_data[] = {
    0x01, 
  };
  APPLY_PATCH(1845);

  uint32_t patch1846_addr = 0x001CB4BA;
  uint8_t patch1846_data[] = {
    0x02, 
  };
  APPLY_PATCH(1846);

  uint32_t patch1847_addr = 0x001CB4BC;
  uint8_t patch1847_data[] = {
    0x01, 
  };
  APPLY_PATCH(1847);

  uint32_t patch1848_addr = 0x001CB4D0;
  uint8_t patch1848_data[] = {
    0x50, 
  };
  APPLY_PATCH(1848);

  uint32_t patch1849_addr = 0x001CB4DA;
  uint8_t patch1849_data[] = {
    0x22, 0x43, 
  };
  APPLY_PATCH(1849);

  uint32_t patch1850_addr = 0x001CB4DD;
  uint8_t patch1850_data[] = {
    0x11, 
  };
  APPLY_PATCH(1850);

  uint32_t patch1851_addr = 0x001CB4E0;
  uint8_t patch1851_data[] = {
    0x55, 
  };
  APPLY_PATCH(1851);

  uint32_t patch1852_addr = 0x001CB4E8;
  uint8_t patch1852_data[] = {
    0x65, 
  };
  APPLY_PATCH(1852);

  uint32_t patch1853_addr = 0x001CB4EA;
  uint8_t patch1853_data[] = {
    0x20, 0x43, 
  };
  APPLY_PATCH(1853);

  uint32_t patch1854_addr = 0x001CB4F0;
  uint8_t patch1854_data[] = {
    0x55, 
  };
  APPLY_PATCH(1854);

  uint32_t patch1855_addr = 0x001CB4F8;
  uint8_t patch1855_data[] = {
    0x65, 
  };
  APPLY_PATCH(1855);

  uint32_t patch1856_addr = 0x001CB4FA;
  uint8_t patch1856_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1856);

  uint32_t patch1857_addr = 0x001CB500;
  uint8_t patch1857_data[] = {
    0x55, 
  };
  APPLY_PATCH(1857);

  uint32_t patch1858_addr = 0x001CB508;
  uint8_t patch1858_data[] = {
    0x05, 
  };
  APPLY_PATCH(1858);

  uint32_t patch1859_addr = 0x001CB50A;
  uint8_t patch1859_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1859);

  uint32_t patch1860_addr = 0x001CB510;
  uint8_t patch1860_data[] = {
    0x55, 
  };
  APPLY_PATCH(1860);

  uint32_t patch1861_addr = 0x001CB518;
  uint8_t patch1861_data[] = {
    0x05, 
  };
  APPLY_PATCH(1861);

  uint32_t patch1862_addr = 0x001CB51A;
  uint8_t patch1862_data[] = {
    0x22, 0x43, 0x10, 0x11, 
  };
  APPLY_PATCH(1862);

  uint32_t patch1863_addr = 0x001CB520;
  uint8_t patch1863_data[] = {
    0x55, 
  };
  APPLY_PATCH(1863);

  uint32_t patch1864_addr = 0x001CB528;
  uint8_t patch1864_data[] = {
    0x60, 
  };
  APPLY_PATCH(1864);

  uint32_t patch1865_addr = 0x001CB52C;
  uint8_t patch1865_data[] = {
    0x01, 
  };
  APPLY_PATCH(1865);

  uint32_t patch1866_addr = 0x001CB530;
  uint8_t patch1866_data[] = {
    0x55, 
  };
  APPLY_PATCH(1866);

  uint32_t patch1867_addr = 0x001CB540;
  uint8_t patch1867_data[] = {
    0x55, 
  };
  APPLY_PATCH(1867);

  uint32_t patch1868_addr = 0x001CB548;
  uint8_t patch1868_data[] = {
    0x60, 
  };
  APPLY_PATCH(1868);

  uint32_t patch1869_addr = 0x001CB54A;
  uint8_t patch1869_data[] = {
    0x20, 0x03, 0x10, 
  };
  APPLY_PATCH(1869);

  uint32_t patch1870_addr = 0x001CB550;
  uint8_t patch1870_data[] = {
    0x55, 
  };
  APPLY_PATCH(1870);

  uint32_t patch1871_addr = 0x001CB558;
  uint8_t patch1871_data[] = {
    0x05, 
  };
  APPLY_PATCH(1871);

  uint32_t patch1872_addr = 0x001CB55A;
  uint8_t patch1872_data[] = {
    0x20, 0x43, 0x10, 0x01, 
  };
  APPLY_PATCH(1872);

  uint32_t patch1873_addr = 0x001CB560;
  uint8_t patch1873_data[] = {
    0x55, 
  };
  APPLY_PATCH(1873);

  uint32_t patch1874_addr = 0x001CB570;
  uint8_t patch1874_data[] = {
    0x05, 
  };
  APPLY_PATCH(1874);

  uint32_t patch1875_addr = 0x001CB588;
  uint8_t patch1875_data[] = {
    0x60, 
  };
  APPLY_PATCH(1875);
}

void patch_u62()
{
  uint32_t patch0_addr = 0x000BF38C;
  uint8_t patch0_data[] = {
    0x10, 
  };
  APPLY_PATCH(0);

  uint32_t patch1_addr = 0x000BF3B8;
  uint8_t patch1_data[] = {
    0x10, 
  };
  APPLY_PATCH(1);

  uint32_t patch2_addr = 0x000BF3BA;
  uint8_t patch2_data[] = {
    0x01, 
  };
  APPLY_PATCH(2);

  uint32_t patch3_addr = 0x000BF3C0;
  uint8_t patch3_data[] = {
    0x77, 
  };
  APPLY_PATCH(3);

  uint32_t patch4_addr = 0x000BF3C2;
  uint8_t patch4_data[] = {
    0x13, 
  };
  APPLY_PATCH(4);

  uint32_t patch5_addr = 0x000BF3C4;
  uint8_t patch5_data[] = {
    0x10, 
  };
  APPLY_PATCH(5);

  uint32_t patch6_addr = 0x000BF3CA;
  uint8_t patch6_data[] = {
    0xBA, 
  };
  APPLY_PATCH(6);

  uint32_t patch7_addr = 0x000BF3CC;
  uint8_t patch7_data[] = {
    0x90, 
  };
  APPLY_PATCH(7);

  uint32_t patch8_addr = 0x000BF3D0;
  uint8_t patch8_data[] = {
    0x13, 
  };
  APPLY_PATCH(8);

  uint32_t patch9_addr = 0x000BF3D2;
  uint8_t patch9_data[] = {
    0x93, 
  };
  APPLY_PATCH(9);

  uint32_t patch10_addr = 0x000BF3D4;
  uint8_t patch10_data[] = {
    0x20, 
  };
  APPLY_PATCH(10);

  uint32_t patch11_addr = 0x000BF3D8;
  uint8_t patch11_data[] = {
    0x70, 
  };
  APPLY_PATCH(11);

  uint32_t patch12_addr = 0x000BF3DA;
  uint8_t patch12_data[] = {
    0x09, 
  };
  APPLY_PATCH(12);

  uint32_t patch13_addr = 0x000BF3DC;
  uint8_t patch13_data[] = {
    0x30, 
  };
  APPLY_PATCH(13);

  uint32_t patch14_addr = 0x000BF3E8;
  uint8_t patch14_data[] = {
    0x71, 
  };
  APPLY_PATCH(14);

  uint32_t patch15_addr = 0x000BF3EA;
  uint8_t patch15_data[] = {
    0xA3, 
  };
  APPLY_PATCH(15);

  uint32_t patch16_addr = 0x000BF3EC;
  uint8_t patch16_data[] = {
    0x10, 
  };
  APPLY_PATCH(16);

  uint32_t patch17_addr = 0x000BF3F0;
  uint8_t patch17_data[] = {
    0x07, 
  };
  APPLY_PATCH(17);

  uint32_t patch18_addr = 0x000BF3F2;
  uint8_t patch18_data[] = {
    0xB1, 
  };
  APPLY_PATCH(18);

  uint32_t patch19_addr = 0x000BF3F4;
  uint8_t patch19_data[] = {
    0x30, 
  };
  APPLY_PATCH(19);

  uint32_t patch20_addr = 0x000BF3FA;
  uint8_t patch20_data[] = {
    0x0B, 
  };
  APPLY_PATCH(20);

  uint32_t patch21_addr = 0x000BF3FC;
  uint8_t patch21_data[] = {
    0xA0, 
  };
  APPLY_PATCH(21);

  uint32_t patch22_addr = 0x000BF400;
  uint8_t patch22_data[] = {
    0x33, 
  };
  APPLY_PATCH(22);

  uint32_t patch23_addr = 0x000BF402;
  uint8_t patch23_data[] = {
    0x94, 
  };
  APPLY_PATCH(23);

  uint32_t patch24_addr = 0x000BF404;
  uint8_t patch24_data[] = {
    0x30, 
  };
  APPLY_PATCH(24);

  uint32_t patch25_addr = 0x000BF408;
  uint8_t patch25_data[] = {
    0x03, 
  };
  APPLY_PATCH(25);

  uint32_t patch26_addr = 0x000BF40A;
  uint8_t patch26_data[] = {
    0xA5, 
  };
  APPLY_PATCH(26);

  uint32_t patch27_addr = 0x000BF40C;
  uint8_t patch27_data[] = {
    0x30, 
  };
  APPLY_PATCH(27);

  uint32_t patch28_addr = 0x000BF410;
  uint8_t patch28_data[] = {
    0x88, 
  };
  APPLY_PATCH(28);

  uint32_t patch29_addr = 0x000BF412;
  uint8_t patch29_data[] = {
    0xBA, 
  };
  APPLY_PATCH(29);

  uint32_t patch30_addr = 0x000BF414;
  uint8_t patch30_data[] = {
    0x90, 
  };
  APPLY_PATCH(30);

  uint32_t patch31_addr = 0x000BF418;
  uint8_t patch31_data[] = {
    0x13, 
  };
  APPLY_PATCH(31);

  uint32_t patch32_addr = 0x000BF41A;
  uint8_t patch32_data[] = {
    0x93, 
  };
  APPLY_PATCH(32);

  uint32_t patch33_addr = 0x000BF41C;
  uint8_t patch33_data[] = {
    0x20, 
  };
  APPLY_PATCH(33);

  uint32_t patch34_addr = 0x000BF420;
  uint8_t patch34_data[] = {
    0x70, 
  };
  APPLY_PATCH(34);

  uint32_t patch35_addr = 0x000BF422;
  uint8_t patch35_data[] = {
    0x09, 
  };
  APPLY_PATCH(35);

  uint32_t patch36_addr = 0x000BF424;
  uint8_t patch36_data[] = {
    0x30, 
  };
  APPLY_PATCH(36);

  uint32_t patch37_addr = 0x000BF432;
  uint8_t patch37_data[] = {
    0x93, 
  };
  APPLY_PATCH(37);

  uint32_t patch38_addr = 0x000BF434;
  uint8_t patch38_data[] = {
    0x10, 
  };
  APPLY_PATCH(38);

  uint32_t patch39_addr = 0x000BF43A;
  uint8_t patch39_data[] = {
    0xA2, 
  };
  APPLY_PATCH(39);

  uint32_t patch40_addr = 0x000BF43C;
  uint8_t patch40_data[] = {
    0x30, 
  };
  APPLY_PATCH(40);

  uint32_t patch41_addr = 0x000BF448;
  uint8_t patch41_data[] = {
    0x71, 
  };
  APPLY_PATCH(41);

  uint32_t patch42_addr = 0x000BF44A;
  uint8_t patch42_data[] = {
    0x11, 
  };
  APPLY_PATCH(42);

  uint32_t patch43_addr = 0x000BF44C;
  uint8_t patch43_data[] = {
    0x10, 
  };
  APPLY_PATCH(43);

  uint32_t patch44_addr = 0x000BF458;
  uint8_t patch44_data[] = {
    0x0C, 
  };
  APPLY_PATCH(44);

  uint32_t patch45_addr = 0x000BF45A;
  uint8_t patch45_data[] = {
    0xBB, 
  };
  APPLY_PATCH(45);

  uint32_t patch46_addr = 0x000BF45C;
  uint8_t patch46_data[] = {
    0xA0, 
  };
  APPLY_PATCH(46);

  uint32_t patch47_addr = 0x000BF460;
  uint8_t patch47_data[] = {
    0xCC, 
  };
  APPLY_PATCH(47);

  uint32_t patch48_addr = 0x000BF462;
  uint8_t patch48_data[] = {
    0x71, 
  };
  APPLY_PATCH(48);

  uint32_t patch49_addr = 0x000BF464;
  uint8_t patch49_data[] = {
    0x30, 
  };
  APPLY_PATCH(49);

  uint32_t patch50_addr = 0x000BF468;
  uint8_t patch50_data[] = {
    0x8B, 
  };
  APPLY_PATCH(50);

  uint32_t patch51_addr = 0x000BF46A;
  uint8_t patch51_data[] = {
    0xA9, 
  };
  APPLY_PATCH(51);

  uint32_t patch52_addr = 0x000BF470;
  uint8_t patch52_data[] = {
    0x08, 
  };
  APPLY_PATCH(52);

  uint32_t patch53_addr = 0x000BF472;
  uint8_t patch53_data[] = {
    0x88, 
  };
  APPLY_PATCH(53);

  uint32_t patch54_addr = 0x000BF48C;
  uint8_t patch54_data[] = {
    0x26, 
  };
  APPLY_PATCH(54);

  uint32_t patch55_addr = 0x000BF48E;
  uint8_t patch55_data[] = {
    0x77, 
  };
  APPLY_PATCH(55);

  uint32_t patch56_addr = 0x000BF494;
  uint8_t patch56_data[] = {
    0x67, 
  };
  APPLY_PATCH(56);

  uint32_t patch57_addr = 0x000BF49C;
  uint8_t patch57_data[] = {
    0x0B, 
  };
  APPLY_PATCH(57);

  uint32_t patch58_addr = 0x000BF49E;
  uint8_t patch58_data[] = {
    0xC0, 
  };
  APPLY_PATCH(58);

  uint32_t patch59_addr = 0x000BF4A2;
  uint8_t patch59_data[] = {
    0x08, 
  };
  APPLY_PATCH(59);

  uint32_t patch60_addr = 0x000BF4A4;
  uint8_t patch60_data[] = {
    0xBA, 
  };
  APPLY_PATCH(60);

  uint32_t patch61_addr = 0x000BF4A6;
  uint8_t patch61_data[] = {
    0x24, 
  };
  APPLY_PATCH(61);

  uint32_t patch62_addr = 0x000BF4AA;
  uint8_t patch62_data[] = {
    0x08, 
  };
  APPLY_PATCH(62);

  uint32_t patch63_addr = 0x000BF4AC;
  uint8_t patch63_data[] = {
    0x4C, 
  };
  APPLY_PATCH(63);

  uint32_t patch64_addr = 0x000BF4AE;
  uint8_t patch64_data[] = {
    0xB3, 
  };
  APPLY_PATCH(64);

  uint32_t patch65_addr = 0x000BF4B2;
  uint8_t patch65_data[] = {
    0x08, 
  };
  APPLY_PATCH(65);

  uint32_t patch66_addr = 0x000BF4B4;
  uint8_t patch66_data[] = {
    0x8B, 
  };
  APPLY_PATCH(66);

  uint32_t patch67_addr = 0x000BF4B6;
  uint8_t patch67_data[] = {
    0x08, 
  };
  APPLY_PATCH(67);

  uint32_t patch68_addr = 0x000BF4BC;
  uint8_t patch68_data[] = {
    0x31, 
  };
  APPLY_PATCH(68);

  uint32_t patch69_addr = 0x000BF4BE;
  uint8_t patch69_data[] = {
    0x06, 
  };
  APPLY_PATCH(69);

  uint32_t patch70_addr = 0x000BF4C4;
  uint8_t patch70_data[] = {
    0x67, 
  };
  APPLY_PATCH(70);

  uint32_t patch71_addr = 0x000BF4CC;
  uint8_t patch71_data[] = {
    0x0C, 
  };
  APPLY_PATCH(71);

  uint32_t patch72_addr = 0x000BF4CE;
  uint8_t patch72_data[] = {
    0xA0, 
  };
  APPLY_PATCH(72);

  uint32_t patch73_addr = 0x000BF4D2;
  uint8_t patch73_data[] = {
    0x08, 
  };
  APPLY_PATCH(73);

  uint32_t patch74_addr = 0x000BF4D4;
  uint8_t patch74_data[] = {
    0xB7, 
  };
  APPLY_PATCH(74);

  uint32_t patch75_addr = 0x000BF4D6;
  uint8_t patch75_data[] = {
    0x77, 
  };
  APPLY_PATCH(75);

  uint32_t patch76_addr = 0x000BF4EC;
  uint8_t patch76_data[] = {
    0x62, 
  };
  APPLY_PATCH(76);

  uint32_t patch77_addr = 0x000BF4EE;
  uint8_t patch77_data[] = {
    0x28, 
  };
  APPLY_PATCH(77);

  uint32_t patch78_addr = 0x000BF4F4;
  uint8_t patch78_data[] = {
    0x76, 
  };
  APPLY_PATCH(78);

  uint32_t patch79_addr = 0x000BF4F6;
  uint8_t patch79_data[] = {
    0x3C, 
  };
  APPLY_PATCH(79);

  uint32_t patch80_addr = 0x000BF4FC;
  uint8_t patch80_data[] = {
    0xCB, 
  };
  APPLY_PATCH(80);

  uint32_t patch81_addr = 0x000BF4FE;
  uint8_t patch81_data[] = {
    0x80, 
  };
  APPLY_PATCH(81);

  uint32_t patch82_addr = 0x000BF504;
  uint8_t patch82_data[] = {
    0x67, 
  };
  APPLY_PATCH(82);

  uint32_t patch83_addr = 0x000BF50C;
  uint8_t patch83_data[] = {
    0xC0, 
  };
  APPLY_PATCH(83);

  uint32_t patch84_addr = 0x000BF50E;
  uint8_t patch84_data[] = {
    0x07, 
  };
  APPLY_PATCH(84);

  uint32_t patch85_addr = 0x000BF512;
  uint8_t patch85_data[] = {
    0x08, 
  };
  APPLY_PATCH(85);

  uint32_t patch86_addr = 0x000BF514;
  uint8_t patch86_data[] = {
    0x0C, 
  };
  APPLY_PATCH(86);

  uint32_t patch87_addr = 0x000BF516;
  uint8_t patch87_data[] = {
    0xA0, 
  };
  APPLY_PATCH(87);

  uint32_t patch88_addr = 0x000BF51A;
  uint8_t patch88_data[] = {
    0x08, 
  };
  APPLY_PATCH(88);

  uint32_t patch89_addr = 0x000BF51C;
  uint8_t patch89_data[] = {
    0xB7, 
  };
  APPLY_PATCH(89);

  uint32_t patch90_addr = 0x000BF51E;
  uint8_t patch90_data[] = {
    0x77, 
  };
  APPLY_PATCH(90);

  uint32_t patch91_addr = 0x000BF532;
  uint8_t patch91_data[] = {
    0x08, 
  };
  APPLY_PATCH(91);

  uint32_t patch92_addr = 0x000BF534;
  uint8_t patch92_data[] = {
    0x40, 
  };
  APPLY_PATCH(92);

  uint32_t patch93_addr = 0x000BF536;
  uint8_t patch93_data[] = {
    0x6C, 
  };
  APPLY_PATCH(93);

  uint32_t patch94_addr = 0x000BF53E;
  uint8_t patch94_data[] = {
    0x7C, 
  };
  APPLY_PATCH(94);

  uint32_t patch95_addr = 0x000BF54A;
  uint8_t patch95_data[] = {
    0x08, 
  };
  APPLY_PATCH(95);

  uint32_t patch96_addr = 0x000BF54C;
  uint8_t patch96_data[] = {
    0x22, 
  };
  APPLY_PATCH(96);

  uint32_t patch97_addr = 0x000BF54E;
  uint8_t patch97_data[] = {
    0xB7, 
  };
  APPLY_PATCH(97);

  uint32_t patch98_addr = 0x000BF552;
  uint8_t patch98_data[] = {
    0x08, 
  };
  APPLY_PATCH(98);

  uint32_t patch99_addr = 0x000BF554;
  uint8_t patch99_data[] = {
    0x07, 
  };
  APPLY_PATCH(99);

  uint32_t patch100_addr = 0x000BF556;
  uint8_t patch100_data[] = {
    0x0C, 
  };
  APPLY_PATCH(100);

  uint32_t patch101_addr = 0x000BF55C;
  uint8_t patch101_data[] = {
    0xAB, 
  };
  APPLY_PATCH(101);

  uint32_t patch102_addr = 0x000BF55E;
  uint8_t patch102_data[] = {
    0xCC, 
  };
  APPLY_PATCH(102);

  uint32_t patch103_addr = 0x000BF564;
  uint8_t patch103_data[] = {
    0x11, 
  };
  APPLY_PATCH(103);

  uint32_t patch104_addr = 0x000BF566;
  uint8_t patch104_data[] = {
    0x20, 
  };
  APPLY_PATCH(104);

  uint32_t patch105_addr = 0x000BF56C;
  uint8_t patch105_data[] = {
    0xCC, 
  };
  APPLY_PATCH(105);

  uint32_t patch106_addr = 0x000BF56E;
  uint8_t patch106_data[] = {
    0xB0, 
  };
  APPLY_PATCH(106);

  uint32_t patch107_addr = 0x000BF572;
  uint8_t patch107_data[] = {
    0x08, 
  };
  APPLY_PATCH(107);

  uint32_t patch108_addr = 0x000BF574;
  uint8_t patch108_data[] = {
    0x88, 
  };
  APPLY_PATCH(108);

  uint32_t patch109_addr = 0x000BF576;
  uint8_t patch109_data[] = {
    0x80, 
  };
  APPLY_PATCH(109);

  uint32_t patch110_addr = 0x000BF580;
  uint8_t patch110_data[] = {
    0x43, 
  };
  APPLY_PATCH(110);

  uint32_t patch111_addr = 0x000BF582;
  uint8_t patch111_data[] = {
    0x21, 
  };
  APPLY_PATCH(111);

  uint32_t patch112_addr = 0x000BF588;
  uint8_t patch112_data[] = {
    0x44, 
  };
  APPLY_PATCH(112);

  uint32_t patch113_addr = 0x000BF58A;
  uint8_t patch113_data[] = {
    0x32, 
  };
  APPLY_PATCH(113);

  uint32_t patch114_addr = 0x000BF58C;
  uint8_t patch114_data[] = {
    0x10, 
  };
  APPLY_PATCH(114);

  uint32_t patch115_addr = 0x000BF590;
  uint8_t patch115_data[] = {
    0x88, 
  };
  APPLY_PATCH(115);

  uint32_t patch116_addr = 0x000BF592;
  uint8_t patch116_data[] = {
    0x83, 
  };
  APPLY_PATCH(116);

  uint32_t patch117_addr = 0x000BF594;
  uint8_t patch117_data[] = {
    0x20, 
  };
  APPLY_PATCH(117);

  uint32_t patch118_addr = 0x000BF598;
  uint8_t patch118_data[] = {
    0x52, 
  };
  APPLY_PATCH(118);

  uint32_t patch119_addr = 0x000BF59A;
  uint8_t patch119_data[] = {
    0xA5, 
  };
  APPLY_PATCH(119);

  uint32_t patch120_addr = 0x000BF59C;
  uint8_t patch120_data[] = {
    0x30, 
  };
  APPLY_PATCH(120);

  uint32_t patch121_addr = 0x000BF5A0;
  uint8_t patch121_data[] = {
    0x64, 
  };
  APPLY_PATCH(121);

  uint32_t patch122_addr = 0x000BF5A2;
  uint8_t patch122_data[] = {
    0xB6, 
  };
  APPLY_PATCH(122);

  uint32_t patch123_addr = 0x000BF5A4;
  uint8_t patch123_data[] = {
    0x20, 
  };
  APPLY_PATCH(123);

  uint32_t patch124_addr = 0x000BF5A8;
  uint8_t patch124_data[] = {
    0x88, 
  };
  APPLY_PATCH(124);

  uint32_t patch125_addr = 0x000BF5AA;
  uint8_t patch125_data[] = {
    0x0B, 
  };
  APPLY_PATCH(125);

  uint32_t patch126_addr = 0x000BF5AC;
  uint8_t patch126_data[] = {
    0xA0, 
  };
  APPLY_PATCH(126);

  uint32_t patch127_addr = 0x000BF5B0;
  uint8_t patch127_data[] = {
    0x30, 
  };
  APPLY_PATCH(127);

  uint32_t patch128_addr = 0x000BF5B2;
  uint8_t patch128_data[] = {
    0x05, 
  };
  APPLY_PATCH(128);

  uint32_t patch129_addr = 0x000BF5B4;
  uint8_t patch129_data[] = {
    0x20, 
  };
  APPLY_PATCH(129);

  uint32_t patch130_addr = 0x000BF5B8;
  uint8_t patch130_data[] = {
    0x73, 
  };
  APPLY_PATCH(130);

  uint32_t patch131_addr = 0x000BF5BA;
  uint8_t patch131_data[] = {
    0x06, 
  };
  APPLY_PATCH(131);

  uint32_t patch132_addr = 0x000BF5BC;
  uint8_t patch132_data[] = {
    0x20, 
  };
  APPLY_PATCH(132);

  uint32_t patch133_addr = 0x000BF5C0;
  uint8_t patch133_data[] = {
    0x88, 
  };
  APPLY_PATCH(133);

  uint32_t patch134_addr = 0x000BF5C2;
  uint8_t patch134_data[] = {
    0x0B, 
  };
  APPLY_PATCH(134);

  uint32_t patch135_addr = 0x000BF5C4;
  uint8_t patch135_data[] = {
    0xA0, 
  };
  APPLY_PATCH(135);

  uint32_t patch136_addr = 0x000BF5C8;
  uint8_t patch136_data[] = {
    0x32, 
  };
  APPLY_PATCH(136);

  uint32_t patch137_addr = 0x000BF5CA;
  uint8_t patch137_data[] = {
    0x95, 
  };
  APPLY_PATCH(137);

  uint32_t patch138_addr = 0x000BF5CC;
  uint8_t patch138_data[] = {
    0x20, 
  };
  APPLY_PATCH(138);

  uint32_t patch139_addr = 0x000BF5D0;
  uint8_t patch139_data[] = {
    0x43, 
  };
  APPLY_PATCH(139);

  uint32_t patch140_addr = 0x000BF5D2;
  uint8_t patch140_data[] = {
    0xBA, 
  };
  APPLY_PATCH(140);

  uint32_t patch141_addr = 0x000BF5D4;
  uint8_t patch141_data[] = {
    0x90, 
  };
  APPLY_PATCH(141);

  uint32_t patch142_addr = 0x000BF5D8;
  uint8_t patch142_data[] = {
    0x70, 
  };
  APPLY_PATCH(142);

  uint32_t patch143_addr = 0x000BF5DA;
  uint8_t patch143_data[] = {
    0xA9, 
  };
  APPLY_PATCH(143);

  uint32_t patch144_addr = 0x000BF5DC;
  uint8_t patch144_data[] = {
    0x90, 
  };
  APPLY_PATCH(144);

  uint32_t patch145_addr = 0x000BF5E0;
  uint8_t patch145_data[] = {
    0x70, 
  };
  APPLY_PATCH(145);

  uint32_t patch146_addr = 0x000BF5E8;
  uint8_t patch146_data[] = {
    0xCC, 
  };
  APPLY_PATCH(146);

  uint32_t patch147_addr = 0x000BF5EA;
  uint8_t patch147_data[] = {
    0xBA, 
  };
  APPLY_PATCH(147);

  uint32_t patch148_addr = 0x000BF5EC;
  uint8_t patch148_data[] = {
    0xA0, 
  };
  APPLY_PATCH(148);

  uint32_t patch149_addr = 0x000BF5F0;
  uint8_t patch149_data[] = {
    0xAA, 
  };
  APPLY_PATCH(149);

  uint32_t patch150_addr = 0x000BF5F2;
  uint8_t patch150_data[] = {
    0x0A, 
  };
  APPLY_PATCH(150);

  uint32_t patch151_addr = 0x000BF5F4;
  uint8_t patch151_data[] = {
    0x90, 
  };
  APPLY_PATCH(151);

  uint32_t patch152_addr = 0x000BF5F8;
  uint8_t patch152_data[] = {
    0x01, 
  };
  APPLY_PATCH(152);

  uint32_t patch153_addr = 0x000BF5FA;
  uint8_t patch153_data[] = {
    0x23, 
  };
  APPLY_PATCH(153);

  uint32_t patch154_addr = 0x000BF5FC;
  uint8_t patch154_data[] = {
    0x20, 
  };
  APPLY_PATCH(154);

  uint32_t patch155_addr = 0x000BF600;
  uint8_t patch155_data[] = {
    0xC7, 
  };
  APPLY_PATCH(155);

  uint32_t patch156_addr = 0x000BF602;
  uint8_t patch156_data[] = {
    0x62, 
  };
  APPLY_PATCH(156);

  uint32_t patch157_addr = 0x000BF604;
  uint8_t patch157_data[] = {
    0x90, 
  };
  APPLY_PATCH(157);

  uint32_t patch158_addr = 0x000BF608;
  uint8_t patch158_data[] = {
    0x80, 
  };
  APPLY_PATCH(158);

  uint32_t patch159_addr = 0x000BF60C;
  uint8_t patch159_data[] = {
    0x80, 
  };
  APPLY_PATCH(159);

  uint32_t patch160_addr = 0x000BF610;
  uint8_t patch160_data[] = {
    0x10, 
  };
  APPLY_PATCH(160);

  uint32_t patch161_addr = 0x000BF612;
  uint8_t patch161_data[] = {
    0x03, 
  };
  APPLY_PATCH(161);

  uint32_t patch162_addr = 0x000BF618;
  uint8_t patch162_data[] = {
    0x70, 
  };
  APPLY_PATCH(162);

  uint32_t patch163_addr = 0x000BF61C;
  uint8_t patch163_data[] = {
    0x90, 
  };
  APPLY_PATCH(163);

  uint32_t patch164_addr = 0x000BF624;
  uint8_t patch164_data[] = {
    0x80, 
  };
  APPLY_PATCH(164);

  uint32_t patch165_addr = 0x000BF62A;
  uint8_t patch165_data[] = {
    0x81, 
  };
  APPLY_PATCH(165);

  uint32_t patch166_addr = 0x000BF62C;
  uint8_t patch166_data[] = {
    0x10, 
  };
  APPLY_PATCH(166);

  uint32_t patch167_addr = 0x000BF630;
  uint8_t patch167_data[] = {
    0x71, 
  };
  APPLY_PATCH(167);

  uint32_t patch168_addr = 0x000BF632;
  uint8_t patch168_data[] = {
    0xA3, 
  };
  APPLY_PATCH(168);

  uint32_t patch169_addr = 0x000BF638;
  uint8_t patch169_data[] = {
    0xBB, 
  };
  APPLY_PATCH(169);

  uint32_t patch170_addr = 0x000BF63A;
  uint8_t patch170_data[] = {
    0xA1, 
  };
  APPLY_PATCH(170);

  uint32_t patch171_addr = 0x000BF63C;
  uint8_t patch171_data[] = {
    0x30, 
  };
  APPLY_PATCH(171);

  uint32_t patch172_addr = 0x000BF640;
  uint8_t patch172_data[] = {
    0x88, 
  };
  APPLY_PATCH(172);

  uint32_t patch173_addr = 0x000BF642;
  uint8_t patch173_data[] = {
    0x0C, 
  };
  APPLY_PATCH(173);

  uint32_t patch174_addr = 0x000BF644;
  uint8_t patch174_data[] = {
    0xB0, 
  };
  APPLY_PATCH(174);

  uint32_t patch175_addr = 0x000BF648;
  uint8_t patch175_data[] = {
    0x22, 
  };
  APPLY_PATCH(175);

  uint32_t patch176_addr = 0x000BF64A;
  uint8_t patch176_data[] = {
    0x95, 
  };
  APPLY_PATCH(176);

  uint32_t patch177_addr = 0x000BF64C;
  uint8_t patch177_data[] = {
    0x40, 
  };
  APPLY_PATCH(177);

  uint32_t patch178_addr = 0x000BF650;
  uint8_t patch178_data[] = {
    0x32, 
  };
  APPLY_PATCH(178);

  uint32_t patch179_addr = 0x000BF652;
  uint8_t patch179_data[] = {
    0xA9, 
  };
  APPLY_PATCH(179);

  uint32_t patch180_addr = 0x000BF654;
  uint8_t patch180_data[] = {
    0x90, 
  };
  APPLY_PATCH(180);

  uint32_t patch181_addr = 0x000BF658;
  uint8_t patch181_data[] = {
    0x88, 
  };
  APPLY_PATCH(181);

  uint32_t patch182_addr = 0x000BF65A;
  uint8_t patch182_data[] = {
    0x88, 
  };
  APPLY_PATCH(182);

  uint32_t patch183_addr = 0x000BF65C;
  uint8_t patch183_data[] = {
    0x10, 
  };
  APPLY_PATCH(183);

  uint32_t patch184_addr = 0x000BF660;
  uint8_t patch184_data[] = {
    0x20, 
  };
  APPLY_PATCH(184);

  uint32_t patch185_addr = 0x000BF662;
  uint8_t patch185_data[] = {
    0x08, 
  };
  APPLY_PATCH(185);

  uint32_t patch186_addr = 0x000BF664;
  uint8_t patch186_data[] = {
    0x20, 
  };
  APPLY_PATCH(186);

  uint32_t patch187_addr = 0x000BF668;
  uint8_t patch187_data[] = {
    0x30, 
  };
  APPLY_PATCH(187);

  uint32_t patch188_addr = 0x000BF66A;
  uint8_t patch188_data[] = {
    0x82, 
  };
  APPLY_PATCH(188);

  uint32_t patch189_addr = 0x000BF66C;
  uint8_t patch189_data[] = {
    0x20, 
  };
  APPLY_PATCH(189);

  uint32_t patch190_addr = 0x000BF670;
  uint8_t patch190_data[] = {
    0x30, 
  };
  APPLY_PATCH(190);

  uint32_t patch191_addr = 0x000BF672;
  uint8_t patch191_data[] = {
    0x83, 
  };
  APPLY_PATCH(191);

  uint32_t patch192_addr = 0x000BF674;
  uint8_t patch192_data[] = {
    0x80, 
  };
  APPLY_PATCH(192);

  uint32_t patch193_addr = 0x000BF678;
  uint8_t patch193_data[] = {
    0x88, 
  };
  APPLY_PATCH(193);

  uint32_t patch194_addr = 0x000BF67A;
  uint8_t patch194_data[] = {
    0x88, 
  };
  APPLY_PATCH(194);

  uint32_t patch195_addr = 0x000BF682;
  uint8_t patch195_data[] = {
    0x08, 
  };
  APPLY_PATCH(195);

  uint32_t patch196_addr = 0x000BF684;
  uint8_t patch196_data[] = {
    0x21, 
  };
  APPLY_PATCH(196);

  uint32_t patch197_addr = 0x000BF68A;
  uint8_t patch197_data[] = {
    0x08, 
  };
  APPLY_PATCH(197);

  uint32_t patch198_addr = 0x000BF68C;
  uint8_t patch198_data[] = {
    0x32, 
  };
  APPLY_PATCH(198);

  uint32_t patch199_addr = 0x000BF68E;
  uint8_t patch199_data[] = {
    0x04, 
  };
  APPLY_PATCH(199);

  uint32_t patch200_addr = 0x000BF692;
  uint8_t patch200_data[] = {
    0x08, 
  };
  APPLY_PATCH(200);

  uint32_t patch201_addr = 0x000BF694;
  uint8_t patch201_data[] = {
    0x43, 
  };
  APPLY_PATCH(201);

  uint32_t patch202_addr = 0x000BF696;
  uint8_t patch202_data[] = {
    0x08, 
  };
  APPLY_PATCH(202);

  uint32_t patch203_addr = 0x000BF69C;
  uint8_t patch203_data[] = {
    0x65, 
  };
  APPLY_PATCH(203);

  uint32_t patch204_addr = 0x000BF69E;
  uint8_t patch204_data[] = {
    0x32, 
  };
  APPLY_PATCH(204);

  uint32_t patch205_addr = 0x000BF6A4;
  uint8_t patch205_data[] = {
    0xB6, 
  };
  APPLY_PATCH(205);

  uint32_t patch206_addr = 0x000BF6A6;
  uint8_t patch206_data[] = {
    0x47, 
  };
  APPLY_PATCH(206);

  uint32_t patch207_addr = 0x000BF6AA;
  uint8_t patch207_data[] = {
    0x08, 
  };
  APPLY_PATCH(207);

  uint32_t patch208_addr = 0x000BF6AC;
  uint8_t patch208_data[] = {
    0xCB, 
  };
  APPLY_PATCH(208);

  uint32_t patch209_addr = 0x000BF6AE;
  uint8_t patch209_data[] = {
    0x80, 
  };
  APPLY_PATCH(209);

  uint32_t patch210_addr = 0x000BF6B4;
  uint8_t patch210_data[] = {
    0xC6, 
  };
  APPLY_PATCH(210);

  uint32_t patch211_addr = 0x000BF6B6;
  uint8_t patch211_data[] = {
    0x01, 
  };
  APPLY_PATCH(211);

  uint32_t patch212_addr = 0x000BF6BC;
  uint8_t patch212_data[] = {
    0xA7, 
  };
  APPLY_PATCH(212);

  uint32_t patch213_addr = 0x000BF6BE;
  uint8_t patch213_data[] = {
    0x07, 
  };
  APPLY_PATCH(213);

  uint32_t patch214_addr = 0x000BF6C2;
  uint8_t patch214_data[] = {
    0x08, 
  };
  APPLY_PATCH(214);

  uint32_t patch215_addr = 0x000BF6C4;
  uint8_t patch215_data[] = {
    0xAB, 
  };
  APPLY_PATCH(215);

  uint32_t patch216_addr = 0x000BF6CE;
  uint8_t patch216_data[] = {
    0x33, 
  };
  APPLY_PATCH(216);

  uint32_t patch217_addr = 0x000BF6D4;
  uint8_t patch217_data[] = {
    0xBB, 
  };
  APPLY_PATCH(217);

  uint32_t patch218_addr = 0x000BF6D6;
  uint8_t patch218_data[] = {
    0x44, 
  };
  APPLY_PATCH(218);

  uint32_t patch219_addr = 0x000BF6DC;
  uint8_t patch219_data[] = {
    0xCC, 
  };
  APPLY_PATCH(219);

  uint32_t patch220_addr = 0x000BF6DE;
  uint8_t patch220_data[] = {
    0xC7, 
  };
  APPLY_PATCH(220);

  uint32_t patch221_addr = 0x000BF6E4;
  uint8_t patch221_data[] = {
    0x67, 
  };
  APPLY_PATCH(221);

  uint32_t patch222_addr = 0x000BF6E6;
  uint8_t patch222_data[] = {
    0x70, 
  };
  APPLY_PATCH(222);

  uint32_t patch223_addr = 0x000BF6EC;
  uint8_t patch223_data[] = {
    0xBC, 
  };
  APPLY_PATCH(223);

  uint32_t patch224_addr = 0x000BF6EE;
  uint8_t patch224_data[] = {
    0xCC, 
  };
  APPLY_PATCH(224);

  uint32_t patch225_addr = 0x000BF6F2;
  uint8_t patch225_data[] = {
    0x08, 
  };
  APPLY_PATCH(225);

  uint32_t patch226_addr = 0x000BF6F4;
  uint8_t patch226_data[] = {
    0x88, 
  };
  APPLY_PATCH(226);

  uint32_t patch227_addr = 0x000BF6F6;
  uint8_t patch227_data[] = {
    0x80, 
  };
  APPLY_PATCH(227);

  uint32_t patch228_addr = 0x000BF6FA;
  uint8_t patch228_data[] = {
    0x08, 
  };
  APPLY_PATCH(228);

  uint32_t patch229_addr = 0x000BF6FC;
  uint8_t patch229_data[] = {
    0xC7, 
  };
  APPLY_PATCH(229);

  uint32_t patch230_addr = 0x000BF6FE;
  uint8_t patch230_data[] = {
    0x77, 
  };
  APPLY_PATCH(230);

  uint32_t patch231_addr = 0x000BF704;
  uint8_t patch231_data[] = {
    0x70, 
  };
  APPLY_PATCH(231);

  uint32_t patch232_addr = 0x000BF714;
  uint8_t patch232_data[] = {
    0x70, 
  };
  APPLY_PATCH(232);

  uint32_t patch233_addr = 0x000BF71C;
  uint8_t patch233_data[] = {
    0xC7, 
  };
  APPLY_PATCH(233);

  uint32_t patch234_addr = 0x000BF722;
  uint8_t patch234_data[] = {
    0x08, 
  };
  APPLY_PATCH(234);

  uint32_t patch235_addr = 0x000BF72C;
  uint8_t patch235_data[] = {
    0x06, 
  };
  APPLY_PATCH(235);

  uint32_t patch236_addr = 0x000BF734;
  uint8_t patch236_data[] = {
    0x67, 
  };
  APPLY_PATCH(236);

  uint32_t patch237_addr = 0x000BF736;
  uint8_t patch237_data[] = {
    0x07, 
  };
  APPLY_PATCH(237);

  uint32_t patch238_addr = 0x000BF73C;
  uint8_t patch238_data[] = {
    0x77, 
  };
  APPLY_PATCH(238);

  uint32_t patch239_addr = 0x000BF73E;
  uint8_t patch239_data[] = {
    0xCC, 
  };
  APPLY_PATCH(239);

  uint32_t patch240_addr = 0x000BF744;
  uint8_t patch240_data[] = {
    0xAB, 
  };
  APPLY_PATCH(240);

  uint32_t patch241_addr = 0x000BF746;
  uint8_t patch241_data[] = {
    0x88, 
  };
  APPLY_PATCH(241);

  uint32_t patch242_addr = 0x000BF74C;
  uint8_t patch242_data[] = {
    0xA6, 
  };
  APPLY_PATCH(242);

  uint32_t patch243_addr = 0x000BF74E;
  uint8_t patch243_data[] = {
    0x33, 
  };
  APPLY_PATCH(243);

  uint32_t patch244_addr = 0x000BF754;
  uint8_t patch244_data[] = {
    0xCC, 
  };
  APPLY_PATCH(244);

  uint32_t patch245_addr = 0x000BF756;
  uint8_t patch245_data[] = {
    0x43, 
  };
  APPLY_PATCH(245);

  uint32_t patch246_addr = 0x000BF75A;
  uint8_t patch246_data[] = {
    0x08, 
  };
  APPLY_PATCH(246);

  uint32_t patch247_addr = 0x000BF75C;
  uint8_t patch247_data[] = {
    0x48, 
  };
  APPLY_PATCH(247);

  uint32_t patch248_addr = 0x000BF75E;
  uint8_t patch248_data[] = {
    0x88, 
  };
  APPLY_PATCH(248);

  uint32_t patch249_addr = 0x000BF762;
  uint8_t patch249_data[] = {
    0x08, 
  };
  APPLY_PATCH(249);

  uint32_t patch250_addr = 0x000BF764;
  uint8_t patch250_data[] = {
    0x40, 
  };
  APPLY_PATCH(250);

  uint32_t patch251_addr = 0x000BF766;
  uint8_t patch251_data[] = {
    0x08, 
  };
  APPLY_PATCH(251);

  uint32_t patch252_addr = 0x000BF76A;
  uint8_t patch252_data[] = {
    0x08, 
  };
  APPLY_PATCH(252);

  uint32_t patch253_addr = 0x000BF76C;
  uint8_t patch253_data[] = {
    0x43, 
  };
  APPLY_PATCH(253);

  uint32_t patch254_addr = 0x000BF76E;
  uint8_t patch254_data[] = {
    0x28, 
  };
  APPLY_PATCH(254);

  uint32_t patch255_addr = 0x000BF772;
  uint8_t patch255_data[] = {
    0x08, 
  };
  APPLY_PATCH(255);

  uint32_t patch256_addr = 0x000BF774;
  uint8_t patch256_data[] = {
    0x84, 
  };
  APPLY_PATCH(256);

  uint32_t patch257_addr = 0x000BF776;
  uint8_t patch257_data[] = {
    0x38, 
  };
  APPLY_PATCH(257);

  uint32_t patch258_addr = 0x000BF77A;
  uint8_t patch258_data[] = {
    0x08, 
  };
  APPLY_PATCH(258);

  uint32_t patch259_addr = 0x000BF77C;
  uint8_t patch259_data[] = {
    0x88, 
  };
  APPLY_PATCH(259);

  uint32_t patch260_addr = 0x000BF77E;
  uint8_t patch260_data[] = {
    0x88, 
  };
  APPLY_PATCH(260);
}

void patch_eeprom()
{
  uint32_t patch0_addr = 0x00000003;
  uint8_t patch0_data[] = {
    0x04, 
  };
  APPLY_PATCH(0);

  uint32_t patch1_addr = 0x00000009;
  uint8_t patch1_data[] = {
    0x04, 
  };
  APPLY_PATCH(1);
}

void patching(int rom)
{
  switch(rom) {
    case 0:
      patch_u26();
      break;
    case 1:
      patch_u27();
      break;
    case 2:
      patch_u51();
      break;
    case 3:
      patch_u62();
      break;
    case 4:
      patch_eeprom();
      break;
    default:
      fprintf(stderr, "Bad ROM ID\n");
      break;
  }
}

